
import QtQuick 2.4

Rectangle {
    id: root

    property variant model
    property variant selectedData: model.get(currentIndex)
    property alias currentIndex: listView.currentIndex
    property int comboHeight: 50
    property int itemHeight: comboBox.height / 2
    property url dropDownIcon: "graphics/ComboBox/down_arrow.png"
    property color highlightColor: "#85A4CC"
    property color comboColor: "#B0C4DE"
    property color itemColor: "lightgray"
    property bool listenKeys: false

    signal comboClicked()

    Connections {
        target: main.isTft && root.listenKeys ? keymapper : null

        onLeftButtonPressed: {
            console.log("leftButtonPressed", "ComboBox")
            listView.decrementCurrentIndex()
        }

        onRightButtonPressed: {
            console.log("rightButtonPressed", "ComboBox")
            listView.incrementCurrentIndex()
        }
    }

    width: 400
    height: 400
    color: "transparent"

    Rectangle {
        id: comboBox
        width: parent.width
        height: root.comboHeight
        color: "transparent"
        z: 100
        smooth: true

        Rectangle {
            id: chosenItem
            radius: 4
            width: parent.width
            height: parent.height
            color: root.comboColor
            smooth: true
            Text {
                anchors.centerIn: parent
                id: chosenItemText
                text: listView.currentItem.option.text
                font.family: "Arial"
                font.pointSize: 14
                smooth: true
            }

            MouseArea {
                anchors.fill: parent
                onClicked: {
                    comboBox.state = comboBox.state === "DropDown" ? "" : "DropDown"
                }
            }
        }

        Image {
            id: dropDownArrow
            visible: main.isTouch

            source: root.dropDownIcon
            anchors {
                right: chosenItem.right
                rightMargin: 10
                verticalCenter: chosenItem.verticalCenter
            }

        }

        Image {
            id: arrowLeft
            visible: main.isTft
            anchors { left: chosenItem.left; leftMargin: 5; verticalCenter: chosenItem.verticalCenter }
            source: "graphics/ComboBox/224_Data_ToolBar_BLK_Arrow_Left.png"
        }

        Image {
            id: arrowRight
            visible: main.isTft
            anchors { right: chosenItem.right; rightMargin: 5; verticalCenter: chosenItem.verticalCenter }
            source: "graphics/ComboBox/224_Data_ToolBar_BLK_Arrow_right.png"
        }

        Rectangle {
            id: dropDown
            width: comboBox.width
            height: 0
            clip: true
            radius: 4
            anchors.top: chosenItem.bottom
            anchors.margins: 2
            color: root.itemColor

            ListView {
                id: listView
                height: 500
                model: root.model
                currentIndex: 0
                keyNavigationWraps: true
                highlight: highlight
                delegate: Item{
                    width: comboBox.width
                    height: itemHeight
                    property alias option: option

                    Text {
                        id: option
                        text: model.label
                        anchors.top: parent.top
                        anchors.left: parent.left
                        anchors.margins: 5

                    }
                    MouseArea {
                        anchors.fill: parent
                        onClicked: {
                            comboBox.state = ""
                            if (index !== listView.currentIndex)
                                root.comboClicked()
                            listView.currentIndex = index
                        }
                    }
                }
            }
        }

        Component {
            id: highlight
            Rectangle {
                width: comboBox.width
                height: root.itemHeight
                color: root.highlightColor
                radius: 4
            }
        }

        states: State {
            name: "DropDown"
            PropertyChanges { target: dropDown; height:root.itemHeight * root.model.count + 1 }
        }

        transitions: Transition {
            NumberAnimation { target: dropDown; properties: "height"; easing.type: Easing.OutExpo; duration: 1000 }
        }
    }
}
