// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Process 0.1

Item {
    id: root
    state: "idle"

    signal discoveringChanged
    signal hrDisconnecting
    signal hrDisconnectingComplete
    signal scanned
    signal connected
    signal hrConnectionFailed
    signal hrTimeout

    signal bleReadHRTerminated()

    signal haveHrServiceHandle ( string notice )
    signal haveConfigHandle (string notice )
    signal listening (string notice )
    property int heartrate: 0

    property bool scanning: false
    property bool scanHrHandle:false
    property bool readHR: false
    property bool waiting: false
    property string hr: "--"
    property string scriptsdir: "/usr/local/bin/truetouch/scripts"
    property int devicesFound: 0
    property bool deviceListChanged: false
    property bool connecting: false
    property bool hrConnected: true


    property string addrType: "random"
    property string deviceMAC: "NULL" //F6:94:92:22:03:5A" //ALPHA=F6:94:92:22:03:5A
    property string startHandle: "empty"
    property string hrHandle: "empty"
    property ListModel hrMonitors: monitorListModel
    property string hrUUID: "180d"
    property string configUUID: "2902"

    function scan() {
        // scan for heart rate monitors and return List
        if(root.scanning == false){
            bluetoothAdapter.temporaryDisconnect()
            root.scanning = true
            console.debug("Process bleScan start")
            bleScan.start()
        }
    }

    function stopScan(result){
        if(root.scanning == true){
            root.scanning = false
            console.debug("Process bleStopScan start")
            bleStopScan.start()
            if(result == false){
                bluetoothAdapter.reconnect();
            }
        }
    }

    function buildArgs(deviceMAC,addrType) {
        var args = ["-b",deviceMAC, "-t",addrType]
        return args
    }

    function getHrServiceHandle(deviceMAC) {

        root.connecting = true
        root.deviceMAC =deviceMAC
        root.startHandle = "empty"
        var deviceArgs=buildArgs(root.deviceMAC,"random")

        var args=deviceArgs.concat(["--primary","--uuid="+root.hrUUID]);
        //console.debug(args)
        //console.debug("calling bleConnect.start process")
        bleGetHRServiceHandle.arguments = args
        console.debug("Process bleGetHRServiceHandle start")
        bleGetHRServiceHandle.start()
    }

    Timer{
        id: haveHrServiceHandleTimer
        interval: 3000
        running: false
        repeat: false
        onTriggered:
        {
            root.scanHrHandle=true
            console.debug("Process bleGetConfigHandle start")
            bleGetConfigHandle.start()
        }
    }


    onHaveHrServiceHandle: {
        //console.debug(notice + "received onHave..")
        var skip=new RegExp("empty")
        if(!skip.test(root.startHandle)){
            var deviceArgs=buildArgs(root.deviceMAC,"random")
            var args=deviceArgs.concat(["--char-desc","-s",root.startHandle,root.hrUUID])
            //console.debug(args)
            //console.debug("calling bleGetCongigHandle.start process")
            bleGetConfigHandle.arguments = args
            haveHrServiceHandleTimer.start()
        }
    }

    Timer{
        id: haveConfigHandleTimer
        interval: 3000
        running: false
        repeat: false
        onTriggered: {
            root.readHR=true
            connected()
            console.debug("Process bleReadHR start")
            bleReadHR.start()
            bluetoothAdapter.reconnect()
        }
    }

    onHaveConfigHandle:{
        //console.debug(notice + "received onHave..")
        //console.debug("handle is " + root.hrHandle)
        if(root.hrHandle!="empty"){
            var preArgs=["gatttool"]
            var deviceArgs=buildArgs(root.deviceMAC,"random")
            var args=preArgs.concat(deviceArgs,["--char-write-req","-a",root.hrHandle,"-n","0100","--listen"])
            bleReadHR.arguments=args
            root.waiting=false
            haveConfigHandleTimer.start()


        } else {
            console.debug("StartHandle not found..now exiting.")
            root.waiting=false
        }
    }

    Process {
        id: bleGetConfigHandle
        program: "gatttool"

        onReadyReadStandardOutput: {
            //console.debug("processing standard output in get handle")
            var output = String(readAllStandardOutput())
            output = output.trim()
            //console.debug(output)
            var items = output.split(" ")
            var UUID=new RegExp(root.configUUID)
            // Now find handle that has UUID 2902

            for(var i=0;i<items.length;i++){
                //console.debug("item " + i+ "= \"" +items[i],"\"")
                //Note: This string handling
                // is different than on my PC
                //console.debug("checking handle: " + items[i])
                // if(items[i]==="2902\nhandle"){
                //if(items[i].match(/root.configUUID/)){
                if(UUID.test(items[i])){
                    root.hrHandle=items[i-3].split(",")[0]
                    //console.debug("uuid 2902 corresponds to handle " + root.hrHandle)
                    haveConfigHandle("emitted from bleGetConfig...")
                }
            }


        }

        onReadyReadStandardError: {
            console.debug("processing standard error in get handle")
            var output = String(readAllStandardError())
            output = output.trim()
            console.debug(output)
            
        }

        onFinished: {
            console.debug("Process bleGetConfigHandle finished")
        }


        function listargs(args){
            console.debug("in listargs")
            console.debug("args" + args)
        }
    }
    /*
    > gatttool -b $ALPHA --addr-type=random --char-write-req -a 0x22 -n 0100 --listen

        > Characteristic value was written successfully
        > Notification handle = 0x0021 value: 10 3d ef 03 
     */
    
     Timer{
        id: hrInterval
        interval: 10000
        running: false
        repeat: false
        onTriggered:
        {
            hrTimeout()
        }
    }

    Process {
        id: bleReadHR
        // program: "gatttool"
        program: "unbuffer"

        onReadyReadStandardOutput: {
            //console.debug("processing standard output in bleReadHr")
            var output = String(readAllStandardOutput())
            //console.debug(output)
            var hr = "--"
            // Expected response
            // Notification handle = 0x0021 value: 10 5c 9c 02
            var items = output.split(" ")
            if(items[0]==="Notification"){
                hr=parseInt(items[6],16)
                //console.debug("Heartrate: "+hr)
                root.heartrate=hr
                hrInterval.restart()
            }
        }

        onReadyReadStandardError: {
            console.debug("processing standard error in bleReadHr")
            var output = String(readAllStandardError())
            output = output.trim()
            //console.debug(output)
        }

        onFinished: {
            console.debug("Process bleReadHR finished")
            bleReadHRTerminated()
        }
    }

    Process {
        id: bleGetHRServiceHandle

        program: "gatttool"
        //program: "ls"
        //program: "gatttwrap.sh"


        onReadyReadStandardError: {
            console.debug("processing standard error in bleGetHRServiceHandle")
            var output = String(readAllStandardError())
            output = output.trim()
            console.debug(output)

        } // end onReadyReadStandardError:

        onReadyReadStandardOutput: {
            //console.debug("processing standard output in bleGetHRServiceHandle")
            var output = String(readAllStandardOutput())
            //console.debug( "scan output: " + output)
            output = output.trim()
            var handles = output.split(" ")

            for(var i=0 ; i < handles.length ; i++) {
                var handle=handles[i];
                //console.debug("handle " + i +" = " +handle)
            }
            root.startHandle="0x"+handles[2];


        } // end onReadyReadStandardOutput

        onFinished: {
            root.scanning = false
            if(exitCode == 0){                
                console.debug("Process bleGetHRServiceHandle finished")
                //console.debug("startHandle "+root.startHandle)

                if(root.startHandle === "empty"){
                    console.debug("startHandle not found")
                    root.connecting = false
                    hrConnectionFailed()
                    return
                }

                haveHrServiceHandle("emitted from bleGetHrServiceHandle\n")
            } else {
                console.debug("process exited with code: " + exitCode)
                root.connecting = false
                hrConnectionFailed()
            }
        }
        function listargs(args){
            console.debug("in listargs")
            console.debug("args" + args)
        }
    }

    ListModel {
        id: monitorListModel
        ListElement{ MAC: "null"; name:"null"}
    }

    Process {
        id: bleStopScan

        program: "bash"
        arguments: [root.scriptsdir + "/stopHeartrateScan.sh" ]
        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            console.debug(output)
        }
        onFinished: {
            console.debug("Process bleStopScan finished")
        }
    }
   

    Process {
        id: bleScan

        program: "bash"
        arguments: [root.scriptsdir + "/startHeartrateScan.sh" ]

        function isBluetoothDeviceString(item){
            var address = item.split(" ")[0]
            if(address.length !== 17) return false
            if(address.charAt(2) !== ":") return false
            if(address.charAt(5) !== ":") return false
            if(address.charAt(8) !== ":") return false
            if(address.charAt(11) !== ":") return false
            if(address.charAt(14) !== ":") return false
            return true
        }



        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            //console.debug(output)
            var item = output.split("\n")
            //console.debug("bleScan: item")

            for(var i = 0; i<item.length; i++){
                /* device string returned from a noble scan do not
                  contain colons, so we insert them to be compatible
                  with the gatttool calls that follow */

                var scanLine=item[i]
                var address=scanLine.split(" ")[0]
                address =address.replace(/(\S{2})/g,"$1:");
                address = address.replace(/:$/,"");
                var name=scanLine.split(" ")[1]
                item[i]= address.concat(" ", name)
                //console.debug("item to test BT: " + item[i])
                if(isBluetoothDeviceString(item[i]) === true) {
                    var address = item[i].slice(0,17)
                    var name = item[i].slice(18)
                    //console.debug("bleScan: address= " + address + " name= " + name )
                    if(name === "(unknown)" || name === "undefined") continue

                    /* No need to do additional duplicate filtering because
                       heartRateManager will do the filtering for us */
                    heartRateManager.addBluetoothHeartRateDevice(name,address)
                }
            }
        }

        onReadyReadStandardError: {
            console.log("bleScan standard error:")
            var output = String(readAllStandardError())
            console.log(output)
        }

        onFinished: {
            console.debug("Process bleScan finished")
            scanned()
            root.scanning = false
        }

    }//bleScan

    onBleReadHRTerminated: {
        root.heartrate=0
        bleReadHRTerminatedTimer.start()
    }

    Timer {
        id: bleReadHRTerminatedTimer
        interval: 4000
        running: false
        repeat: false
        onTriggered: {
            console.debug("Process bleHRdisconnect start")
            bleHRdisconnect.start()
        }
    }

    function disconnect(deviceMAC,handle){
        console.debug("Disconnect function launched")
        hrDisconnecting()
        // Set up arguments for the bleHRdisconnect process
        var deviceArgs=buildArgs(root.deviceMAC,"random")
        var args=deviceArgs.concat(["--char-write-req","-a",root.hrHandle,"-n","0000"])
        console.debug(args)
        bleHRdisconnect.arguments=args

        // Stop process that is reading HR
        bleReadHR.terminate()
    }

    Process {
        id: bleHRdisconnect

        program: "gatttool"

        onReadyReadStandardError: {
            console.debug("processing standard error in bleHRdisconnect")
            var output = String(readAllStandardError())
            output = output.trim()
            console.debug(output)
        } // end onReadyReadStandardError:

        onReadyReadStandardOutput: {
            //console.debug("processing standard output in bleHRdisconnect")
            var output = String(readAllStandardOutput())
            //console.debug( "scan output: " + output)
            output = output.trim()
        } // end onReadyReadStandardOutput

        onFinished: {
            root.scanning = false
            root.heartrate = 0
            console.debug("Process bleHRdisconnect finished")
            hrDisconnectingComplete()
        }
        function listargs(args){
            console.debug("in listargs")
            console.debug("args" + args)
        }
    }
}

