import QtQuick 2.4

import "string_format.js" as StrFormat
import Components 1.0

ModalDialog {
    id: bleDialog

    visible: dialogVisible
    isTop: true

    anchors.verticalCenter: parent.verticalCenter
    anchors.horizontalCenter: parent.horizontalCenter

    dismissable: true

    onVisibleChanged: {
        if (visible)
            idle_timer.restart()
    }

    onDismissed: disconnect()

    Connections {
        target: main.isTft && bleDialog.visible ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "WorkoutSummary", "bleDialog")
            idle_timer.restart()
        }
    }

    onTimedOut: {
        disconnect()
    }

    BorderImage {   // pop-up dialog background
        id: border

        anchors.horizontalCenter: parent.horizontalCenter
        width: 800 //root.width * 0.8
        height: 490 //width / 2
        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenterOffset: 0
        source: "graphics/Pop_Up_Lrg_Grey.png"
        border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

        Text {
            id: dialogTitle

            width: parent.width * 0.8
            color: "white"
            text: qsTr("Sending Data") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap

            font.bold: true
            font.family: "sans serif"
            font.pixelSize: 48

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 0
            anchors.top: parent.top
            anchors.topMargin: 70
        }

        Text {
            id: dialogInstruction

            color: "white"
            text: qsTr("Open the TRUE Fitness App to log workout.") + application.emptyString
            anchors.horizontalCenter: dialogTitle.horizontalCenter
            anchors.top: dialogTitle.bottom
            anchors.topMargin: 10
        }

        Text {
            id: dialogInstruction2

            color: "white"
            text: qsTr("Select below workout in your App to complete:") + application.emptyString
            font.family: "sans serif"

            anchors.horizontalCenter: dialogTitle.horizontalCenter
            anchors.top: bleCounterDigits.bottom //moreTimeText.bottom
            anchors.topMargin: 10
        }

        Text {
            id: dialogElapsed

            color: "white"
            text: qsTr("Workout") + " " + StrFormat.formatTimeStringMinAndSec(root.workoutElapsed)  + application.emptyString
            font.bold: true
            font.family: "sans serif"
            font.pixelSize: 48

            anchors.horizontalCenter: dialogTitle.horizontalCenter
            anchors.top: isTft ? tftHelpText.bottom : dialogInstruction2.bottom
            anchors.bottomMargin: 4
        }

        Image{
            id: _BlueToothLogo

            anchors.top: dialogInstruction.bottom
            anchors.topMargin: 12
            anchors.horizontalCenter: dialogTitle.horizontalCenter
            source: "graphics/Bluetooth/bluetooth_blue.png"
        }

        Image{
            id: _BlueToothLogoConnected

            anchors.top: dialogInstruction.bottom
            anchors.topMargin: 12
            anchors.horizontalCenter: dialogTitle.horizontalCenter
            source: "graphics/Bluetooth/bluetooth_blue.png"
        }

        ImageButton {
            id: closeButton

            z:200
            visible: main.isTouch
            width: 48
            height: 48
            anchors {
                right: parent.right ; rightMargin: 80
                top: parent.top ; topMargin: 40
            }
            upimage: "Keypad/KeyPad_X_Large.png"
            downimage: "Keypad/KeyPad_X_Large.png"

            onClicked: bleDialog.dismissed()
            mouseAreaScale: 2.0
        }

        Text {
            id: bleCounterDigits

            color: "white"
            text: StrFormat.formatTimeString(root.timeLeft)
            font.family: "sans serif"

            font.pixelSize: 34
            horizontalAlignment: Text.AlignHCenter
            anchors {
                horizontalCenter: dialogTitle.horizontalCenter; horizontalCenterOffset: 0
                top: moreTimeText.bottom;  topMargin: 4
            }
        }

        Text {
            id: moreTimeText

            color: "white"
            visible: main.isTouch
            text: qsTr("Touch for more time") + application.emptyString
            font.family: "sans serif"
            font.pointSize: 15
            anchors.top: _BlueToothLogo.bottom
            anchors.topMargin: 5
            anchors.horizontalCenter: bleCounterDigits.horizontalCenter
            horizontalAlignment: Text.AlignHCenter
        }

        Text {
            id: tftHelpText

            color: "white"
            visible: main.isTft
            text: qsTr("Press ENTER for more time, BACK to exit") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            font.family: "sans serif"

            anchors.top: bleCounterDigits.bottom
            anchors.topMargin: 35
            anchors.horizontalCenter: bleCounterDigits.horizontalCenter
        }

        Item {
            id: broadcastAnimation

            x: 492
            y: 244
            width: 108
            height: 58
            anchors.verticalCenter: _BlueToothLogo.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter

            Image{
                id: scanningBluetoothWave

                property int opacityInteger: 0

                width: 142
                height: 58
                anchors.topMargin: -10
                anchors.bottomMargin: -10
                anchors.rightMargin: -20
                anchors.leftMargin: -20
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
                source: "graphics/Bluetooth/Bluetooth_waves_medium.png"
                sourceSize.width: 150
                opacity: opacityInteger / 100.0

                NumberAnimation on opacityInteger {
                    from: 0;
                    to: 100;
                    duration: 500
                    running : broadcastAnimation.visible
                    loops: Animation.Infinite
                }
            }
        }
    }
}
