import QtQuick 2.4
import "string_format.js" as Format

Item {
    id: root
    property variant c360program: workoutProgram.c360Program
    property int segmentTime: c360program.phaseTimeRemaining
    property int phase: c360program.currentPhase

    signal phaseTitleChanged(string title)

    onPhaseChanged: {
        var text = qsTr(c360Modes.title(phase))
        root.phaseTitleChanged(text)
    }

    Component {
        id: phaseImages

        Image {
            id: c360PhaseView
            property int imageIndex: viewObject.imageNum

            onImageIndexChanged: {
                photo.source = (c360Modes.imagePath() + images.get(imageIndex).source)
            }
            anchors.verticalCenter: parent.verticalCenter
            width: parent.width
            height: parent.height

            source: "graphics/224/224_Data_Main_Window_Bkgr.png"

            Image {
                id: header
                source: "graphics/c360/Header.png"

                anchors { top: parent.top; topMargin: 3 ; left: parent.left ; leftMargin: 2; right: parent.right; rightMargin: 3 }
                width: 1000

                ScrollingText {
                    id: titleText

                    boundsBehavior: Flickable.StopAtBounds
                    text: c360program.coolDown ? "" : qsTr(viewObject.model.title(index)) + application.emptyString
                    onTextChanged: console.log("text>>",text)
                    color: "white"
                    font.bold: true
                    font.pixelSize: 40
                    anchors { horizontalCenter: parent.horizontalCenter; verticalCenter: parent.verticalCenter }
//                    wrapMode: Text.Wrap
//                    lineHeight: 0.7
                    width: 980
//                    elide: Text.ElideRight
                }
            }

            Image {
                id: photo
                anchors {
                    top: header.bottom ;
                    topMargin: 5 ;
                    left: parent.left ;
                    leftMargin: 20;
                    bottom: parent.bottom;
                    bottomMargin: 5

                }
                source: (c360Modes.imagePath() + images.get(0).source)

                fillMode: Image.PreserveAspectFit
                smooth: true

                MouseArea {
                    anchors.fill: parent

                    onClicked: { // for demonstration purposes, allow swithing phases by clicking photo: to be removed.
//                        viewObject.incrementCurrentIndex()
                    }
                }
            }

            Text {
                id: instText
                text: qsTr(viewObject.model.instructions(index)) + application.emptyString
                anchors { verticalCenter: photo.verticalCenter ; left: photo.right ; leftMargin: 0 }
            }

            Image {
                id: motionMan
                anchors {
                    top: header.bottom ;
                    topMargin: 5 ;
                    right: parent.right ;
                    leftMargin: 20 ;
                    bottom: parent.bottom;
                    bottomMargin: 5;

                }
                fillMode: Image.PreserveAspectFit
                smooth: true

                source: "graphics/c360/MotionMan/" + icon
            }

            Text {
                id: segTimeLabel
                anchors { bottom: parent.bottom ; bottomMargin: 50 ; left: photo.right ; leftMargin: 10 }
                text: qsTr("SEGMENT TIME REMAINING") + application.emptyString
                font.pointSize: 12
                font.bold: true
            }
            Text {
                id: segTimeIndicator
                anchors { left: segTimeLabel.right ; verticalCenter: segTimeLabel.verticalCenter }
                text: Format.formatTimeString(root.segmentTime)
                font.pointSize: 30
                font.bold: true
            }
        }
    }

    PathView {
        id: viewObject
        property int imageNum: 0

        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5
        pathItemCount: 2
        anchors.fill: parent
        interactive: false
        currentIndex: root.phase
        width: 1000
        height: 406

        model: c360Modes
        delegate: phaseImages
        clip: true
        path: Path {
            startX: viewObject.width *1.5
            startY: viewObject.height / 2
            PathLine {
                x: -viewObject.width /2
                y: viewObject.height / 2
            }
        }

        // timer to switch photo images between full and close-up
        Timer {
            id: imageTimer
            running: true
            repeat: true
            interval: 6000
            onTriggered: {
                viewObject.imageNum = (viewObject.imageNum ? 0 : 1)
            }
        }
    }
}
