import QtQuick 2.4
import Components 1.0

Item {
    id: root

    // REQUIRED property: for translation to work (via qsTranslate), it must know where the external model is stored.
    // To use, set this property to the basename of the file you're including from (e.g. "MyComponent" for MyComponent.qml)
    property string sourceFile: ""

    property variant model: programsModel
    property variant selectedData
    property alias currentIndex: wheel.currentIndex
    property bool _pathedit: false

    width: 700
    height: 768

    ListModel
    {
        id: demoprogramsModel
        ListElement { name: "HRC TARGET" }
        ListElement { name: "HRC AEROBIC" }
        ListElement { name: "HRC WEIGHT LOSS" }
        ListElement { name: "HILL INTERVALS" }
        ListElement { name: "HRC 2 MILE" }
        ListElement { name: "HRC 5k" }
        ListElement { name: "HRC 10k" }
        ListElement { name: "Calorie Goal" }
        ListElement { name: "Rolling Hills" }
        ListElement { name: "5meter cluster" }

    }

    Component {
        id: testDelegate

        Rectangle {
            color: "black" ; width: 50 ; height: 50
            transform: Rotation {
                axis { x:1 ; y:0 ; z:0 }
                angle: zrotation
                origin.y: height * PathView.h |0
            }
        }
    }

    Component {
        id: setupItem

        ImageButton {
            id: button

            property real zrotation: PathView.angle
            property string src: PathView.isCurrentItem ? "graphics/setup/Setup_Large_Up_Step1.png" : "graphics/setup/Setup_Small_Down.png"

            //scale: PathView.xscale
            z: PathView.z
            //height: PathView.h
            visible: PathView.onPath

            // rotate about the x-axis giving a pseudo-3D perspective shift
            transform: [
                Scale { xScale: button.PathView.xscale ; yScale: button.PathView.yscale ; origin.x: button.width /2 },
                Rotation {
                    axis { x:1 ; y:0 ; z:0 }
                    angle: zrotation
                    origin.y: button.height * PathView.h | 0
                }
            ]
            onClicked: { wheel.currentIndex = index }

            //opacity: PathView.opacity
            upimage: src //"graphics/setup/Setup_Small_Down.png"
            downimage: src //"graphics/setup/Setup_Small_Down.png"
            label_color: PathView.isCurrentItem ? "red" : "black"
            label_y_offset: PathView.isCurrentItem ? -35:  -10
            label: qsTranslate(root.sourceFile, model.label) + application.emptyString
            smooth: true
        }
    }

    PointEdit {
        id: startpoint

        visible: _pathedit
        anchors.fill: parent
        label: qsTr("start") + application.emptyString
        dx: wheel.width /2
        dy: 0
        z: 4
    }

    PointEdit {
        id: midpoint

        visible: _pathedit
        anchors.fill: parent
        label: "midpoint"
        dx: wheel.width /2
        dy: wheel.height/2
        z: 4
    }

    PointEdit {
        id: ctx1

        visible: _pathedit
        anchors.fill: parent
        label: "ctl1"
        dx: wheel.width /2
        dy: wheel.height/8
        z: 4
    }

    PointEdit {
        id: ctx2

        visible: _pathedit
        anchors.fill: parent
        label: "ctl2"
        dx: wheel.width /2
        dy: 13*wheel.height/16
        z: 4
    }

    PointEdit {
        id: endpoint

        visible: _pathedit
        anchors.fill: parent
        label: "end"
        dx: wheel.width /2
        dy: wheel.height
        z: 4
    }

    PathView {
        id: wheel

        anchors.fill: parent

        onCurrentIndexChanged: root.selectedData = model.get(currentIndex)
        onModelChanged: { console.log("new model") ;currentIndex = 1 }
        model: root.model
        delegate: setupItem

        highlightMoveDuration: 100
        //highlight: Rectangle {z:4; width: 100 ; height: 50 ; color: "yellow" ; opacity: 0.5 }
        pathItemCount: 7
        highlightRangeMode: PathView.StrictlyEnforceRange
        preferredHighlightBegin: 0.5
        preferredHighlightEnd: 0.5
        path: Path {
            startX: startpoint.dx //width / 2
            startY: startpoint.dy //0
            PathAttribute { name: "angle" ; value: -75 }
            PathAttribute { name: "opacity" ; value: 0.3 }
            PathAttribute { name: "xscale" ; value: 0.5 }
            PathAttribute { name: "yscale" ; value: 1.2 }
            PathAttribute { name: "h" ; value: 1 }
            PathAttribute { name: "z" ; value: 0 }

            // ------------
            //PathLine { x: midpoint.dx ; y: midpoint.dy } //{ x: width / 2 ; y: height/2 }
            PathQuad { x: midpoint.dx ; y: midpoint.dy ; controlX: ctx1.dx ; controlY: ctx1.dy }

            PathAttribute { name: "angle" ; value: 0 }
            PathAttribute { name: "opacity" ; value: 1 }
            PathAttribute { name: "xscale" ; value: 1.1 }
            PathAttribute { name: "yscale" ; value: 1.0 }
            PathAttribute { name: "z" ; value: 2 }
            //PathPercent { value: 0.6 }
            //PathLine { x: width / 2 ; y: height/2 + 100 }
            PathAttribute { name: "h" ; value: 0.5 }

            // ---------------
            //PathLine { x: endpoint.dx ; y: endpoint.dy } //{ x: width / 2 ; y: height }

            PathQuad { x: endpoint.dx ; y: endpoint.dy ; controlX: ctx2.dx ; controlY: ctx2.dy }
            PathAttribute { name: "angle" ; value: 75 }
            PathAttribute { name: "opacity" ; value: 0.3 }
            PathAttribute { name: "xscale" ; value: 0.5 }
            PathAttribute { name: "yscale" ; value: 1.2 }
            PathAttribute { name: "h" ; value: 0 }
            PathAttribute { name: "z" ; value: 0 }

        }
    }
}
