// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Components 1.0

Item {
    id: root

    width: 104
    height: 210
    property int channelNumber:main.channelNumber
    signal keypadClicked()
    property variant channelList

    property int _numChans:0

    // update the channel count when the channel list is modified
    Connections {
        target: channelList
        onDataChanged: {
            _numChans = channelList.count
        }
    }

    onChannelListChanged: {
        _numChans = channelList.count
    }

    // get the current channel mrl, given the selected channel number
    function getTVMrl() {

        if( channelList.get(channelNumber) )
            return channelList.get(channelNumber).mrl
        else
            return ""
    }

    function getTVChannelName() {

        if( channelList.get(channelNumber) )
            return channelList.get(channelNumber).name
        else
            return ""
    }

    Row {
        id: row1
        anchors.fill: parent

        Column {
            id: column1
            width: 77
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 0
            anchors.top: parent.top
            anchors.topMargin: 0

            ImageButton {
                id: channel_fwd_button
                anchors.horizontalCenter: parent.horizontalCenter
                icon: "graphics/Media_TV_Forward.png"
                upimage: "graphics/224/224_ToolBar_Square_Disabled.png"
                downimage: "graphics/224/224_ToolBar_Square_Down.png"
                onClicked: (main.channelNumber < _numChans-1) ? main.channelNumber++ : main.channelNumber = 0

            }

            Text {
                id: channel_text
                x: 34
                y: 72
                text: qsTr("CHANNEL") + application.emptyString
                font.bold: true
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: 15
            }

            Text {
                id: channel_value
                x: 13
                y: 55
                text: main.channelNumber //root._numChans > 0 ? (root.channelNumber + ":"+channelList.get(root.channelNumber).name) : ""
                font.bold: true
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: 52
            }

            Text {
                id: channel_name
                text: (root._numChans > 0) ? (channelList.get(main.channelNumber).name) : ""
                font.bold: true
                anchors.horizontalCenter: parent.horizontalCenter
                font.pixelSize: 10
            }

            ImageButton {
                id: channel_back_button
                anchors.horizontalCenter: parent.horizontalCenter
                upimage: "graphics/224/224_ToolBar_Square_Disabled.png"
                icon: "graphics/Media_TV_Back.png"
                downimage: "graphics/224/224_ToolBar_Square_Down.png"
                onClicked: (main.channelNumber > 0) ? main.channelNumber-- : main.channelNumber = _numChans-1
            }
        } // end Column

        ImageButton {
            id: channel_keypad
            anchors.verticalCenter: parent.verticalCenter
            upimage: "graphics/224/224_Data_SM_Keypad_Icon.png"
            downimage: "graphics/224/224_Data_SM_Keypad_Icon.png"
            onClicked: root.keypadClicked()
        }
    }
}
