import QtQuick 2.4
import ".."
import Components 1.0

ModalDialog {
    id: root
    dismissable: true
    blockKeys: true
    property string norm: normValue.totalValue
    property string frequency: Globals.stripLeadingZeros(frequencyRow.totalValue)
    property string network: networkRow.totalValue
    property string channelNumber: channelRow.totalValue
    property string navState: "norm"
    signal channelAdded(string norm, string freq, string network, string number)

    function submit() {
        root.channelAdded(root.norm, root.frequency, root.network, root.channelNumber)
    }

    Connections {
        target: main.isTft && root.visible ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "AddChannelPopup")
            root.submit()
        }
    }

    BorderImage {   // pop-up dialog background
        id: border2

        x: 332
        y: 161
        width: 800
        height: 420
        source: "../graphics/Pop_Up_Lrg_Grey.png"
        border { top: 152; bottom: 165; left: 145; right: 144 }
        Text {
            id: headerText
            width: 501
            color: "#ffffff"
            text: qsTr("ADD CHANNEL?") + application.emptyString
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 35
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.pixelSize: 40
        }

        Text {
            id: helpText
            anchors { left: parent.left; leftMargin: 30; top: headerText.bottom; topMargin: 30 }
            text: qsTr("Add a Channel by Frequency") + application.emptyString
            font { pixelSize: 16; bold: true }
        }

        Text {
            id: stdHeader
            text: qsTr("Standard") + ":" + application.emptyString
            anchors { left: helpText.left; top: helpText.bottom; topMargin: 25 }
            font { pixelSize: 16; bold: true }
        }

        Text {
            id: freqHeader
            text: qsTr("Frequency") + ":" + application.emptyString
            anchors { left: frequencyRow.left; top: helpText.bottom; topMargin: 25 }
            font { pixelSize: 16; bold: true }
        }

        Text {
            id: netHeader
            text: qsTr("Network") + ":" + application.emptyString
            anchors { left: networkRow.left; top: helpText.bottom; topMargin: 25 }
            font { pixelSize: 16; bold: true }
        }

        Text {
            id: chanHeader
            text: qsTr("Channel Number") + ":" + application.emptyString
            anchors { left: channelRow.left; top: helpText.bottom; topMargin: 25 }
            font { pixelSize: 16; bold: true }
        }

        ValuePickerRow {
            id: normValue
            listenKeys: root.navState === "norm" && root.visible
            onExitedLeft: { channelRow.currentIndex = 1; root.navState = "channel" }
            onExitedRight: { frequencyRow.currentIndex = 0; root.navState = "frequency" }
            anchors.top: stdHeader.bottom
            anchors.topMargin: 5
            anchors.left: helpText.left
            anchors.leftMargin: -3
            numberOfItems: 1
            width: 100
            delegate: Component {
                NumberPicker {
                    id: picker
                    ListModel {
                        id: analogStandards
                        ListElement { label: "NTSC-M"; value: "NTSC-M" }
                        ListElement { label: "PAL-BG"; value: "PAL-BG" }
                        ListElement { label: "PAL-DK"; value: "PAL-DK" }
                        ListElement { label: "PAL-I"; value: "PAL-I" }
                        ListElement { label: "PAL-N"; value: "PAL-N" }
                        ListElement { label: "SECAM-L"; value: "SECAM-L" }
                        ListElement { label: "SECAM-B"; value: "SECAM-B" }
                        ListElement { label: "SECAM-DK"; value: "SECAM-DK" }
                    }
                    listenKeys: picker.ListView.isCurrentItem && normValue.listenKeys
                    minValue: 0
                    maxValue: analogStandards.count - 1
                    printedValue: analogStandards.get(value).value
                    defaultValue: 0
                    valueWraps: true
                    font { pixelSize: 24; bold: true }
                    columnSpacing: 5
                    upImage: "../graphics/tft/arrow_up.png"
                    upImagePressed: upImage
                    downImage: "../graphics/tft/arrow_down.png"
                    downImagePressed: downImage
                    width:100
                    height:90
                    showArrows: main.isTouch || listenKeys
                }
            }
        }

        ValuePickerRow {
            id: frequencyRow
            listenKeys: root.navState === "frequency" && root.visible
            onExitedRight: { networkRow.currentIndex = 0; root.navState = "network" }
            onExitedLeft: { normValue.currentIndex = 0; root.navState = "norm" }
            anchors.top: freqHeader.bottom
            anchors.topMargin: 5
            anchors.left: normValue.right
            anchors.leftMargin: 30
            numberOfItems: 6
            width: 240
            delegate: Component {
                NumberPicker {
                    id: picker
                    listenKeys: picker.ListView.isCurrentItem && frequencyRow.listenKeys
                    minValue: 0
                    maxValue: 9
                    defaultValue: 0
                    valueWraps: true
                    font { pixelSize: 24; bold: true }
                    columnSpacing: 5
                    upImage: "../graphics/tft/arrow_up.png"
                    upImagePressed: upImage
                    downImage: "../graphics/tft/arrow_down.png"
                    downImagePressed: downImage
                    width:40
                    height:90
                    showArrows: main.isTouch || listenKeys
                }
            }
        }
        Text {
            // Wedge in a decimal point after the third frequency digit
            id: decimalPoint
            text: "."
            font.pixelSize: 50
            font.family: "Arial"
            x: 270
            y: 200
        }

        ValuePickerRow {
            id: networkRow
            listenKeys: root.navState === "network" && root.visible
            onExitedRight: { channelRow.currentIndex = 0; root.navState = "channel" }
            onExitedLeft: { frequencyRow.currentIndex = 5; root.navState = "frequency" }
            anchors.top: netHeader.bottom
            anchors.topMargin: 5
            anchors.left: frequencyRow.right
            anchors.leftMargin: 30
            numberOfItems: 4
            width: 160
            delegate: Component {
                NumberPicker {
                    id: picker
                    listenKeys: picker.ListView.isCurrentItem && networkRow.listenKeys
                    minValue: "A".charCodeAt(0)
                    maxValue: "Z".charCodeAt(0)
                    defaultValue: minValue
                    alpha: true
                    valueWraps: true
                    font { pixelSize: 24; bold: true }
                    columnSpacing: 5
                    upImage: "../graphics/tft/arrow_up.png"
                    upImagePressed: upImage
                    downImage: "../graphics/tft/arrow_down.png"
                    downImagePressed: downImage
                    width:40
                    height:90
                    showArrows: main.isTouch || listenKeys
                }
            }
        }
        ValuePickerRow {
            id: channelRow
            listenKeys: root.navState === "channel" && root.visible
            onExitedRight: { normValue.currentIndex = 0; root.navState = "norm" }
            onExitedLeft: { networkRow.currentIndex = 3; root.navState = "network" }
            anchors.top: chanHeader.bottom
            anchors.topMargin: 5
            anchors.left: networkRow.right
            anchors.leftMargin: 30
            numberOfItems: 2
            width: 80
            delegate: Component {
                NumberPicker {
                    id: picker
                    listenKeys: picker.ListView.isCurrentItem && channelRow.listenKeys
                    minValue: 0
                    maxValue: 9
                    defaultValue: 0
                    valueWraps: true
                    font { pixelSize: 24; bold: true }
                    columnSpacing: 5
                    upImage: "../graphics/tft/arrow_up.png"
                    upImagePressed: upImage
                    downImage: "../graphics/tft/arrow_down.png"
                    downImagePressed: downImage
                    width:40
                    height:90
                    showArrows: main.isTouch || listenKeys
                }
            }
        }
        Item {
            id: buttonRow
            visible: main.isTouch
            anchors { top: parent.top; topMargin: 300; right: parent.right; rightMargin: 50 }
//            width: 300
//            height: 50

            Text {
                id: okText
                text: qsTr("OK") + application.emptyString
                anchors.right: parent.right
                anchors.rightMargin: 20
                anchors.verticalCenter: okButton.verticalCenter
                font { pixelSize: 18; bold: true }
            }
            ImageButton {
                id: okButton
                anchors.right: okText.left
                anchors.rightMargin: 10
                anchors.top: parent.top
                upimage: "../graphics/205/SM_Button_BLUE.png"
                downimage: "../graphics/205/SM_Button_ORANGE.png"
                onClicked: {
                    root.submit()
                }
            }
            Text {
                id: cancelText
                text: qsTr("Cancel") + application.emptyString
                anchors.right: okButton.left
                anchors.rightMargin: 10
                anchors.verticalCenter: cancelButton.verticalCenter
                font { pixelSize: 18; bold: true }
            }
            ImageButton {
                id: cancelButton
                anchors.right: cancelText.left
                anchors.rightMargin: 10
                anchors.top: parent.top
                upimage: "../graphics/205/SM_Button_RED.png"
                downimage: "../graphics/205/SM_Button_ORANGE.png"
                onClicked: {
                    root.dismissed()
                }
            }
        }
    }


    Component.onCompleted: hide()
    onTimedOut: hide()
}
