// Diagnostics Menu

import QtQuick 2.4
import StorageMgr 1.0
import BootLoader 1.0
import "../LanguageMenu"
import ".."
import Components 1.0

Rectangle {
    id: root
    width: 1366
    height: 768
    anchors.fill: parent

    signal close()
    ImageButton {
        id: langbutton
        x: 642
        y: 44
        z:99
        opacity: 1
        upimage: "../graphics/LANGUAGE_ICON_DISABLED.png"
        downimage: "../graphics/LANGUAGE_ICON_DOWN.png"
        onClicked: langmenu.opacity=1
    }


    LanguageMenu {
        id: langmenu

        anchors.fill: parent
        opacity: 0
        onLanguageSelected: {
            console.log("setting default language: " + lang)
            if(lang)
                Preferences.setSetting("lang", lang)
            //console.log("new language: " + Preferences.preferences[0].value)
            opacity = 0
        }
    }

    Column {
        x: 69
        y: 20
        spacing: 3
        Text {
            id: app_version
            text: qsTr("Application Version: ") + application.appVersion
        }

        Text {
            id: control_version
            text: qsTr("Control Version: ") + application.emptyString + machineinfo.brainboardFirmwareVersion
        }

        Text {
            id: lower_board_name
            text: qsTr("Controller: ") + application.emptyString + brainboard.machineType
        }

        Rectangle {
            id: bootload_indicator

            visible: bootloader.enabled
            radius: 0.5 *width
            width: 10
            height: width
            color: "red"
            Text {
                anchors.left: parent.right
                anchors.verticalCenter: parent.verticalCenter
                text: qsTr("Bootloader Mode")  + application.emptyString
            }
        }
        Rectangle {
            id: control_indicator

            opacity: brainboard.enabled ? 1.0 : 0.0
            radius: 0.5 *width
            width: 10
            height: width
            color: "green"
            Text {
                anchors.left: parent.right
                anchors.verticalCenter: parent.verticalCenter
                text: qsTr("Controller Connected") + application.emptyString
            }
        }

        Text {
            id: usb_instruction
            width: 290
            height: 15
            text: qsTr("Insert USB Key to load controller firmware.") + application.emptyString
            font.pixelSize: 12
        }
    }


    ImageButton {
        id: exit_button
        x: 1208
        y: 655
        upimage: "../graphics/205/SM_Button_Up.png"
        downimage: "../graphics/205/SM_Button_Down.png"
        label_color: "black"
        label: qsTr("Exit") + application.emptyString
        onClicked: close()
    }

    ImageButton {
        id: shutdown_button
        x: 453
        y: 20
        width: 118
        height: 141
        anchors.rightMargin: 795
        anchors.bottomMargin: 607
        anchors { bottom: parent.bottom ; right: parent.right }
        label_color: "black"
        label_under: true
        upimage: "../graphics/205/SM_Button_Up.png"
        downimage: "../graphics/205/SM_Button_Down.png"

        label: qsTr("Shutdown Console") + application.emptyString
        onClicked: { Qt.quit() }

    }

    ImageButton {
        id: eepromWriteClearButton
        x: shutdown_button.x + (shutdown_button.width*3)
        y: shutdown_button.y
        label_color: "#000000"
        label_under: true
        upimage: "../graphics/205/SM_Button_Up.png"
        downimage: "../graphics/205/SM_Button_Down.png"

        label: "EEPROM"

        enabled: true
        opacity: 100
        onClicked: {
           //brainboard.goToBootloader();
           //bootloader.loadFirmware( storage.firmwareFilename )
        }
    }

    ParameterAdjustControl{
        id: testButton
        label: qsTr("Buttons") + application.emptyString
        value: 0
        minValue: 0
        maxValue: 100
        x: 600
        y: 100
    }
    ParameterAdjustControl{
        id: testButton2
        label: qsTr("Buttons 2") + application.emptyString
        value: 0
        minValue: 0
        maxValue: 4000
        anchors.top: testButton.bottom
        anchors.left: testButton.left
    }





    StorageMgr {
        id: storage
        //onMessage: { console.log(string) }
    }

    Timer {
        id: hexPollTimer
        interval: 5000
        repeat: true
        running: root.visible && (root.opacity >0)
        onTriggered: {
            console.log('looking for hex files')
            storage.pollHexFiles()
        }
    }

    Item {
        id: bootloader_panel
        x: 85
        y: 185
        width: 510
        height: 388
        visible: storage.firmwareFilename !== ""

        ImageButton {
            id: blbutton
            x: 53
            y: 5
            label_color: "#000000"
            label_under: true
            upimage: "../graphics/205/SM_Button_Up.png"
            downimage: "../graphics/205/SM_Button_Down.png"

            label: qsTr("Load") + application.emptyString

            enabled: storage.firmwareFilename != ""
            opacity: (enabled ? 100: 50 )
            onClicked: {
               brainboard.goToBootloader();
               bootloader.loadFirmware( storage.firmwareFilename )
            }
        }



        Text {
            id: hexfilename_label
            x: 0
            y: 88
            anchors { top: blbutton.bottom ; topMargin: 5; }

            text: storage.firmwareFilename
            horizontalAlignment: Text.AlignLeft
            wrapMode: Text.WrapAnywhere
            width: 400
            height: 23
        }

        BootLoader {
            id: bootloader
        }

        Rectangle {
            id: blprogress
            x: 168
            y: 44
            visible: (bootloader.progress > 0)
            width: 232
            height: 30
            border.color: "#000000"
            Rectangle {
                anchors {left: parent.left; top: parent.top ; bottom: parent.bottom }

                color: "#07a22b"
                width: bootloader.progress
            }
        }
        ScrollText {
            id: bl_console
            font.pointSize: 12

            anchors {top: hexfilename_label.bottom ; }
            Connections {
                target: bootloader
                onMessage: bl_console.addText(msg)
            }
        }

}

    /* //  menu experiments

    Component {
        id: menu_button
        ImageButton {
            upimage: "../graphics/205/SM_Button_Up.png"
            downimage: "../graphics/205/SM_Button_Down.png"
            label: name

            onClicked: {
                console.log("pressed: " + menuitem)
                if (menuitem === "defaults" ) {
                    diagscreen.sourceComponent = settings
                    diagscreen.visible = true
                    diagscreen.anchors.fill = root
                }

            }
        }
    }

    Component {
        id: settings
        Rectangle{

            Text { text: qsTr("Measure Units:") + application.emptyString }
        }

    }

        ListModel {
            id: menu_model
            ListElement { name: "exit" ; text: qsTr("Defaults") + application.emptyString; menuitem: "defaults" }
            ListElement { name: "exit" ; text: qsTr("Exit") + application.emptyString; menuitem: "exit" }

        }
        ListView {
            x: 136
            y: 115
            model: menu_model
            delegate: menu_button
            contentHeight: 100
            width: 100
            height: 500
        }

        Text {
            width:60
            height: 20
            x: 326
            y: 98
            id: setupfield
            property variant value:"empty";

            MouseArea{
                x: 40
                y: -18
                anchors.rightMargin: -40
                anchors.bottomMargin: 18
                anchors.leftMargin: 40
                anchors.topMargin: -18
                anchors.fill: parent
                onClicked: {
                    setup_keypad.visible = true
                    setup_keypad.target = setupfield
                }
            }
            text: value

        }

        Keypad {
            id: setup_keypad
            visible: false
            //x: 424; y: 88
            property variant target
            onValueEntered: { if (target) { target.value = val } }

        }

        Loader {
            anchors.fill: parent
            id: diagscreen
            x: 100
            y: 272
            anchors.rightMargin: -100
            anchors.bottomMargin: -272
            anchors.leftMargin: 100
            anchors.topMargin: 272

        }

    */

}
