import QtQuick 2.4
import Process 0.1
import Bluetooth 1.0
import Components 1.0

import ".."

Item {
    id: root
    Component.onCompleted: {

    }

    Component.onDestruction: {
        scanButton.state = "idle"
    }


    Component{
        id: deviceInfoComponent
        Item {
            width: 400
            height: 60
            Item{
                height: parent.height/2
                width: parent.width * 0.8
                anchors.left: parent.left
                anchors.top: parent.top
                Text {
                    anchors.fill: parent
                    verticalAlignment: Text.AlignVCenter
                    text: name
                    font.pointSize: 16
                    color: "black"
                }

            }
            Item{
                height: parent.height/2
                width: parent.width * 0.8
                anchors.left: parent.left
                anchors.bottom: parent.bottom
                Text {
                    anchors.fill: parent
                    verticalAlignment: Text.AlignVCenter
                    text: address
                    font.pointSize: 16
                    color: "black"
                }
            }
            Item{
                height: parent.height
                width: parent.width * 0.2
                anchors.right: parent.right
                anchors.top: parent.top
                Text {
                    anchors.fill: parent
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                    text: rssi
                    font.pointSize: 16
                    color: "black"
                }
            }
        }
    }

    Row{
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        spacing: 20


        Rectangle {
            id: bluetoothDeviceListBox
            color: "lightgray"
            radius: 10
            width: 400
            height: 250

            Text{
                anchors.bottom: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                width: parent.width
                height: 60
                text: "Bluetooth Audio Devices"
            }

            ListView {
                id: bluetoothDeviceList

                clip: true
                anchors.fill: parent
                anchors.margins: 5
                model: bluetoothAdapter.scannedDevices
                highlight: Rectangle { color: "darkgray" ; radius: 5 ; opacity: 0.7 ; width: 400 }
                highlightMoveVelocity: 1500
                delegate: deviceInfoComponent
            }
        }

        Rectangle {
            id: bluetoothHeadsetListBox
            color: "lightgray"
            radius: 10
            width: 400
            height: 250

            Text{
                anchors.bottom: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                width: parent.width
                height: 60
                text: "Bluetooth Headsets"
            }

            ListView {
                id: bluetoothHeadsetList

                clip: true
                anchors.fill: parent
                anchors.margins: 5
                model: bluetoothAdapter.scannedHeadSets
                highlight: Rectangle { color: "darkgray" ; radius: 5 ; opacity: 0.7 ; width: 400 }
                highlightMoveVelocity: 1500
                delegate: deviceInfoComponent
            }
        }

    }


    ImageButton {
        id: scanButton
        anchors.horizontalCenter: parent.horizontalCenter
        y: 525

        state: "idle"
        enabled: !bluetoothAdapter.connected
        visible: true
        label_color: "black"
        label_under: true
        upimage: "../graphics/205/Lrg_Button_Up.png"
        downimage: "../graphics/205/Lrg_Button_Down.png"
        onClicked: state === "idle" ? state = "scanning" : state = "idle"

        onStateChanged: {
            if(state === "idle"){
                bluetoothAdapter.stopDiscovery()
            } else if(state === "scanning"){
                bluetoothAdapter.startDiscovery(false)
            }
        }

        states: [
            State {
                name: "idle"
                PropertyChanges { target: scanButton; label: qsTr("Start Scan") + application.emptyString }
            },
            State {
                name: "scanning"
                PropertyChanges { target: scanButton; label: qsTr("Stop Scan") + application.emptyString }
            }
        ]
    }
}



