
// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import Process 0.1
import FileIO 1.0
import "../string_format.js" as Format
import ".."
import Components 1.0

Rectangle {
    id: root
    state: "NoUsbState"

    property bool isUsbDeviceLoaded: storageMgr.usbDeviceLoaded
    property int numberOfImages
    property string cursorState: "controls" // controls is the only state currently

    function loadImageList() {
        var images = storageMgr.listFiles(slidesFileManager.slidesSource, ["*.png", "*.jpg"])
        root.numberOfImages = images.length
        slidesModel.clear()
        for (var i = 0; i < images.length; i++) {
            slidesModel.append({ file: slidesFileManager.slidesSource + "/" + images[i] })
        }
    }

    function doSave() {
        slidesFileManager.commitSlides()
        dialogText.text = qsTr("Slides have been updated")
        actionSuccessfulDialog.show()
        actionSuccessfulDialog.startTimeout(1)
    }

    function doClearSlides() {
        slidesFileManager.deleteCurrentSlides()
        dialogText.text = qsTr("Slides have been cleared")
        actionSuccessfulDialog.show()
        actionSuccessfulDialog.startTimeout(1)
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsFacility")
            diagnostics_screen.item.unselectScreen()
        }
    }

    onStateChanged: {
        if (state === "FoundUsbState") {
            loadImageList()
        }
    }

    onIsUsbDeviceLoadedChanged: {
        if (isUsbDeviceLoaded)
            state = "FoundUsbState"
        else
            state = "NoUsbState"
    }

    anchors.fill: parent
    width: 1366
    height: 768
    color: "transparent"

    SlidesFileManager {
        id: slidesFileManager
        slidesDestination: "/data/facility/user"
        slidesSource: "/media/usb/facility"
    }

    ListModel {
        id: slidesModel
    }

    Text {
        id: previewText
        font { pixelSize: 30; family: "arial" }
        text: qsTr("Preview") + application.emptyString
        anchors.top: parent.top
        anchors.topMargin: -10
        anchors.left: parent.left
        anchors.leftMargin: 50
    }

    Slideshow {
        id: previewSlideshow
        width: 1366 * 0.5
        height: 768 * 0.5
        anchors.top: previewText.bottom
        anchors.topMargin: 5
        anchors.left: parent.left
        anchors.leftMargin: 50
        imageList: slidesModel
        useCustomModel: true
        showControls: main.isTouch
        slideInterval: 3000
        clip: true
    }

    Text {
        id: slideshowCounter

        visible: previewSlideshow.imageIndex >= 0 && state === "FoundUsbState"
        anchors.horizontalCenter: previewSlideshow.horizontalCenter
        anchors.top: previewSlideshow.bottom
        font { pixelSize: 24; family: "arial" }
        text: qsTr("Image") + " " + (1 + previewSlideshow.imageIndex) + " / " + previewSlideshow.imageList.count + application.emptyString
    }


    Text {
        id: insertUsbText
        anchors.top: parent.top
        anchors.topMargin: 50
        anchors.horizontalCenter: parent.horizontalCenter
        font { pixelSize: 30; family: "arial" }
        text: qsTr("INSERT USB KEY TO ADD IMAGES...") + application.emptyString
    }

    Text {
        id: foundText
        anchors.top: previewSlideshow.top
        anchors.topMargin: 0
        anchors.left: previewSlideshow.right
        anchors.leftMargin: 50
        font { pixelSize: 24; family: "arial" }
        text: qsTr("Images Found") + ": " + numberOfImages + application.emptyString
    }

    KeyedControlList {
        id: controlList
        listening: root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "controls"
        listView: mode
        InlineButton {
            id: clearInlineButton
            visible: main.isTft
            label: qsTr("Clear Current Slides") + application.emptyString
            onPressed: {
                root.doClearSlides()
            }
        }
        InlineButton {
            id: saveInlineButton
            visible: main.isTft && root.state === "FoundUsbState"
            label: qsTr("Save") + application.emptyString
            onPressed: {
                root.doSave()
            }
        }
    }

    ListView{
        id: mode
        anchors {
            bottom: root.bottom ; bottomMargin: -5
            left: root.left ; leftMargin: 40
        }
        width: root.width * 0.8
        height: 250
        model: controlList.model
        snapMode: ListView.SnapToItem
        interactive: false
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            BorderImage {
                id: selectionCursor
                visible: main.isTft && controlList.listening
                border { left: 70; top: 5; bottom: 5; right: 70 }
                source: "../graphics/tft/maintenance_menus_cursor.png"
                width: mode.currentItem ? mode.currentItem.navCursorWidth + 70 : 0
                height: 56
                horizontalTileMode: BorderImage.Stretch
            }
        }
    }

    ImageButton {
        id:saveButton
        label: qsTr("SAVE") + application.emptyString
        upimage:"../graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"../graphics/200/TRU_200_other_small_Button_Down.png"
        label_under: false
        label_y_offset: -3
        anchors.right: parent.right
        anchors.rightMargin: 20
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        onClicked: {
            root.doSave()
        }
        visible: true
    }

    ModalDialog {
        id: actionSuccessfulDialog
        BorderImage {   // pop-up dialog background
            id: border

            x: 332
            y: 161
            width: 800
            height: 350
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text {
                id: dialogText
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    Item {
        id: missingFolderText
        anchors.top: foundText.bottom
        anchors.topMargin: 20
        anchors.left: foundText.left
        visible: true

        Text {
            width: 250
            text: qsTr("Create a folder on your USB thumb drive titled \"facility\" (case sensitive). Any JPG file in that folder can be uploaded here.") + application.emptyString
            font.pixelSize: 14
            wrapMode: Text.WordWrap
        }
    }

    ImageButton {
        id: clearButton
        visible: main.isTouch

        anchors.right: parent.right
        anchors.rightMargin: 50
        anchors.bottom: saveButton.top
        anchors.bottomMargin: 20

        label: qsTr("Clear") + application.emptyString
        label_color: "black"
        label_under: true
        label_y_offset: 10
        upimage:"../graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"../graphics/200/TRU_200_other_small_Button_Down.png"
        onClicked: root.doClearSlides()

    }

    FileIO {
        id: fileio
        onError: print("IO error: " + error)
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("use") +  " <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> " + qsTr("to navigate, use") + " <img src='../graphics/tft/arrow_left.png' /> <img src='../graphics/tft/arrow_right.png' /> " + qsTr("to change value") + application.emptyString
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }

    states: [
        State {
            name: "NoUsbState"
            PropertyChanges { target: insertUsbText; visible: true }
            PropertyChanges { target: foundText; visible: false }
            PropertyChanges { target: previewText; visible: false }
            PropertyChanges { target: previewSlideshow; visible: false }
            PropertyChanges { target: saveButton; visible: false }
        },

        State {
            name: "FoundUsbState"
            PropertyChanges { target: insertUsbText; visible: false }
            PropertyChanges { target: foundText; visible: true }
            PropertyChanges { target: previewText; visible: true }
            PropertyChanges { target: previewSlideshow; visible: true }
            PropertyChanges { target: saveButton; visible: main.isTouch }
        }
    ]

    transitions:  [
        Transition {
            from: "NoUsbState"
            to: "FoundUsbState"
        }
    ]
}
