/* @file workout_menus.js
    @brief Definitions of the workout program menu for all machine types.
*
*   Each menu_xxx array definition is a menu.  Each entry may be
*    either another menu by defining the "nextmenu" property, or
*   a workout program by definining the "program" property to the corresponding xml filename.
*/
var diagnosticsPageSummary = {label: QT_TRANSLATE_NOOP("Diagnostics", "Summary"),qmlSource:"DiagnosticsSummary.qml", hasControls:true }
var diagnosticsPageOptions = {label: QT_TRANSLATE_NOOP("Diagnostics", "Options"),qmlSource:"DiagnosticsOption.qml", hasControls:true }
var diagnosticsPageTimers = {label: QT_TRANSLATE_NOOP("Diagnostics", "Timers"),qmlSource:"DiagnosticsTimers.qml", hasControls:true }
var diagnosticsPageProgramStatistics = {label: QT_TRANSLATE_NOOP("Diagnostics", "Program Usage"),qmlSource:"DiagnosticsProgramStatistics.qml", hasControls:true }
var diagnosticsPageMiscStatistics = {label: QT_TRANSLATE_NOOP("Diagnostics", "Other Statistics"),qmlSource:"DiagnosticsMiscStatistics.qml", hasControls:true }
var diagnosticsPageStatistics = {label: QT_TRANSLATE_NOOP("Diagnostics", "Summary"),qmlSource:"DiagnosticsStatistics.qml", hasControls:true }
var diagnosticsPageDemo = {label: QT_TRANSLATE_NOOP("Diagnostics", "Demo"),qmlSource:"DiagnosticsSummary.qml", hasControls:true }
var diagnosticsPageProductSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "Product Setup"),qmlSource:"DiagnosticsSetup.qml", hasControls:true }
var diagnosticsPageClockSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "Clock"),qmlSource:"DiagnosticsClockSetup.qml", hasControls:true }
var diagnosticsPageSoftwareUpdate = {label: QT_TRANSLATE_NOOP("Diagnostics", "Software Update"),qmlSource:"DiagnosticsUpdate.qml", hasControls:true }
var diagnosticsPageNucleusUpdate = {label: QT_TRANSLATE_NOOP("Diagnostics", "Nucleus Update"),qmlSource:"DiagnosticsNucleusUpdate.qml", hasControls:true }
var diagnosticsPageNetworkSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "Network Setup"),qmlSource:"DiagnosticsNetwork.qml", hasControls:false }
var diagnosticsPageTVSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "TV Setup"),qmlSource:"DiagnosticsTVSetup.qml", hasControls:true }
var diagnosticsPageTVAdvanced = {label: QT_TRANSLATE_NOOP("Diagnostics", "TV Advanced"),qmlSource:"DiagnosticsTVAdvanced.qml", hasControls:true }
var diagnosticsPageTVRoot = {label: QT_TRANSLATE_NOOP("Diagnostics", "TV Setup"),qmlSource:"DiagnosticsTVRoot.qml", hasControls:true }
var diagnosticsPageTest = {label: QT_TRANSLATE_NOOP("Diagnostics", "Tests"),qmlSource:"DiagnosticsTests.qml", hasControls:true }
var diagnosticsPageTreadmillCalibrationTest = {label: QT_TRANSLATE_NOOP("Diagnostics", "Calibration"),qmlSource:"DiagnosticsTreadmillCalibration.qml", hasControls:true }
var diagnosticsPageStrideCalibration = {label: QT_TRANSLATE_NOOP("Diagnostics", "Calibration"),qmlSource:"DiagnosticsStrideEllipticalCalibration.qml", hasControls:true }
var diagnosticsPageErrorLog = {label: QT_TRANSLATE_NOOP("Diagnostics", "Fault Log"),qmlSource:"DiagnosticsError.qml", hasControls:true }
var diagnosticsPageNetpulse = {label: QT_TRANSLATE_NOOP("Diagnostics", "Netpulse"), qmlSource:"DiagnosticsNetpulse.qml", hasControls:false }
var diagnosticsPageTouchCal = {label: QT_TRANSLATE_NOOP("Diagnostics", "Touch Screen"), qmlSource:"DiagnosticsTouchCalibration.qml", hasControls:false  }
var diagnosticsPageDevelop = {label: QT_TRANSLATE_NOOP("Diagnostics", "Advanced"), qmlSource:"DiagnosticsDevelop.qml", hasControls:true  }
var diagnosticsPageSlidesSetup = {label: QT_TRANSLATE_NOOP("Diagnostics", "Screen Saver"), qmlSource: "DiagnosticsSlides.qml", hasControls:true  }
var diagnosticsPageFacility = {label: QT_TRANSLATE_NOOP("Diagnostics", "Facility Images"), qmlSource: "DiagnosticsFacility.qml", hasControls:true  }
var diagnosticsPageIPTV = {label: QT_TRANSLATE_NOOP("Diagnostics", "IP Television"), qmlSource: "DiagnosticsIPTV.qml", hasControls:true  }
var diagnosticsPageBluetooth = {label: QT_TRANSLATE_NOOP("Diagnostics", "Bluetooth"), qmlSource: "DiagnosticsBluetooth.qml" }
var diagnosticsPageCAB = {label: QT_TRANSLATE_NOOP("Diagnostics", "C.A.B. Setup"), qmlSource: "DiagnosticsCAB.qml", hasControls:true }
var diagnosticsPageStrideAdjust = {label: QT_TRANSLATE_NOOP("Diagnostics", "Stride Adjust"), qmlSource: "Diagnostics/DiagnosticsStrideAdjust.qml", hasControls: true }
// ===== Menus =====

var diagnosticsMenuUtilities = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: [
            diagnosticsPageProductSetup,
            diagnosticsPageClockSetup,
            diagnosticsPageSlidesSetup,
            diagnosticsPageFacility,
            diagnosticsPageTVRoot,
            diagnosticsPageTVAdvanced,
            diagnosticsPageNetworkSetup,
            diagnosticsPageCAB
        ],
        qmlSource:"DiagnosticsSetup.qml",
        hasControls: false
    }
}

var diagnosticsMenuUtilitiesStride = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: [
            diagnosticsPageProductSetup,
            diagnosticsPageStrideCalibration,
            diagnosticsPageClockSetup,
            diagnosticsPageSlidesSetup,
            diagnosticsPageFacility,
            diagnosticsPageTVRoot,
            diagnosticsPageTVAdvanced,
            diagnosticsPageNetworkSetup,
            diagnosticsPageCAB
        ],
        qmlSource:"DiagnosticsSetup.qml",
        hasControls: false
    }
}

var diagnosticsMenuUtilitiesStrideTft = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: [
            diagnosticsPageProductSetup,
            diagnosticsPageStrideCalibration,
            diagnosticsPageClockSetup,
            diagnosticsPageSlidesSetup,
            diagnosticsPageFacility,
            diagnosticsPageTVRoot,
            diagnosticsPageTVAdvanced,
            //            diagnosticsPageNetworkSetup,
            diagnosticsPageCAB
        ],
        qmlSource:"DiagnosticsSetup.qml",
        hasControls: false
    }
}

var diagnosticsMenuUtilitiesTft = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: [
            diagnosticsPageProductSetup,
            diagnosticsPageClockSetup,
            diagnosticsPageSlidesSetup,
            diagnosticsPageFacility,
            diagnosticsPageTVRoot,
            diagnosticsPageTVAdvanced,
            //            diagnosticsPageNetworkSetup,
            diagnosticsPageCAB
        ],
        qmlSource:"DiagnosticsSetup.qml",
        hasControls: false
    }
}

var diagnosticsMenuUtilitiesTread = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: [
            diagnosticsPageProductSetup,
            diagnosticsPageTreadmillCalibrationTest,
            diagnosticsPageClockSetup,
            diagnosticsPageSlidesSetup,
            diagnosticsPageFacility,
            diagnosticsPageTVRoot,
            diagnosticsPageTVAdvanced,
            diagnosticsPageNetworkSetup,
            diagnosticsPageCAB
        ],
        qmlSource:"DiagnosticsSetup.qml",
        hasControls: false
    }
}

var diagnosticsMenuUtilitiesTreadTft = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Setup..."),
        children: [
            diagnosticsPageProductSetup,
            diagnosticsPageTreadmillCalibrationTest,
            diagnosticsPageClockSetup,
            diagnosticsPageSlidesSetup,
            diagnosticsPageFacility,
            diagnosticsPageTVRoot,
            diagnosticsPageTVAdvanced,
            //            diagnosticsPageNetworkSetup,
            diagnosticsPageCAB
        ],
        qmlSource:"DiagnosticsSetup.qml",
        hasControls: false
    }
}

var diagnosticsMenuDiagnosticsTft  = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
        children: [
            diagnosticsPageTest,
            diagnosticsPageErrorLog,
            diagnosticsPageSoftwareUpdate,
            machineinfo.systemConfig === "NUCLEUS" || machineinfo.systemConfig === "NUCBOOT"  ? diagnosticsPageNucleusUpdate : null,
            diagnosticsPageDevelop
        ],
        qmlSource:"DiagnosticsTests.qml",
        hasControls: false
    }
}

var diagnosticsMenuDiagnostics = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
        children: [
            diagnosticsPageTest,
            diagnosticsPageErrorLog,
            diagnosticsPageSoftwareUpdate,            
            machineinfo.systemConfig === "NUCLEUS" || machineinfo.systemConfig === "NUCBOOT"  ? diagnosticsPageNucleusUpdate : null,
            diagnosticsPageTouchCal,
            diagnosticsPageDevelop,
            diagnosticsPageBluetooth
        ],
        qmlSource:"DiagnosticsTests.qml",
        hasControls: false
    }
}

var diagnosticsMenuDiagnosticsStride = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
        children: [
            diagnosticsPageTest,
            diagnosticsPageErrorLog,
            diagnosticsPageSoftwareUpdate,            
            machineinfo.systemConfig === "NUCLEUS" || machineinfo.systemConfig === "NUCBOOT"  ? diagnosticsPageNucleusUpdate : null,
            diagnosticsPageTouchCal,
            diagnosticsPageDevelop,
            diagnosticsPageBluetooth
        ],
        qmlSource:"DiagnosticsTests.qml",
        hasControls: false
    }
}

var diagnosticsMenuDiagnosticsStrideTft = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Diagnostics..."),
        children: [
            diagnosticsPageTest,
            diagnosticsPageErrorLog,
            diagnosticsPageSoftwareUpdate,
            machineinfo.systemConfig === "NUCLEUS" || machineinfo.systemConfig === "NUCBOOT"  ? diagnosticsPageNucleusUpdate : null,
            diagnosticsPageDevelop
        ],
        qmlSource:"DiagnosticsTests.qml",
        hasControls: false
    }
}

var diagnosticsMenuStatistics = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Statistics..."),
        children: [
            diagnosticsPageStatistics,
            diagnosticsPageProgramStatistics,
            diagnosticsPageMiscStatistics
        ],
        qmlSource: "DiagnosticsStatistics.qml",
        hasControls: false
    }
}

var diagnosticsMenuMain = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Main"),
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilities(),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(),
            diagnosticsMenuDiagnostics()
        ],
        qmlSource:"DiagnosticsSummary.qml",
        hasControls: false
    }
}

var diagnosticsMenuMainTft = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Main"),
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilitiesTft(),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(),
            diagnosticsMenuDiagnosticsTft()
        ],
        qmlSource:"DiagnosticsSummary.qml",
        hasControls: false
    }
}

var diagnosticsMenuMainTread = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Main"),
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilitiesTread(),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(),
            diagnosticsMenuDiagnostics()
        ],
        qmlSource:"DiagnosticsSummary.qml",
        hasControls: false
    }
}

var diagnosticsMenuMainStride = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Main"),
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilitiesStride(),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(),
            diagnosticsMenuDiagnosticsStride()
        ],
        qmlSource:"DiagnosticsSummary.qml",
        hasControls: false
    }
}

var diagnosticsMenuMainStrideTft = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Main"),
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilitiesStrideTft(),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(),
            diagnosticsMenuDiagnosticsStrideTft()
        ],
        qmlSource:"DiagnosticsSummary.qml",
        hasControls: false
    }
}

var diagnosticsMenuMainTreadTft = function() {
    return {
        label: QT_TRANSLATE_NOOP("Diagnostics", "Main"),
        children: [
            diagnosticsPageSummary,
            diagnosticsMenuUtilitiesTreadTft(),
            diagnosticsPageOptions,
            diagnosticsPageTimers,
            diagnosticsMenuStatistics(),
            diagnosticsMenuDiagnosticsTft()
        ],
        qmlSource:"DiagnosticsSummary.qml",
        hasControls: false
    }
}
