import QtQuick 2.4
import ".."
import ConfigurationData 1.0
import Components 1.0


Rectangle {
    id: root
    width: 1366
    height: 768
    anchors.fill: parent
    state: ""
    color: "transparent"

    property int topOffset: 130
    property int itemSpacing: 0
    property int menuItemWidth: 150
    property int menuItemHeight: 75
    property bool isSetupWizard: false
    property string keyDown: ""
    property bool isActive: (main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || isSetupWizard


    signal close()

    Connections {
        target: main.isTft && root.isActive && !goingToCalibrateMessage.visible && !calibratingMessage.visible ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideUp()
            root.keyDown = "up"
        }

        onUpButtonReleased: {
            main.debugKeys("upButtonReleased", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideStop()
            root.keyDown = ""
        }
        onDownButtonReleased: {
            main.debugKeys("downButtonReleased", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideStop()
            root.keyDown = ""
        }
        onStrideUpReleased: {
            main.debugKeys("inclineUpReleased", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideStop()
            root.keyDown = ""
        }
        onStrideDownReleased: {
            main.debugKeys("inclineDownReleased", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideStop()
            root.keyDown = ""
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideDown()
            root.keyDown = "down"
        }

        onStrideUpPressed: {
            main.debugKeys("inclineUpPressed", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideUp()
            root.keyDown = "up"
        }

        onStrideDownPressed: {
            main.debugKeys("inclineDownPressed", "DiagnosticsStrideEllipticalCalibration")
            machinecontrol.strideDown()
            root.keyDown = "down"
        }

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsStrideEllipticalCalibration")
            if (!isSetupWizard)
                diagnostics_screen.item.unselectScreen()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsStrideEllipticalCalibration")
            startCalibrationTimer.start()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsStrideEllipticalCalibration")
            if (isSetupWizard)
                setupWizard.changeState()
        }
    }

    Row{
        id: controlsArea
        spacing: 0
        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter

        Rectangle{

            height: 250
            width: 300
            color: "transparent"
        Column{
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            Text{
                id:modelString
                text: qsTr("Model: ") + application.emptyString + machineinfo.modelString
            }
            Text{
                text: qsTr("Maximum Stride Length: ") + application.emptyString + machineinfo.adjustableStrideEllipticalMaxStrideIn
            }
            Text{
                text: qsTr("Minimum Stride Length: ") + application.emptyString + machineinfo.adjustableStrideEllipticalMinStrideIn
            }
            Text{
                text: qsTr("Maximum Stride ADC: ") + application.emptyString + machineinfo.adjustableStrideEllipticalCalibratedStrideMaxAdc
            }
            Text{
                text: qsTr("Minimum Stride ADC: ") + application.emptyString + machineinfo.adjustableStrideEllipticalCalibratedStrideMinAdc
            }
        }
        }

        Item {
            id: tftStrideAdc
            visible: main.isTft
            height: 250
            width: 500

            Image {
                source: "../graphics/Arrow_Up_Button.png"
                anchors { bottom: strideAdcValue.top; bottomMargin: 10; horizontalCenter: strideAdcValue.horizontalCenter }
                visible: root.keyDown === "up"
            }

            Text {
                id: strideAdcValue
                text: qsTr("Stride ADC = ") + machinecontrol.strideLengthAdcActual + application.emptyString
                font { pixelSize: 40; bold: true }
                anchors.centerIn: parent
            }

            Image {
                source: "../graphics/Arrow_Down_Button.png"
                anchors { top: strideAdcValue.bottom; topMargin: 10; horizontalCenter: strideAdcValue.horizontalCenter }
                visible: root.keyDown === "down"
            }
        }

        Rectangle{
            id: strideControlPanel
            visible: main.isTouch
            color: "transparent"
            height: 250
            width: 300
            Column{
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                spacing: 20
                ImageButton{
                    id: strideUpButton
                    upimage: "../graphics/netpulse/UpArrow_blue.png"
                    downimage: "../graphics/netpulse/UpArrow_PRESSED.png"
                    onIsDownChanged: {
                        if(isDown) machinecontrol.strideUp()
                        else machinecontrol.strideStop()
                    }
                }
                Text{
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: machinecontrol.strideLengthAdcActual
                    font.pixelSize: 40
                    font.bold: true

                }

                ImageButton{
                    id: strideDownButton
                    upimage: "../graphics/netpulse/DownArrow_blue.png"
                    downimage: "../graphics/netpulse/DownArrow_PRESSED.png"
                    onIsDownChanged: {
                        if(isDown) machinecontrol.strideDown()
                        else machinecontrol.strideStop()
                    }
                }
            }

        }

        Item{
            visible: main.isTouch
            height: strideControlPanel.height
            width: 300
            ImageButton{
                id: calibrateButton
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                upimage: "../graphics/200/TRU_200_other_small_Button_Up.png"
                downimage: "../graphics/200/TRU_200_other_small_Button_Down.png"
                label: qsTr("CALIBRATE") + application.emptyString
                label_color: "black"
                label_under: true
                beep:false
                onIsDownChanged: if(isDown) startCalibrationTimer.start()
            }
        }

        MessagePopup{
            id:calibratingMessage
            message: "Calibrating..."
            dismissable: false
            Connections {
                target: machinecontrol
                onIsCalibratingChanged: {
                    if(isCalibrating) {
                        calibratingMessage.show()
                        calibratingMessage.message = qsTr("CALIBRATING...")+application.emptyString
                    }
                }
                onCalibrationComplete: {
                    if(result){
                        calibratingMessage.showMessage(qsTr("CALIBRATION SUCCESSFUL")+application.emptyString,4)
                        if (isSetupWizard)
                            bottomHelpText.text = qsTr("press") + ' <img src="../graphics/tft/arrow_right.png" /> ' + qsTr("to continue")
                    }
                    else
                       calibratingMessage.showMessage(qsTr("CALIBRATION FAILED")+application.emptyString,4)
                }
            }

        }
        MessagePopup{
            id:goingToCalibrateMessage
            dismissable: false

        }

        Timer{
            id: startCalibrationTimer
            interval: 1000
            repeat: true
            running: false

            property int counter: 3

            function updateGoingToCalibrateMessage(){
                goingToCalibrateMessage.message = qsTr("STARTING CALIBRATION IN ") +"<br>" + counter + application.emptyString
            }

            onRunningChanged: if(running) {
                                  buzzer.warningBeep()
                                  goingToCalibrateMessage.show();
                                  updateGoingToCalibrateMessage()
                              }
            onTriggered: {
                counter--;
                if(counter == 0){
                    counter = 3
                    startCalibrationTimer.stop()
                    machinecontrol.calibrationStart()
                    goingToCalibrateMessage.hide()
                }
                else
                {
                    buzzer.warningBeep()
                    updateGoingToCalibrateMessage();
                }
            }

        }

    }

    Text{
        id: dciInstructionText
        visible: main.isTouch && brainboard.eepromMachineTypeString === "CSA" ? true : false
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: controlsArea.top
        anchors.bottomMargin: 25
        width: 750
        height: 150
        wrapMode: Text.WordWrap
        text: "<b>" + qsTr("Calibrating the Stride Length:") + "</b><br>" + qsTr("Press the \"CALIBRATE\" button to calibrate machine") + application.emptyString
    }

    Text{
        id: tftInstructions
        visible: main.isTft
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: controlsArea.top
        anchors.bottomMargin: 25
        width: 750
        height: 150
        wrapMode: Text.WordWrap
        text: {
            var str = "<b>" + qsTr("Calibrating the Stride Length:") + "</b>"
            str += "<ul>"
            str += "<li>" + qsTr("Press ENTER to begin the stride length calibration") + "</li>"
            str += "<li>" + qsTr("Use the UP and DOWN arrow keys to adjust stride level") + "</li>"
            str += "</ul>"
            return str
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && root.isActive && !goingToCalibrateMessage.visible && !calibratingMessage.visible

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("press ENTER to begin calibration") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
