import QtQuick 2.4
import ".."
import Process 0.1
import Components 1.0

Item{
    id: root
    anchors.fill: parent

    property int fontSize: 24
    property int topOffset: -150
    property int itemSpacing: 5
    property int itemColumnSpacing: 50
    property bool isSetupWizard: false
    property bool showPkgList: false
    property string systemChecksum
    property string biosVersion

    property string cursorState: "softwareSum" // softwareSum, or reset

    Connections {
        id: keys1
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !root.showPkgList && !resetConfirmationPrompt.visible ? keymapper : null

        function nextState() {
            if (root.cursorState === "softwareSum") {
                root.cursorState = "reset"
            } else {
                root.cursorState = "softwareSum"
            }
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "DiagnosticsSummary")
            keys1.nextState()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "DiagnosticsSummary")
            keys1.nextState()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsSummary")

            if (cursorState === "reset") {
                resetConfirmationPrompt.show()
            } else {
                root.showPkgList = true
            }
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !root.showPkgList && !resetConfirmationPrompt.visible ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsSummary")

            diagnostics_screen.item.unselectScreen()
        }
    }

    Row{
        anchors.horizontalCenter: root.horizontalCenter ; anchors.horizontalCenterOffset: -width/6
        anchors.verticalCenter: root.verticalCenter ; anchors.verticalCenterOffset: -height / 4
        spacing: 40
        Column{
            id: labels
            width: 400
            spacing: itemSpacing

            Text{
                text: qsTr("Product Model") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("Serial Number") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }



            Text{
                text: qsTr("Tuner Type") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("Software Version") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("Firmware Version") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("Product Version") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("BIOS Version") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                visible: false // hide this for now to save screen space
                text: qsTr("Bootloader Version") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                text: qsTr("System Software Sum") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }

            Text{
                visible: brainboard.validLowerBoardString === "DCI" ? true : false
                text: qsTr("Motor Controller Version") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }
            Text{
                visible: brainboard.validLowerBoardString === "DCI" ? true : false
                text: qsTr("Smart Card Version") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignRight
            }
        }
        Column{
            id:values
            spacing: itemSpacing

            width: 400

            Text{
                text: (brainboard.enabled ? (machineinfo.modelString + " " + machineinfo.productTypeString) : qsTr("not detected") ) + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: main.serialNumber
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }


            Text{
                text: tv.tunerType ? tv.tunerType : qsTr("Not Installed") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: application.appVersion
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: brainboard.enabled ? machineinfo.brainboardFirmwareVersion : qsTr("not detected") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: main.productVersion
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: root.biosVersion
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                text: root.systemChecksum
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft

                MouseArea {
                    anchors.fill: parent
                    onClicked: root.showPkgList = true
                }
                BorderImage {
                    id: selectionCursor
                    visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "softwareSum"
                    border { left: 70; top: 5; bottom: 5; right: 70 }
                    anchors { left: parent.left; leftMargin: -35; verticalCenter: parent.verticalCenter }
                    source: "../graphics/tft/maintenance_menus_cursor.png"
                    width: 640
                    height: 56
                    horizontalTileMode: BorderImage.Stretch
                }
            }

            Text{
                visible: brainboard.validLowerBoardString === "DCI" ? true : false
                text: brainboard.enabled ? brainboard.motorControllerModelString+" "+brainboard.motorControllerVersionString : qsTr("not detected") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }

            Text{
                visible: brainboard.validLowerBoardString === "DCI" ? true : false
                text: brainboard.enabled ? brainboard.smartCardModelString+" "+brainboard.smartCardVersionString : qsTr("not detected") + application.emptyString
                font.pointSize: fontSize
                width: 400
                horizontalAlignment: Text.AlignLeft
            }
        }
    }

    ImageButton{
        id: factoryResetButton

        wrapWidth: 300
        visible: !root.isSetupWizard

        anchors.right: root.right ; anchors.rightMargin: 10
        anchors.bottom: root.bottom ; anchors.bottomMargin: 80

        upimage:"../graphics/200/TRU_200_other_small_Button_Up.png"
        downimage:"../graphics/200/TRU_200_other_small_Button_Down.png"

        label: qsTr("RESET FACTORY DEFAULTS") + application.emptyString
        label_under: true
        label_y_offset: 5
        label_color: "black"

        onClicked: {
            resetConfirmationPrompt.show()
        }
    }

    Image {
        source: "../graphics/tft/NAV_selector_2.png"
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState === "reset"
        anchors.verticalCenter: factoryResetButton.verticalCenter
        anchors.right: parent.right
        anchors.rightMargin: 130
        z: factoryResetButton.z - 1
    }

    ConfirmationPrompt {
        id: resetConfirmationPrompt
        x: 300 ; y: 300
        visible: false
        prompt: qsTr("Are you sure?\nALL setup will be cleared.") + application.emptyString

        onYesClicked: {
            statisticManager.resetAll();
            errorManager.clearAllError()
            brainboard.clearEEPROM()
            options.resetToDefaults()
            tv.channelList.clearChannels()
            workoutStats.clearAll()
            slidesFileManager.deleteCurrentSlides()
            facilitySlidesManager.deleteCurrentSlides()
            resetEthernet.start()
            main.restartRequired = true
            syncDisk.start()
            hide()
        }

        onNoClicked: {
            hide()
        }
    }

    Process {
        id: resetEthernet

        onFinished: { dataExport.getNetworkAddresses() }

        program: "scripts/configure_network.sh"
        arguments: ["p2p1"]
    }

    SlidesFileManager {
        id: slidesFileManager
    }

    SlidesFileManager {
        id: facilitySlidesManager
        slidesDestination: "/data/facility/user"
    }

    Loader {
        id: packagelistView
        x: 200
        y: -20
        source: root.showPkgList ? "PackageListView.qml" : ""

        Connections {
            target: packagelistView.item
            ignoreUnknownSignals: true
            onClose: {
                print("close pkg view")
                root.showPkgList = false
            }
        }
    }

    Process {
        id: getSystemChecksumProcess
        Component.onCompleted: start()
        program: "bash"
        arguments: [ "scripts/list_installed_packages.sh", "-s" ]
        onReadyReadStandardOutput: {
            root.systemChecksum = readAllStandardOutput()
            root.systemChecksum = root.systemChecksum.trim()
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !resetConfirmationPrompt.visible

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            if (root.showPkgList)
                return qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, press BACK to close") + application.emptyString
            else
                return qsTr("press ENTER to select") + application.emptyString
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Process {
        id: getBiosVerProcess

        Component.onCompleted: start()
        program: "sudo"
        arguments: ["cat", "/sys/class/dmi/id/bios_version"]
        onReadyReadStandardOutput: {
            var version = String(readAllStandardOutput())
            root.biosVersion = version.trim()
            print("Bios Version: " + root.biosVersion)
        }
    }

}
