
import QtQuick 2.4
import Process 0.1
import "."
import "../Television"
import ".."
import FileIO 1.0
import Components 1.0

Item {
    id: root
    property QtObject filteredCountryList
    property bool isUsbDeviceLoaded: storageMgr.usbDeviceLoaded
    property string tuner_id: tv.tunerType
//    property string tuner_id: "DVB"
    property variant scanner: dvbscan
    property bool isSetupWizard: false
    property bool isActive: (main.state === "DiagnosticState" && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0) || root.isSetupWizard
    property string cursorState: "setup" // setup or next

    anchors.fill: parent
    width: 1166
    height: 568

    Connections {
        target: root.isActive && !setupScanDialog.visible && !root.scanner.scanning && !countryListPopup.visible ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsTVSetup")
            diagnostics_screen.item.unselectScreen()
        }
    }

    function doSave() {
        // take the channels in scanChannelList and dump them to tv.channelList
        tv.channelList.channels.clear()
        for(var i=0 ; i < scanChannelList.channels.count ; i++) {
            var item = scanChannelList.channels.get(i)
            var words = String(item.name).split(" ")
            if(words[0] === "service_id"){
                //console.log("channel name=" + item.name)
                //console.log("service string" + words[1])
                words[0]="Service "
                item.name=words.join(" ")
                //console.log("new name is:" + item.name)
            }

            tv.channelList.addChannel(item)
        }
        tv.channelList.saveChannels(tv.channelFile)
        tv.channelList.readChannels(tv.channelFile)
        syncDisk.start()
    }

    function startScan() {
        if(digitalButton.isDown) {
            var tunerType = root.getTunerType(countryListPopup.selectedData.tuner, cableAntToggle.value)
            dvbScanStart(countryListPopup.selectedData.code, tunerType, cableAntToggle.value)
            // digital will fire analog after it completes, if it also checked
        }
        else if(analogButton.isDown) {
            analogScanStart(countryListPopup.selectedData.code, cableAntToggle.value, analogSelector.selectedData.value)
        }
        scanningDialog.show()
    }

    Component.onCompleted: {
        if(!tuner_id) {
            print("no tuner installed")
            noTuner.showWithTimeout(10)
        }
        print("tuner type:" + tuner_id)

        if(tuner_id == "DVB") {
            cableAntToggle.value = false
            print("tuner type is " + tuner_id + ".  Hiding cable option.")
        }

        // get current channel list from TV element
        for(var i=0 ; i < tv.channelList.channels.count ; i++) {
            var item = tv.channelList.channels.get(i)
            scanChannelList.addChannel(item)
        }
    }

    onTuner_idChanged: {
        filterCountries(tuner_id)
        // force re-selection of analog standard
        countryListPopup.currentIndexChanged()
    }

    // We are using a universal tuner, so compute a string representing the
    // "tuner type" used and store it
    function getTunerType(tunerType, isCable) {
        if (root.tuner_id === "DVB-T2") {
            return isCable ? "DVB-C" : "DVB-T2"
        }

        if (tunerType === "ATSC") {
            return isCable ? "QAM" : "ATSC"
        } else if (tunerType === "DVB") {
            return isCable ? "DVB-C" : "DVB-T"
        } else if (tunerType === "ISDB") {
            return "ISDB-T"
        } else if (tunerType === "DMB") {
            return "DTMB"
        }

        return "ATSC"
    }

    function dvbScanStart(countryCode, tunerType, isCable) {
        tv.player.stop()
        if (root.tuner_id === "DVB-C") {
            // force frontend mode switch for multi-standard tuner
            setDelsys.arguments = ["/dev/dvb/adapter0/frontend0", isCable ? "1" : "3"]
            setDelsys.start()
            setDelsys.waitForFinished(5000);
        }
        root.scanner = dvbscan
        dvbscan.tunerType = tunerType
        dvbscan.startScan(countryCode, isCable)
    }

    function analogScanStart(countryCode, isCable, norm) {
        tv.stop()
        root.scanner = analogScanner
        analogScanner.startScan(countryCode, isCable, norm)
    }

    function stopScan() {
        root.scanner.stopScan()
        scanningDialog.hide()
    }

    function filterCountries(tuner) {
        if (tuner === "DVB-C" || tuner === "DVB-T2") {
            tuner = "DVB"
        }

        var newModel = tv_country_codes
        if (tuner === "MGT") {
            // No filtering for MGT
        } else {
            for( var i = tv_country_codes.count-1 ; i >= 0 ; i--) {
                if ( newModel.get(i).tuner != tuner ) {
                    newModel.remove(i)
                }
            }
        }
        root.filteredCountryList = newModel
        countryListPopup.model = newModel
    }

    Process {
        id: setDelsys
        program: "scripts/set_delsys"
        onReadyReadStandardError: {
            var outp = String(setDelsys.readAllStandardError())
            console.log("Output from setDelsys:", outp)
        }
    }

    Row {
        id: iptvConfigRow
        anchors { left: channelListBox.left; bottom: channelListBox.top; bottomMargin: 20 }
        visible: main.isTouch
        height: 50
        spacing: 40

        Text {
            id:iptvModeText
            font { pointSize: 16 }
            text: qsTr("IPTV")
        }
        ToggleButton {
            id: iptvToggle

            pos0image: "../graphics/tft/maintenance_toggle.png"
            pos0image_disabled: "../graphics/tft/maintenance_toggle_GRAYED.png"
            pos1image: "../graphics/maintenance_toggle_OFF_gray.png"
            pos1image_disabled: "../graphics/maintenance_toggle_OFF_gray.png"
            labelcolor: "black"
            pos1label: ""
            pos0label: ""
            posFont { pixelSize: 18; bold: true }
            value: options.iptvEnabled
            onValueChanged: {
                options.iptvEnabled = value
            }
            Component.onCompleted: value = options.iptvEnabled

            enabled: true
        }
    }

    Rectangle {
        id: channelListBox

        color: "lightgray"
        width: 725
        height: 460
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -mode.width/2
        anchors.top: rightControlArea.top

        Item {
            id: dataArrows

            width: 40
            height: parent.height

            anchors { top: parent.top; right: parent.right ; rightMargin: Qt.application.layoutDirection === Qt.RightToLeft ? -20 : -5 }
            Image {
                id: dataUpArrow
                visible: !channelList.atYBeginning
                source: "../graphics/Swipe_Arrows_Left.png"
                rotation: 90
                anchors { top: parent.top; topMargin: 35; right: parent.right }
            }
            Image {
                id: dataDownArrow
                visible: !channelList.atYEnd
                source: "../graphics/Swipe_Arrows_Right.png"
                rotation: 90
                anchors { bottom: parent.bottom; bottomMargin: 35; right: parent.right }
            }
        }

        GridView {
            id: channelList

            property int imageClickIndex

            clip: true
            anchors.fill: parent
            anchors {
                leftMargin: 30
                topMargin: 10
                bottomMargin: 5
                rightMargin: 5
            }
            model: scanChannelList.channels
            cellWidth: 160
            cellHeight: 150

            delegate: Component {
                Item {
                    width: 160; height: 150
                    Item {
                        width: 110; height: 135
                        anchors { left: parent.left; top: parent.top }

                        Rectangle{
                            id: iconBg
                            color: "white"
                            height: 110; width: 110

                            Image {
                                id: iconImage
                                anchors.horizontalCenter: parent.horizontalCenter
                                anchors.top: parent.top
                                source: icon ? "/netpulse/www/images/channelIcons/" + icon : "/netpulse/www/images/channelIcons/tv_default.png"
//                                MouseArea {
//                                    anchors.fill: parent
//                                    onClicked: {
//                                        channelList.imageClickIndex = index
//                                        iconSelector.show()
//                                    }
//                                }
                            }
                        }

                        Text {
                            text: {
                                if (number && name && number != name) {
                                    return Globals.truncate(name, 23) + " " + number
                                } else if (name) {
                                    return Globals.truncate(name, 26)
                                } else if (number) {
                                    return number
                                } else {
                                    return ""
                                }
                            }
                            font.bold: true
                            font.pointSize: 12
                            anchors { horizontalCenter: iconBg.horizontalCenter; top: iconBg.bottom; topMargin: 0 }
                            verticalAlignment: Text.AlignVCenter
                            width: 110
                            horizontalAlignment: Text.AlignHCenter
                            lineHeight: 0.85
                            wrapMode: Text.WrapAnywhere
                        }
                    }
                }
            }
        }
    }

    Text {
        id: instructionalText
        text: qsTr("NOTE: If you are having trouble receiving channels after scanning, or having issues with channel clarity after confirming good connections to this machine, please contact your TV provider to ensure proper scan settings and signal strength.") + application.emptyString
        width: channelListBox.width
        wrapMode: Text.WordWrap
        anchors.left: channelListBox.left
        anchors.top: channelListBox.bottom
        anchors.topMargin: 5
        font { pixelSize: 18; bold: true }
    }

    Rectangle {
        id: rightControlArea

        width: 280
        height: 460
        color: "#7f8082"
        anchors { left: channelListBox.right; top: parent.top; topMargin: 98 }
    }

    ListView{
        id: mode
        anchors {
            top: rightControlArea.top; topMargin: -150
            left: rightControlArea.left
        }
        width: 280
        height: 700
        spacing: 5
        z: 100
        model: controlList.model
        snapMode: ListView.SnapToItem
        interactive: false
        highlightRangeMode: ListView.ApplyRange
        preferredHighlightBegin: height/2 - 30
        preferredHighlightEnd: height/2 + 30
        highlightMoveVelocity: 10000
        currentIndex: controlList.curIndex
        highlight: Component {
            BorderImage {
                id: selectionCursor
                visible: main.isTft && controlList.listening
                border { left: 70; top: 5; bottom: 5; right: 70 }
                source: "../graphics/tft/maintenance_menus_cursor2.png"
                width: mode.currentItem ? mode.currentItem.navCursorWidth : 0
                height: 71
                horizontalTileMode: BorderImage.Stretch
            }
        }
    }

    MessagePopup {
        id: noTuner
        message: qsTr("No Tuner Installed.") + application.emptyString
        dismissable: true
    }

    Connections {
        target: root.scanner
        onScanComplete: {
            print("channel scanning complete.")
            for(var i=0 ; i < root.scanner.channels.count ; i++)
                scanChannelList.addChannel(root.scanner.channels.get(i))

            if (root.scanner.scanType === "digital" && analogButton.isDown && !root.scanner.aborted) {
                analogScanStart(countryListPopup.selectedData.code, cableAntToggle.value, analogSelector.selectedData.value)
            } else {
                scanningDialog.hide()
            }

            scanChannelList.filterDuplicatePrograms()

            root.doSave()
        }
    }

    Connections {
        target: main.isTft && root.visible && root.isActive && root.cursorState === "next" ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsTVSetup")
            controlList.curIndex = controlList.findLastValidIndex()
            cursorState = "setup"
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsTVSetup")
            controlList.curIndex = controlList.findFirstValidIndex()
            cursorState = "setup"
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsTVSetup")
            setupWizard.changeState()
        }
    }

    KeyedControlList {
        id: controlList
        listening: main.isTft && root.visible && root.isActive && !setupScanDialog.visible && !root.scanner.scanning && !countryListPopup.visible && root.cursorState === "setup"
        listView: mode
        width: mode.width
        curIndex: 4

        edgeBehavior: isSetupWizard ? "emit" : "wrap"
        onFirstExited: root.cursorState = "next"
        onLastExited: root.cursorState = "next"

        InlineButton {
            id: importButton

            enabled: root.isUsbDeviceLoaded && fileio.exists("/media/usb/tv_conf.xml")
            label: qsTr("Import Scan from USB") + application.emptyString
            showImage: true
            width: 180
            labelWidth: 130
            height: 71
            navCursorWidth: mode.width+20
            font { pixelSize: 18; bold: true }

            onPressed: {
                scanChannelList.channels.clear()

                // this call is asynchronous - channels are added in the onLoadComplete callback
                externalChanList.readChannels("/media/usb/tv_conf.xml")
            }
        }

        InlineButton {
            id: exportButton

            enabled: channelList.count > 0 && root.isUsbDeviceLoaded
            label: qsTr("Export Scan to USB") + application.emptyString
            showImage: true
            width: 180
            labelWidth: 130
            height: 71
            navCursorWidth: mode.width+20
            font { pixelSize: 18; bold: true }

            onPressed: {
                scanChannelList.saveChannels("/media/usb/tv_conf.xml")

                exportSuccess.showWithTimeout(1)
            }
        }

        InlineButton {
            id: importNetworkButton

            visible: main.isTouch && main.netpulseAvailable
            label: qsTr("Import from Network") + application.emptyString
            showImage: true
            width: 200
            labelWidth: 130
            height: visible ? 71 : 0
            navCursorWidth: mode.width+20
            font { pixelSize: 18; bold: true }

            onPressed: {
                downloadNetpulseTv.start()
            }
        }

        InlineButton {
            id: exportNetworkButton

            visible: main.isTouch && main.netpulseAvailable
            label: qsTr("Export to Network") + application.emptyString
            showImage: true
            width: 200
            labelWidth: 130
            height: visible ? 71 : 0
            navCursorWidth: mode.width+20
            font { pixelSize: 18; bold: true }

            onPressed: {
                uploadNetpulseTv.start()
            }
        }

        InlineButton {
            id: startScan

            enabled: digitalButton.isDown || analogButton.isDown
            label: qsTr("Begin Channel Scan") + application.emptyString
            showImage: true
            width: 200
            labelWidth: 130
            height: 71
            navCursorWidth: mode.width+20
            font { pixelSize: 18; bold: true }

            onPressed: {
                setupScanDialog.show()
            }
        }
    }

    // When scan is complete, show how many services were found.
    Text {
        id: channelsFoundText
        text: {
            if (root.scanner.scanning)
                return ""
            else if (channelList.count > 0)
                return qsTr("Number of Channels:") + " " + channelList.count + application.emptyString
            else
                return qsTr("No Channels Configured") + application.emptyString
        }
        anchors.bottom: channelListBox.top
        anchors.bottomMargin: 7
        anchors.left: channelListBox.left
        font { pixelSize: 18; bold: true }
    }

    Process {
        id: uploadNetpulseTv
        program: "scripts/upload_netpulse.sh"
        onReadyReadStandardError: {
            var data = uploadNetpulseTv.readAllStandardError()
            console.log("upload netpulse stderr:", data)
        }
        onReadyReadStandardOutput: {
            var data = uploadNetpulseTv.readAllStandardOutput()
            console.log("upload netpulse stdout:", data)
        }
        onFinished: {
            exportNetworkMessage.showWithTimeout(1)
        }
    }

    MessagePopup {
        id: exportNetworkMessage
        message: qsTr("Exported to Network") + application.emptyString
        dismissable: false
    }

    Process {
        id: downloadNetpulseTv
        program: "scripts/download_netpulse.sh"
        onReadyReadStandardError: {
            var data = downloadNetpulseTv.readAllStandardError()
            console.log("download netpulse stderr:", data)
        }
        onReadyReadStandardOutput: {
            var data = downloadNetpulseTv.readAllStandardOutput()
            console.log("download netpulse stdout:", data)
        }
        onFinished: {
            scanChannelList.channels.clear()
            // this call is asynchronous - channels are added in the onLoadComplete callback
            externalChanList.readChannels("/data/tv_conf.xml")
        }
    }

    ModalDialog {
        id: setupScanDialog
        dismissable: true

        onDismissed: {
            setupScanDialog.hide()
        }

        onVisibleChanged: {
            if (!visible)
                countryListPopup.close()
        }

        BorderImage {   // pop-up dialog background
            id: border2

            x: 332
            y: 101
            width: 800
            height: 650
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }
            ImageButton {
                id: close_button2
                visible: main.isTouch

                z: 200

                width: 36
                height: 36
                anchors {   right: parent.right ; rightMargin: 100 ;
                    top: parent.top ; topMargin: 40
                }
                upimage: "../Keypad/KeyPad_X_Large.png"
                downimage: "../Keypad/KeyPad_X_Large.png"

                onClicked: setupScanDialog.hide()
                mouseAreaScale: 2.0

            }
            Text {
                id: scanHeader
                width: 501
                height: 99
                color: "#ffffff"
                text: qsTr("Channel Scan") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40
            }

            ListView{
                id: scanControls
                anchors {
                    top: scanHeader.bottom
                    topMargin: -20
                    horizontalCenter: parent.horizontalCenter
                }
                width: 280
                height: 700
                spacing: 5
                z: 100
                model: tvSetupControlList.model
                snapMode: ListView.SnapToItem
                interactive: false
                highlightRangeMode: ListView.ApplyRange
                preferredHighlightBegin: height/2 - 30
                preferredHighlightEnd: height/2 + 30
                highlightMoveVelocity: 10000
                currentIndex: tvSetupControlList.curIndex
                onVisibleChanged: if (visible) tvSetupControlList.curIndex = 0
                highlight: Component {
                    BorderImage {
                        id: selectionCursor
                        visible: main.isTft && tvSetupControlList.listening
                        border { left: 70; top: 5; bottom: 5; right: 70 }
                        source: "../graphics/tft/maintenance_menus_cursor2.png"
                        width: scanControls.currentItem ? scanControls.currentItem.navCursorWidth : 0
                        height: 71
                        horizontalTileMode: BorderImage.Stretch
                    }
                }
            }
            KeyedControlList {
                id: tvSetupControlList
                listening: main.isTft && setupScanDialog.visible && root.isActive && !root.scanner.scanning && !countryListPopup.visible && root.cursorState === "setup"
                listView: scanControls
                width: scanControls.width
                curIndex: 0

                edgeBehavior: "wrap"
                Item {
                    id: analogItem
                    height: 71
                    width: scanControls.width
                    x: 30

                    // attributes needed to be used in a KeyedControlList
                    property bool selected: false
                    property int navCursorWidth: analogItem.width+20
                    function leftPressed() { analogButton.setDown(! analogButton.isDown) }
                    function rightPressed() { analogButton.setDown(! analogButton.isDown) }
                    function enterPressed() { analogButton.setDown(! analogButton.isDown) }
                    ImageButton {
                        id: analogButton

                        enabled: true

                        //                label: qsTr("Analog") + application.emptyString
                        //                label_color: "black"
                        //                label_under: true
                        toggle: true

                        upimage: "../graphics/205/SM_Button_Up.png"
                        downimage: upimage
                        icon: isDown ? "../graphics/205/IPOD_Checkmark.png" : ""
                    }
                    Text{
                        id: analogLabel
                        text: qsTr("Analog") + application.emptyString
                        anchors.left: analogButton.right
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: -8
                        color: "black"
                        font { pixelSize: 18; bold: true }
                    }
                }

                Item {
                    id: digitalItem
                    height: 71
                    width: scanControls.width
                    x: 30

                    // attributes needed to be used in a KeyedControlList
                    property bool selected: false
                    property int navCursorWidth: digitalItem.width+20
                    function leftPressed() { digitalButton.setDown(! digitalButton.isDown) }
                    function rightPressed() { digitalButton.setDown(! digitalButton.isDown) }
                    function enterPressed() { digitalButton.setDown(! digitalButton.isDown) }

                    ImageButton {
                        id: digitalButton

                        enabled: true
                        isDown: true
                        //                label: qsTr("Digital") + application.emptyString
                        //                label_color: "black"
                        //                label_under: true
                        toggle: true

                        upimage: "../graphics/205/SM_Button_Up.png"
                        downimage: upimage
                        icon: isDown ? "../graphics/205/IPOD_Checkmark.png" : ""
                    }

                    Text{
                        id: digitalLabel
                        text: qsTr("Digital") + application.emptyString
                        anchors.left: digitalButton.right
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: -8
                        color: "black"
                        font { pixelSize: 18; bold: true }
                    }
                }

                Item {
                    id: normSelection
                    height: visible ? 71 : 0
                    width: scanControls.width
                    x: 45
                    visible: analogButton.isDown
                    z:1000

                    // attributes needed to be used in a KeyedControlList
                    property bool selected: false
                    property int navCursorWidth: normSelection.width+20
                    function leftPressed() {}
                    function rightPressed() {}
                    function enterPressed() {}

                    //            Text{
                    //                id: normSelectionLabel
                    //                text: qsTr("Analog Standard") + application.emptyString
                    //                anchors.left: parent.left
                    //                anchors.verticalCenter: parent.verticalCenter
                    //                anchors.verticalCenterOffset: -8
                    //                color: "black"
                    //            }
                    ListModel {
                        id: analogCodes

                        ListElement { label: "NTSC-M"; value: "NTSC-M" }
                        ListElement { label: "NTSC"; value: "NTSC" }
                        ListElement { label: "PAL-BG"; value: "PAL-BG" }
                        ListElement { label: "PAL-DK"; value: "PAL-DK" }
                        ListElement { label: "PAL-I"; value: "PAL-I" }
                        ListElement { label: "PAL-N"; value: "PAL-N" }
                        ListElement { label: "SECAM-L"; value: "SECAM-L" }
                        ListElement { label: "SECAM-B"; value: "SECAM-B" }
                        ListElement { label: "SECAM-DK"; value: "SECAM-DK" }
                    }


                    ComboBox {
                        id: analogSelector

                        listenKeys: main.isTft && normSelection.selected

                        comboHeight: 40
                        itemHeight: 35
                        width: 200; height: 40
                        model: analogCodes
                        anchors.verticalCenter: parent.verticalCenter
                    }
                }

                ToggleButtonLabeled {
                    id: cableAntToggle

                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: -40
                    pos0label: qsTr("Antenna") + application.emptyString
                    pos1label: qsTr("Cable") + application.emptyString
                    pos0image: "../graphics/tft/maintenance_toggle.png"
                    pos0image_disabled: "../graphics/tft/maintenance_toggle_GRAYED.png"
                    pos1image: "../graphics/tft/maintenance_toggle_OFF.png"
                    pos1image_disabled: "../graphics/tft/maintenance_toggle_OFF_GRAYED.png"
                    labelcolor: "black"
                    highlightcolor: "black"
                    posFont { pixelSize: 18; bold: true }
                    value: true // Set default to Cable
                    navCursorWidth: scanControls.width+20
                    enabled: root.tuner_id !== "DVB" || !digitalButton.isDown
                    disabled: !enabled

                    Connections {
                        target: digitalButton
                        onIsDownChanged: if(digitalButton.isDown && (tuner_id == "DVB")) {
                                             cableAntToggle.value = false
                                         }
                    }
                }

                Item {
                    id: countrySelect
                    width: scanControls.width
                    height: 71

                    // properties needed to be used in a KeyedControlList
                    property int navCursorWidth: scanControls.width+20
                    property bool selected: false
                    function enterPressed() { countryListPopup.visible = true }
                    function leftPressed() { countryListPopup.decrementCurrentIndex() }
                    function rightPressed() { countryListPopup.incrementCurrentIndex() }

                    Rectangle {
                        color: "#5f6062"
                        radius: 10
                        width: parent.width - 35
                        height: 30
                        x: 25
                        anchors.verticalCenter: parent.verticalCenter
                        Text {
                            id: countryValue
                            text: countryListPopup.selectedData ? qsTranslate("TelevisionRegionList", countryListPopup.selectedData.label) + application.emptyString : ""
                            anchors.left: parent.left
                            anchors.leftMargin: 15
                            anchors.verticalCenter: parent.verticalCenter
                            font.bold: true
                        }
                        MouseArea {
                            anchors.fill: parent
                            onClicked: {
                                countryListPopup.visible = true
                            }
                        }
                    }

                }
                InlineButton {
                    id: beginScanButton

                    enabled: digitalButton.isDown || analogButton.isDown
                    label: qsTr("Begin Channel Scan") + application.emptyString
                    showImage: true
                    width: 200
                    labelWidth: 130
                    height: 71
                    navCursorWidth: mode.width+20
                    font { pixelSize: 18; bold: true }

                    onPressed: {
                        setupScanDialog.hide()
                        root.startScan()
                    }
                }
            }

            Text {
                visible: main.isTft
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 40
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -10
                color: "#ffffff"
                font { bold: true; pixelSize: 24 }
                text: qsTr("press BACK to abort") + application.emptyString
            }

            CountryListPopup {
                id: countryListPopup
                model: filteredCountryList
                modelTranslationContext: "TelevisionRegionList"
                anchors {
                    right: parent.right
                    top: parent.top
                    topMargin: -20
                }
                onCurrentIndexChanged: {
                    // autoselect analog norm matching the selected country
                    var val = selectedData.norm
                    for (var i = 0; i < analogCodes.count; i++) {
                        if (analogCodes.get(i).value === val) {
                            analogSelector.currentIndex = i
                            break
                        }
                    }
                }
            }

        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }
    ModalDialog {
        id: scanningDialog
        dismissable: true

        onDismissed: {
            root.stopScan()
        }

        BorderImage {   // pop-up dialog background
            id: border

            x: 332
            y: 161
            width: 800
            height: 390
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }
            Text {
                id: warningText
                width: 501
                height: 99
                color: "#ffffff"
                text: qsTr("Scanning in progress") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40
            }

            Rectangle {
                id: progressBar

                property real progress: root.scanner.progress

                x: 240
                y: 125
                visible: root.scanner.scanning
                width: 300
                height: 40
                radius: 5

                color: "transparent"
                border.color: "black"
                border.width: 3

                Text {
                    id: scanTypeText
                    anchors.bottom: progressBar.top; anchors.bottomMargin: 5
                    visible: root.scanner.scanning
                    text: qsTr("Scanning ") + (root.scanner.scanType === "digital" ? qsTr("digital") : qsTr("analog")) + "..." + application.emptyString
                }

                Rectangle {
                    anchors {left: parent.left; top: parent.top ; bottom: parent.bottom }
                    radius: 5
                    color: "steelblue"
                    width: progressBar.progress * parent.width
                    height: parent.height
                }

                Text {
                    text: (100 * progressBar.progress | 0) + "%"
                    anchors.fill: parent
                    horizontalAlignment: Text.AlignHCenter
                    verticalAlignment: Text.AlignVCenter
                }
            }

            // while scanning show how many frequencies are tuned
            Text {
                id: frequenciesFoundText
                x: 240
                y: 175
                visible: root.scanner.scanning
                text: qsTr("Frequencies Found: ") + (dvbscan.signalsFound + analogScanner.signalsFound) + application.emptyString
            }

            Text {
                id: currentScanText
                x: 240
                y: 170
                anchors.top: frequenciesFoundText.bottom
                anchors.topMargin: 10
                visible: root.scanner.scanning
                text: qsTr("Scanning Frequency: ") + root.scanner.scanFreq + application.emptyString
            }

            TransientText {
                id: foundChannelText
                x: 240
                y: 190
                anchors.top: currentScanText.bottom
                anchors.topMargin: 10
                Connections {
                    target: root.scanner
                    onChannelFound: {
                        if (chandata.name) {
                            foundChannelText.setText("Found " + chandata.name)
                        }
                    }
                }
            }

            Text {
                visible: main.isTft
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 40
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -10
                color: "#ffffff"
                font { bold: true; pixelSize: 24 }
                text: qsTr("press BACK to abort") + application.emptyString
            }

            ImageButton {
                id: stopScanButton

                visible: root.scanner.scanning && main.isTouch
                anchors {
                    bottom: parent.bottom
                    bottomMargin: 40
                    horizontalCenter: parent.horizontalCenter
                }
                label: qsTr("Stop Scan") + application.emptyString
                label_color: "black"
                label_under: true
                upimage: "../graphics/205/Lrg_Button_Up.png"
                downimage: "../graphics/205/Lrg_Button_Down.png"

                onClicked: {
                    root.stopScan()
                }
            }
        }
        Component.onCompleted: hide()
        onTimedOut: hide()
    }

    TelevisionRegionList {
        id: tv_country_codes
    }

    TelevisionScanDVB {
        id: dvbscan
        tunerType: "ATSC"
//        useMock: true
    }

    TelevisionScanAnalog {
        id: analogScanner
//        useMock: true
    }

    MessagePopup {
        id: importSuccess
        message: qsTr("Channel List Loaded") + application.emptyString
        dismissable: false
    }

    MessagePopup {
        id: exportSuccess
        message: qsTr("Channel List Saved to Device") + application.emptyString
        dismissable: false
    }

    ChannelList {
        id: externalChanList

        onLoadComplete: {
            if (externalChanList.channels.count > 0) {
                for (var i = 0; i < externalChanList.channels.count; i++) {
                    var item = externalChanList.channels.get(i)
                    scanChannelList.addChannel(item)
                }

                importSuccess.showWithTimeout(1)
                root.doSave() //Save channels after importing
            }
        }
    }

    ChannelList {
        id: scanChannelList
    }

    FileIO {
        id: fileio
    }

    ImageButton { id: nextButton
        downimage: "../graphics/setup/Start_Button_Down.png"
        upimage: "../graphics/setup/Start_Button.png"

        // TFT items are responsible for adding their own next button
        visible: root.isSetupWizard && main.isTft
        label: qsTr("NEXT") + application.emptyString
        label_color: "black"
        label_under: true
        fontsize: 18

        anchors {
            bottom: parent.bottom ; bottomMargin: 25
            right: parent.right ; rightMargin: 46
        }

        onClicked: {
            setupWizard.changeState()
        }
    }

    Image {
        source: "../graphics/tft/NAV_selector_2.png"
        visible: main.isTft && root.isActive && cursorState === "next"
        anchors.centerIn: nextButton
        z: nextButton.z - 1
    }

}
