// Diagnostics Software Update Page

import QtQuick 2.4
import StorageMgr 1.0
import BootLoader 1.0
import Process 0.1
import ".."
import Components 1.0

Rectangle {
    id: root
    width: 1366
    height: 768
    anchors.fill: parent
    color: "transparent"

    property int fontSize: 20
    property int topOffset: 130
    property int itemSpacing: 5
    property string firmwareUpdateFile: firmwareLoader.firmwareUpdateFile
    property bool firmwareUpdating: firmwareLoader.firmwareUpdating
    property bool softwareUpdating: updatingDialog.visible
    property bool checkingForUpdates: checkUpdates.processState == Process.Running
    property bool softwareUpdatesAvailable: checkUpdates.packages.length > 0
    property bool firmwareUpdateAvailable: firmwareLoader.firmwareUpdateAvailable()

    property string modelName
    property bool isDecline
    property string cursorState: "" // check, firmware, or software

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState !== "" && !softwareUpdating && !firmwareUpdating  ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "DiagnosticsUpdate")
            if (cursorState === "firmware") {
                if (checkForUpdatesButton.visible)
                    cursorState = "check"
                else
                    cursorState = "software"
            } else if (cursorState === "software" || cursorState === "check") {
                if (bootloadButton.visible)
                    cursorState = "firmware"
            }
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "DiagnosticsUpdate")
            if (cursorState === "firmware") {
                if (checkForUpdatesButton.visible)
                    cursorState = "check"
                else
                    cursorState = "software"
            } else if (cursorState === "software" || cursorState === "check") {
                if (bootloadButton.visible)
                    cursorState = "firmware"
            }
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "DiagnosticsUpdate")
            if (checkingForUpdates || softwareUpdating || firmwareUpdating) // safeguard
                return

            if (cursorState === "firmware" && bootloadButton.enabled) {
                bootloadButton.clicked()
            } else if (cursorState === "software" && packageUpdateButton.enabled) {
                packageUpdateButton.clicked()
            } else if (cursorState === "check" && checkForUpdatesButton.enabled) {
                checkForUpdatesButton.clicked()
            }
        }
    }

    Connections {
        target: main.isTft && main.state === "DiagnosticState" && root.visible && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !softwareUpdating && !firmwareUpdating ? keymapper : null

        onBackPressed: {
            main.debugKeys("backPressed", "DiagnosticsUpdate")
            diagnostics_screen.item.unselectScreen()
        }
    }

    onSoftwareUpdatingChanged: {
        if(softwareUpdating === false){
            productConfig.configureProduct(modelName,isDecline)
        }
    }

    signal close()

    ModalDialog{
        id:bootloadErrorReceivedDialog
        blockKeys: true
        dismissable: true

        BorderImage {   // pop-up dialog background
            id: errorborder

            x: 332
            y: 161
            width: 800
            height: 350
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text {
                id: bootloadErrorReceivedDialogText
                anchors.fill: parent
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50

            }
            MouseArea{
                anchors.fill: parent
                onClicked: bootloadErrorReceivedDialog.hide()
            }
        }
        Component.onCompleted: hide()
    }

    Item{
        id: informationSection
        //color: "blue"
        //opacity: 0.3
        //z: 5
        width: childrenRect.width
        height: childrenRect.height
        anchors.horizontalCenter: parent.horizontalCenter
        //anchors.verticalCenter: parent.verticalCenter
        anchors.top: root.top
        anchors.topMargin: 50
        Row{
            spacing: 200
            Column{
                id: labels
                spacing: itemSpacing

                Text{
                    text: qsTr("Application Version") + application.emptyString
                    font.pointSize: fontSize
                }

                Text{
                    text: qsTr("Firmware Version") + application.emptyString
                    font.pointSize: fontSize
                }

                Text{
                    text: qsTr("Lower Board") + application.emptyString
                    font.pointSize: fontSize
                }

            }
            Column{
                id:values
                spacing: itemSpacing

                Text{
                    text: application.appVersion
                    font.pointSize: fontSize
                }

                Text{
                    text: brainboard.enabled ? machineinfo.brainboardFirmwareVersion : qsTr("Not Detected")+application.emptyString
                    font.pointSize: fontSize
                }

                Text{
                    text: brainboard.enabled ? brainboard.detectedMachineTypeString : qsTr("Not Detected")+application.emptyString
                    font.pointSize: fontSize
                }


            }
        }
    }

    Item{
        id: firmwareUpdateSection

        width: parent.width
        height: childrenRect.height


        anchors {
            top: informationSection.bottom ; topMargin: 50
            left: parent.left ; leftMargin: 80
        }

        Text{
            id: hexFileStatusText
            font.pointSize: fontSize
            anchors { left: bootloadButton.right ; verticalCenter: bootloadButton.verticalCenter }

            text:
            {
                if( bootloadButton.visible ) {
                    return qsTr("Firmware to load: ") + application.emptyString + firmwareLoader.firmwareUpdateFileShortname
                }
                else
                    return ""//qsTr("Looking for firmware on USB memory...") + application.emptyString
            }
        }

        Image {
            source: "../graphics/tft/NAV_selector_2.png"
            visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && cursorState !== "" && checkUpdates.processState !== Process.Running
            anchors.centerIn: {
                switch (cursorState) {
                case "firmware":
                    return bootloadButton
                case "software":
                    return packageUpdateButton
                case "check":
                    return checkForUpdatesButton
                }
            }
            anchors.horizontalCenterOffset: -26
            z: checkForUpdatesButton.z - 1
        }

        ImageButton {
            id: bootloadButton
            label_color: "#000000"
            label_under: true
            label_y_offset: 10
            upimage: "../graphics/205/IPOD_Wheel_Center_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Center_Down.png"
            anchors { left: parent.left ; top: restartMsg.bottom }

            label: qsTr("Load Firmware") + application.emptyString
            visible: firmwareLoader.firmwareUpdateAvailable() && !softwareUpdating && !checkingForUpdates
            onVisibleChanged: {
                if (visible)
                    root.cursorState = "firmware"
            }
            onClicked: {
                print("Diagnostics Update: Loading firmware:" + firmwareLoader.firmwareUpdateFile)
                firmwareLoader.loadFirmware(firmwareLoader.firmwareUpdateFile)
            }
        }

        Text {
            id: restartMsg
            visible: false
            text: qsTr("Software updated. Restart console.") + application.emptyString
            font.pointSize: fontSize
            anchors { horizontalCenter: parent.horizontalCenter ; top: parent.top }
        }

        Text {
            id: updateCheckingText
            visible: checkUpdates.processState == Process.Running
            text: qsTr("Checking for software updates...") + application.emptyString
            font.pointSize: fontSize
            anchors { horizontalCenter: parent.horizontalCenter ; horizontalCenterOffset: -80 ; top: restartMsg.bottom }
        }

        Text {
            id: packageUpdateText
            visible: checkUpdates.packages.length > 0
            text: qsTr("Software updates are available.") + application.emptyString
            font.pointSize: fontSize
            anchors { left: packageUpdateButton.right ; verticalCenter: packageUpdateButton.verticalCenter }
        }

        ImageButton {
            id: packageUpdateButton

            visible: root.softwareUpdatesAvailable
            onVisibleChanged: {
                if (visible)
                    root.cursorState = "software"
            }
            label_color: "#000000"
            label_under: true
            label_y_offset: 10
            label: qsTr("Update Software") + application.emptyString
            upimage: "../graphics/205/IPOD_Wheel_Center_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Center_Down.png"
            anchors.left: parent.left
            anchors.top: bootloadButton.bottom
            onClicked: {
                // clear list of packages before starting upgrade so button disappears
                checkUpdates.packages = ""
                updatePackages.start()

                /* Save current product info */
                modelName = machineinfo.modelString
                isDecline = machineinfo.treadmillInclineMinPercentGrade < 0 ? true : false
            }
        }

        // check for updates button visible only while not already checking or update button shown
        ImageButton {
            id: checkForUpdatesButton

            visible: (checkUpdates.processState != Process.Running) && !packageUpdateButton.visible
            onVisibleChanged: {
                if (visible)
                    root.cursorState = "check"
            }
            label_color: "#000000"
            label: qsTr("Check for Updates") + application.emptyString
            label_under: true
            label_y_offset: 5
            upimage: "../graphics/205/IPOD_Wheel_Center_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Center_Down.png"
            anchors.left: parent.left
            anchors.top: bootloadButton.bottom

            onClicked: {
                checkUpdates.packages = ""
                checkUpdates.start()
            }
        }
    }

    Text {
        id: instructions

        width: parent.width - 100

        anchors { bottom: parent.bottom ; bottomMargin: 90 ;  horizontalCenter: parent.horizontalCenter }
        horizontalAlignment: Text.AlignLeft
        wrapMode: Text.WordWrap
        text: {
            if(root.firmwareUpdating || root.softwareUpdating)
                return qsTr("Software is now being updated.  DO NOT power off the machine while software update is taking place.")
            else if(root.checkingForUpdates)
                return qsTr("Checking the network and connected USB devices for software updates.  This may take several seconds.  If updates are found, options for updating will be available above.")
            else if(root.softwareUpdatesAvailable || root.firmwareUpdateAvailable)
                return qsTr("Use the controls above to begin updating software.  Updates may take several minutes, and the machine power must not be interrupted.")
            else
                return qsTr("The machine software and firmware appear to be current.  Insert a software USB memory device and press the button above to check for updates.")
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft && diagnostics_screen.item !== null && diagnostics_screen.item.currentSelectedIndex >= 0 && !checkingForUpdates && !firmwareUpdating && !softwareUpdating

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("use <img src='../graphics/tft/arrow_up.png' /><img src='../graphics/tft/arrow_down.png' /> to navigate, press ENTER to select") + application.emptyString

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }

    StorageMgr {
        id: storage
    }

    ModalDialog{
        id: waitingForBootloaderDialog
        blockKeys: true

        //visible: bootloader.connected && bootloader.progress > 0
        BorderImage {   // pop-up dialog background
            id: waitingForBootloaderDialogBackground

            x: 332
            y: 161
            width: 800
            height: 350
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text{
                id: waitingForBootloaderDialogText
                text: qsTr("Waiting for bootloader...") + application.emptyString
                color: "white"
                font.bold: true
                font.pixelSize: 50
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
            }
	}
	Component.onCompleted: hide()
    }

    FirmwareLoader {
        id: firmwareLoader

        onFaultMsg: {
            print("Diagnostics Update: " + message)
            firmwareUpdatingDialog.hide()
            bootloadErrorReceivedDialogText.text = message
            bootloadErrorReceivedDialog.show()
        }
        onUpdateStarted: firmwareUpdatingDialog.show()
        onUpdateFinished: {
            print("Diagnostics Update: Firmware update complete.")
            firmwareUpdatingDialog.hide()
        }
        onStatus: firmwareUpdatingDialog.text = message
    }

    Timer {
        id: hexPollTimer
        interval: 5000
        repeat: true
        running: root.visible && (root.opacity >0) && !firmwareLoader.firmwareUpdating
        onTriggered: {
            firmwareLoader.checkForUpdates()
        }
    }

    ModalDialog{
        id: firmwareUpdatingDialog
        blockKeys: true

        //visible: bootloader.connected && bootloader.progress > 0
        property alias text: bootLoadStatusText.text

        BorderImage {   // pop-up dialog background
            id: firmwareUpdatingDialogBackground

            x: 332
            y: 161
            width: 800
            height: 350
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text{
                id: bootLoadStatusText
                text:""
                color: "white"
                font.bold: true
                font.pixelSize: 50
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottom: bootloadProgress.top
                anchors.bottomMargin: 5
            }

            ProgressBar {
                id: bootloadProgress
                width: 400
                height: 50
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                value: firmwareLoader.progress
            }
        }
        Component.onCompleted: hide()

    }

    ModalDialog {
        id: updatingDialog
        blockKeys: true
        visible: false  // shown when update process starts

        BorderImage {   // pop-up dialog background
            id: border

            x: 332
            y: 161
            width: 800
            height: 350
            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Text {
                id: dialogText
                x: 149
                y: 35
                width: 501
                height: 99
                color: "#ffffff"
                text: qsTr("Updating software...") + application.emptyString
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: 35
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 40
            }
        }
    }

    // The following process gathers a list of packages that may be updated
    Process {
        id: checkUpdates
        property string packages

        program: "bash"
        arguments: [ "scripts/list_upgrades.sh" ]
        onReadyReadStandardOutput: {
            packages += readAllStandardOutput()
        }
        onStarted: { cursorState = ""; console.log("checking updates") }
        onFinished: console.log("packages upgradable:" + packages)
    }

    // The following process updates packages using apt-get
    Process {
        id: updatePackages

        program: "bash"
        arguments: ["scripts/do_upgrades.sh"]

        onReadyReadStandardOutput: {
            console.log(readAllStandardOutput())
        }
        onReadyReadStandardError: {
            console.log(readAllStandardError())
        }
        onStarted: { updatingDialog.show() ; console.log("updating packages...") }
        onFinished: {
            checkUpdates.packages = ""
            checkUpdates.start()
            print("Diagnostics Update: package update complete.")
            main.restartRequired = true
            restartMsg.visible = true
            updatingDialog.hide()
            firmwareLoader.checkHexFileUpdate() // check if any hex files were installed
        }
    }

    Component.onCompleted: {
        console.log("starting software update check...")
        checkUpdates.start()
    }
}
