import QtQuick 2.4
import Process 0.1
import ".."

Item {
    id: root

    property real percentComplete: 0
    property bool uploading: false
    property bool transferStarted: false
    property bool running: uploadProcess.processState === Process.Running || uploadProcess.processState === Process.Starting
    state: "Idle"

    signal dataTransferStarted()
    signal uploadFailed()
    signal transferComplete()
    signal terminated()
    signal connectionError()

    function start() {
        state = "Connecting"
        uploadProcess.start()
    }

    function stop() {
        state = "Terminating"
        uploadProcess.terminate()
    }

    ReadFullLines {
        id: fullLineReader
    }

    Process {
        id: uploadProcess
        program: "scripts/export_diag.sh"
        onReadyReadStandardOutput: {
            var stdio = String(readAllStandardOutput())
            console.log("Diagnostics Upload: [stdout]", stdio)
            fullLineReader.readFullLines(stdio)
            if (fullLineReader.isPartial) {
                return
            }

            var data = fullLineReader.parseLine
            var match = function(text) { return data.indexOf(text) >= 0 }
            if (match("Starting transfer")) {
                dataTransferStarted()
                state = "Transferring"
            } else if (match("Problem connecting via ssh")) {
                // A problem occurred during the SSH connection test
                state = "Failed"
                connectionError()
            } else if (match("%")) {
                var parts = data.split("%")
                if (parts.length == 2) {
                    root.percentComplete = parseInt(parts[0], 10)
                }
            } else if (match("Rsync: ") || match("SSH: ")) {
                state = "Failed"
                uploadFailed()
            } else if (match("Transfer complete")) {
            }
        }

        onReadyReadStandardError: {
            var data = String(readAllStandardError())
            console.log("Diagnostics Upload: [stderr]", data)
        }

        onFinished: {
            if (state === "Terminating") {
                state = "Idle"
                terminated()
                return
            }
            if (exitCode === 0) {
                state = "Idle"
                transferComplete()
            }
        }
    }


    states: [
        State {
            name: "Idle"
            PropertyChanges { target: root; uploading: false }
            PropertyChanges { target: root; transferStarted: false }
            PropertyChanges { target: root; percentComplete: 0 }
        },

        State {
            name: "Connecting"
            PropertyChanges { target: root; uploading: true }
            PropertyChanges { target: root; transferStarted: false }
            PropertyChanges { target: root; percentComplete: 0 }
        },

        State {
            name: "Transferring"
            PropertyChanges { target: root; uploading: true }
            PropertyChanges { target: root; transferStarted: true }
            PropertyChanges { target: root; percentComplete: 0 }
        },

        State {
            name: "Failed"
            PropertyChanges { target: root; uploading: false }
            PropertyChanges { target: root; transferStarted: false }
            PropertyChanges { target: root; percentComplete: 0 }
        },

        State {
            name: "Terminating"
        }

    ]
}

