import QtQuick 2.4
import ConfigurationData 1.0
import Brainboard 1.0

Item {
    id: root

    signal configurationChanged(variant config)

    function configureProduct(name, decline) {
        var config = getProductConfig(name, decline)
        var type = getProductType(name)

        brainboard.sendConfigurationData(name,type,config)
        root.configurationChanged(config)
    }

    // get the product type from the product model name
    function getProductType(name) {
        if(!name)
            return Brainboard.MACHINE_NONE

        // Special case for CSA elliptical
        if (name === "TS1000") {
            return Brainboard.MACHINE_ELLIPTICAL
        }

        // Special case for Lateral Trainer
        if (name === "TL1000") {
            return Brainboard.MACHINE_LATERALTRAINER
        }

        var initial = name[0]
        switch(initial) {
        case "T": return Brainboard.MACHINE_TREADMILL
        case "X": return Brainboard.MACHINE_ELLIPTICAL
        case "R":
        case "U":
            return Brainboard.MACHINE_BIKE
        default: return Brainboard.MACHINE_INVALID
        }
    }

    // get the product configuration data from the product model name
    function getProductConfig(name, decline)
    {
        switch(name)
        {
        case "RCS400": return configurationDataCS400_RB
        case "UCS400": return configurationDataCS400_UB
        case "UCS900": return configurationDataCS900_UB
        case "RCS900": return configurationDataCS900_RB
            //Elliptical
        case "XCS400": return configurationDataCS400_E
        case "XCS900": return configurationDataCS900_E
        case "TS1000": return configurationDataTS1000_CSA
            //Treadmill
        case "TCS400": return configurationDataCS400_T
        case "TCS600": return configurationDataCS600_T
        case "TCS650": {
            if(decline === false) {
                return configurationDataCS650_T
            }
            else {
                return configurationDataCS650_TD
            }
        }
        case "TCS900": {
            if(decline === false) {
                return configurationDataCS900_T
            }
            else {
                return configurationDataCS900_TD
            }
        }
        case "TES900": return configurationDataES900_T
//        case "TPS800": return configurationDataPS800_T
        case "TPS825": return configurationDataPS825_T
        case "TL1000": return configurationDataTL1000
        default: return null
        }
    }
    // get the product max user weight from the product model name
    function getProductConfigMaxUserWeight(name)
    {
        switch(name)
        {
        case "RCS400": return configurationDataCS400_RB.userWeightMax
        case "UCS400": return configurationDataCS400_UB.userWeightMax
        case "UCS900": return configurationDataCS900_UB.userWeightMax
        case "RCS900": return configurationDataCS900_RB.userWeightMax
            //Elliptical
        case "XCS400": return configurationDataCS400_E.userWeightMax
        case "XCS900": return configurationDataCS900_E.userWeightMax
        case "TS1000": return configurationDataTS1000_CSA.userWeightMax
            //Treadmill
        case "TCS400": return configurationDataCS400_T.userWeightMax
        case "TCS600": return configurationDataCS600_T.userWeightMax
        case "TCS650": return configurationDataCS650_T.userWeightMax
        case "TCS900": return configurationDataCS900_T.userWeightMax
        case "TES900": return configurationDataES900_T.userWeightMax
//        case "TPS800": return configurationDataPS800_T.userWeightMax
        case "TPS825": return configurationDataPS825_T.userWeightMax
        case "TL1000": return configurationDataTL1000.userWeightMax
        default: return 0
        }
    }

    // Treadmill configurations
    ConfigurationData{
        id: configurationDataCS600_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:80
        crankRatio:357
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 601
        userWeightMax: 400
        inclineFactor1: 19
        inclineFactor2: 33
        inclineOffset: 20
    }

    ConfigurationData{
        id: configurationDataCS650_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:80
        crankRatio:350
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 651
        userWeightMax: 500
        inclineFactor1: 19
        inclineFactor2: 33
        inclineOffset: 20
    }

    ConfigurationData{
        id: configurationDataCS650_TD
        maxInclinePercentGrade:150
        minInclinePercentGrade:-30
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:80
        crankRatio:350
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 651
        userWeightMax: 500
        inclineFactor1: 33
        inclineFactor2: 36
        inclineOffset: 10
    }

    ConfigurationData{
        id: configurationDataCS900_T
        maxInclinePercentGrade:180
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:150
        rollerDiameter:92
        crankRatio:293
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 901
        userWeightMax: 500
        inclineFactor1: 24
        inclineFactor2: 34
        inclineOffset: 10

    }

    ConfigurationData{
        id: configurationDataCS900_TD
        maxInclinePercentGrade:180
        minInclinePercentGrade:-30
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:150
        rollerDiameter:92
        crankRatio:293
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 901
        userWeightMax: 500
        inclineFactor1: 7
        inclineFactor2: 38
        inclineOffset: 10

    }

    ConfigurationData{
        id: configurationDataES900_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:-30
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:84
        crankRatio:283
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_ENDEX_IDC8X
        csafeID: 10
        userWeightMax: 400
        inclineFactor1: 62
        inclineFactor2: 140
        inclineOffset: 100

    }

    ConfigurationData{
        id: configurationDataPS825_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:84
        crankRatio:283
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_ENDEX_IDC8X
        csafeID: 0
        userWeightMax: 400
        inclineFactor1: -50
        inclineFactor2: 189
        inclineOffset: 40

    }

//    ConfigurationData{
//        id: configurationDataPS800_T
//        maxInclinePercentGrade:150
//        minInclinePercentGrade:0
//        maxInclineADC:0
//        minInclineADC:0
//        minSpeed:5
//        maxSpeed:120
//        rollerDiameter:84
//        crankRatio:283
//        ticksPerRevolution:0
//        torqueFactor0:0
//        torqueFactor1:0
//        torqueFactor2:0
//        torqueFactor3:0
//        torqueFactor4:0
//        kP:0
//        kI:0
//        kD:0
//        lowerboard: Brainboard.LOWERBOARD_ENDEX_IDC8X
//        csafeID: 0
//        userWeightMax: 400
//        inclineFactor1: -50
//        inclineFactor2: 189
//        inclineOffset: 40

//    }

    ConfigurationData{
        id: configurationDataCS400_T
        maxInclinePercentGrade:150
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:5
        maxSpeed:120
        rollerDiameter:80
        crankRatio:357
        ticksPerRevolution:0
        torqueFactor0:0
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:0
        torqueFactor4:0
        kP:0
        kI:0
        kD:0
        lowerboard: Brainboard.LOWERBOARD_DCI
        csafeID: 401
        userWeightMax: 400
        inclineFactor1: -17
        inclineFactor2: 48
        inclineOffset: 10
    }

    // Bike configurations
    ConfigurationData{
        id: configurationDataCS400_UB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:792 //specs says 823
        ticksPerRevolution:600
        torqueFactor0:196
        torqueFactor1:192
        torqueFactor2:52649
        torqueFactor3:10
        torqueFactor4:3331
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 404
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 0
    }

    ConfigurationData{
        id: configurationDataCS400_RB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:1133//spec says 1161
        ticksPerRevolution:600
        torqueFactor0:117
        torqueFactor1:186
        torqueFactor2:59235
        torqueFactor3:20
        torqueFactor4:620
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 403
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 0
    }

    ConfigurationData{
        id: configurationDataCS900_UB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:1195
        ticksPerRevolution:600
        torqueFactor0:247
        torqueFactor1:186
        torqueFactor2:62877
        torqueFactor3:9
        torqueFactor4:1673
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 904
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 0
    }

    ConfigurationData{
        id: configurationDataCS900_RB
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio: 1181
        ticksPerRevolution:600
        torqueFactor0:234
        torqueFactor1:177
        torqueFactor2:57188
        torqueFactor3:10
        torqueFactor4:1616
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 903
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 0
    }

    // Elliptical configurations
    ConfigurationData{
        id: configurationDataCS400_E
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:603
        ticksPerRevolution:600
        torqueFactor0:196
        torqueFactor1:290
        torqueFactor2:102421
        torqueFactor3:13
        torqueFactor4:2511
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 402
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 0
    }

    ConfigurationData{
        id: configurationDataCS900_E
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:979
        ticksPerRevolution:600
        torqueFactor0:299
        torqueFactor1:321
        torqueFactor2:113642
        torqueFactor3:11
        torqueFactor4:3722
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 902
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 0
    }

    ConfigurationData{
        id: configurationDataTS1000_CSA
        maxInclinePercentGrade:30
        minInclinePercentGrade:13
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:264
        ticksPerRevolution:600
        torqueFactor0:260
        torqueFactor1:16
        torqueFactor2:-486
        torqueFactor3:114
        torqueFactor4:46
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CSA
        csafeID: 0
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 6500
    }

    ConfigurationData{
        id: configurationDataTL1000
        maxInclinePercentGrade:0
        minInclinePercentGrade:0
        maxInclineADC:0
        minInclineADC:0
        minSpeed:0
        maxSpeed:0
        rollerDiameter:0
        crankRatio:1750
        ticksPerRevolution:600
        torqueFactor0:1
        torqueFactor1:0
        torqueFactor2:0
        torqueFactor3:29
        torqueFactor4:-1957
        kP:4
        kI:2
        kD:30
        lowerboard: Brainboard.LOWERBOARD_CHIHUA
        csafeID: 902
        userWeightMax: 400
        inclineFactor1: 0
        inclineFactor2: 0
        inclineOffset: 0
    }
}
