import QtQuick 2.4
import "MediaBrowser"
import "."
import Components 1.0

ModalDialog {
    id: root
    isTop: false
    isTransparent: true
    visible: false
    state: "idle"
    opacity: 1.0
    property bool keysAccepted
    property bool isDiscovering: bluetoothAdapter.nonLeScan
    property bool isLowEnergy: false

    signal closed()
    signal deviceConnected()
    signal deviceDisconnected()
    signal headsetConnected()
    signal headsetDisconnected()

    onVisibleChanged: {
        state = "list"
        if(visible) {
            if(isLowEnergy == false){
                if(!bluetoothAdapter.discovering){
                    bluetoothAdapter.startDiscovery(true)
                }
            } else {
                console.debug("Low Energy scan")
                bluetoothLEAdapter.scan()
            }
        } else {
            if(isLowEnergy == false){
                if(bluetoothAdapter.discovering){
                    bluetoothAdapter.stopDiscovery()
                }
            } else { //Low Energy
                console.debug("onVisibleChanged: Stop Scan")
                bluetoothLEAdapter.stopScan(false)
            }
        }
    }

    Connections{
        target: heartRateManager
        onDeviceSelected: {
            hide();
            bluetoothAdapter.reconnect()
        }

        onNoneSelected: {
            if(bluetoothLEAdapter.hrConnected == true) {
                bluetoothLEAdapter.disconnect(bluetoothLEAdapter.deviceMAC,bluetoothLEAdapter.hrHandle)
            }
        }
    }

    Connections{
        target: workoutScreen
        onWorkoutStopped: {
            if(bluetoothLEAdapter.scanning){
                bluetoothLEAdapter.stopScan(true)
            }

            if(heartRateManager.currentBtAddress !== ""){
                console.debug("Bluetooth HR disconnect")
                bluetoothLEAdapter.disconnect(bluetoothLEAdapter.deviceMAC,bluetoothLEAdapter.hrHandle)
            }
            hide();
        }
    }

    Connections{
        target: setupScreen
        onOpacityChanged: {
            if(setupScreen.opacity == 0){
                hide()
            }
        }
    }

    Connections{
        target: bluetoothLEAdapter

        onConnectingChanged: {
            console.debug("connecting changed: " + bluetoothLEAdapter.connecting)
            if(bluetoothLEAdapter.connecting) {
                root.state = "connecting"
            }
        }
        onReadHRChanged: {
        }

        onConnected: {
            bluetoothLEAdapter.hrConnected=true
            hide();

        }
        onScanningChanged: {
            console.debug("scanning changed: " + bluetoothLEAdapter.scanning)
            if(bluetoothLEAdapter.scanning == false)
                if(heartRateManager.deviceCount === 0){
                    root.state = "notfound"
                } else {
                    root.state = "list"
                }

        }


        onHrDisconnecting:{
            console.debug("BLE disconnecting signal received, deviceMAC = " + bluetoothLEAdapter.deviceMAC)
            root.state = "disconnecting"
            disconnectionTimeoutTimer.start()
        }

        onHrDisconnectingComplete:{
            console.debug("disconnectingComplete signal received")
            bluetoothLEAdapter.hrConnected = false
            hide()
        }

        onHrConnectionFailed: {
            hide()
        }
    }

    Timer{
        id: disconnectionTimeoutTimer
        interval: 5000
        repeat: false
        onTriggered: {
            if(bluetoothLEAdapter.hrConnected == true)
                console.debug("disconnectionTimeoutTimer: Timeout triggered")
                bluetoothLEAdapter.hrDisconnectingComplete()
        }
    }

    Connections {
        target: main.isTft && !main.blockKeys && root.keysAccepted && root.visible && !btHelpDialog.visible ? keymapper : null

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "MediaBrowser", "(btStatusDialog)")
            btExitButton.clicked()
        }
    }

    BorderImage {   // pop-up dialog background
        id: btStatusDialogborder

        anchors.fill: root
        anchors.topMargin: -15
        anchors.bottomMargin: -33
        anchors.leftMargin: -14
        anchors.rightMargin: -33

        source: "graphics/Pop_Up_Lrg_Grey.png"
        border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

        // This rectangle is to give the GUI component a reference to a drawing area. This
        // was added to allow adjustments for the shadows offset of the graphic border image.
        Rectangle{
            id: referenceArea
            color:"transparent"
            height: parent.height + parent.anchors.topMargin + parent.anchors.bottomMargin
            width: parent.width + parent.anchors.rightMargin + parent.anchors.leftMargin
            anchors.top: parent.top
            anchors.left: parent.left
            anchors.topMargin: -parent.anchors.topMargin
            anchors.leftMargin: -parent.anchors.leftMargin
        }

        Item {
            id: btPairingItems
            visible: false
            anchors.verticalCenter: referenceArea.verticalCenter
            anchors.horizontalCenter: referenceArea.horizontalCenter
            width: referenceArea.width
            height: referenceArea.height

            Text {
                id: btPairCodeText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -implicitHeight / 2
                width: parent.width * 0.50

                color: "white"
                text: qsTr("CONFIRM ON DEVICE:") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.14
            }
            Text {
                id: btPairCodeKeyText
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: implicitHeight / 2
                width: parent.width * 0.50
                color: "white"
                text: ""
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.14
            }
        }

        Item{
            id: btDeviceListBox
            visible: false
            anchors.verticalCenter: referenceArea.verticalCenter
            anchors.horizontalCenter: referenceArea.horizontalCenter
            width: referenceArea.width
            height: referenceArea.height

            Text{
                id: btSelectDeviceText
                text: qsTr("SELECT YOUR DEVICE:") + application.emptyString
                width: parent.width * 0.6
                wrapMode: Text.WordWrap
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: parent.top
                anchors.topMargin: parent.height * 0.08

                color: "white"
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.15
            }

            Item {
                id: scanningAnimation
                height: 58
                width: 108
                anchors.horizontalCenter: parent.left
                anchors.horizontalCenterOffset: 100
                anchors.verticalCenter: parent.verticalCenter

                Image{
                    id: scanningBluetoothWave
                    property int opacityInteger: 0
                    anchors.fill: parent
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    source: "graphics/Bluetooth/Bluetooth_waves.png"
                    opacity: opacityInteger / 100.0
                    visible: waveAnimation.running
                    NumberAnimation on opacityInteger {
                        id: waveAnimation
                        from: 0;
                        to: 100;
                        duration: 500
                        running : bluetoothLEAdapter.scanning
                        loops: Animation.Infinite
                    }
                }
                ImageButton{
                    id: scanningBluetoothIcon
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.horizontalCenter: parent.horizontalCenter
                    upimage: "graphics/Bluetooth/Bluetooth_icon_medium.png"
                    downimage: upimage
                }
            }

            Rectangle {
                id: bluetoothDeviceListBoxBrowser

                color: "transparent"
                radius: 10
                width: parent.width * 0.5
                height: 180
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 3
                anchors.horizontalCenter: parent.horizontalCenter

                Item {
                    id: clippingItem

                    anchors.fill: parent
                    clip: true
                    height: 180

                    ListView {
                        id: bluetoothDeviceList
                        spacing: main.isTouch ? 20 : 1
                        height: 180
                        anchors.fill: parent
                        anchors.margins: 10

                        Connections {
                            target: main.isTft && !main.blockKeys && root.keysAccepted && root.visible && root.state === "list" && !btHelpDialog.visible ? keymapper : null

                            onUpButtonPressed: {
                                main.debugKeys("upButtonPressed", "MediaBrowser", "(bluetoothDeviceList)")
                                bluetoothDeviceList.decrementCurrentIndex()
                            }

                            onDownButtonPressed: {
                                main.debugKeys("downButtonPressed", "MediaBrowser", "(bluetoothDeviceList)")
                                bluetoothDeviceList.incrementCurrentIndex()
                            }

                            onEnter2Pressed: {
                                main.debugKeys("enter2Pressed", "MediaBrowser", "(bluetoothDeviceList)")
                                bluetoothDeviceList.currentItem.pressed()
                            }
                        }

                        interactive: false
                        //clip: true
                        model: heartRateManager.wirelessSourceList
                        Component {
                            id: highlightComponent
                            Rectangle { color: "#5f9e45"; radius: 0 ; opacity: 1.0; width: 410 }
                        }
                        highlight: highlightComponent
                        highlightMoveVelocity: 1500
                        delegate: Component {
                            Item{
                                id: listItem
                                function pressed(index) {
                                    console.debug("index pressed: " + index)
                                    bluetoothDeviceList.currentIndex = index
                                    heartRateManager.selectIndex(index)
                                }
                                height: 40
                                width: parent.width
                                Timer {
                                    id: scanStopTimer
                                    interval: 0100
                                    repeat: false
                                    running: false
                                    onTriggered: {
                                        console.log("Scan timer timed out")
                                        listItem.pressed(index)
                                    }
                                }
                                Text {
                                    text: modelData
                                    color: "white"
                                    font.bold: true
                                    font.family: "sans serif"
                                    font.pixelSize: parent.height * 0.45
                                    verticalAlignment: Text.AlignVCenter
                                    anchors.left: parent.left
                                    anchors.leftMargin: 10
                                    anchors.verticalCenter: parent.verticalCenter
                                    MouseArea {
                                        anchors.fill: parent
                                        onClicked: {
                                            bluetoothDeviceList.currentIndex = index
                                        }
                                    }
                                }
                                ImageButton {
                                    id: selectDeviceButton
                                    visible: main.isTouch
                                    onClicked: {
                                        bluetoothLEAdapter.stopScan(true)
                                        scanStopTimer.start()
                                        console.debug("Stop the Scan")

                                    }
                                    anchors { top: parent.top; topMargin: -13; right: parent.right }
                                    upimage: index === heartRateManager.currentSourceIndex ? "graphics/205/SM_Button_ORANGE.png" : "graphics/205/SM_Button_GRAY.png"
                                    downimage: "graphics/205/SM_Button_ORANGE.png"
                                }
                            }
                        }
                    }
                }
            }
            Column {
                id: btDeviceListArrows

                width: 40
                height: 160
                spacing: 50
                visible: main.isTft && bluetoothDeviceList.model.count > 0
                anchors {
                    left: bluetoothDeviceListBoxBrowser.right
                    verticalCenter: bluetoothDeviceListBoxBrowser.verticalCenter
                }

                Image {
                    id: dataUpArrow
                    visible: bluetoothDeviceList.contentY > 30
                    source: "graphics/Swipe_Arrows_Left.png"
                    rotation: 90
                }
                Image {
                    id: dataDownArrow
                    visible: bluetoothDeviceList.contentHeight - bluetoothDeviceList.height - bluetoothDeviceList.contentY > 10
                    source: "graphics/Swipe_Arrows_Left.png"
                    rotation: -90
                }
            }
        }

        Text {
            id: btGettingPairingCodeText
            visible: false
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width * 0.8
            height: parent.height * 0.5
            color: "white"
            text: qsTr("GETTING PAIRING CODE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.family: "sans serif"
            font.pixelSize: parent.height * 0.15
        }

        Item {
            id: btNoDeviceFoundItem
            visible: false
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.fill: referenceArea
            Text {
                id: btNoDeviceFoundText
                anchors.top: parent.top
                anchors.topMargin: parent.height * 0.08
                anchors.horizontalCenter: parent.horizontalCenter
                width: parent.width * 0.8
                color: "white"
                text: qsTr("No Heart Rate Device Found") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: parent.height * 0.15
            }

            ImageButton {
                id: scanButton
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.top: btNoDeviceFoundText.bottom
                anchors.topMargin: parent.height * 0.1
                visible: true
                label_color: "white"
                label_under: true
                label: qsTr("Rescan") + application.emptyString
                upimage: "graphics/205/Lrg_Button_Up.png"
                downimage: "graphics/205/Lrg_Button_Down.png"
                onClicked: {
                    root.state = "list"
                    bluetoothLEAdapter.scan()
                }
            }
        }



        Text {
            id: btConnectingText
            visible: false
            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            width: parent.width * 0.8
            height: parent.height * 0.5
            color: "white"
            text: qsTr("CONNECTING TO BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.family: "sans serif"
            font.pixelSize: parent.height * 0.15
        }

        Text {
            id: btDisconnectingText
            visible: false
            anchors.verticalCenter: referenceArea.verticalCenter
            anchors.horizontalCenter: referenceArea.horizontalCenter
            width: referenceArea.width * 0.8
            height: referenceArea.height * 0.8
            color: "white"
            text: qsTr("DISCONNECTING FROM BLUETOOTH DEVICE...") + application.emptyString
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
            font.bold: true
            font.family: "sans serif"
            font.pixelSize: parent.height * 0.15
        }

        ImageButton{
            id: btExitButton
            visible: false
            upimage: "Keypad/KeyPad_X_Large.png"
            downimage: "Keypad/KeyPad_X_Large.png"
            anchors.top: referenceArea.top
            anchors.topMargin: 35
            anchors.right: referenceArea.right
            anchors.rightMargin: 35
            onClicked: {
                if(bluetoothAdapter.pairing == true){
                    bluetoothAdapter.cancelDeviceCreation()
                }
                root.state = "list"
                closed()

            }
        }

    }

    states: [
        State{
            name: "idle"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}            
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}

        },
        State{
            name: "notfound"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: main.isTouch}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: true}
        },
        State{
            name: "list"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: true}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: main.isTouch}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "pairing"
            PropertyChanges {target: btPairingItems; visible: true}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: main.isTouch}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "connecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: true}
            PropertyChanges {target: btExitButton; visible: main.isTouch}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "disconnecting"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: true}
            PropertyChanges {target: btGettingPairingCodeText; visible: false}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        },
        State{
            name: "gettingpairingcode"
            PropertyChanges {target: btPairingItems; visible: false}
            PropertyChanges {target: btDeviceListBox; visible: false}
            PropertyChanges {target: btConnectingText; visible: false}
            PropertyChanges {target: btExitButton; visible: false}
            PropertyChanges {target: btDisconnectingText; visible: false}
            PropertyChanges {target: btGettingPairingCodeText; visible: true}
            PropertyChanges {target: btNoDeviceFoundItem; visible: false}
        }
    ]

    function paddy(n, p, c){
        var pad_char = typeof c !== 'undefined' ? c : '0';
        var pad = new Array(1+p).join(pad_char);
        return (pad+n).slice(-pad.length);
    }
}

