import QtQuick 2.4
import Busy 1.0
import Components 1.0

Item {
    id: root

    property real hrFillPercent: _hrFillPercent()
    property int heartRate: heartRateManager.heartRate
    property int heartRateMax: 220
    property int targetHeartRate: 0
    property bool showTargetHeartRate: false

    property bool _hr_valid: heartRateManager.heartRateAvailable

    property alias hrCruiseEnabled: hrCruiseButton.isDown
    property bool cruiseAllowed: false
    property bool dialogVisible: false
    property string hrDeviceMAC: ""


    function _hrFillPercent() {
        var hrPercent = root.heartRate / root.heartRateMax
        var ret = 0.0
        if (hrPercent <= 0.3) {
            ret = 0.0
        } else if (hrPercent > 0.3 && hrPercent <= 0.6) {
            ret = 0.25 * ((hrPercent - 0.3) / 0.3)
        } else if (hrPercent > 0.6 && hrPercent <= 0.75) {
            ret = 0.25 + (0.25 * ((hrPercent - 0.6) / 0.15))
        } else if (hrPercent > 0.75 && hrPercent <= 0.85) {
            ret = 0.5 + (0.25 * ((hrPercent - 0.75) / 0.10))
        } else if (hrPercent > 0.85) {
            ret = 0.75 + (0.25 * ((hrPercent - 0.85) / 0.15))
        }
        return ret
    }

    Image {
        id: hrBackground

        anchors.top: parent.top
        anchors.topMargin: -4
        anchors.horizontalCenter: parent.horizontalCenter
        width: 987
        height: 304
        source: "graphics/224/224_Data_Curved_Window.png"
    }

    Image {
        id: hrMeterBackground

        anchors.horizontalCenter: hrBackground.horizontalCenter
        anchors.horizontalCenterOffset: -2
        y: 34
        source: "graphics/224/224_Data_Color_Meter_Dark.png"
    }

    Item {
        id: hrMeterFill

        anchors.left: hrMeterBackground.left
        y: 34
        width: hrFillPercent * 502
        height: 113
        clip: true

        Image {
            id: hrMeterFillColor
            source: "graphics/224/224_Data_Color_Meter_Light.png"
        }
    }

    Image {
        id: hrMeterRule
        anchors.horizontalCenter: hrBackground.horizontalCenter
        anchors.horizontalCenterOffset: -2
        y: 34
        source: "graphics/224/224_Data_Color_Meter_Rule.png"
    }

    Image{
        id: hrMeterText
        anchors.top: hrMeterRule.top
        anchors.topMargin: -15
        anchors.right: hrMeterRule.right
        anchors.rightMargin: 10
        source: "graphics/224/HRmeter_text_ENG.png"
    }

    ImageButton {
        id: hrCruiseButton

        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: -90
        anchors.verticalCenter: hrValue.verticalCenter
        anchors.verticalCenterOffset: 4
        fontsize: 12
        downimage: "graphics/224/Data_HRC_Cruise_Down.png"
        upimage: "graphics/224/Data_HRC_Cruise_Up.png"
        label: qsTr("CRUISE") + application.emptyString
        label_color: "black"
        label_y_offset: 30
        mouseAreaScale: 2.0
        toggle: true
        enabled: root.cruiseAllowed
        disabledimage: "graphics/224/Data_HRC_Cruise_Disabled.png"
    }

    Text {
        id: hrValue

        anchors.horizontalCenter: parent.horizontalCenter
        y: 93
        color: "black"
        font.pointSize: 32
        font.bold: true
        // display value if in range between 20 and 251, else display --
        text: root.heartRate != 0 ? root.heartRate : "--"
        visible: !bluetoothLEAdapter.connecting
    }

    Text {
        id: hrUnitsLabel

        anchors.horizontalCenter: parent.horizontalCenter
        y: text.length > 3 ? 137 : 144
        color: "black"
        font.pointSize: text.length > 3 ? 9 : 11
        font.bold: true
        width: 150
        horizontalAlignment: Text.AlignHCenter
        wrapMode: Text.WordWrap
        text: qsTr("BPM") + application.emptyString
    }

    Item {
        id: hrIcon
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 60
        anchors.verticalCenter: hrValue.verticalCenter
        anchors.verticalCenterOffset: 4
        state: heartRateManager.heartRateAvailable ? "active" : "inactive"

        ImageButton{
            id: hrIconInactive

            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter

            fontsize: 18
            downimage: "graphics/Bluetooth/Data_Target_Icon_gray.png"
            upimage: "graphics/Bluetooth/Data_Target_Icon_gray.png"
            label: qsTr("?") + application.emptyString
            label_color: "black"
            label_y_offset: -2
            label_x_offset: -2
            mouseAreaScale: 2.0
        }

        BeatingHeart {
            id: hrIconActive
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
        }
        states:[
            State{
                name: "inactive"
                PropertyChanges { target: hrIconActive; visible: false }
                PropertyChanges { target: hrIconInactive; visible: true }
            },
            State{
                name: "active"
                PropertyChanges { target: hrIconActive; visible: true }
                PropertyChanges { target: hrIconInactive; visible: false }
            }
        ]
    }

    MouseArea{
        visible: hrIcon.visible
        anchors.horizontalCenter: hrIcon.horizontalCenter
        anchors.verticalCenter: hrIcon.verticalCenter
        height: 100
        width: 250

        onClicked: heartRateDeviceSelectionDialog.show()

        Rectangle{
            opacity: 0.3
            color: "transparent"
            anchors.fill: parent
        }
    }

    Text {
        id: targetHRValue

        anchors.horizontalCenter: hrIcon.right
        anchors.horizontalCenterOffset: 43
        anchors.verticalCenter: hrIcon.verticalCenter
        color: "black"
        font.pointSize: 18
        font.bold: true
        text: root.targetHeartRate
        visible: root.showTargetHeartRate || hrCruiseButton.isDown
    }


    Text {
        id: targetHRUnitsLabel

        anchors.horizontalCenter: targetHRValue.horizontalCenter
        anchors.verticalCenter: targetHRValue.verticalCenter
        anchors.verticalCenterOffset: 20
        color: "black"
        font.pointSize: 9
        font.bold: true
        text: qsTr("TARGET") + application.emptyString
        visible: root.showTargetHeartRate || hrCruiseButton.isDown
    }
    ImageButton {
        id: blueToothIcon
        visible: heartRateManager.currentBtAddress !== ""

        anchors.left: targetHRValue.right

        anchors.leftMargin: 0
        anchors.verticalCenter: targetHRValue.verticalCenter
        upimage: "graphics/Bluetooth/Bluetooth_icon_small.png"
        downimage: "graphics/Bluetooth/bluetooth_blue.png"
        enabled:true
    }

    BusyIndicator {
        id: busyIndicator
        width: 50
        height: 50
        anchors.horizontalCenter: hrValue.horizontalCenter
        anchors.verticalCenter: hrValue.verticalCenter
        visible: bluetoothLEAdapter.connecting
        RotationAnimation
        {
            target: busyIndicator
            property: "rotation" // Suppress a warninge
            from: 0
            to: 360
            direction: RotationAnimation.Clockwise
            duration: 1000
            loops: Animation.Infinite
            running: bluetoothLEAdapter.connecting
        }
    }

} // end heartRateCenter
