// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4

Item {
    width: 100
    height: 62

    property int productType: machineinfo.productType
    property string modelName: machineinfo.modelString
    property variant currentKeyMap: keyMapList
    property int keybeingpressed: 0
    property bool keysEnabled: true
    property int pressAndHoldDuration: 3000
    property alias slewCount: repeatTimer.slewCount

    onProductTypeChanged: updateKeyMapList()
    onModelNameChanged: updateKeyMapList()

    signal inclineUpPressed()
    signal inclineDownPressed()
    signal inclineUpReleased()
    signal inclineDownReleased()
    signal enter2Released()

    signal speedUpFirstPressed()
    signal speedUpPressed()
    signal speedUpReleased()

    signal speedDownPressed()
    signal startQuickStartPressed()
    signal stopPausePressed()
    signal levelUpPressed()
    signal levelDownPressed()
    signal cruiseControlPressed()
    signal changeDisplayPressed()
    signal enterPressed()
    signal strideUpPressed()
    signal strideDownPressed()

    // signals for TFT keypad
    signal downButtonPressed()
    signal downButtonReleased()
    signal upButtonPressed()
    signal upButtonReleased()
    signal leftButtonPressed()
    signal rightButtonPressed()
    signal enter2Pressed()
    signal startPressed()
    signal stopPressed()
    signal backPressed()
    signal tvPressed()
    signal doubleLeftPressed()
    signal doubleRightPressed()
    signal plusPressed()
    signal minusPressed()

    signal pressAndHold(int functionIndex)


    function keyPressHandler(keynum){
        var functionIndex = currentKeyMap.get(keynum - 1).functionIndex

        if(keynum !== keybeingpressed && (functionIndex === 3 || functionIndex === 4)){
            if(functionIndex === 3){
                console.debug("Speed up first pressed")
                speedUpFirstPressed()
            }
            repeatTimer.counter = 3;
            repeatTimer.repeatTimerInterval = 350
            repeatTimer.diffSlew = true
        } else if (keynum !== keybeingpressed && (functionIndex >= 12 && functionIndex <= 16)) {
            repeatTimer.counter = 3;
            repeatTimer.repeatTimerInterval = 500
            repeatTimer.diffSlew = true
        }
        else if(keynum !== keybeingpressed)
        {
            repeatTimer.counter = 1;
            repeatTimer.repeatTimerInterval = 350
            repeatTimer.diffSlew = false
        }

        var keyChanged = (keybeingpressed !== keynum)
        keybeingpressed = keynum
        var res = keyFunctionHandler(functionIndex)

        if(res){
            buzzer.buttonPress()
            if (keyChanged) {
                pressAndHoldTimer.restart()
                if (functionIndex !== 16) // disable slewing for ENTER
                    repeatTimer.restart()
            } else {
                pressAndHoldTimer.start()
                if (functionIndex !== 16) // disable slewing for ENTER
                    repeatTimer.start()
            }
        }
    }

    function keyReleaseHandler(keynum){
        pressAndHoldTimer.stop()
        repeatTimer.stop()
        keybeingpressed = 0
        if(currentKeyMap.get(keynum - 1).functionIndex == 3){
            speedUpReleased()
            console.debug("Speed up released")
        }
        // send released signals for some keys only
        switch (currentKeyMap.get(keynum - 1).functionIndex) {
            case 1:
                inclineUpReleased()
                break
            case 2:
                inclineDownReleased()
                break
            case 12:
                upButtonReleased()
                break
            case 13:
                downButtonReleased()
                break
            case 16:
                enter2Released()
                break
        }
    }

    function keyFunctionHandler(keyfunc){

        switch(keyfunc)
        {
        case 1: console.debug("inclineUpPressed");inclineUpPressed(); return true;
        case 2: console.debug("inclineDownPressed");inclineDownPressed();return true;
        case 3: console.debug("speedUpPressed");speedUpPressed();return true;
        case 4: console.debug("speedDownPressed");speedDownPressed();return true;
        case 5: console.debug("startQuickStartPressed");startQuickStartPressed();return true;
        case 6: console.debug("stopPausePressed");stopPausePressed();return true;
        case 7: console.debug("levelUpPressed");levelUpPressed();return true;
        case 8: console.debug("levelDownPressed");levelDownPressed();return true;         
        case 9: console.debug("cruiseControlPressed");cruiseControlPressed();return true;
        case 10: console.debug("changeDisplayPressed");changeDisplayPressed();return true;
        case 11: console.debug("enterPressed");enterPressed();return true;
        // handling for TFT keypad
        case 12: console.debug("upButtonPressed");upButtonPressed();return true;
        case 13: console.debug("downButtonPressed");downButtonPressed();return true;
        case 14: console.debug("leftButtonPressed");leftButtonPressed();return true;
        case 15: console.debug("rightButtonPressed");rightButtonPressed();return true;
        case 16: console.debug("enter2Pressed");enter2Pressed();return true;
        case 17: console.debug("startPressed");startPressed();return true;
        case 18: console.debug("stopPressed");stopPressed();return true;
        case 19: console.debug("backPressed");backPressed();return true;
        case 20: console.debug("tvPressed");tvPressed();return true;
        case 21: console.debug("doubleLeftPressed");doubleLeftPressed();return true;
        case 22: console.debug("doubleRightPressed");doubleRightPressed();return true;
        case 23: console.log("plusPressed");plusPressed();return true;
        case 24: console.log("minusPressed");minusPressed();return true;
        case 25: console.log("strideUpPressed"); strideUpPressed(); return true;
        case 26: console.log("strideDownPressed"); strideDownPressed(); return true;
        default: return false;
        }

    }

    function updateKeyMapList()
    {
        // Get list based on product Type and model name
        if(productType === undefined || modelName === undefined) return;

        switch(productType)
        {
            //Bike
        case 1:
            if(modelName ==="RCX900") currentKeyMap = keyMapList_CX900_B
            else if(modelName === "UCX900") currentKeyMap = keyMapList_CX900_B
            else if(modelName === "UCS900") currentKeyMap = keyMapList_CS900_B
            else if(modelName === "RCS900") currentKeyMap = keyMapList_CS900_B
            break;
            //Elliptical
        case 2:
            if(modelName === "XCX900") currentKeyMap = keyMapList_CX900_E
            else if(modelName === "XCS900") currentKeyMap = keyMapList_CS900_E
            else if(modelName === "TS1000") currentKeyMap = keyMapList_TS1000_E
            break;
            //Treadmill
        case 3:
            if(modelName === "TCX900") currentKeyMap = keyMapList_CX900_T
            else if(modelName === "TCS600") currentKeyMap = keyMapList_CS600_T
            else if(modelName === "TCS650") currentKeyMap = keyMapList_CS650_T
            else if(modelName === "TCS900") currentKeyMap = keyMapList_CS900_T
            else if(modelName === "TES900") currentKeyMap = keyMapList_ES900_T
            else if(modelName === "TCS400") currentKeyMap = keyMapList_CS400_T
            else if(modelName === "TPS825") currentKeyMap = keyMapList_CS825_T
            // GREG - Commented out above and added code below for testing
            //currentKeyMap = keyMapList_CX900_T;
            break;
            //Lateral Trainer
        case 4:
            if(modelName === "TL1000") currentKeyMap = keyMapList_TL1000
            break;

        }
        // update keyMapList
    }

    Timer{
        property int counter: 0
        property int repeatTimerInterval: 350
        property bool diffSlew: false
        property int slewCount: 0

        id:repeatTimer


        interval: repeatTimerInterval
        repeat: true
        running: false
        onTriggered: {
            counter--
            if(!counter){
                counter = 0
                if(diffSlew)
                    repeatTimerInterval = 100
            }

            slewCount++
            keyPressHandler(keybeingpressed)
        }

        onRunningChanged: {
            slewCount = 0
        }
    }

    Timer {
        id: pressAndHoldTimer

        interval: pressAndHoldDuration
        repeat: false
        running: false
        onTriggered: {
            var functionIndex = currentKeyMap.get(keybeingpressed - 1).functionIndex
            pressAndHold(functionIndex)
        }
    }

//    ListModel{
//        id:keyMapList
//        ListElement{functionIndex: 3}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 7}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 4}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 8}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 5}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 0}
//        ListElement{functionIndex: 6}
//    }
    ListModel{
        id:keyMapList
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CX900_T
        ListElement{functionIndex: 4}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 1}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 3}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 2}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 6}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 18}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }

    ListModel{
        id:keyMapList_CS900_T
        ListElement{functionIndex: 4}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 1}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 3}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 2}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 6}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 18}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CS600_T
        ListElement{functionIndex: 4}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 1}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 3}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 2}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 6}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 18}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CS650_T
        ListElement{functionIndex: 4}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 1}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 3}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 2}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 6}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 18}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_ES900_T
        ListElement{functionIndex: 4}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 1}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 3}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 2}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 6}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 18}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CS400_T
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 6}
        ListElement{functionIndex: 3}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 1}
        ListElement{functionIndex: 4}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 2}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 18}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CS825_T
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 6}
        ListElement{functionIndex: 3}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 1}
        ListElement{functionIndex: 4}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 2}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 18}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CX900_B
        ListElement{functionIndex: 8}
        ListElement{functionIndex: 11}
        ListElement{functionIndex: 10}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 7}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 9}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CS900_B
        ListElement{functionIndex: 8}
        ListElement{functionIndex: 11}
        ListElement{functionIndex: 10}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 7}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 9}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CX900_E
        ListElement{functionIndex: 8}
        ListElement{functionIndex: 11}
        ListElement{functionIndex: 10}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 7}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 9}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }
    ListModel{
        id:keyMapList_CS900_E
        ListElement{functionIndex: 8}
        ListElement{functionIndex: 11}
        ListElement{functionIndex: 10}
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 7}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 9}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 25}
        ListElement{functionIndex: 26}
    }

    ListModel{
        id:keyMapList_TS1000_E
        ListElement{functionIndex: 8}
        ListElement{functionIndex: 11}
        ListElement{functionIndex: 26} //Stride Down
        ListElement{functionIndex: 5}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 7}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 25}//Stride Up
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 19}
        ListElement{functionIndex: 23}
        ListElement{functionIndex: 14}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 20}//35
        ListElement{functionIndex: 16}
        ListElement{functionIndex: 21}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 15}
        ListElement{functionIndex: 12}
        ListElement{functionIndex: 22}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 24}
        ListElement{functionIndex: 13}
        ListElement{functionIndex: 17}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
    }

    ListModel{
        id:keyMapList_TL1000
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0} //Stride Down
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//Stride Up
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//index 18
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//20
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//25
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//30
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//35
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//40
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//45
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//50
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//55
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}//59
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
        ListElement{functionIndex: 0}
    }
}
