// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4

Item {
    id: root

    width: childrenRect.width
    height: childrenRect.height

    property bool listening: false
    default property alias controls: visualModel.children
    property variant listView
    property alias model: visualModel
    property int curIndex: findFirstValidIndex()
    property string edgeBehavior: "wrap" // wrap - to wrap index around; emit - to emit a signal
    signal firstExited()
    signal lastExited()

    function nextIndex() {
        var nextVal
        var wrap = function(idx) { return (idx + 1) % visualModel.count }
        for (var i = wrap(curIndex);; i = wrap(i)) {
            if (controls[i].visible && !controls[i].disabled) {
                nextVal = i
                break
            }
        }
        if (nextVal < curIndex) {
            if (edgeBehavior === "wrap")
                curIndex = nextVal
            else
                lastExited()
        } else {
            curIndex = nextVal
        }
    }
    function prevIndex() {
        var nextVal
        var wrap = function(idx) { return (idx - 1 < 0) ? visualModel.count-1 : idx-1 }
        for (var i = wrap(curIndex);; i = wrap(i)) {
            if (controls[i].visible && !controls[i].disabled) {
                nextVal = i
                break
            }
        }
        if (nextVal > curIndex) {
            if (edgeBehavior === "wrap")
                curIndex = nextVal
            else
                firstExited()
        } else {
            curIndex = nextVal
        }
    }

    function findFirstValidIndex() {
        for (var i = 0; i < visualModel.count; i++) {
            console.log("in findFirstValidIndex", controls[i].visible, controls[i].disabled)
            if (controls[i].visible && !controls[i].disabled){
                return i
            }
        }
        return -1
    }

    function findLastValidIndex() {
        for (var i = visualModel.count - 1; i >= 0; i--) {
            if (controls[i].visible && !controls[i].disabled){
                return i
            }
        }
        return -1
    }

    function setSelectedFlag() {
        for (var i = 0; i < controls.length; i++) {
            if (i !== curIndex)
                controls[i].selected = false
            else
                controls[i].selected = true
        }
    }

    onVisibleChanged: {
        console.log("visible changed", visible)
        if (!visible)
            curIndex = -1
        else
            curIndex = findFirstValidIndex()
        setSelectedFlag()
    }

    onCurIndexChanged: {
        setSelectedFlag()
    }

    Connections {
        target: main.isTft && listening ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "KeyedControlList")
            root.prevIndex()
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "KeyedControlList")
            root.nextIndex()
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "KeyedControlList")
            var item = visualModel.children[root.curIndex]
            item.leftPressed()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "KeyedControlList")
            var item = visualModel.children[root.curIndex]
            item.rightPressed()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "KeyedControlList")
            var item = visualModel.children[root.curIndex]
            item.enterPressed()
        }
    }

    VisualItemModel {
        id: visualModel
    }
}
