import QtQuick 2.4
import "workout_menus.js" as Menus
import Components 1.0

Item {
    id: home_screen

    property bool netpulseAvailable: options.netpulseEnabled && netpulse.connected
    property bool showCardio360: false
    property bool showTv: tv.channelList.channels.count > 0
    property string imagedir: "graphics/100/"
    property string tft_imagedir: "graphics/tft/"
    property bool entertainmentShown: true
    property bool buttonsEnabled: true
    property bool hideBackground: false

    property bool ipodSelected: mainNav.currentItem !== undefined && mainNav.currentItem.action === "ipod" && mainNav.currentItem.button !== null && mainNav.currentItem.button.isDown
    property bool tvSelected: mainNav.currentItem !== undefined && mainNav.currentItem.action === "tv" && mainNav.currentItem.button !== null && mainNav.currentItem.button.isDown

    signal loginPressed()
    signal registerPressed()
    signal signoutPressed()
    signal quickstartPressed()
    signal c360QuickstartPressed()
    signal c360QuickstartHeld()
    signal workoutFinderPressed()

    width: 1366
    height: 768
    anchors.fill: parent

    Component.onCompleted: {
        resetModel()
    }

    Connections {
        target: options
        onModestyModeChanged: {
            resetModel()
        }
    }

    Connections {
        target: brainboard
        onProductTypeStringChanged: home_screen.resetModel()
    }

    function resetCursor() {
        if (machineinfo.productTypeString === "Elliptical") {
            browser.currentIndex = 1
        } else {
            browser.currentIndex = 0
        }
    }

    function setIPodButton(connected) {
        if (connected) {
            for (var i = 0; i < mainNav.count; i++) {
                    if (mainNav.model.get(i).action === "ipod") {
                        browser.currentIndex = i
                        mainNav.currentItem.button.setDown(true)
                        break
                    }
            }
        } else {
            if (ipodSelected)
                mainNav.currentItem.button.setDown(false)
        }
    }

    function setTvButton(state) {
        if (state) {
            for (var i = 0; i < mainNav.count; i++) {
                    if (mainNav.model.get(i).action === "tv") {
                        browser.currentIndex = i
                        mainNav.currentItem.button.setDown(true)
                        break
                    }
            }
        } else {
            if (tvSelected)
                mainNav.currentItem.button.setDown(false)
        }
    }

    onShowTvChanged: resetModel()
//    onShowCardio360Changed: resetModel()

    function resetModel() {
        homeButtons.clear()
        // Copy over from baseModel, skipping items that should not be included
        for (var i = 0; i < baseModel.count; i++) {
            var item = baseModel.get(i)
            if (item.action === "tv" && !showTv)
                continue
            if (item.action === "c360quickstart" && !showCardio360)
                continue
            homeButtons.append({label: item.label, desc: item.desc, icon: item.icon, navicon: item.navicon, image: options.modestyMode && item.modestyModeImage ? item.modestyModeImage : item.image, action: item.action})
        }

        browser.model = undefined
        browser.model = homeButtons
        mainNav.model = undefined
        mainNav.model = homeButtons
    }

    Connections {
        id: keyhandler
        property int lastKeypress: 0

        target: main.isTft && !main.blockKeys && main.state === "HomeState" && buttonsEnabled && !ipodSelected && !tvSelected ? keymapper : null
        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "KeyedHomeScreen")
            if (!mainNav.currentItem.button.isDown) {
                scroll_timer.reset()
                var prevItem = mainNav.model.get(browser.currentIndex - 1)
                if (prevItem && prevItem.action === "blank") {
                    browser.decrementCurrentIndex()
                    browser.decrementCurrentIndex()
                } else
                    browser.decrementCurrentIndex()
            }
        }
        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "KeyedHomeScreen")
            if (!mainNav.currentItem.button.isDown) {
                scroll_timer.reset()
                var nextItem = mainNav.model.get(browser.currentIndex + 1)
                if (nextItem && nextItem.action === "blank") {
                    browser.incrementCurrentIndex()
                    browser.incrementCurrentIndex()
                } else
                    browser.incrementCurrentIndex()
            }
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "KeyedHomeScreen")
            keyhandler.lastKeypress = keymapper.keybeingpressed

            var item = mainNav.currentItem

            if (!item.isEnabled)
                return

            if (item.action) {
                if (item.action === "ipod" || item.action === "tv") {
                    mainNav.currentItem.button.setDown(true);
                } else if (item.action === "workoutfinder") {
                    home_screen.workoutFinderPressed()
                } else if (item.action === "languagemenu") {
                    main.state = "LanguageMenuState";
                } else if (item.action === "quickstart") {
                    home_screen.quickstartPressed()
                }
            }
        }
        onEnter2Released: {
            main.debugKeys("enter2Released", "KeyedHomeScreen")

            // Respond to C360 button on release, so that we also handle a press-and-hold event

            // Make sure key press for this key release began on this screen
            var lastpress = keyhandler.lastKeypress
            keyhandler.lastKeypress = 0
            if (lastpress !== 36)
                return

            var item = mainNav.currentItem

            if (!item.isEnabled)
                return

            if(item.action) {
                if (item.action === "c360quickstart") {
                    home_screen.c360QuickstartPressed()
                }
            }
        }

        onPressAndHold: {
            if (mainNav.currentItem && mainNav.currentItem.action === "c360quickstart") {
                if (functionIndex === 16) {
                    home_screen.c360QuickstartHeld()
                }
            }
        }

        onBackPressed: {
            main.debugKeys("backPressed", "KeyedHomeScreen")

            if (mainNav.currentItem.button.isDown) {
                mainNav.currentItem.button.isDown = false;
            }
        }
    }

    Connections {
        target: main.isTft && !main.blockKeys && main.state === "HomeState" && buttonsEnabled && !ipodSelected ? keymapper : null
        onTvPressed: {
            main.debugKeys("tvPressed", "KeyedHomeScreen")
            if (showTv)
                setTvButton(tvSelected ? false : true)
        }
    }

    focus: true

    ProgramBrowser {
        id: browser
        width: 900
        height: 576
        showArrows: false

        opacity: hideBackground ? 0.0 : home_screen.opacity
        focus: visible && (opacity > 0)
        // wait a full timer period after user flips before flipping again
//        onMovingChanged: { description_flip_timer.restart() }
        model: homeButtons
        translationContext: "KeyedHomeScreen"
    }

    ListModel {
        id: homeButtons
    }

    ListModel {
        id: baseModel
        ListElement {
            label: QT_TR_NOOP("Cardio360 QUICK START")
            desc: QT_TR_NOOP("Get right into a pre-set 20-minute workout designed to shape and tone every major muscle group");
            icon: "tft/nav_icon_C360.png"; navicon: "navbar/Navigation_360";
            image: "WF/WF_202_Cardio_360_Workouts.png";
            modestyModeImage: "WF/MaleOnly/WF_202_Cardio_360_Workouts.png"
            action: "c360quickstart"

        }
        ListElement {
            label: QT_TR_NOOP("QUICK START");
            desc: QT_TR_NOOP("Use QUICK START to begin your workout right away!");
            icon: "tft/nav_icon_QS.png"; navicon: "navbar/Navigation_360"
            image: "tft/WF_quickstart.png";
            modestyModeImage: "tft/MaleOnly/WF_image_QuickStart_15inTFT.png"
            action: "quickstart"

        }
        ListElement {
            label: QT_TR_NOOP("WORKOUT FINDER");
            desc: QT_TR_NOOP("Want to try something different? The WORKOUT FINDER will lead you to great workout options based on your fitness goal.");
            icon: "tft/nav_icon_WF.png"; navicon: "navbar/Navigation_360"
            image: "tft/WF_workoutfinder.png";
            action: "workoutfinder"
        }
        ListElement {
            label: ""
            desc: ""
            icon: "tft/nav_icon_blank.png"; navicon: ""
            image: "";
            action: "blank"
        }
        ListElement {
            label: ""
            desc: QT_TR_NOOP("Select settings for your iPod")
            icon: "tft/nav_icon_iPod_gray.png"
            navicon: "navbar/Navigation_360"
            image: "tft/WF_iPod.png"
            modestyModeImage: "tft/MaleOnly/WF_image_iPod_15inTFT.png"
            action: "ipod"

        }
        ListElement {
            label: ""
            desc: QT_TR_NOOP("Adjust television settings");
            icon: "tft/nav_icon_TV_gray.png"; navicon: "navbar/Navigation_360"
            image: "tft/WF_TV.png";
            action: "tv"

        }
        ListElement {
            label: ""
            desc: QT_TR_NOOP("Language Menu");
            icon: "tft/nav_icon_LANGUAGE_gray.png"; navicon: "navbar/Navigation_360"
            image: "tft/WF_language.png";
            action: "languagemenu"
        }
    }

    // pseudo-highlight item for the listview, so that the highlight can be wider than the delegates
    // without worrying about clipping issues, because it is drawn on top of the list view
    Image {
        source: "graphics/tft/NAV_selector.png"
        smooth: true
        x: mainNav.currentItem ? mainNav.x + (mainNav.currentItem.x - mainNav.contentX - 41) : mainNav.x
        y: mainNav.y
        Behavior on x {
            SmoothedAnimation {
                duration: 200
            }
        }
    }
    ListView {
        id: mainNav

        orientation: ListView.Horizontal
        visible: !hideBackground
        width: model ? 160 * model.count : 160*6
        height: 200
        model: homeButtons
        delegate: mainNavDelegate
        highlightMoveVelocity: 1000
        focus: true
        interactive: false
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 90
//        anchors.leftMargin: 200
        anchors.horizontalCenter: parent.horizontalCenter
        preferredHighlightBegin: 0; preferredHighlightEnd: width
        highlightRangeMode: ListView.ApplyRange

        currentIndex: browser.currentIndex
    }

    Component {
        id: mainNavDelegate
        Item {

            width: 160; height: 200;
            property alias button: theButton
            property string action: model.action || ""
            property bool isEnabled: true

            ImageButton {
                id: theButton
                fontsize: 16
                toggle: model.action !== undefined && (model.action === "ipod" || model.action === "tv")

                label: {
                    if (application.currentLanguage === "en" && model.label === "Cardio360 QUICK START") {
                        // Special case: Due to Qt Bug 33204, we cannot include the non-breaking space
                        // character (\xa0) in the QT_TR_NOOP item in the model. Therefore, replace it
                        // specially here for English text.
                        return "Cardio360 QUICK\xa0START"
                    } else {
                        return qsTr(model.label) + application.emptyString
                    }
                }
                label_under: true;
                wrapWidth: 80
                label_y_offset: 50
                label_color: model.action === "quickstart" ? "#5a9634" : "black"
                anchors.verticalCenter: parent.verticalCenter
                anchors.horizontalCenter: parent.horizontalCenter
//                anchors.verticalCenterOffset: (model.action === "ipod" || model.action === "tv" || model.action === "languagemenu") ? -5 : 0
                upimage: Globals.graphicsPath + model.icon
                downimage: Globals.graphicsPath + model.icon
                opacity: buttonsEnabled && isEnabled ? 1.0 : 0.5

                beep: false
                mouseAreaScale: 0.7

            }
        }
    }

    Text {
        id: bottomHelpText

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            if (ipodSelected)
                return qsTr("press BACK to exit iPod navigation") + application.emptyString
            else if (tvSelected)
                return qsTr("press ENTER to select, press TV to exit") + application.emptyString
            else
                return qsTr("press ENTER to select") + application.emptyString
        }

        anchors.top: mainNav.bottom
        anchors.topMargin: 24
        anchors.horizontalCenter: parent.horizontalCenter
    }

    Timer {
        id: scroll_timer
        function reset() {
            scroll_timer.interval = 5000
            scroll_timer.restart()
        }
        running: main.state === "HomeState" && ((machineinfo.productTypeString === "Elliptical" && browser.currentIndex >= 0 && browser.currentIndex <= 2) || (machineinfo.productTypeString !== "Elliptical" && browser.currentIndex >= 0 && browser.currentIndex <= 1))
        onRunningChanged: {
            if (!running)
                interval = 5000
        }
        repeat: true
        interval: 5000
        onTriggered: {
            if (interval === 5000) // interval is 5s from stopped state, and then 3s after
                interval = 3000

            if (machineinfo.productTypeString === "Elliptical") {
                browser.currentIndex = (browser.currentIndex + 1) % 3
            } else {
                browser.currentIndex = (browser.currentIndex + 1) % 2
            }
        }
    }

    Image {
        id: bluetoothSmartLogo
        visible: main.isTft
        source: "graphics/tft/Bluetooth_S_logo.png"
        anchors {
            bottom: parent.bottom
            bottomMargin: 8
            right: parent.right
            rightMargin: 90
        }
    }

}
