import QtQuick 2.4
import WorkoutManager 1.0
import Components 1.0

import "string_format.js" as Format
import "program_setup.js" as Fields
import "tft_workout_menus.js" as TftMenus
import "setup_params.js" as SetupJS

Item {
    id: root
    property alias model: myListView.model
    property QtObject timeItem
    property QtObject distItem
    property QtObject calItem
    property bool timeGoal: true
    property bool distGoal: false
    property int maxCalPerHr: 1600

    onModelChanged: SetupJS.modelPostProcessing()

    function setParameter(type, value) {
        return SetupJS.setParameter(type, value)
    }

    function validateEntries() {
        return SetupJS.validateEntries()
    }

    function recalcMaxSegments() {
        SetupJS.calculateMaxSegmentsFromTime()
    }

    // Reset saved flag when any data is changed
    Connections {
        target: root.model ? root.model : null
        ignoreUnknownSignals: true
        onDataChanged: {
            mainProgItem.saveHasHappened = false
        }
    }

    // Validate data relationships when any value is changed
    Connections {
        target: root.model ? root.model : null
        ignoreUnknownSignals: true
        onDataChanged: {
            if(isTreadmill && calItem) // Treadmill calorie goal setup
                SetupJS.validateTreadCalorieGoal()
            if (!isTreadmill && calItem) {
                SetupJS.validateNonTreadCalorieGoal()
            }
        }
    }

    Connections {
        target: timeItem
        onDataChanged: {
            if(timeItem.dataValue > 0) {
                root.timeGoal = true
                root.distGoal = false
            }
        }
    }
    Connections {
        target: distItem
        onDataChanged: {
            if(distItem.dataValue > 0) {
                root.timeGoal = false
                root.distGoal = true
            }
        }
    }

    Connections {
        target: main.isTft && !main.blockKeys && root.opacity > 0 && root.visible && main.state == "SetupState" && !hrGuide.item ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "KeyedSetupParams")
            var nextIndex = myListView.getNextLeftIndex()
            if (nextIndex > myListView.currentIndex) { // navigation wrapped
                myListView.highlightMoveVelocity = 4000
                myListView.currentIndex = nextIndex
                myListView.highlightMoveVelocity = 400
            } else {
                myListView.currentIndex = nextIndex
            }
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "KeyedSetupParams")
            if (myListView.model.get(myListView.currentIndex).fieldType === WorkoutProgram.MORE_TYPE) {
                mainProgItem.nextState()
            }

            var nextIndex = myListView.getNextRightIndex()
            if (nextIndex < myListView.currentIndex) { // navigation wrapped
                myListView.highlightMoveVelocity = 4000
                myListView.currentIndex = nextIndex
                myListView.highlightMoveVelocity = 400
            } else {
                myListView.currentIndex = nextIndex
            }
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "KeyedSetupParams")
            myListView.currentItem.downValue()
        }

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "KeyedSetupParams")
            myListView.currentItem.upValue()
        }

        onInclineUpPressed: {
            main.debugKeys("inclineUpPressed", "KeyedSetupParams")
            myListView.currentItem.upValue()
        }

        onInclineDownPressed: {
            main.debugKeys("inclineDownPressed", "KeyedSetupParams")
            myListView.currentItem.downValue()
        }

        onSpeedUpPressed: {
            main.debugKeys("speedUpPressed", "KeyedSetupParams")
            myListView.currentItem.upValue()
        }

        onSpeedDownPressed: {
            main.debugKeys("speedDownPressed", "KeyedSetupParams")
            myListView.currentItem.downValue()
        }

        onLevelUpPressed: {
            main.debugKeys("levelUpPressed", "KeyedSetupParams")
            myListView.currentItem.upValue()
        }

        onLevelDownPressed: {
            main.debugKeys("levelDownPressed", "KeyedSetupParams")
            myListView.currentItem.downValue()
        }

        onPlusPressed: {
            main.debugKeys("plusPressed", "KeyedSetupParams")
            myListView.currentItem.upValue()
        }

        onMinusPressed: {
            main.debugKeys("minusPressed", "KeyedSetupParams")
            myListView.currentItem.downValue()
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "KeyedSetupParams")
            if (myListView.currentIndex === 0) {
                navbar.goBack()
            } else if (myListView.model.get(myListView.currentIndex).fieldType === WorkoutProgram.SAVE_TYPE) {
                setupScreenManager.state = "SaveWorkoutScreen"
            } else if (myListView.model.get(myListView.currentIndex).fieldType === WorkoutProgram.VIEW_HRC_TYPE) {
                mainProgItem.showHRChart()
            } else if (myListView.model.get(myListView.currentIndex).fieldType === WorkoutProgram.MORE_TYPE) {
                mainProgItem.nextState()
            }
        }
    }

    Rectangle{
        id:imageContainer
        anchors { top: parent.top; left: parent.left; topMargin: 95; leftMargin: 25 }
        radius: 20
        color: "#909090"
        width: 400
        height: 290
        Image {
            id: workout_image
            source: Globals.graphicsPath + TftMenus.getProgramImage(workoutProgram.programIndex)
        }
    }

    Image {
        id: imageShadow
        source: "graphics/200/Swipe_Shadow.png"
        anchors { top: imageContainer.bottom; left: imageContainer.left; leftMargin: -15 }
    }

    Text {
        id: prog_setup_desc_text
        x: 850
        y: 156
        width: 450
        text: {
            var tftOffset = main.isTft ? -1 : 0 // subtract 1 to offset back button on TFT
            var item = myListView.model ? myListView.model.get(myListView.currentIndex) : undefined
            if (main.isTft && item && item.fieldType === WorkoutProgram.BACK_TYPE) {
                return qsTr("Return to previous menu") + application.emptyString
            }
            else if (main.isTft && item && item.fieldType === WorkoutProgram.SAVE_TYPE) {
                return qsTr("Do you want to save this workout setup?") + application.emptyString
            } else if (main.isTft && item && item.fieldType === WorkoutProgram.VIEW_HRC_TYPE) {
                return qsTr("To view HEART RATE guidelines based on age, press ENTER.") + application.emptyString
            }
            // TODO can be simplified because programIndex now maps to correct index, even for saved workouts
            else if (programIndex >= WorkoutProgram.MANUAL_PROG && programIndex < WorkoutProgram.SAVED_WORKOUT) {
                // Subtract 3 from programIndex to account for NO_PROG and QUICK_START_PROG and TREAD_QUICK_START_PROG
                var str = Fields.workout_programs[(programIndex - 3)][(mainProgItem.fieldIndex - 1) + tftOffset]
                return str ? application.translateText("Setup", str) + application.emptyString : ""
            }
            else if (programIndex == WorkoutProgram.SAVED_WORKOUT) {
                if (mainProgItem.customProgType == WorkoutProgram.CUSTOM_PACE_PROG ||
                        mainProgItem.customProgType == WorkoutProgram.CUSTOM_HILLS_PROG ||
                        mainProgItem.customProgType == WorkoutProgram.CUSTOM_ULTRA_PROG ||
                        mainProgItem.customProgType == WorkoutProgram.TREAD_CUSTOM_HILLS_PROG ||
                        mainProgItem.customProgType == WorkoutProgram.TREAD_CUSTOM_SPEED_PROG ||
                        mainProgItem.customProgType == WorkoutProgram.TREAD_CUSTOM_ULTRA_PROG) {
                    var str = Fields.workout_programs[(mainProgItem.customProgType - 3)][(mainProgItem.fieldIndex - 1) + tftOffset]
                    return str ? application.translateText("Setup", str) + application.emptyString : ""
                } else {
                    return "NA"
                }
            }
            else {
                return "NA"
            }
        }
        color: "black"
        wrapMode: Text.WordWrap
        lineHeight: 1.0
        horizontalAlignment: Text.AlignRight
        font.pixelSize: (text.length > 300) ? 24 : 28
    }

    Item {
        id: calWarning

        visible: false
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 50
        anchors.left: parent.left
        anchors.leftMargin: 10
        width: 450
        height: 50

        Image{
            id: calCautionSymbol
            source: "graphics/Icon_Warning.png"
            anchors.left: parent.left
            anchors.verticalCenter: parent.verticalCenter
        }

        Text {
            text: qsTr( "The calorie goal chosen is too high for selected workout time.") + application.emptyString
            wrapMode: Text.WordWrap
            font.pixelSize: 16
            anchors.left: calCautionSymbol.right
            anchors.verticalCenter: parent.verticalCenter
        }
    }

    Text {
        id: upDownHelpText
        text: qsTr("use") + "  <img src=\"graphics/tft/arrow_up.png\" />  " + qsTr("or") + "  <img src=\"graphics/tft/arrow_down.png\" />  " + qsTr("to change value") + application.emptyString
        font.pixelSize: 15
        font.bold: true
        anchors { bottom: myListView.top; bottomMargin: 35; horizontalCenter: parent.horizontalCenter }
        height: 25
        verticalAlignment: Text.AlignVCenter
    }

    // pseudo-highlight item for the listview, so that the highlight can be wider than the delegates
    // without worrying about clipping issues, because it is drawn on top of the list view
    Image {
        source: "graphics/tft/NAV_selector.png"
        smooth: true
        x: myListView.currentItem ? myListView.x + (myListView.currentItem.x - myListView.contentX - 40) : myListView.x
        y: myListView.y
        Behavior on x {
            SmoothedAnimation {
                duration: 100
            }
        }
    }

    ListView {
        id: myListView
        property bool wrapNavigation: !(workoutProgram.profile1.isCustom || workoutProgram.profile2.isCustom || isC360Custom)
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 65
        anchors.horizontalCenter: parent.horizontalCenter
        cacheBuffer: 400
        width: {
            if (!myListView.model)
                return 1366
            else {
                var visibleCount = myListView.model.count
                var visibleMax = 7
                if (workoutProgram.programIndex === WorkoutProgram.TREAD_CALORIE_PROG) {
                    // calorie goal field is hidden, and moved outside list, in tread calorie goal
                    // this leads to special layout needs for the workout setup
                    visibleCount--
                    visibleMax = 5
                }
                return (visibleCount < visibleMax ? 160 * visibleCount : 160*visibleMax)
            }
        }
        height: 250
        interactive: false
        delegate: myDelegate
        orientation: ListView.Horizontal
        clip: true
        preferredHighlightBegin: width/2 - 80
        preferredHighlightEnd: width/2 + 80
        highlightRangeMode: ListView.ApplyRange

        function getNextLeftIndex() {
            if (currentIndex === 0 && !myListView.wrapNavigation)
                return 0

            var origIndex = currentIndex
            var wrap = function(idx) { return (idx - 1) < 0 ? myListView.count - 1 : (idx - 1) };
            for (var i = wrap(origIndex);; i = wrap(i)) {
                if (!SetupJS.isReadOnlyType(model.get(i).fieldType))
                    return i

                if (i === 0 && !myListView.wrapNavigation)
                    return origIndex // no valid items to left of starting point, so index does not change
            }
            return -1
        }

        function getNextRightIndex() {
            if (currentIndex === myListView.count - 1 && !myListView.wrapNavigation)
                return currentIndex

            var origIndex = currentIndex
            var wrap = function(idx) { return (idx + 1) % myListView.count };
            for (var i = wrap(origIndex);; i = wrap(i)) {
                if (!SetupJS.isReadOnlyType(model.get(i).fieldType))
                    return i

                if (i === myListView.count - 1 && !myListView.wrapNavigation)
                    return origIndex // no valid items to right of starting point, so index does not change
            }
            return -1
        }

        onCurrentIndexChanged: {
            var item = model.get(currentIndex)
            if(!item)
                return

            mainProgItem.selectedIndex = currentIndex
            mainProgItem.fieldIndex = item.fieldIndex

            if (item.fieldType === WorkoutProgram.MORE_TYPE) {
                mainProgItem.nextState()
            }
        }

        Component {
            id: myDelegate
            Item {
                id: dataElement

                width: hiddenField ? 0 : 160
                height: hiddenField ? 0 : 213
                visible: !hiddenField

                property alias _slider3: sliderObject3
                property bool isDummyButton: model.fieldType === WorkoutProgram.SAVE_TYPE || model.fieldType === WorkoutProgram.BACK_TYPE || model.fieldType === WorkoutProgram.VIEW_HRC_TYPE || model.fieldType === WorkoutProgram.MORE_TYPE
                property bool hiddenField: model.fieldType === WorkoutProgram.CALORIE_POTENTIAL_TYPE

                function downValue() {
                    if (model.fieldType === WorkoutProgram.DISTANCE_QUICK_TYPE) {
                        distancePreset.prevDistance()
                    } else {
                        var slider = getSliderForUpdate()
                        if (slider) {
                            if (model.fieldType === WorkoutProgram.CALORIES_TYPE && keymapper.slewCount >= 50) {
                                slider.decrementBy(10)
                            } else {
                                slider.decrementValue()
                            }
                        }
                    }
                }

                function upValue() {
                    if (model.fieldType === WorkoutProgram.DISTANCE_QUICK_TYPE) {
                        distancePreset.nextDistance()
                    } else {
                        var slider = getSliderForUpdate()
                        if (slider) {
                            if (model.fieldType === WorkoutProgram.CALORIES_TYPE && keymapper.slewCount >= 50) {
                                slider.incrementBy(10)
                            } else {
                                slider.incrementValue()
                            }
                        }
                    }
                }

                function getSliderForUpdate() {
                    switch(model.fieldType) {
                        case WorkoutProgram.MAX_SPEED_TYPE:
                        case WorkoutProgram.MAX_INCLINE_TYPE:
                        case WorkoutProgram.SPEED_TYPE:
                        case WorkoutProgram.RUN_SPEED_TYPE:
                        case WorkoutProgram.WORK_SPEED_TYPE:
                        case WorkoutProgram.WALK_SPEED_TYPE:
                        case WorkoutProgram.REST_SPEED_TYPE:
                        case WorkoutProgram.TIME_TYPE:
                        case WorkoutProgram.PACE_TYPE:
                        case WorkoutProgram.WORKLOAD_TYPE:
                        case WorkoutProgram.AGE_TYPE:
                        case WorkoutProgram.WEIGHT_TYPE:
                        case WorkoutProgram.DISTANCE_TYPE:
                        case WorkoutProgram.INCLINE_TYPE:
                        case WorkoutProgram.CALORIES_TYPE:
                        case WorkoutProgram.LEVEL_TYPE:
                        case WorkoutProgram.MIN_STRIDE_TYPE:
                        case WorkoutProgram.MAX_STRIDE_TYPE:
                            return sliderObject
                        case WorkoutProgram.GENDER_TYPE:
                            return genderSlider
                        case WorkoutProgram.WORK_HEARTRATE_TYPE:
                        case WorkoutProgram.REST_HEARTRATE_TYPE:
                        case WorkoutProgram.TARGET_HEARTRATE_TYPE:
                            return sliderObject2
                        case WorkoutProgram.DISTANCE_QUICK_TYPE:
                            // distance quick type uses presets and sets dataValue directly
                            return undefined
                        case WorkoutProgram.TARGET_HEARTRATEREADONLY_TYPE:
                        case WorkoutProgram.FIXED_DISTANCE_TYPE:
                        case WorkoutProgram.TIMEREADONLY_TYPE:
                        case WorkoutProgram.CALORIE_POTENTIAL_TYPE:
                            // do not update any slider for read-only types
                            return undefined
                        case WorkoutProgram.SEGMENT_TYPE:
                            return sliderObject3

                    }
                }

                state: {
                    if (model.fieldType === WorkoutProgram.DISTANCE_QUICK_TYPE)
                        return "DistanceQuickState"
                    else if (isDummyButton)
                        return "DummyButtonState"
                    else
                        return "NormalState"
                }

                Item {
                    id: distancePreset
                    property int distIndex: 0
                    property string value: ""
                    function nextDistance() {
                        distIndex = (distIndex + 1) % 4
                    }
                    function prevDistance() {
                        distIndex = (distIndex - 1) < 0 ? 3 : (distIndex - 1)
                    }
                    onDistIndexChanged: {
                        if (model.fieldType != WorkoutProgram.DISTANCE_QUICK_TYPE)
                            return

                        var dist, units
                        switch (distIndex) {
                            case 0: {
                                dist = 5
                                units = "K"
                                break
                            }
                            case 1: {
                                dist = 10
                                units = "K"
                                break
                            }
                            case 2: {
                                dist = 2
                                units = "MI"
                                break
                            }
                            case 3: {
                                dist = 4
                                units = "MI"
                                break
                            }
                        }
                        myListView.model.setProperty(index, "dataValue", dist)
                        myListView.model.setProperty(index, "units", units)
                    }
                }

                Text {
                    id: viewText
                    visible: model.fieldType === WorkoutProgram.VIEW_HRC_TYPE
                    text: qsTr("VIEW") + application.emptyString
                    font { family: "arial"; pointSize: 18; letterSpacing: -1; weight: Font.DemiBold }
                    anchors { bottom: imageIcon.top; bottomMargin: -5; horizontalCenter: parent.horizontalCenter }
                }

                // folded up state elements
                Image {
                    id: imageIcon
                    visible: isDummyButton
                    anchors {
                        top: itemName.top
                        topMargin: {
                            switch (model.fieldType) {
                                case WorkoutProgram.VIEW_HRC_TYPE:
                                    return 24
                                case WorkoutProgram.MORE_TYPE:
                                    return 6
                                default:
                                    return -12
                            }
                        }
                        horizontalCenter: parent.horizontalCenter
                    }
                    source: {
                        switch (model.fieldType) {
                            case WorkoutProgram.BACK_TYPE:
                                return "graphics/tft/nav_icon_BACK.png"
                            case WorkoutProgram.SAVE_TYPE:
                                return "graphics/tft/nav_icon_SAVED.png"
                            case WorkoutProgram.VIEW_HRC_TYPE:
                                return "graphics/tft/nav_icon_HRC_blue.png"
                            case WorkoutProgram.MORE_TYPE:
                                return "graphics/tft/arrow_right.png"
                            default:
                                return ""
                        }
                    }
                }

                Text {
                    id: dummyText
                    visible: isDummyButton
                    text: {
                        switch (model.fieldType) {
                            case WorkoutProgram.BACK_TYPE:
                                return qsTr("BACK") + application.emptyString
                            case WorkoutProgram.SAVE_TYPE:
                                return qsTr("SAVE?") + application.emptyString
                            case WorkoutProgram.VIEW_HRC_TYPE:
                                return qsTr("CHART") + application.emptyString
                            case WorkoutProgram.MORE_TYPE:
                                return qsTr("NEXT") + application.emptyString
                            default:
                                return ""
                        }
                    }
                    anchors {
                        top: imageIcon.bottom
                        topMargin: model.fieldType === WorkoutProgram.VIEW_HRC_TYPE ? -10 : 20
                        horizontalCenter: parent.horizontalCenter
                    }
                    font.pointSize: 14
                    horizontalAlignment: Text.AlignHCenter
                    width: parent.width
                    font.bold: true
                    color: model.fieldType === WorkoutProgram.MORE_TYPE ? "gray" : "black"
                    smooth: true
                }

                Text {
                    id: itemName
                    anchors.top: parent.top
                    anchors.topMargin: font.pointSize === 12 ? 56 : 54
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: 0
                    text: isDummyButton ? "" : qsTranslate("WorkoutSetup", SetupJS.getItemLabel(model)) + SetupJS.getItemAdditionalLabel(model) + application.emptyString
                    font {
                        family: "arial"
                        pointSize: text.length > 17 || application.currentLanguage === "nl" && text.length > 10 ? 12 : 18
                        letterSpacing: -1
                        weight: Font.DemiBold
                    }
                    horizontalAlignment: Text.AlignHCenter
                    width: parent.width
                    wrapMode: Text.WordWrap
                    lineHeight: 0.9
                    smooth: true
                    color: "black"
                    z: 2
                    visible: !isDummyButton
                }

                Text {
                    id: itemValue
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.verticalCenterOffset: 20
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: 0
                    text: isDummyButton ? "" : SetupJS.getValueString(model)
                    font {
                        family: "arial"
                        pointSize: 36
                        bold: true
                    }
                    smooth: true
                    color: "black"
                    z: 2
                    visible: !isDummyButton
                }

                Text {
                    id: itemUnits
                    anchors.top: itemValue.bottom
                    anchors.topMargin: 6
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: 0
                    text: model.units
                    font {
                        family: "arial"
                        pointSize: 12
                        bold: true
                    }
                    wrapMode: Text.WordWrap
                    smooth: true
                    color: "black"
                    z: 2
                    visible: !isDummyButton
                }

                Text {
                    id: distanceValue
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.verticalCenterOffset: 20
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: 0
                    text: model.dataValue + (model.units === "K" ? "k" : "mi")
                    font {
                        family: "arial"
                        pointSize: 36
                        bold: true
                    }
                    smooth: true
                    color: "black"
                    z: 2
                }

                Image {
                    id: grayBackground
                    visible: levelDetailsArea.visible
                    source: "graphics/tft/setup_HR_grayshape.png"
                    anchors { top: itemValue.top; horizontalCenter: parent.horizontalCenter }
                    z: cautionText.z + 2
                }

                Item {

                    id: levelDetailsArea

                    visible: isTreadmill && model.fieldType === WorkoutProgram.LEVEL_TYPE
                    anchors { top: itemValue.bottom; topMargin: 25; horizontalCenter: parent.horizontalCenter }
                    width: 95
                    z: 1000

                    Text {
                        id: levelSubValue
                        width: paintedWidth
                        text: SetupJS.levelDetailsGetSubValue(model.dataValue)
                        font { pixelSize: 36; bold: true }
                        color: "white"
                        anchors {
                            top: parent.top
                            horizontalCenter: parent.horizontalCenter
                            horizontalCenterOffset: -levelSubUnits.width/2
                        }
                        smooth: true
                        z: 2
                    }

                    Text {
                        id: levelSubUnits
                        width: paintedWidth
                        anchors { left: levelSubValue.right; bottom: levelSubValue.bottom; bottomMargin: 10 }
                        text: SetupJS.levelDetailsGetUnits() + application.emptyString
                        font { pointSize: 12; bold: true }
                        smooth: true
                        color: "white"
                        z: 2
                    }

                    Text {
                        id: levelSubLabel
                        width: paintedWidth
                        text: SetupJS.levelDetailsGetLabel() + application.emptyString
                        font { family: "arial"; pointSize: 12; letterSpacing: -1; weight: Font.DemiBold }
                        anchors { top: levelSubValue.bottom ; horizontalCenter: parent.horizontalCenter }
                        smooth: true
                        color: "white"
                        z: 2
                    }
                }

                Image {
                    id: segmentBackground
                    source: "graphics/tft/setup_HR_grayshape.png"
                    visible: model.fieldType === WorkoutProgram.SEGMENT_TYPE
                    anchors { top: itemValue.top; horizontalCenter: parent.horizontalCenter }
                    z: cautionText.z + 2
                }

                Text {
                    id: segmentComputedTime
                    font { pixelSize: 36; bold: true }
                    color: "white"
                    visible: segmentBackground.visible
                    text: Format.formatTimeString(mainProgItem.segTime)
                    anchors {
                        top: segmentBackground.top
                        topMargin: 85
                        horizontalCenter: parent.horizontalCenter
                    }
                    z: cautionText.z + 2
                }

                Text {
                    id: segmentTimeLabel
                    font { pixelSize: 16; bold: true }
                    color: "white"
                    visible: segmentBackground.visible
                    text: qsTr("TIME") + application.emptyString
                    anchors { horizontalCenter: parent.horizontalCenter; top: segmentComputedTime.bottom; topMargin: -10 }
                    z: cautionText.z + 2
                }

                Image {
                    id: hrBackground
                    source: "graphics/tft/setup_HR_grayshape.png"
                    visible: SetupJS.isHeartRateType(model.fieldType)
                    anchors { top: itemValue.top; horizontalCenter: parent.horizontalCenter }
                    z: cautionText.z + 2
                }

                Text {
                    id: hrPercentValue
                    font { pixelSize: 36; bold: true }
                    color: "white"
                    visible: hrBackground.visible
                    text: model.heartRatePercentage
                    anchors {
                        top: hrBackground.top
                        topMargin: 85
                        horizontalCenter: parent.horizontalCenter
                        horizontalCenterOffset: -5
                    }
                    z: cautionText.z + 2
                }

                Text {
                    id: hrPercentSign
                    font { pixelSize: 16; bold: true }
                    color: "white"
                    visible: hrBackground.visible
                    text: "%"
                    anchors { verticalCenter: hrPercentValue.verticalCenter; left: hrPercentValue.right }
                    z: cautionText.z + 2
                }

                Text {
                    id: maxHrText
                    font { pixelSize: 16; bold: true }
                    color: "white"
                    visible: hrBackground.visible
                    text: qsTr("MAX HR") + application.emptyString
                    anchors { horizontalCenter: parent.horizontalCenter; top: hrPercentValue.bottom; topMargin: -10 }
                    z: cautionText.z + 2
                }

                states: [
                    State { name: "NormalState"
                        PropertyChanges { target: imageIcon; visible: false }
                        PropertyChanges { target: dummyText; visible: false }
                        PropertyChanges { target: itemName; visible: true }
                        PropertyChanges { target: distanceValue; visible: false }
                        PropertyChanges { target: itemValue; visible: true }
                        PropertyChanges { target: itemUnits; visible: true }
                    },

                    State { name: "DistanceQuickState"
                        PropertyChanges { target: imageIcon; visible: false }
                        PropertyChanges { target: dummyText; visible: false }
                        PropertyChanges { target: itemName; visible: true }
                        PropertyChanges { target: distanceValue; visible: true }
                        PropertyChanges { target: itemValue; visible: false }
                        PropertyChanges { target: itemUnits; visible: false }
                    },

                    State { name: "DummyButtonState"
                        PropertyChanges { target: imageIcon; visible: true }
                        PropertyChanges { target: dummyText; visible: true }
                        PropertyChanges { target: itemName; visible: true }
                        PropertyChanges { target: distanceValue; visible: false }
                        PropertyChanges { target: itemValue; visible: false }
                        PropertyChanges { target: itemUnits; visible: false }
                    }
                ]

                // expanded state elements
                Text {
                    id: itemUnitsDetails
                    anchors.top: parent.top
                    anchors.topMargin: 87
                    anchors.right: parent.right
                    anchors.rightMargin: 15
                    text: model.units
                    font.pointSize: 20
                    wrapMode: Text.WordWrap
                    font.bold: true
                    smooth: true
                    color: "black"
                    z: 2
                    visible: false
                }
                Text {
                    // Value seen while editing expanded item
                    id: itemValueDetails
                    anchors.bottom: itemUnitsDetails.bottom
                    anchors.bottomMargin: -4
                    anchors.right: itemUnitsDetails.left
                    anchors.rightMargin: 5
                    text: isDummyButton ? "" : SetupJS.getValueString(model)

                    font.pointSize: 34
                    font.bold: true
                    smooth: true
                    color: "black"
                    z: 2
                    visible: false
                    onTextChanged: {
                        SetupJS.itemValueDetailsTextChanged(sliderObject, sliderObject2, sliderObject3, genderSlider, model)
                    }
                }

                Text {
                    id: hrDividerText
                    anchors.top: parent.top
                    anchors.topMargin: 72
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.horizontalCenterOffset: 40
                    text: "<Center>/<br>"+qsTr("OR")+"</Center>" + application.emptyString
                    font.pointSize: 14
                    font.bold: true
                    smooth: true
                    color: "black"
                    z: 2
                    visible: false
                }

                Text {
                    id: hrPercentageUnits
                    anchors.top: parent.top
                    anchors.topMargin: 83
                    anchors.right: parent.right
                    anchors.rightMargin: 20
                    text: qsTr("%MAX") + application.emptyString
                    font.pointSize: text.length > 6 ? 12 : 18
                    wrapMode: Text.WordWrap
                    width: 80
                    height: 40
                    verticalAlignment: Text.AlignBottom
                    font.bold: true
                    smooth: true
                    color: "black"
                    z: 2
                    visible: false
                }

                Text {
                    id: hrPercentageValue
                    anchors.bottom: hrPercentageUnits.bottom
                    anchors.bottomMargin: -6
                    anchors.right: hrPercentageUnits.left
                    anchors.rightMargin: 5
                    text: model.heartRatePercentage
                    font.pointSize: 32
                    font.bold: true
                    smooth: true
                    color: "black"
                    z: 2
                    visible: false
                }


//                Text {
//                    id: indexValue
//                    text: model.selectedIndex
//                    font.pointSize: 24
//                    color: "black"
//                    visible: false
//                }

                Item {
                    // slider control box seen after expanding most simple items (age, weight, time, etc.)
                    id: details

                    property int value: sliderObject.value

                    height: 155
                    width: 460
                    anchors.top: dataElement.top
                    anchors.topMargin: 85
                    anchors.left: dataElement.left
                    anchors.leftMargin: 50
                    opacity: 0
                    visible: false

                    Image {
                        id: dataIndicatorBackground
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                        source: "graphics/setup/Setup_Large_Up_Step2.png"
                    }

                    SliderControl {
                        id: sliderObject
                        repeat: true

                        Component.onCompleted: {
                            valueProxy = model.dataValue
                        }

                        onValueChanged: {
                            SetupJS.sliderObjectValueChanged(model, value, valueProxyChange, index)
                        }
                        showValue: false
                        maxValue: model.maxValue
                        minValue: model.minValue
                        value: model.dataValue
                        precision: model.precision
                        stepValue: {
                            if (model.precision == 0) {
                                return 1;
                            }
                            else if (model.precision == 1) {
                                return 0.1;
                            }
                        }

                        incrementButtonImage: "graphics/Pace_Setter_Simple_Plus.png"
                        decrementButtonImage: "graphics/Pace_Setter_Simple_Minus.png"
                        anchors.top: parent.top
                        anchors.topMargin: 75
                        anchors.left: parent.left
                        anchors.leftMargin: 45
                        width: 350
                        height: 34
                    }
                }

                Item {
                    // slider control box seen after expanding gender control
                    id: genderDetails
                    height: 155
                    width: 460
                    anchors.top: dataElement.top
                    anchors.topMargin: 85
                    anchors.left: dataElement.left
                    anchors.leftMargin: 50
                    opacity: 0
                    visible: false

                    Image {
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                        source: "graphics/setup/Setup_Large_Up_Step2.png"
                    }

                    SliderControl {
                        id: genderSlider

                        function incrementValue() {
                            genderSlider.value = (genderSlider.value + 1) % 2
                        }
                        function decrementValue() {
                            genderSlider.value = (genderSlider.value === 0) ? 1 : 0
                        }
                        onValueChanged: {
                            SetupJS.genderSliderValueChanged(model, value, index)
                        }
                        showValue: false
                        maxValue: 1 // FEMALE
                        minValue: 0 // MALE
                        value: model.dataValue
                        precision: 0
                        showButtons: false
                        anchors.top: parent.top
                        anchors.topMargin: 75
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.horizontalCenterOffset: -20
                        width: 300 - femaleText.width - maleText.width
                        height: 34

                        Text {
                            id: maleText
                            width:paintedWidth
                            anchors { right: parent.left ; rightMargin: 40; verticalCenter: parent.verticalCenter }
                            text: qsTr("MALE") + application.emptyString
                            MouseArea {
                                anchors.fill: parent ; onClicked: genderSlider.value = 0
                            }
                        }

                        Text {
                            id: femaleText
                            width:paintedWidth
                            text: qsTr("FEMALE") + application.emptyString
                            anchors { left: parent.right ; leftMargin: 40; verticalCenter : parent.verticalCenter  }
                            MouseArea {
                                anchors.fill: parent ; onClicked: genderSlider.value = 1
                            }
                        }
                    }
                }

                Item {
                    // heart rate setting drop down sliders
                    id: expandedDetails2
                    height: 155
                    width: 460
                    anchors.top: dataElement.top
                    anchors.topMargin: 85
                    anchors.left: dataElement.left
                    anchors.leftMargin: 40
                    opacity: 0
                    visible: false

                    Image {
                        id: dataIndicatorBackground3
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                        source: "graphics/setup/Setup_Large_Up_Step2.png"
                    }

                    SliderControl {
                        id: sliderObject2

                        onValueChanged: {
                            SetupJS.sliderObject2ValueChanged(model, value, index)
                        }
                        showValue: false
                        maxValue: model.maxValue
                        minValue: model.minValue
                        value: model.dataValue
                        incrementButtonImage: "graphics/Pace_Setter_Simple_Plus.png"
                        decrementButtonImage: "graphics/Pace_Setter_Simple_Minus.png"
                        anchors.top: parent.top
                        anchors.topMargin: 75
                        anchors.left: parent.left
                        anchors.leftMargin: 45
                        width: 350
                        height: 34
                    }
                }

                Item {
                    // drop down slider for setting number of segments for custom profile programs
                    id: segmentDetails
                    height: 155
                    width: 460
                    anchors.top: dataElement.top
                    anchors.topMargin: 85
                    anchors.left: dataElement.left
                    anchors.leftMargin: 50
                    opacity: 0
                    visible: false

                    Image {
                        id: dataIndicatorBackground5
                        anchors.top: sliderObject3.top
                        anchors.topMargin: 15
                        anchors.left: sliderObject3.left
                        anchors.leftMargin: 15
                        source: "graphics/setup/Setup_Large_Up_Step3.png"
                    }

                    Text {
                        id: calculatedSegTime1
                        anchors.verticalCenter: dataIndicatorBackground5.verticalCenter
                        anchors.left: dataIndicatorBackground5.left
                        anchors.leftMargin: 30
                        text: qsTr("SEGMENT TIME") + application.emptyString
                        font.pointSize: 18
                        font.bold: true
                        smooth: true
                        color: "black"
                        z: 2
                    }

                    Text {
                        id: calculatedSegTimeValue1
                        anchors.verticalCenter: dataIndicatorBackground5.verticalCenter
                        anchors.right: dataIndicatorBackground5.right
                        anchors.rightMargin: 40
                        text: Format.formatTimeString(mainProgItem.segTime);
                        font.pointSize: 32
                        font.bold: true
                        smooth: true
                        color: "black"
                        z: 2
                    }

                    Text {
                        id: calculatedSegTimeNote
                        anchors.verticalCenter: dataIndicatorBackground5.verticalCenter
                        anchors.verticalCenterOffset: 30
                        anchors.right: dataIndicatorBackground5.right
                        anchors.rightMargin: 40
                        text: qsTr("(MINIMUM SEGMENT TIME IS 1:00)") + application.emptyString
                        font.pointSize: 12
                        font.bold: true
                        smooth: true
                        color: "black"
                        z: 2
                    }

                    Image {
                        id: dataIndicatorBackground4
                        anchors.horizontalCenter: parent.horizontalCenter
                        anchors.verticalCenter: parent.verticalCenter
                        source: "graphics/setup/Setup_Large_Up_Step2.png"
                    }

                    SliderControl {
                        id: sliderObject3

                        onValueChanged: {
                            SetupJS.sliderObject3ValueChanged(model, value, index)
                        }
                        showValue: false
                        minValue: model.minValue
                        maxValue: model.maxValue
                        value: model.dataValue
                        precision: model.precision
                        stepValue: {
                            if (model.precision == 0) {
                                return 1;
                            }
                            else if (model.precision == 1) {
                                return 0.1;
                            }
                        }

                        anchors.top: parent.top
                        anchors.topMargin: 75
                        anchors.left: parent.left
                        anchors.leftMargin: 45
                        width: 350
                        height: 34
                    }
                }
            }
        }
    }

    Item {
        id: calculatedCaloriesField
        visible: calItem !== null && workoutProgram.programIndex === WorkoutProgram.TREAD_CALORIE_PROG
        anchors { right: parent.right; rightMargin: 60; verticalCenter: myListView.verticalCenter; verticalCenterOffset: -37 }
        width: calcCalImage.width
        height: calcCalImage.height

        Image {
            id: calcCalImage
            source: "graphics/tft/setup_calgoal_grayshape.png"
            anchors { top: parent.top }
        }
        Text {
            id: calcCalItemName
            anchors { top: parent.top; topMargin: 5; horizontalCenter: parent.horizontalCenter }
            text: qsTr("CALCULATED CALORIES") + application.emptyString
            font { family: "arial"; pointSize: 17; letterSpacing: -1; weight: Font.DemiBold }
            horizontalAlignment: Text.AlignHCenter
            width: 140
            wrapMode: Text.WordWrap
            lineHeight: 0.9
            smooth: true
            color: "black"
            z: 2
        }
        Text {
            id: calcCalItemValue
            anchors { verticalCenter: parent.verticalCenter; verticalCenterOffset: 30; horizontalCenter: parent.horizontalCenter }
            text: calItem ? calItem.dataValue : 0
            font { family: "arial";  pointSize: 36;  bold: true }
            smooth: true
            color: "black"
            z: 2
        }
    }

    Text {
        id: bottomHelpText
        property bool showingStartText: false

        font { family: "arial"; pixelSize: 36; bold: true }
        color: showingStartText ? "#0db14b" : "#6c6c6c"
        text: {
            showingStartText = false
            if (!myListView.model || myListView.currentIndex < 0)
                return ""

            switch (myListView.model.get(myListView.currentIndex).fieldType) {
                case WorkoutProgram.SAVE_TYPE:
                    return qsTr("press ENTER to save this workout setup") + application.emptyString
                case WorkoutProgram.VIEW_HRC_TYPE:
                case WorkoutProgram.MORE_TYPE:
                    return qsTr("press ENTER to select") + application.emptyString
                default:
                    if (setupScreenManager.state === "Step1" && !isC360Custom)
                        return qsTr("step 1 of 3") + application.emptyString
                    else if (setupScreenManager.state === "Step1" && isC360Custom)
                        return qsTr("step 1 of 2") + application.emptyString
                    else {
                        showingStartText = true
                        return qsTr("press START to begin") + application.emptyString
                    }
            }
        }

        anchors {
            bottom: parent.bottom
            bottomMargin: 25
            horizontalCenter: parent.horizontalCenter
        }
        z: cautionText.z + 1
    }

    Item {
        id: moreButtonLeft
        visible: !myListView.atXBeginning
        width: 160
        height: 213

        Image {
            source: "graphics/tft/arrow_MORE_nav_left.png"
            anchors { top: parent.top; topMargin: 6; horizontalCenter: nextText.horizontalCenter }
        }

        Text {
            id: nextText
            font { pixelSize: 16; bold: true }
            text: qsTr("MORE") + application.emptyString
            color: "#9c9c9c"
            anchors { top: parent.top; topMargin: 90; right: parent.right }
        }

        anchors {
            right: myListView.left
            rightMargin: 10
            top: myListView.top
            topMargin: 60
        }
    }

    Item {
        id: moreButtonRight
//        visible: !myListView.atXEnd
        visible: myListView.contentWidth - (myListView.width + myListView.contentX) > 10
        width: 160
        height: 213

        Image {
            source: "graphics/tft/arrow_MORE_nav.png"
            anchors { top: parent.top; topMargin: 6; horizontalCenter: nextText2.horizontalCenter }
        }

        Text {
            id: nextText2
            font { pixelSize: 16; bold: true }
            text: qsTr("MORE") + application.emptyString
            color: "#9c9c9c"
            anchors { top: parent.top; topMargin: 90; left: parent.left }
        }

        anchors {
            left: myListView.right
            leftMargin: 10
            top: myListView.top
            topMargin: 60
        }
    }

    Item { id: cautionMessage

        property variant item: myListView.model ? myListView.model.get(selectedIndex) : undefined
        property bool showInclineMessage: item !== undefined && isTreadmill && (item.fieldType === WorkoutProgram.INCLINE_TYPE || item.fieldType === WorkoutProgram.MAX_INCLINE_TYPE || (item.fieldType === WorkoutProgram.LEVEL_TYPE && workoutProgram.programIndex !== WorkoutProgram.TREAD_LEG_SHAPER_PROG))
        property bool showWorkloadMessage: item !== undefined && !isTreadmill && (item.fieldType === WorkoutProgram.LEVEL_TYPE || item.fieldType === WorkoutProgram.WORKLOAD_TYPE)
        property bool showSpeedMessage: item !== undefined && (SetupJS.isSpeedType(item.fieldType) || (item.fieldType === WorkoutProgram.LEVEL_TYPE && workoutProgram.programIndex === WorkoutProgram.TREAD_LEG_SHAPER_PROG))

        visible: showInclineMessage || showWorkloadMessage || showSpeedMessage

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 20
        anchors.left: parent.left
        anchors.leftMargin: 10
        width: childrenRect.width
        height:childrenRect.height

        Image{
            id: cautionSymbol
            source: "graphics/Icon_Warning.png"
            y: -8
        }

        Text{
            id: cautionTitle
            text: qsTr("CAUTION") + application.emptyString
            font.bold: true
            font.pixelSize: 22
            anchors.left: cautionSymbol.right
            anchors.leftMargin: 5
            anchors.verticalCenter: cautionSymbol.verticalCenter
            anchors.verticalCenterOffset: 0
        }

        Text{
            id: cautionText
            width: 400
            wrapMode: Text.WordWrap
            text: {
                if (cautionMessage.showInclineMessage)
                    return qsTr("Use caution when selecting incline level. Injury can result if not prepared for incline levels beyond your physical limits.") + application.emptyString
                else if (cautionMessage.showWorkloadMessage)
                    return qsTr("Use caution when selecting level. Injury can result if not prepared for workload resistance beyond your physical limits.") + application.emptyString
                else if (cautionMessage.showSpeedMessage)
                    return qsTr("Use caution when selecting speed. Injury can result if not prepared for speeds beyond your physical limits.") + application.emptyString
                else
                    return ""
            }
            font.pixelSize: 16
            anchors.left: parent.left
            anchors.leftMargin: 20
            anchors.top: cautionTitle.bottom
            anchors.topMargin: 10
        }
    }

}

