import QtQuick 2.4
import ".." // to access ImageButton
import Components 1.0

FocusScope {
    id: root

    property bool isSetupWizard: false

    signal languageSelected(string lang)

    width: 1366
    height: 720

    Connections {
        target: root.visible && root.opacity > 0 ? keymapper : null

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "LanguageMenu")
            language_path.incrementCurrentIndex();
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "LanguageMenu")
            language_path.decrementCurrentIndex();
        }

        // Allow minus to act as left, as workaround for unconfigured keypad during Setup Wizard
        onMinusPressed: {
            main.debugKeys("minusPressed", "LanguageMenu")
            language_path.decrementCurrentIndex();
        }

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "LanguageMenu")
            language_path.incrementCurrentIndex();
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "LanguageMenu")
            language_path.decrementCurrentIndex();
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "LanguageMenu")
            languageSelected(language_path.currentItem);
        }

        onBackPressed: {
            main.debugKeys("backPressed", "LanguageMenu")
            languageSelected("") // return null means cancel
        }
    }

    onOpacityChanged: {
        if (opacity === 1.0)
            language_path.setIndexToCurrentLanguage()
    }

    // map background
    Image {
        source: "Language_Bkgr.png"
        anchors.fill: parent
    }

    // back button
    Row {
        id: row1

        visible: !root.isSetupWizard && main.isTouch
        x: 1183
        y: 16
        anchors.top: parent.top
        anchors.topMargin: 16
        anchors.right: parent.right
        anchors.rightMargin: 56

        ImageButton {
            id: back_button
            upimage: "../graphics/navbar/Navigation_Arrow_Disabled.png"
            downimage: "../graphics/navbar/Navigation_Arrow_Down.png"
            onClicked: languageSelected("") // return null means cancel
            mouseAreaScale: 1.5
            labelClickable: true
            label: qsTr("BACK") + application.emptyString
            font.bold: true
            label_color: "#A0A0A0"
            label_x_offset: 50
        }

    } // end back button row

    Image {
        id: marker

        x:1019
        y:341
        anchors.horizontalCenterOffset: -21
        anchors.horizontalCenter: parent.horizontalCenter
        visible: true
        opacity: 0
        z: 8
        source: "Language_Down.png"
    }

    // lay out the array of language button options
    PathView {
        id: language_path

        property string currentItem: model[currentIndex].lang
        property int o: 38

        function setIndexToCurrentLanguage() {
            for (var i = 0, l = model.length; i < l; i++) {
                if (model[i].lang === application.currentLanguage) {
                    currentIndex = i;
                    break;
                }
            }
        }

        interactive: false
        preferredHighlightBegin: 0.17; preferredHighlightEnd: 0.17
        highlightRangeMode: PathView.StrictlyEnforceRange
        highlight: Component {
            Image {
                source: "../graphics/tft/NAV_selector_2.png"
                visible: main.isTft
                width: 244
                height: 174
            }
        }
        anchors {
            top: parent.top
            topMargin: 100
            left: parent.left
            leftMargin: 50
        }

        // img: flag image   lang: language code   caption: label under button
        // add application.emptyString to end of caption to force re-translation when new language selected
        model: [
            { img: "Language_USA.png", lang: "en", caption: qsTr("ENGLISH") + application.emptyString } ,
            { img: "Language_Russian.png", lang: "ru", caption: qsTr("RUSSIAN") + application.emptyString } ,
            { img: "Language_French.png", lang: "fr", caption: qsTr("FRENCH") + application.emptyString } ,
            { img: "Language_Mandarin.png", lang: "zh", caption: qsTr("CHINESE") + application.emptyString } ,
            { img: "Language_German.png", lang: "de", caption: qsTr("GERMAN") + application.emptyString } ,
            { img: "Language_Nederlandse.png", lang: "nl", caption: qsTr("DUTCH") + application.emptyString } ,
            { img: "Language_Saudiarabia.png", lang: "ar", caption: qsTr("ARABIC") + application.emptyString } ,
            { img: "Language_Spanish.png", lang: "es", caption: qsTr("SPANISH") + application.emptyString } ,
            { img: "Language_Portuguese.png", lang: "pt", caption: qsTr("PORTUGUESE") + application.emptyString } ,
            { img: "Language_Korean.png", lang: "ko", caption: qsTr("KOREAN") + application.emptyString } ,
            { img: "Language_Japanese.png", lang: "ja", caption: qsTr("JAPANESE") + application.emptyString } ,
            { img: "Language_Italian.png", lang: "it", caption: qsTr("ITALIAN") + application.emptyString } ,

        ]

        path: Path {
            startX: 233; startY: 116 // USA
            PathLine { x: 438; y: 73 } // Russian
            PathLine { x: 644; y: 61 } // French
            PathLine { x: 852; y: 74 } // Chinese
            PathLine { x: 1047; y: 116 } // Germany
            PathLine { x: 1207; y: 233 } // Nederlands
            PathLine { x: 1047; y: 341 } // Arabic
            PathLine { x: 870; y: 379 } // Spanish
            PathLine { x: 644; y: 394 } // Planguage_path.ortugese
            PathLine { x: 438; y: 382 } // Klanguage_path.orean
            PathLine { x: 233; y: 337 } // Japanese
            PathLine { x: 77; y: 233 } // Italian
            PathLine { x: 233; y: 116 }
        }

        // delegate for each of the language buttons from the model above
        delegate: ImageButton {
            id: flag_button

            //            x: modelData.x
            //            y: modelData.y

            upimage: modelData.lang === application.currentLanguage ? "Language_Down.png" : "Language_Disabled.png"
            downimage: "Language_Down.png"

            icon: modelData.img
            icon_y_offset: -3
            icon_x_offset: -3

            label: modelData.caption
            fontsize: 16
            label_color: "black"
            label_under: true
            label_x_offset: -6

            reenableDelay: 1000

            onClicked: languageSelected( modelData.lang )

        } // end delegate for repeater

    } // end repeater

    // White band under "LANGUAGE"
    Rectangle {
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 59
        height: 83
        opacity: 0.400

    }

    Text {
        height: 78
        text: qsTr("LANGUAGE") + application.emptyString

        style: Text.Normal
        font.pointSize: 70
        font.bold: true
        smooth: true

        verticalAlignment: Text.AlignVCenter
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 58
    }

    // This functions returns the human-readable name of a language, given the
    // language code
    function getLanguageName(lang) {
        switch(lang) {
        case "en":
            return qsTr("ENGLISH") + application.emptyString
        case "es":
            return qsTr("SPANISH")  + application.emptyString
        case "fr":
            return qsTr("FRENCH")  + application.emptyString
        case "de":
            return qsTr("GERMAN") + application.emptyString
        case "it":
            return qsTr("ITALIAN") + application.emptyString
        case "nl":
            return qsTr("DUTCH") + application.emptyString
        case "pt":
            return qsTr("PORTUGUESE") + application.emptyString
        case "ru":
            return qsTr("RUSSIAN") + application.emptyString
        case "ja":
            return qsTr("JAPANESE") + application.emptyString
        case "ko":
            return qsTr("KOREAN") + application.emptyString
        case "zh":
            return qsTr("CHINESE") + application.emptyString
        case "ar":
            return qsTr("ARABIC") + application.emptyString
        }
        return ""
    }

    // This functions returns the name of the icon file associated with the given
    // language code.  This functions does not return the full path to the
    // LanguageMenu/ directory, where these files are
    function getLanguageIcon(lang) {
        switch(lang) {
        case "en":
            return "Language_USA.png"
        case "es":
            return "Language_Spanish.png"
        case "fr":
            return "Language_French.png"
        case "de":
            return "Language_German.png"
        case "it":
            return "Language_Italian.png"
        case "nl":
            return "Language_Nederlandse.png"
        case "pt":
            return "Language_Portuguese.png"
        case "ru":
            return "Language_Russian.png"
        case "ja":
            return "Language_Japanese.png"
        case "ko":
            return "Language_Korean.png"
        case "zh":
            return "Language_Mandarin.png"
        case "ar":
            return "Language_Saudiarabia.png"
        }
        return ""
    }
}
