import QtQuick 2.4

// Manages having a mixture of C++ ListModel items and QML items
// Users should call model.getItem(i). UI-only items will have their dummy property set to true.
Item {
    id: root
    property variant base: bluetoothAdapter.scannedDevices
    property variant model: listModel

    Connections {
        target: base
        onCountChanged: {
            listModel.refreshItems()
        }
    }

    ListModel {
        id: listModel
        property int dummyCount: 0

        function getItem(index) {
            if (index < count - listModel.dummyCount)
                return base.itemAt(index)
            else
                return get(index)
        }

        function addExtraItems() {
            if (main.isTft) {
                append({"name": qsTr("Refresh List"), "action": "refresh", "dummy": true})
                append({"name": qsTr("Help"), "action": "help", "dummy": true})
                listModel.dummyCount = 2
            }
        }

        function refreshItems() {
            listModel.dummyCount = 0
            clear()
            for (var i = 0; i < base.count; i++) {
                append(base.itemAt(i))
                //console.log("appending", base.itemAt(i), get(i))
            }
            addExtraItems()
        }
    }

    Component.onCompleted: {
        listModel.refreshItems()
    }

}
