
import QtQuick 2.4
import VLCVideo 1.0
import Components 1.0

import ".."

Image {

    id: root

    property bool showCloseButton: true
    property int highlightedItem:1
    property bool isDialogVisible: false
    property variant menu
    property int menu_bottom_margin: 70
    property bool videoShown: false
    property bool viewShowing: false
    property bool keysAccepted: false
    property bool allowFullscreen: false
    property variant currentBtPlayer: bluetoothAdapter.currentConnectedDevice !== null ? bluetoothAdapter.currentConnectedDevice.player : undefined
    property bool ipodVideoShowing: videoShown && (videoView.visible || fullscreenVideoFrame.visible)

    // possible dialogState values
    // - idle: mediaBrowserNoDeviceConnectedDialog is displayed
    // - connecting: btConnectionStatusDialog is displayed
    // - help: btHelpDialog is displayed
    // - connected: mediaBrowserNoDeviceConnectedDialog is displayed
    property string dialogState: "idle"

    onDialogStateChanged: {
        if(dialogState === "idle") {
            btConnectionStatusDialog.hide()
            mediaBrowserNoDeviceConnectedDialog.show()
            btHelpDialog.hide()
        } else if(dialogState === "connecting") {
            btConnectionStatusDialog.show()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.hide()
        } else if(dialogState === "help") {
            btConnectionStatusDialog.hide()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.show()
        } else if(dialogState === "connected") {
            btConnectionStatusDialog.hide()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.hide()
        } else if(dialogState === "disconnecting") {
            btConnectionStatusDialog.show()
            mediaBrowserNoDeviceConnectedDialog.hide()
            btHelpDialog.hide()
        }
    }

    state: ipodmanager.browserState

    // iPod - Menu Navigation
    Connections {
        target: main.isTft && root.opacity > 0 && keysAccepted && (state === "notplaying_menu" || state === "playing_menu") ? keymapper : null

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "MediaBrowser")
            leftPressed()
        }
        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "MediaBrowser")
            rightPressed()
        }
        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "MediaBrowser")
            ipodmenulistview.decrementCurrentIndex()
            upPressed()
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "MediaBrowser")
            ipodmenulistview.incrementCurrentIndex()
            downPressed()
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "MediaBrowser")
            centerPressed()
        }
    }

    // Video Controls - key controls when video is playing
    Connections {
        target: main.isTft && root.opacity > 0 && keysAccepted && root.ipodVideoShowing && (state === "playing_notmenu" || state === "notplaying_notmenu") ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "MediaBrowser", "video shown")
            root.toggleFullscreen()
        }
        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "MediaBrowser", "video shown")
            leftPressed()
        }
        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "MediaBrowser", "video shown")
            rightPressed()
        }

        onBackPressed: {
            main.debugKeys("backPressed", "MediaBrowser", "video shown")
            if (tv.player.fullscreen)
                return
            else
                menuPressed()
        }

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "MediaBrowser", "video shown")
            if (tv.player.fullscreen)
                root.toggleFullscreen()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "MediaBrowser", "video shown")
            if (tv.player.fullscreen)
                root.toggleFullscreen()
        }

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "MediaBrowser", "video shown")
            volume_controls.volumeUp()
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "MediaBrowser", "video shown")
            volume_controls.volumeDown()
        }
    }

    // iPod - Playing controls - Excludes video
    Connections {
        target: main.isTft && root.opacity > 0 && keysAccepted && !videoView.visible && !fullscreenVideoFrame.visible && (state === "playing_notmenu" || state === "notplaying_notmenu") ? keymapper : null

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "MediaBrowser", "not menu")
            menuPressed()
        }
        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "MediaBrowser")
            leftPressed()
        }
        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "MediaBrowser", "not menu")
            rightPressed()
        }
        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "MediaBrowser", "not menu")
            volume_controls.volumeUp()
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "MediaBrowser", "not menu")
            volume_controls.volumeDown()
        }
    }

    function previousTrack() {
    }

    function resetMenuState(){
        ipodmanager.clear();
    }

    function toggleFullscreen() {
        if (root.allowFullscreen) {
            if (tv.player.fullscreen) {
                fullscreenVideoFrame.endFullscreen()
            } else {
                fullscreenVideoFrame.showFullscreen(tv.player)
            }
        }
    }

    function showVideo(show) {
        if(show) {
            tv.tuneChannelID("IPODINPUT")
            root.videoShown = true
        }
        else
            root.videoShown = false
    }

    function shown() {
        viewShowing = true
        if(audioManager.ipodPlaying)
            audioManager.ipodRequest()
        if(audioManager.ipodPlayingVideo) {
            // if an ipod video is already allowed and we're not showing it, show it.
            if(audioManager.ipodVideoAllowed) {
                root.showVideo(true)
            }
            else // request showing the videov
                audioManager.ipodVideoRequest()
        }
        if (audioManager.btconnected) {
            audioManager.btRequest()
        }

    }

    function hidden() {
        viewShowing = false
    }

    signal close()

    signal upPressed()
    signal downPressed()
    signal rightPressed()
    signal leftPressed()
    signal centerPressed()
    signal menuPressed()
    signal menuItemPressed(int index)
    signal playPausePressed()
    signal nextTrackPressed()
    signal previousTrackPressed()

    source: "../graphics/netpulse/Center_Gray_Box.png"


    function changeState(event)
    {
        //console.debug("changing state - State: "+root.state+" Event: "+event)
        switch(root.state)
        {
        case "notplaying_notmenu":
            switch(event){
            case "centerbuttonpressed":
                brainboard.iPodPlayPause()
                break;
            case "upbuttonpressed": break;
            case "downbuttonpressed": break;
            case "leftbuttonpressed":
                ipodmanager.previousTrack()
                break;
            case "rightbuttonpressed":
                ipodmanager.nextTrack()
                break;
            case "menupressed":
                ipodmanager.browserState = "notplaying_menu"
                break;
            case "timertriggered":
                break;
            case "pausestop":
                break;
            case "playing": {
                ipodmanager.browserState = "playing_notmenu"
                ipodTimer.stop()
                break;
            }
            } // end switch(event)
            break;
        case "notplaying_menu":
            switch(event){
            case "centerbuttonpressed":
                menuItemPressed(ipodmenulistview.currentIndex)
                break;
            case "upbuttonpressed": break;
            case "downbuttonpressed": break;
            case "leftbuttonpressed": {
                ipodmanager.leftButtonPressedSlot()
                break;
            }
            case "rightbuttonpressed":
                menuItemPressed(ipodmenulistview.currentIndex)
                break;
            case "menupressed": {
                ipodmanager.leftButtonPressedSlot()
                break;
            }
            case "timertriggered":
                break;
            case "pausestop":
                break;
            case "playing": {
                ipodmanager.browserState = "playing_notmenu"
                ipodTimer.stop()
                break;
            }

            } //end switch(event)
            break;
        case "playing_notmenu":
            switch(event){
            case "centerbuttonpressed":
                brainboard.iPodPlayPause()
                break;
            case "upbuttonpressed": break;
            case "downbuttonpressed": break;
            case "leftbuttonpressed":
                ipodmanager.previousTrack()
                break;
            case "rightbuttonpressed":
                ipodmanager.nextTrack()
                break;
            case "menupressed": {
                ipodmanager.browserState = "playing_menu"
                ipodTimer.start()
                break;
            }
            case "timertriggered":
                break;
            case "pausestop":
                ipodmanager.browserState = "notplaying_notmenu"
                break;
            case "playing":
                break;
            }
            break;
        case "playing_menu":
            switch(event){
            case "centerbuttonpressed": {
                ipodTimer.restart()
                menuItemPressed(ipodmenulistview.currentIndex)
                break;
            }
            case "upbuttonpressed": {
                ipodTimer.restart()
                break;
            }
            case "downbuttonpressed": {
                ipodTimer.restart()
                break;
            }
            case "leftbuttonpressed": {
                ipodTimer.restart()
                ipodmanager.leftButtonPressedSlot()
                break;
            }
            case "rightbuttonpressed": {
                ipodTimer.restart()
                print("right button current index:" + ipodmenulistview.currentIndex)
                menuItemPressed(ipodmenulistview.currentIndex)
                break;
            }
            case "menupressed": {
                ipodTimer.restart()
                ipodmanager.leftButtonPressedSlot()
                break;
            }
            case "timertriggered": {
                ipodmanager.browserState = "playing_notmenu"
                ipodTimer.stop()
                break;
            }
            case "pausestop": {
                ipodmanager.browserState = "notplaying_menu"
                ipodTimer.stop()
                break;
            }
            case "playing":
                break;
            case "trackchanged": {
                ipodmanager.browserState = "playing_notmenu"
                ipodTimer.stop()
                break;
            }
            }
            break;
        }
    }

    states:[
        State{name: "not_connected"
            PropertyChanges {target: now_playing; visible: false}
            PropertyChanges {target: ipodmenu; visible: false}
            //PropertyChanges {target: videoPlayer; visible: false}
            PropertyChanges {target: ipod_wheel; visible: false}
            PropertyChanges {target: menu_button; visible: false}
            PropertyChanges {target: nike_plus_button; visible: false}
        },

        State{name: "notplaying_notmenu"
            PropertyChanges {target: now_playing; visible: true}
            PropertyChanges {target: ipodmenu; visible: false}
            PropertyChanges {target: ipod_wheel; visible: main.isTouch }
            PropertyChanges {target: help_pane; visible: main.isTft }
            PropertyChanges {target: menu_button; visible: main.isTouch }
            PropertyChanges {target: nike_plus_button; visible: ipod_wheel.visible & ipodmanager.nikePlusSupport}
        },
        State{name: "notplaying_menu"
            PropertyChanges {target: now_playing; visible: false}
            PropertyChanges {target: ipodmenu; visible: true}
            PropertyChanges {target: ipod_wheel; visible: main.isTouch }
            PropertyChanges {target: help_pane; visible: main.isTft }
            PropertyChanges {target: menu_button; visible: main.isTouch }
            PropertyChanges {target: nike_plus_button; visible: ipod_wheel.visible & ipodmanager.nikePlusSupport}

        },
        State{name: "playing_notmenu"
            PropertyChanges {target: now_playing; visible: !videoView.visible}
            PropertyChanges {target: ipodmenu; visible: false}
            PropertyChanges {target: ipod_wheel; visible: main.isTouch }
            PropertyChanges {target: help_pane; visible: main.isTft }
            PropertyChanges {target: menu_button; visible: main.isTouch }
            PropertyChanges {target: nike_plus_button; visible: ipod_wheel.visible & ipodmanager.nikePlusSupport}

        },
        State{name: "playing_menu"
            PropertyChanges {target: now_playing; visible: false}
            PropertyChanges {target: ipodmenu; visible: true}
            PropertyChanges {target: ipod_wheel; visible: main.isTouch }
            PropertyChanges {target: help_pane; visible: main.isTft }
            PropertyChanges {target: menu_button; visible: main.isTouch }
            PropertyChanges {target: nike_plus_button; visible: ipod_wheel.visible & ipodmanager.nikePlusSupport}

        }
    ]

    Timer{
        id:ipodTimer
        interval: 10000
        running: false
        onTriggered: {
            //console.debug("Timer triggered")
            changeState("timertriggered")
        }
    }

    Connections{
        target: root
        onUpPressed: {console.debug("UP");changeState("upbuttonpressed")}
        onDownPressed: {console.debug("DOWN");changeState("downbuttonpressed")}
        onRightPressed:{ console.debug("RIGHT");changeState("rightbuttonpressed")}
        onLeftPressed: {changeState("leftbuttonpressed")}
        onCenterPressed:{ console.debug("CENTER");changeState("centerbuttonpressed")}
        onMenuPressed: {changeState("menupressed")}
        onMenuItemPressed:{ ipodmanager.menuItemPressedSlot(index)}
    }

    Connections{
        target: brainboard
        onIPodTrackChanged: {changeState("trackchanged"); console.debug("trackchanged")}
        onIPodPlayingStatusChanged: {
            if(brainboard.iPodPlayingStatus === "playing") {
                changeState("playing")
            }
            else
            {
                changeState("pausestop")
            }
        }
    }

    // mouse area to mask anything under this pop-up
    MouseArea {
        anchors.fill: parent
    }

    function getIndexFromMenuItem(i)
    {
        var item = ipodmenulistview.model.get(i)
        return item.index
    }

    MouseArea{
        id: cover_area
        visible: mediaBrowserNoDeviceConnectedDialog.visible
        z: 99
        anchors.fill: parent
        anchors.rightMargin: 70
    }

    ModalDialog {
        id: mediaBrowserNoDeviceConnectedDialog
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5
        isTop: false
        isTransparent: true
        visible: (!ipodmanager.iPodConnected &&
                  !bluetoothAdapter.connected &&
                  !btConnectionStatusDialog.visible)

        width: root.width * 0.74
        height: width / 2

        anchors.verticalCenter: root.verticalCenter
        anchors.horizontalCenter: root.horizontalCenter

        Connections {
            target: main.isTft && !main.blockKeys && root.keysAccepted && mediaBrowserNoDeviceConnectedDialog.visible ? keymapper : null
            onEnter2Pressed: {
                main.debugKeys("enter2Pressed", "MediaBrowser", "(connectionDialog)")
                dialogState = "connecting"
            }
        }

        BorderImage {   // pop-up dialog background
            id: border
            anchors.fill: parent
            anchors.topMargin: -15
            anchors.bottomMargin: -33
            anchors.leftMargin: -14
            anchors.rightMargin: -33

            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter

            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

            Rectangle{
                id: referenceArea
                color:"transparent"
                opacity: 0.3
                height: parent.height + parent.anchors.topMargin + parent.anchors.bottomMargin
                width: parent.width + parent.anchors.rightMargin + parent.anchors.leftMargin
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.topMargin: -parent.anchors.topMargin
                anchors.leftMargin: -parent.anchors.leftMargin
            }

            Text {
                id: dialogText
                anchors.verticalCenter: referenceArea.verticalCenter
                anchors.horizontalCenter: referenceArea.horizontalCenter
                anchors.verticalCenterOffset: -60
                width: referenceArea.width * 0.8
                height: referenceArea.height * 0.5
                color: "white"
                text: qsTr("NO DEVICE CONNECTED") + application.emptyString
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: text.length >= 22 ? 48 : 62
            }
            Item {
                id: btConnectionPromptBox
                anchors.verticalCenter: referenceArea.verticalCenter
                anchors.horizontalCenter: referenceArea.horizontalCenter
                anchors.verticalCenterOffset: 70
                width: referenceArea.width * 0.5
                height: referenceArea.height * 0.4

                Column{
                    spacing: 10
                    anchors.horizontalCenter: parent.horizontalCenter
                    anchors.verticalCenter: parent.verticalCenter
                    Text{
                        id: btAudioDeviceText
                        anchors.horizontalCenter: parent.horizontalCenter
                        text: qsTr("BLUETOOTH AUDIO DEVICE?") + application.emptyString
                        font.bold: true
                        font.family: "sans serif"
                        font.pixelSize: dialogText.font.pixelSize * 0.3
                        color: "white"
                    }
                    ImageButton {
                        id: btScanButton
                        visible: main.isTouch
                        enabled: !bluetoothAdapter.connectedHeadset && !bluetoothAdapter.discovering && !bluetoothAdapter.pairing
                        anchors.horizontalCenter: parent.horizontalCenter
                        upimage: "../graphics/224/224_Data_ToolBar_Round.png"
                        downimage: "../graphics/224/224_Data_ToolBar_Round_Down.png"
                        icon: "../graphics/Bluetooth/Bluetooth_icon_small.png"
                        onClicked: {
                            dialogState = "connecting"
                        }
                    }
                    Item {
                        id: btScanTextItem
                        visible: main.isTft
                        anchors.horizontalCenter: parent.horizontalCenter
                        width:implicitWidth
                        height:implicitHeight
                        Image {
                            id:btTextImage
                            source: "../graphics/Bluetooth/Bluetooth_icon_small.png"
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left:parent.left
                        }
                        Text {
                            id: btScanTextTft
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.left: btTextImage.right
                            anchors.leftMargin: 10
                            text: qsTr("press ENTER to search for devices") + application.emptyString
                            font.bold: true
                            font.family: "sans serif"
                            font.pixelSize: 24
                            color: "#ffffff"
                        }
                    }

                    Text{
                        id: btAudioDeviceMustBeDiscoverableText
                        visible: !bluetoothAdapter.connectedHeadset
                        anchors.horizontalCenter: parent.horizontalCenter
                        text: qsTr("DEVICE MUST BE DISCOVERABLE") + application.emptyString
                        font.bold: true
                        font.family: "sans serif"
                        font.pixelSize: dialogText.font.pixelSize * 0.3
                        color: "white"
                    }
                    Text{
                        id: btAudioHeadsetNotAllowedText
                        visible: bluetoothAdapter.connectedHeadset
                        width: 670
                        wrapMode: Text.WordWrap
                        anchors.horizontalCenter: parent.horizontalCenter
                        horizontalAlignment: Text.AlignHCenter
                        text: qsTr("Listening to Bluetooth audio while headset is connected is not supported. Please disconnect headset to continue.") + application.emptyString
                        font.bold: true
                        font.family: "sans serif"
                        font.pixelSize: dialogText.font.pixelSize * 0.3
                        color: "white"
                    }
                }
            }
            ImageButton{
                id: btHelpButton
                visible: main.isTouch && !bluetoothAdapter.connectedHeadset
                upimage: "../graphics/netpulse/GRAYbutton_video.png"
                downimage: "../graphics/netpulse/GRAYbutton_video_PRESSED.png"
                anchors.bottom: btConnectionPromptBox.bottom
                anchors.left: btConnectionPromptBox.right
                width: 50
                height: 50
                onClicked: {
                    dialogState = "help"
                }
                label: "?"
                label_under: false
                label_color: "black"
            }
        }


    }
    Connections{
        target: ipodmanager
        onIPodConnectedChanged: if(ipodmanager.iPodConnected === false) dialogState = "idle"
    }


    ModalDialog {
        id: btHelpDialog
        isTop: false
        isTransparent: true
        visible: false
        z: mediaBrowserNoDeviceConnectedDialog.z + 1

        width: root.width * 0.74
        height: width / 2

        anchors.verticalCenter: parent.verticalCenter
        anchors.horizontalCenter: parent.horizontalCenter

        Connections {
            target: main.isTft && !main.blockKeys && root.keysAccepted && btHelpDialog.visible ? keymapper : null
            onBackPressed: {
                main.debugKeys("backPressed", "MediaBrowser", "(btHelpDialog)")
                helpExitButton.clicked()
            }
        }

        BorderImage {   // pop-up dialog background
            id: border1

            anchors.fill: parent
            anchors.topMargin: -15
            anchors.bottomMargin: -33
            anchors.leftMargin: -14
            anchors.rightMargin: -33

            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter

            source: "../graphics/Pop_Up_Lrg_Grey.png"
            border { top: height*0.33; bottom: height*0.33; left: width*0.33; right: width*0.33 }

            Rectangle{
                id: helpDialogReferenceArea
                color:"transparent"
                opacity: 0.3
                height: parent.height + parent.anchors.topMargin + parent.anchors.bottomMargin
                width: parent.width + parent.anchors.rightMargin + parent.anchors.leftMargin
                anchors.top: parent.top
                anchors.left: parent.left
                anchors.topMargin: -parent.anchors.topMargin
                anchors.leftMargin: -parent.anchors.leftMargin
            }

            ImageButton{
                id: helpExitButton
                visible: main.isTouch
                upimage: "../Keypad/KeyPad_X_Large.png"
                downimage: "../Keypad/KeyPad_X_Large.png"
                anchors.top: helpDialogReferenceArea.top
                anchors.topMargin: 50
                anchors.right: helpDialogReferenceArea.right
                anchors.rightMargin: 50
                onClicked: {
                    dialogState = "idle"
                }
            }
            Text{
                id: fromYourDeviceText
                anchors.top: helpDialogReferenceArea.top
                anchors.topMargin: 15
                anchors.horizontalCenter: helpDialogReferenceArea.horizontalCenter
                width: helpDialogReferenceArea.width * 0.8
                text: qsTr("FROM YOUR DEVICE:") + application.emptyString
                color: "white"
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: helpDialogReferenceArea.height * 0.12
            }

            property string appleDeviceString: qsTr("- APPLE DEVICE: go to Settings, then Bluetooth") + application.emptyString
            property string androidDeviceString: qsTr("- ANDROID DEVICE: go to Bluetooth Settings") + application.emptyString
            property string confirmConnectionString: qsTr("- Confirm connection from your device") + application.emptyString
            property string navigateAndPlayString: qsTr("- NAVIGATE and PLAY content from your device, connect ear buds and control volume from this console.") + application.emptyString
            property string dialogString: appleDeviceString + "\n\n" + androidDeviceString + "\n\n" + confirmConnectionString + "\n\n" + navigateAndPlayString

            Item{
                id: appleDeviceTextContainer
                width: helpDialogReferenceArea.width * 0.8
                anchors.horizontalCenter: helpDialogReferenceArea.horizontalCenter

                anchors.top: fromYourDeviceText.bottom
                anchors.topMargin: 25

                anchors.bottom: helpDialogReferenceArea.bottom
                anchors.bottomMargin: 10
            }

            Text{
                id: appleDeviceText
                anchors.fill: appleDeviceTextContainer

                text: parent.dialogString
                color: "white"
                horizontalAlignment: Text.AlignLeft
                wrapMode: Text.WordWrap
                font.bold: true
                font.family: "sans serif"
                font.pixelSize: getNewFontPixelSize()
                transformOrigin: Item.TopLeft

                function getNewFontPixelSize(){
                    switch(application.currentLanguage) {
                    case "en":
                        return 23
                    case "es":
                        return 21
                    case "fr":
                        return 18
                    case "de":
                        return 19
                    case "it":
                        return 21
                    case "nl":
                        return 21
                    case "pt":
                        return 21
                    case "ru":
                        return 16
                    case "ja":
                        return 23
                    case "ko":
                        return 24
                    case "zh":
                        return 26
                    case "ar":
                        return 24
                    }
                    return 26
                }
            }


        }
        onTimedOut: hide()
    }

    Item {
        id: ipod_wheel
        x: 562

        visible: true
        width: 300
        height: 300
        anchors.top: parent.top
        anchors.topMargin: 86
        ImageButton {
            id: up_button
            x: 43
            y: -93
            anchors.bottom: center_button.verticalCenter
            anchors.bottomMargin: 42
            anchors.horizontalCenterOffset: 0
            anchors.horizontalCenter: center_button.horizontalCenter
            upimage: "../graphics/205/IPOD_Wheel_Top_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Top_Down.png"
            icon: "../graphics/205/IPOD_Controls_Up.png"
            onClicked:
            {
                if(ipodmenulistview.currentIndex > 0)
                {
                    ipodmenulistview.currentIndex--
                }
                upPressed()
            }
            mouseAreaScale: 0.7

        }
        ImageButton {
            id: center_button
            x: 114
            y: 66

            upimage: (ipodmanager.playStatus == "playing") ? downimage : "../graphics/205/IPOD_Wheel_Center_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Center_Down.png"
            icon: "../graphics/205/IPOD_Controls_Select.png"

            onClicked: {
                centerPressed()
            }
            mouseAreaScale: 0.7
        }

        ImageButton {
            id: down_button
            anchors.horizontalCenterOffset: 1
            anchors.top: center_button.verticalCenter
            anchors.topMargin: 42
            anchors.horizontalCenter: center_button.horizontalCenter
            upimage: "../graphics/205/IPOD_Wheel_Bottom_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Bottom_Down.png"
            icon: "../graphics/205/IPOD_Controls_Down.png"
            onClicked:
            {
                if(ipodmenulistview.currentIndex + 1 < ipodmenulistview.count)
                    ipodmenulistview.currentIndex++
                downPressed()
            }
            mouseAreaScale: 0.7

        }

        ImageButton {
            id: left_button
            x: 0
            y: 116
            anchors.right: center_button.horizontalCenter
            anchors.rightMargin: 36
            anchors.verticalCenterOffset: 0
            anchors.verticalCenter: center_button.verticalCenter
            anchors.topMargin: 0
            upimage: "../graphics/205/IPOD_Wheel_Left_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Left_Down.png"
            icon: "../graphics/205/IPOD_Controls_Back.png"
            onClicked: {
                leftPressed()
            }
            mouseAreaScale: 0.7

        }

        ImageButton {
            id: right_button
            anchors.verticalCenterOffset: 0
            anchors.left: center_button.horizontalCenter
            anchors.leftMargin: 41
            anchors.verticalCenter: center_button.verticalCenter
            upimage: "../graphics/205/IPOD_Wheel_Right_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Right_Down.png"
            icon: "../graphics/205/IPOD_Controls_Forward.png"
            onClicked: {
                rightPressed()
            }
            mouseAreaScale: 0.7

        }

        Rectangle {
            id: wheel_well
            // helpful for alignment of circular button array, as buttons have shadows
            x: 75
            y: 43
            width: 285
            height: width
            color: "#ffffff"
            radius: width*0.5
            anchors.verticalCenterOffset: -2
            anchors.horizontalCenterOffset: -2
            z: -1
            anchors.horizontalCenter: center_button.horizontalCenter
            anchors.verticalCenter: center_button.verticalCenter
            opacity: 0
        }
    } // end ipod wheel

    IPodTftHelp {
        id: help_pane
        ipodState: root.state
        keysAccepted: root.keysAccepted
        allowFullscreen: root.allowFullscreen
        x: 532
        anchors.top: parent.top
    }

    NowPlayingControl {
        id: now_playing
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5

        x: 31
        y: 20
        //visible: !isMenuVisible
        // connect data model for song meta-data here (duration, title, etc.)

        duration: ipodmanager.nowPlayingTrackDuration
        title: ipodmanager.nowPlayingTrackName
        artist: ipodmanager.nowPlayingTrackArtist
        album: ipodmanager.nowPlayingTrackAlbum
        position: ipodmanager.nowPlayingTrackTimeElapsed

        visible: true
        // scrub event happens when user moves slider
        // onScrub: { now_playing.position = new_time }

        anchors.top: parent.top
        anchors.topMargin: 36
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 80
        anchors.left: parent.left
        anchors.leftMargin: 31
    }

    ImageButton{
        id: nike_plus_button
        anchors {
            top: ipod_wheel.bottom ; topMargin: -50
            horizontalCenter: ipod_wheel.horizontalCenter
        }
        upimage:"../graphics/205/SM_Button_Up.png"
        downimage:"../graphics/205/SM_Button_Down.png"
        icon: ipodmanager.nikePlusRecord ? "../graphics/205/IPOD_Checkmark.png" : ""
        label: "Nike + iPod"
        fontsize: 30
        label_color: "white"
        label_x_offset: 120
        onClicked: {
            ipodmanager.nikePlusRecord = !ipodmanager.nikePlusRecord
        }

        enabled: main.state == "RunState" & ipodmanager.nikePlusRecord ? false : true
    }

    Connections{
        target:ipodmanager
        onIPodConnectedChanged: {
            resetMenuState()
            if(ipodmanager.iPodConnected){
                if(bluetoothAdapter.connected){
                    bluetoothAdapter.disconnect()
                }
                dialogState = "connected"
            }
        }

    }



    IPodMenuControl{

        id:ipodmenu
        property string selectedItemHeading: ""
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5
        x: 31
        y: 20
        //visible: isMenuVisible
        anchors.top: parent.top
        anchors.topMargin: 36
        anchors.bottom: parent.bottom
        anchors.bottomMargin: root.menu_bottom_margin
        anchors.left: parent.left
        anchors.leftMargin: 31
        visible: true

        heading: ipodmanager.menuHeading


        ListView {
            id: ipodmenulistview

            anchors.fill: parent
            anchors.topMargin: 80
            anchors.bottomMargin: 20
            anchors.leftMargin: 30
            anchors.rightMargin: 20
            clip: true
            onMovingChanged: root.upPressed()
            currentIndex: 1
            highlight: Rectangle { color: "lightsteelblue"; radius: 1 }
            pressDelay: 200
            highlightMoveDuration: 1
            //model: testmodel
            model: ipodmanager.menu
            visible: true
            delegate: Component {
                Row {
                    Image {
                        source: "../graphics/tft/toggle_arrow_black.png"
                        visible: label !== "" && (["Tracks", "Music Videos", "TV Shows", "Video Podcasts", "Video iTunes U", "Audiobooks"].indexOf(ipodmanager.menuHeading) < 0)
                    }
                    Text {
                        text: label
                        width: ipodmenulistview.width
                        height: label == "" ? 0 : implicitHeight
                        MouseArea{
                            anchors.fill: parent
                            onClicked: {
                                menuItemPressed(index)
                            }
                            onPressed: {
                                ipodmenulistview.currentIndex = index
                                buzzer.buttonPress()
                            }
                        }
                    }
                }
            }
        }
    }

    // close button
    ImageButton {
        id: close_button

        z: 200

        visible: root.showCloseButton && main.isTouch
        width: 48
        height: 48
        anchors {   right: parent.right ; rightMargin: 40 ;
            top: parent.top ; topMargin: 40
        }
        upimage: "../Keypad/KeyPad_X_Large.png"
        downimage: "../Keypad/KeyPad_X_Large.png"

        onClicked: close()
        mouseAreaScale: 2.0

    }

    ImageButton {
        id: menu_button
        anchors.top: ipod_wheel.bottom
        anchors.topMargin: -285
        anchors.left: ipod_wheel.right
        anchors.leftMargin: 30
        fontsize: 14
        label: qsTr("MENU") + application.emptyString
        upimage: "../graphics/205/Lrg_Button_Up.png"
        downimage: "../graphics/205/Lrg_Button_Down.png"
        onClicked: {
            menuPressed()
        }
    }

    VLCSurface {
        id: videoView

        player: tv.player
        playing: !player.fullscreen && visible && ( tv.playing  || tv.tuning)
        aspect: tv.aspect

        x: 31
        width: 545
        height: width / tv.aspect
        anchors.verticalCenter: parent.verticalCenter

        visible: root.videoShown && root.state == "playing_notmenu" && brainboard.iPodTrackType === "video"

        MouseArea {
            anchors.fill: parent
            onClicked: fullscreenVideoFrame.showFullscreen(tv.player)
        }
    } // end videoView

    Connections {
        target: root.viewShowing ? audioManager : null

        ignoreUnknownSignals: true

        onIpodVideoAllowedChanged: {
            if(audioManager.ipodVideoAllowed){
                if(audioManager.ipodPlayingVideo && viewShowing){
                    showVideo(true)
                }
            }
            else {
                showVideo(false)
            }
        }

        onIpodPlayingChanged: {
            if(audioManager.ipodPlaying && viewShowing){
                audioManager.ipodRequest()
                if(audioManager.ipodPlayingVideo && audioManager.ipodVideoAllowed) {
                    showVideo(true)
                }
            }
        }

        onBtconnectedChanged: {
            if (audioManager.btconnected && viewShowing) {
                audioManager.btRequest()
            }
        }

        onIpodPlayingVideoChanged: {
            if(audioManager.ipodPlayingVideo && viewShowing){
                if(!videoShown) {
                    if(audioManager.ipodVideoAllowed) {
                        showVideo(true)
                    }
                    else {  // ask for permission to show the video
                        audioManager.ipodVideoRequest()
                    }
                }
            }
            else if(!audioManager.ipodPlayingVideo) {
                showVideo(false)
            }
        }
    }

    function btControlsHandler(button){
        root.currentBtPlayer.restartMenuTimer();
        if(root.currentBtPlayer.isMenu){
            switch(button){
            case "up":
                if(bt_menulistview.currentIndex > 0)
                    bt_menulistview.currentIndex--
                break;
            case "down":
                if(bt_menulistview.currentIndex + 1 < bt_menulistview.count)
                    bt_menulistview.currentIndex++
                break;
            case "left":
                root.currentBtPlayer.previousFolder()
                break;
            case "right":
                root.currentBtPlayer.selectItem(bt_menulistview.currentIndex)
                break;
            case "center":
                root.currentBtPlayer.selectItem(bt_menulistview.currentIndex)
                break;
            case "menu":
                root.currentBtPlayer.isMenu = false
                break;
            default:
                break;
            }
        } else {
            switch(button){
            case "up":
                break;
            case "down":
                break;
            case "left":
                root.currentBtPlayer.previous()
                break;
            case "right":
                root.currentBtPlayer.next();
                break;
            case "center":
                if(root.currentBtPlayer.isPlaying){
                    root.currentBtPlayer.pause()
                }else{
                    root.currentBtPlayer.play()
                }
                break;
            case "menu":
                root.currentBtPlayer.isMenu = true
                break;
            default:
                break;
            }
        }
    }

    // Bluetooth playlist - Key navigation
    Connections {
        target: main.isTft && root.opacity > 0 && keysAccepted && bluetoothAdapter.connected ? keymapper : null

        onDoubleLeftPressed: {
            main.debugKeys("doubleLeftPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("left")
        }
        onDoubleRightPressed: {
            main.debugKeys("doubleRightPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("right")
        }
        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("up")
        }
        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "MediaBrowser", "(bt menu)")
            btControlsHandler("down")
        }
        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "MediaBrowser")
            btControlsHandler("menu")
        }
    }

    IPodMenuControl{

        id:bt_menu
        property string selectedItemHeading: ""
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5
        x: 31
        y: 20
        //visible: isMenuVisible
        anchors.top: parent.top
        anchors.topMargin: 36
        anchors.bottom: parent.bottom
        anchors.bottomMargin: root.menu_bottom_margin
        anchors.left: parent.left
        anchors.leftMargin: 31
        visible: bluetoothAdapter.connected && root.currentBtPlayer !== undefined && root.currentBtPlayer.isMenu

        heading: bluetoothAdapter.connected && root.currentBtPlayer !== undefined && root.currentBtPlayer.menuHeading !== "" ? root.currentBtPlayer.menuHeading : "Menu"

        Text {
            anchors.fill: parent
            anchors.topMargin: 80
            anchors.bottomMargin: 20
            anchors.leftMargin: 30
            anchors.rightMargin: 20

            visible: !bt_menulistview.visible

            text: "No Menu Available"
        }

        ListView {
            id: bt_menulistview

            anchors.fill: parent
            anchors.topMargin: 80
            anchors.bottomMargin: 20
            anchors.leftMargin: 30
            anchors.rightMargin: 20
            clip: true
            onMovingChanged: root.upPressed()
            currentIndex: 1
            highlight: Rectangle { color: "lightsteelblue"; radius: 1 }
            pressDelay: 200
            highlightMoveDuration: 1
            //model: testmodel
            model: root.currentBtPlayer !== undefined && root.currentBtPlayer.menu
            visible: root.currentBtPlayer !== undefined && root.currentBtPlayer.menuSize > 0
            delegate: Component {
                Row {
                    Image {
                        source: "../graphics/tft/toggle_arrow_black.png"
                        visible: type === "folder"
                    }
                    Text {
                        text: name
                        width: bt_menulistview.width
                        height: name == "" ? 0 : implicitHeight
                        MouseArea{
                            anchors.fill: parent
                            onClicked: {
                                root.currentBtPlayer.selectItem(index)
                                //menuItemPressed(index)
                            }
                            onPressed: {
                                bt_menulistview.currentIndex = index
                                buzzer.buttonPress()
                            }
                        }
                    }
                }
            }
        }
    }

    NowPlayingControl {
        id: bt_now_playing
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5

        x: 31
        y: 20
        //visible: !isMenuVisible
        // connect data model for song meta-data here (duration, title, etc.)
        duration: root.currentBtPlayer !== undefined ? root.currentBtPlayer.duration / 1000 : 0
        //title: title
        title: root.currentBtPlayer !== undefined && root.currentBtPlayer.title !== "" ? root.currentBtPlayer.title : "Title info not available"
        artist: root.currentBtPlayer !== undefined && root.currentBtPlayer.artist !== "" ? root.currentBtPlayer.artist : "Artist info not available"
        album: root.currentBtPlayer !== undefined && root.currentBtPlayer.album !== "" ? root.currentBtPlayer.album : "Album info not available"
        position: root.currentBtPlayer !== undefined ? root.currentBtPlayer.position / 1000 : 0

        visible: bluetoothAdapter.connected && root.currentBtPlayer !== undefined && !root.currentBtPlayer.isMenu
        // scrub event happens when user moves slider
        // onScrub: { now_playing.position = new_time }

        anchors.top: parent.top
        anchors.topMargin: 36
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 80
        anchors.left: parent.left
        anchors.leftMargin: 31


    }

    ImageButton {
        id: bt_menu_button
        visible: bluetoothAdapter.connected && main.isTouch
        anchors.top: bluetooth_controls.bottom
        anchors.topMargin: -285
        anchors.left: bluetooth_controls.right
        anchors.leftMargin: 30
        fontsize: 14
        label: qsTr("MENU") + application.emptyString
        upimage: "../graphics/205/Lrg_Button_Up.png"
        downimage: "../graphics/205/Lrg_Button_Down.png"
        onClicked: {
            btControlsHandler("menu")
        }
    }

    ImageButton{
        id: bt_disconnect_button
        visible: main.isTouch && bluetoothAdapter.connected
        upimage: "../graphics/205/Lrg_Button_Up.png"
        downimage: "../graphics/205/Lrg_Button_Down.png"
        icon: "../graphics/Bluetooth/Bluetooth_icon_small.png"
        icon_x_offset: -2
        icon_y_offset: 0
        anchors.horizontalCenter: bt_menu_button.horizontalCenter
        anchors.verticalCenter: bt_nike_plus_button.verticalCenter
        onClicked: if(bluetoothAdapter.connected) {
                       dialogState = "disconnecting"
                       bluetoothAdapter.disconnect()
                   }
        Image{
            source: "../graphics/Bluetooth/small_red_X.png"
            width: 18
            height: 17
            x: 20
            y: 23
            fillMode: "PreserveAspectFit"
            smooth: true
        }
    }

    ImageButton{
        id: bt_nike_plus_button
        anchors {
            top: bluetooth_controls.bottom ; topMargin: -50
            horizontalCenter: bluetooth_controls.horizontalCenter
        }
        upimage:"../graphics/205/SM_Button_Up.png"
        downimage:"../graphics/205/SM_Button_Down.png"
        icon: ""
        label: "Nike + iPod"
        fontsize: 30
        label_color: "white"
        label_x_offset: 120
        enabled: false
        visible: bluetoothAdapter.connected && main.isTouch
    }

    Item {
        id: bluetooth_controls
        x: 562

        Connections {
            target: main.isTft && !main.blockKeys && root.keysAccepted && bluetoothAdapter.connected && (!root.currentBtPlayer || !root.currentBtPlayer.isMenu) ? keymapper : null

            onUpButtonPressed: {
                main.debugKeys("upButtonPressed", "MediaBrowser", "(bluetooth controls)")
                volume_controls.volumeUp()
            }
            onDownButtonPressed: {
                main.debugKeys("downButtonPressed", "MediaBrowser", "(bluetooth controls)")
                volume_controls.volumeDown()
            }
        }

        visible: bluetoothAdapter.connected && main.isTouch
        width: 300
        height: 300
        anchors.top: parent.top
        anchors.topMargin: 86
        ImageButton {
            id: bt_up_button
            x: 43
            y: -93
            anchors.bottom: bt_center_button.verticalCenter
            anchors.bottomMargin: 42
            anchors.horizontalCenterOffset: 0
            anchors.horizontalCenter: bt_center_button.horizontalCenter
            upimage: "../graphics/205/IPOD_Wheel_Top_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Top_Down.png"
            icon: "../graphics/205/IPOD_Controls_Up.png"
            mouseAreaScale: 0.7
            enabled: root.currentBtPlayer !== undefined && root.currentBtPlayer.isMenu ? true : false
            onClicked: btControlsHandler("up")

        }
        ImageButton {
            id: bt_center_button
            x: 114
            y: 66

            upimage: (root.currentBtPlayer !== undefined && root.currentBtPlayer.isPlaying) ? "../graphics/205/IPOD_Wheel_Center_Down.png" : "../graphics/205/IPOD_Wheel_Center_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Center_Down.png"
            icon: "../graphics/205/IPOD_Controls_Select.png"

            onClicked: {
                btControlsHandler("center")
            }
            mouseAreaScale: 0.7
        }

        ImageButton {
            id: bt_down_button
            anchors.horizontalCenterOffset: 1
            anchors.top: bt_center_button.verticalCenter
            anchors.topMargin: 42
            anchors.horizontalCenter: bt_center_button.horizontalCenter
            upimage: "../graphics/205/IPOD_Wheel_Bottom_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Bottom_Down.png"
            icon: "../graphics/205/IPOD_Controls_Down.png"
            mouseAreaScale: 0.7
            enabled: (root.currentBtPlayer !== undefined && root.currentBtPlayer.isMenu) ? true : false
            onClicked: btControlsHandler("down")

        }

        ImageButton {
            id: bt_left_button
            x: 0
            y: 116
            anchors.right: bt_center_button.horizontalCenter
            anchors.rightMargin: 36
            anchors.verticalCenterOffset: 0
            anchors.verticalCenter: bt_center_button.verticalCenter
            anchors.topMargin: 0
            upimage: "../graphics/205/IPOD_Wheel_Left_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Left_Down.png"
            icon: "../graphics/205/IPOD_Controls_Back.png"
            onClicked: {
                btControlsHandler("left")
            }
            mouseAreaScale: 0.7

        }

        ImageButton {
            id: bt_right_button
            anchors.verticalCenterOffset: 0
            anchors.left: bt_center_button.horizontalCenter
            anchors.leftMargin: 41
            anchors.verticalCenter: bt_center_button.verticalCenter
            upimage: "../graphics/205/IPOD_Wheel_Right_Up.png"
            downimage: "../graphics/205/IPOD_Wheel_Right_Down.png"
            icon: "../graphics/205/IPOD_Controls_Forward.png"
            onClicked: {
                btControlsHandler("right")
            }
            mouseAreaScale: 0.7

        }

        Rectangle {
            id: bt_wheel_well
            // helpful for alignment of circular button array, as buttons have shadows
            x: 75
            y: 43
            width: 285
            height: width
            color: "#ffffff"
            radius: width*0.5
            anchors.verticalCenterOffset: -2
            anchors.horizontalCenterOffset: -2
            z: -1
            anchors.horizontalCenter: bt_center_button.horizontalCenter
            anchors.verticalCenter: bt_center_button.verticalCenter
            opacity: 0
        }
    } // end ipod wheel bluetooth


    // Help pane for Bluetooth TFT
    BluetoothTftHelp {
        id: bt_help_pane
        keysAccepted: root.keysAccepted
        visible: main.isTft && bluetoothAdapter.connected
        isPlaying: root.currentBtPlayer !== undefined && root.currentBtPlayer.isPlaying
        isMenu: root.currentBtPlayer !== undefined && root.currentBtPlayer.isMenu
        x: 532
        anchors.top: parent.top
    }

    ConfirmationPromptTft {
        id: confirmDisconnectDialog
        isTop: false
        visible: false
        anchors.centerIn: parent
        prompt: qsTr("This will disconnect the device. Are you sure?") + application.emptyString
        onYesClicked: {
            if(bluetoothAdapter.connected) {
                bluetoothAdapter.disconnect()
            }
            confirmDisconnectDialog.hide()
        }
        onNoClicked: {
            confirmDisconnectDialog.hide()
        }
    }

    BluetoothDeviceSelectionDialog{
        id: btConnectionStatusDialog
        width: root.width * 0.74
        height: width / 2
        isTop: false
        list: bluetoothAdapter.scannedDevices
        keysAccepted: root.keysAccepted
        pairingAllowed: !(bluetoothAdapter.pairing || bluetoothAdapter.connectingHeadset)

        anchors.horizontalCenter: root.horizontalCenter
        anchors.verticalCenter: root.verticalCenter
        opacity: main.isTouch || root.keysAccepted ? 1.0 : 0.5

        onClosed: dialogState = "idle"
        onDeviceConnected: dialogState = "connected"
        onDeviceDisconnected: dialogState = "idle"
    }

}

