import QtQuick 2.4
import QtQuick.LocalStorage 2.0

Item {
    id: root

    function getDatabase() {
        return LocalStorage.openDatabaseSync("Touch", "1.0", "MicsStats", 4096 );
    }

    function initialize() {
        var db = getDatabase();
        console.log("get database")
        db.transaction (
                    function(tx) {
                        tx.executeSql('CREATE TABLE IF NOT EXISTS statisticcount(name TEXT UNIQUE, count INT)');
                    }
                    );
    }

    function incrementiPodUsage(){
        incrementUsage("iPod Connections")
    }
    function incrementNikePlusUsage(){
        incrementUsage("Nike+ Usage")
    }

    function incrementVaVideoUsage(name){
        var res = name.split('/');
        var i
        var str
        str = ""
        for(i = 0; i < res.length; i++){
            if(res[i].search(".mp4") !== -1){
                str = res[i];
                break;
            }
        }
        var fullstr = "VA Video - "
        incrementUsage(fullstr.concat(str))
    }

    function getiPodUsage(){
        return getUsage("iPod Connections")
    }
    function getNikePlusUsage(){
        return getUsage("Nike+ Usage")
    }

    function getVaVideoUsage(name){
        var fullstr = "VA Video - "
        return getUsage(fullstr.concat(name))
    }

    function incrementUsage(name) {
        var db = getDatabase();
        var res = "";
        var count = 0;
        db.transaction(
                    function(tx) {
                        var rs = tx.executeSql('SELECT count FROM statisticcount WHERE name=?;', [name]);

                        if( rs.rows.length > 0) {
                            count = rs.rows.item(0).count;
                        }
                    }
                    )
        count++;
        if (count > 0) {
            db.transaction(
                        function(tx) {
                            var rs = tx.executeSql('INSERT OR REPLACE INTO statisticcount VALUES (?,?);', [name, count]);
                            if(rs.rowsAffected > 0) {
                                res = "OK";
                            } else {
                                res = "Error";
                            }
                        }

                        )
        }
    }

    function getUsage(name) {
        var db = getDatabase();
        var newcount=-1;

        db.transaction(
                    function(tx) {
                        var rs = tx.executeSql('SELECT count FROM statisticcount WHERE name=?;', [name]);
                        if(rs.rows.length > 0) {
                            newcount = rs.rows.item(0).count
                        }
                    }
                    )
        if(newcount > 0)
            return newcount;
        else
            return 0;
    }

    function getUsageAll() {
        var db = getDatabase()
        var rows

        db.readTransaction(
                    function(tx) {
                        var rs = tx.executeSql('SELECT * FROM statisticcount ORDER BY count DESC;')
                        if(rs.rows.length > 0) {
                            rows = rs.rows
                        }
                    }
                    )
        return rows
    }

    function clearAll() {
        var db = getDatabase()
        var rs

        db.transaction(
                    function(tx) {
                        rs = tx.executeSql('DELETE FROM statisticcount')
                    }
                    )
        return rs.rowsAffected
    }

    Component.onCompleted: initialize();
}
