import QtQuick 2.4
import Components 1.0

Rectangle {
    id: root

    signal clicked( string icon, string state, variant data, int highlightIndex )

    height: 62
    width: childrenRect.width
    property variant _item_stack: []

    ListModel {
        id: items

    }

    function handleItemPressed(index) {
        var searchIcon = items.get(index).icon
        var item
        do {
            item = root.pop()
        } while (item.icon !== searchIcon)

        root.clicked(item.icon, item.state, item.data, item.highlightIndex)
    }

    function goBack() {
        var item = pop()
        root.clicked(item.icon, item.state, item.data, item.highlightIndex)
    }

    function clear() {
        var itemstack= []
        root._item_stack = itemstack
        items.clear()
    }

    function push(icon, state, data, highlightIndex) {
        var itemstack= root._item_stack

        var item = { icon: icon, state: state, data: data, highlightIndex: highlightIndex }
        itemstack.push( item )
        items.append( item )

        root._item_stack = itemstack
    }

    function peek() {
        return items.get(items.count - 1)
    }

    function pop() {
        var itemstack= root._item_stack

        items.remove(items.count-1)
        var item = itemstack.pop()

        root._item_stack = itemstack

        return item
    }

    Component {
        id: nav_item_view
        Row {
            layoutDirection: Qt.RightToLeft
            spacing: 5

            ImageButton {
                upimage: model.icon + "_Disabled.png"
                downimage: model.icon + "_Down.png"
                mouseAreaScale: 1.2
                onClicked: {
//                    var item = root.peek()
//                    while (item.icon !== searchIcon) {
//                        root.pop()
//                        item = root.peek()
//                    }

                    handleItemPressed(index)
//                    root.clicked(item.icon, item.state, item.data, item.highlightIndex)
//                    root.pop()
                }
            }

            Image {
                source: "graphics/navbar/Navigation_Carrot.png"
                visible: index > 0
            }
        }
    }

    // button row
    Row {
        id: row1

        spacing: 10
        Repeater {
            model: items
            delegate: nav_item_view
        }

        // back button
        ImageButton {
            id: back_button

            onClicked: {
                root.goBack();
            }
            mouseAreaScale: 1.2
            labelMouseAreaScale: 2.5
            upimage: "graphics/navbar/Navigation_Arrow_Disabled.png"
            downimage: "graphics/navbar/Navigation_Arrow_Down.png"
            visible: items.count > 0
            label: qsTr("BACK") + application.emptyString
            font.bold: true
            label_color: "#A0A0A0"
            label_x_offset: 50
            labelClickable: true
        }
    } // end button row
}
