import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property variant activeConnections
    property bool preventEthDisconnect: false

    signal disconnectRequest(string interfaceName)

    function refresh() {
        // Force re-selection of current item
        cnxList.currentIndex = -1
        cnxList.currentIndex = 0
    }

    width: childrenRect.width
    height: childrenRect.height

    Text {
        id: activeCnxText
        text: qsTr("Active Connections") + ":" + application.emptyString
        anchors {
            top: parent.top
            left: parent.left
        }
    }

    Rectangle {
        id: connectionsListBox
        color: "#808080"
        width: 290
        height: 310
        border { width: 2; color: "black" }
        anchors { left: parent.left; top: activeCnxText.bottom; topMargin: 5 }
        clip: true

        ListView {
            id: cnxList

            visible: !netConnections.isRefreshing
            anchors.fill: parent
            anchors.margins: 5
            model: netConnections.list
            delegate: connDelegate
            highlight: Component {
                Rectangle {
                    height: 44
                    width: parent.width
                    color: "#9d9d9d"
                }
            }
        }

        Text {
            id: refreshingText
            visible: netConnections.isRefreshing
            text: qsTr("Refreshing...") + application.emptyString
            anchors { top: parent.top; left: parent.left; topMargin: 10; leftMargin: 10 }
        }
    }

    Component {
        id: connDelegate
        Row {
            height: 44
            spacing: 10

            Image {
                id: padlock
                source: encrypted ? "graphics/padlock.png" : "graphics/padlock-unlocked.png"
                Text {
                    id: problemX
                    visible: (intf === "p2p1" && (!netConnections.wiredEnabled || netConnections.wireDisconnected)) || intf === "wlan0" && !netConnections.wirelessEnabled
                    color: "#ff3300"
                    font.pixelSize: 24
                    text: "X"
                    anchors { bottom: parent.bottom; left: parent.left }
                }
            }

            Item {
                id: spacingItem
                width: 10
                height: 10
            }

            Text {
                text: essid ? essid : ""
                font { pixelSize: 26 }
                width: 170
                verticalAlignment: Text.AlignVCenter
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        console.log("clicked")
                        cnxList.currentIndex = index
                    }
                }
            }
            ImageButton {
                upimage: "Keypad/KeyPad_X.png"
                downimage: upimage
                enabled: !(intf === "p2p1" && root.preventEthDisconnect)
                onClicked: {
                    disconnectRequest(intf)
                }
            }
        }
    }

    Row {
        id: ethInfo
        spacing: 40
        visible: cnxList.currentIndex >= 0 && cnxList.model.get(cnxList.currentIndex).intf === "p2p1"
        anchors { left: connectionsListBox.right; leftMargin: 70; top: connectionsListBox.top; topMargin: 40 }
        Column {
            Text { text: qsTr("Interface") + application.emptyString; font.pointSize: 22  }
            Text { text: qsTr("Status") + application.emptyString; font.pointSize: 22 }
            Text { text: qsTr("IP Address") + application.emptyString; font.pointSize: 22; visible: !netConnections.wireDisconnected }
            Text { text: qsTr("Subnet Mask") + application.emptyString; font.pointSize: 22; visible: !netConnections.wireDisconnected }
            Text { text: qsTr("MAC Address") + application.emptyString; font.pointSize: 22; visible: !netConnections.wireDisconnected }
        }

        Column {
            Text { text: qsTr("Ethernet") + application.emptyString; font { pointSize: 22 } }
            Text {
                text: {
                    if (netConnections.wireDisconnected) {
                        return qsTr("Wire Disconnected")
                    } else if (netConnections.wiredEnabled) {
                        return qsTr("Connected")
                    } else {
                        return qsTr("No Connection")
                    }
                }
                color: netConnections.wireDisconnected ? "gray" : "black"
                font { pointSize: 22 }
            }
            Text { text: netConnections.wiredIp; font.pointSize: 22; visible: !netConnections.wireDisconnected }
            Text { text: netConnections.wiredNetmask; font.pointSize: 22; visible: !netConnections.wireDisconnected }
            Text { text: netConnections.wiredMac; font.pointSize: 22; visible: !netConnections.wireDisconnected }
        }
    }

    Row {
        id: wirelessInfo
        spacing: 40
        visible: cnxList.currentIndex >= 0 && cnxList.model.get(cnxList.currentIndex).intf === "wlan0"
        anchors { left: connectionsListBox.right; leftMargin: 70; top: connectionsListBox.top; topMargin: 40 }
        Column {
            Text { text: qsTr("Status") + application.emptyString; font { pointSize: 22 } }
            Text { text: qsTr("Signal Strength") + application.emptyString; font { pointSize: 22 } }
            Text { text: qsTr("IP Address") + application.emptyString; font { pointSize: 22 } }
            Text { text: qsTr("Subnet Mask") + application.emptyString; font { pointSize: 22 } }
            Text { text: qsTr("MAC Address") + application.emptyString; font { pointSize: 22 } }
        }

        Column {
            Text {
                text: {
                    if (netConnections.wirelessEnabled) {
                        return qsTr("Connected") + application.emptyString
                    } else {
                        return qsTr("No Connection") + application.emptyString
                    }
                }
                font { pointSize: 22 }
            }
            Text { text: netConnections.signalStrength; font { pointSize: 22 } }
            Text { text: netConnections.wirelessIp; font { pointSize: 22 } }
            Text { text: netConnections.wirelessNetmask; font { pointSize: 22 } }
            Text { text: netConnections.wirelessMac; font { pointSize: 22 } }
        }
    }
}
