import QtQuick 2.4
import Components 1.0

Item {
    id: root

    property int highlight: 0 // index of currently lighted item
    property variant menu   // list model containing the button details
    property bool curve_edit: false
    property int currentIndex
    property real buttonrot: 0
    property bool buttonsEnabled: true

    // programSelected signal is emitted when the user selects a workout program to run
    signal itemClicked( int index )
    signal itemPushed( int index )

    // this is the component which is the "delegate" item for the PopsicleMenu
    Component {
        id: menuButton

        ImageButton {
            id: button

            enabled: root.buttonsEnabled
            opacity: model.shim ? 0.0 : 1.0
            width: 212
            height: 212

            transform: Rotation {
                axis { x: 0 ; y: 1; z: 0 }
                angle: root.buttonrot
                origin.x: width /2
            }
            // scale up the item which is highlighted, but "push" it down when pressed
            scale: (index === root.highlight) && !isDown ? 1.1: 1.0
            Behavior on scale {
                NumberAnimation { duration: 800; easing.type: Easing.OutExpo }
            }
            mouseAreaScale: 0.7
            onClicked: { itemClicked( index ) }
            onIsDownChanged: {
                if( isDown ) {
                    root.itemPushed(index)
                }
            }
            upimage: (Globals.graphicsPath + ((index === root.highlight) ? "200/TRU_200_other_Icons_Down.png":"200/TRU_200_other_Icons_UP.png"))
            downimage: (Globals.graphicsPath + "200/TRU_200_other_Icons_Down.png")
            disabledimage: upimage
            // set an icon image only if model.icon is defined
            icon: model.icon ? Globals.graphicsPath + model.icon : ""
            label: qsTr(model.label) + application.emptyString
            label_under: true
            label_color: "black"
            font { pointSize: 14 ; bold: true }
        }
    } // end Component menuButton

    // The following point editors allow interactive adjustment of the button layout path when curve_edit is true
    // the coded dx and dy are used by the PathView
    PointEdit {
        id: pthstart
        anchors.fill: parent
        visible: curve_edit
        label: "start"
        dx: 997 ; dy: 72
        z:5
    }

    PointEdit {
        id: pthend
        anchors.fill: parent
        visible: curve_edit
        label: "end"
        dx:132 ; dy: 488
        z:5
    }
    PointEdit {
        id: ctl1
        anchors.fill: parent
        visible: curve_edit
        label: "ctl1"
        dx: 952 ; dy: 663
        z:5
    }
    PointEdit {
        id: ctl2
        z:5
        anchors.fill: parent
        visible: curve_edit
        label: "ctl2"
        dx: 128
        dy: 488
    }

    PathView {
        id: pathview

        interactive: false
        anchors.fill: parent
        model: menu
        delegate: menuButton
        currentIndex: root.currentIndex
        highlightMoveDuration: 200
         path: Path {
            id: path
            startX: pthstart.dx
            startY: pthstart.dy

            PathCubic {
                id: swoop
                x: pthend.dx-300 ; y:pthend.dy;
                control1X: ctl1.dx  ; control1Y: ctl1.dy
                control2X: ctl2.dx; control2Y: ctl2.dy
            }
            PathLine {x: swoop.x ; y: swoop.y }
        }
    } // end PathView
}
