// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
import WorkoutManager 1.0

Item {
    id: root
    clip:false

    property int elapsedTime: aWorkoutRunData.workoutTime + aWorkoutRunData.coolDownTime
    property bool isTreadmill: machineinfo.productType === WorkoutProgram.TREADMILL

    function firstTab() {
        switch (workoutProgram.programIndex) {
            // incline first
        case WorkoutProgram.TREAD_CUSTOM_HILLS_PROG:
        case WorkoutProgram.TREAD_HILL_INTERVALS_PROG:
        case WorkoutProgram.TREAD_RANDOM_HILLS_PROG:
        case WorkoutProgram.TREAD_ROLLING_HILLS_PROG:
        case WorkoutProgram.TREAD_SINGLE_HILL_PROG:
        case WorkoutProgram.TREAD_GLUTE_BUSTER_PROG:
        case WorkoutProgram.TREAD_WEIGHT_LOSS_HILLS_PROG:
            return "profile2tab"
            // workload first
        case WorkoutProgram.CALORIE_PROG:
        case WorkoutProgram.GLUTE_BUSTER_PROG:
        case WorkoutProgram.HRC_WEIGHT_LOSS_PROG:
        case WorkoutProgram.HRC_TARGET_PROG:
        case WorkoutProgram.HRC_AEROBIC_PROG:
        case WorkoutProgram.HRC_INTERVALS_PROG:
        case WorkoutProgram.ROLLING_HILLS_PROG:
        case WorkoutProgram.SINGLE_HILL_PROG:
        case WorkoutProgram.HILL_INTERVALS_PROG:
        case WorkoutProgram.RANDOM_HILLS_PROG:
        case WorkoutProgram.CUSTOM_HILLS_PROG:
        case WorkoutProgram.CUSTOM_ULTRA_PROG:
        case WorkoutProgram.CUSTOM_HRC_PROG:
        case WorkoutProgram.FITNESS_TEST_PROG:
            return "profile2tab"
        default:
            return "profile1tab" // speed or pace first
        }
    }

    function nextTab() {
        root.state = root.state == "profile1tab" ? "profile2tab" : "profile1tab"
    }

    state: firstTab()

    TabbedView{
        id:profile2tab
        index: firstTab() === "profile2tab" ? 0 : 1
        width:parent.width
        height: parent.height - 5
        anchors.bottom: parent.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        activeTabImageSciFile: "graphics/netpulse/activeTabImage.sci"
        inactiveTabImageSciFile: "graphics/netpulse/inactiveTabImage.sci"
        backgroundImageSciFile: isTreadmill ? "graphics/setup/Profile_Edit_White.sci" : "graphics/netpulse/tabBorderImage.sci"
        label: if (machineinfo.productType === WorkoutProgram.TREADMILL) {
                   return qsTr("INCLINE") + application.emptyString
               }
               else {
                   return qsTr("WORKLOAD") + application.emptyString
               }
        state: "ACTIVE"
        onTabSelected: {
            root.state = "profile2tab"
        }
    }

    TabbedView{
        id:profile1tab
        index: firstTab() === "profile1tab" ? 0 : 1
        width:parent.width
        height: parent.height - 5
        anchors.bottom: parent.bottom
        anchors.horizontalCenter: parent.horizontalCenter
        activeTabImageSciFile: "graphics/netpulse/activeTabImage.sci"
        inactiveTabImageSciFile: "graphics/netpulse/inactiveTabImage.sci"
        backgroundImageSciFile: isTreadmill ? "graphics/setup/Profile_Edit_White.sci" : "graphics/netpulse/tabBorderImage.sci"
        label: if (isTreadmill) {
                   return qsTr("SPEED") + application.emptyString
               }
               else {
                   return qsTr("PACE") + application.emptyString
               }
        onTabSelected: {
            root.state = "profile1tab"
        }
    }

    states:[
        State{
            name:"profile2tab"
            PropertyChanges{target: profile2tab; state: "ACTIVE"; z: 2}
            PropertyChanges{target: profile1tab; state: "INACTIVE"; z: 1 }
            PropertyChanges{target: profile1Widget ; active: true ;z:2}
            PropertyChanges{target: profile2Widget ; active: false ;z:1}
        },
        State{
            name:"profile1tab"
            PropertyChanges{target: profile2tab; state: "INACTIVE"; z: 1}
            PropertyChanges{target: profile1tab; state: "ACTIVE"; z: 2}
            PropertyChanges{target: profile1Widget ; active: false; z:1 }
            PropertyChanges{target: profile2Widget ; active: true; z:2}
        }
    ]

    Item {
          anchors.fill: parent
          z: 3
          clip: false

          // special mousearea to expand touchable area for tabs
          MouseArea {
              id: tabMouseArea
              preventStealing: true
              anchors.top: parent.top
              anchors.left: parent.left
              width: parent.width
              height: 75
              onClicked: {
                  if (mouseX >= profile1tab.tabXOffset && mouseX <= profile1tab.tabXOffset + profile1tab.tabWidth){
                      console.log("profile 1 tab selected through fake mousearea")
                      profile1tab.tabSelected()
                      buzzer.buttonPress()
                  } else if (mouseX >= profile2tab.tabXOffset && mouseX <= profile2tab.tabXOffset + profile2tab.tabWidth){
                      console.log("profile 2 tab selected through fake mousearea")
                      profile2tab.tabSelected()
                      buzzer.buttonPress()
                  }
              }
              z:10000
          }

          ProfileWidget {
            id: profile1Widget

            anchors { left: parent.left ; leftMargin: 17 ; right: parent.right ; rightMargin: 16 ; top: parent.top ; topMargin: 50 ; bottom: parent.bottom ; bottomMargin: 1 }
            model: workoutProgram.profile1
            xPositionOffset: 5
            yPosition: isTreadmill ? 60 : 5
            editable: false
            levelIndicatorVisibility: false
            profileVisible: true
            columnWidth: 35 // Must not be below 10
            isWorkoutView: true
            segmentFill: (100* (root.elapsedTime / model.segmentDuration)) % 100
            activeSegment: workoutManager.currentSegment
            segmentColorHistory: "#5D9731"
        }

        ProfileWidget {
            id: profile2Widget

            anchors { left: parent.left ; leftMargin: 17 ; right: parent.right ; rightMargin: 16 ; top: parent.top ; topMargin: 50 ; bottom: parent.bottom ; bottomMargin: 1 }
            model: workoutProgram.profile2
            xPositionOffset: 25 // offset profile2 a bit from profile1
            yPosition: isTreadmill ? 60 : 5
            editable: false
            levelIndicatorVisibility: false
            profileVisible: true
            columnWidth: 35 // Must not be below 10
            isWorkoutView: true
            segmentFill: profile1Widget.segmentFill
            activeSegment: workoutManager.currentSegment
        }
    }
}

