import QtQuick 2.4

FocusScope {
    id: root

    width: 850

    property variant model
    property alias currentIndex: workout_detail.currentIndex
    property int slideDuration: 500
    property bool showArrows: true
    property string translationContext: "Menu"
    property alias moving: workout_detail.moving

    function reset() {
        // find and select the first menu item which is not a shim
        var i=0
        while(model.get(i).shim)
            i++
        root.currentIndex = i
    }

    function incrementCurrentIndex() {
        var wrap = function(i) {
            return i >= workout_detail.count ? 0 : i
        }

        if (model.count < 1) return

        for (var i = wrap(currentIndex + 1);; i = wrap(i + 1)) {
            if (!model.get(i).shim) {
                workout_detail.currentIndex = i
                break
            }
        }
    }

    function decrementCurrentIndex() {
        var wrap = function(i) {
            return i < 0 ? workout_detail.count - 1 : i
        }

        if (model.count < 1) return

        for (var i = wrap(currentIndex - 1);; i = wrap(i -1)) {
            if (!model.get(i).shim) {
                workout_detail.currentIndex = i
                break
            }
        }
    }

    // This is the item that is scrolled horizontally in the workout image field
    Component {
        id: image_delegate
        Item{
            width: model.shim ? 0 : workout_image_scroll.width
            height: workout_image_scroll.height
            z: workout_detail.z
            visible: !model.shim && model.image !== ""

            Rectangle{
                id:imageContainer
                radius: 20
                color: "#909090"
                width: 400
                height: 290

                Image {
                    id:image
                    // create an alias to the model data so accessible from outside the ListView element
                    property variant mycurrentData: model
                    fillMode: Image.Tile
                    source: {
                        if (options.modestyMode && model.modestyImage)
                            return "graphics/" + model.modestyImage
                        if(model.image)
                            return "graphics/" + model.image
                        else if (model.icon)
                            return "graphics/" + model.icon
                        else
                            return ""
                    }
                }
            }

            Image {
                id: imageShadow
                source: "graphics/200/Swipe_Shadow.png"
                anchors { top: imageContainer.bottom; left: imageContainer.left; leftMargin: -15 }
            }


            Text {
                id: desc_text
                anchors.left: imageContainer.right
                anchors.leftMargin: 20
                anchors.right: parent.right
                anchors.rightMargin: 20
                anchors.top: parent.top
                anchors.topMargin: 15
                anchors.bottom: parent.bottom
                anchors.bottomMargin: 15
                text: model ? qsTranslate(translationContext, model.desc ? model.desc : "") + application.emptyString : ""
                color: "black"
                wrapMode: Text.WordWrap
                lineHeight: 1.3
                font.pixelSize: {
                    if (application.currentLanguage === "ja") {
                        return text.length < 60 ? 32 : (text.length < 80 ? 30 : (text.length < 125 ? 24 : 20))
                    } else if (application.currentLanguage === "zh") {
                        return text.length < 60 ? 32 : (text.length < 85 ? 30 : 24)
                    } else if (application.currentLanguage === "ko") {
                        return text.length > 140 ? 20 : 24
                    } else {
                        return text.length > 420 ? 16 : (text.length > 400 ? 18 : (text.length > 240 ? 20 : 24))
                    }
                }
            }
        }
    }

    Item { // grey rectangle background
        id: workout_image_scroll

        anchors {
            left: parent.left ; leftMargin: 25
            top: parent.top ; topMargin: 100
        }

        width: root.width
        height: 356

        PathView {
            id: workout_detail

            model: root.model
            delegate: image_delegate
            interactive: true
            clip:true
            anchors.fill: parent

            highlightMoveDuration: root.slideDuration
            highlightRangeMode: PathView.StrictlyEnforceRange   // force the current item to always be the visible one
            preferredHighlightBegin: 0.5
            preferredHighlightEnd: 0.5
            focus: true

            // propagate the moving changed signal to allow resetting scroll timer
            //onMovingChanged: root.movingChanged()

            pathItemCount: 2

            path: Path {
                startX: workout_image_scroll.width*1.5
                startY: workout_image_scroll.height / 2
                PathAttribute { name: "z" ; value: -1 }
                PathLine {
                    x: -workout_image_scroll.width/2 ;
                    y: workout_image_scroll.height / 2
                }
                PathAttribute { name: "z" ; value: 1 }
            }

        } // end workout_detail ListView
    } // end grey rectangle background

    Image {
        id: leftArrow
        source: "graphics/Swipe_Arrows_Left.png"
        anchors { left: workout_image_scroll.left ; top: workout_image_scroll.bottom ; topMargin: 10 }
        visible: showArrows
    }
    Item {
        width: leftArrow.width*1.5
        height: leftArrow.height*1.5
        anchors { left: leftArrow.left; leftMargin: -20; top: leftArrow.top; topMargin: -10 }

        // roll to previous workout if swipe arrow pressed
        MouseArea {
            anchors.fill: parent
            onClicked: { root.incrementCurrentIndex() }
            enabled: leftArrow.visible
        }
    }

    Image {
        id: rightArrow
        source: "graphics/Swipe_Arrows_Right.png"
        anchors { right: workout_image_scroll.right ; rightMargin: 450; top: workout_image_scroll.bottom ; topMargin: 10 }
        visible: showArrows

    }
    Item {
        width: rightArrow.width*1.5
        height: rightArrow.height*1.5
        anchors { right: rightArrow.right; rightMargin: -20; top: rightArrow.top; topMargin: -10 }

        // roll to next workout if swipe arrow pressed
        MouseArea {
             anchors.fill: parent
             onClicked: { root.decrementCurrentIndex() }
        }
    }

}
