import QtQuick 2.4
import WorkoutManager 1.0
import "string_format.js" as Format
import Components 1.0

Item {
    id: root

    property string profile1Title
    property string profile2Title
    property int setupAge
    property int setupWeight
    property int totalTime: workoutProgram.workoutGoalTime
    property int numSegments: workoutProgram.profile1.count
    property int segmentTime: workoutProgram.profile1.segmentDuration
    property int profile1Max: workoutProgram.profile1.findMax("segmentLevel") || 0
    property int profile2Max: workoutProgram.profile2.findMax("segmentLevel") || 0
    property real maxIncline: workoutProgram.maxIncline
    property real maxSpeed: workoutProgram.maxSpeed
    property real incline: workoutProgram.incline
    property real speed: workoutProgram.speed
    property real maxLevelIncline: getInclineLevelMax(workoutProgram.level)
    property real maxLevelSpeed: getSpeedLevelMax(workoutProgram.level)
    property int workload: workoutProgram.workload
    property int maxLevelWorkload
    property int targetHR: workoutProgram.targetHR
    property int restHR: workoutProgram.restHR
    property int workHR: workoutProgram.workHR
    property real workSpeed: workoutProgram.workRunSpeed
    property real restSpeed: workoutProgram.restWalkSpeed
    property real distance: workoutProgram.workoutGoalDistance
    property string speedUnits: (options.metricUnits ? qsTr("KPH") : qsTr("MPH"))
    property string weightUnits: (options.metricUnits ? qsTr("KG") : qsTr("LB"))
    property int distanceFromTop: 172
    property int distanceFromLeft: 1140

    function getSpeedLevelMax(level) {
        if (workoutProgram.programIndex != WorkoutProgram.TREAD_LEG_SHAPER_PROG)
            return 0
        var result = workoutProgram.profile2.findMaxWithLevel("segmentMagnitude", level)
        result = parseInt(result)/10.0
        if (options.metricUnits)
            result = Globals.mileToKm(result)
        return result.toFixed(1)
    }

    function getInclineLevelMax(level) {
        switch(workoutProgram.programIndex) {
        case WorkoutProgram.TREAD_CARDIO_CHALLENGE_PROG:
        case WorkoutProgram.TREAD_GLUTE_BUSTER_PROG:
        case WorkoutProgram.TREAD_HILL_INTERVALS_PROG:
        case WorkoutProgram.TREAD_ROLLING_HILLS_PROG:
        case WorkoutProgram.TREAD_SINGLE_HILL_PROG:
        case WorkoutProgram.TREAD_WEIGHT_LOSS_HILLS_PROG:
        case WorkoutProgram.TREAD_RANDOM_HILLS_PROG:
            var result = workoutProgram.profile1.findMaxWithLevel("segmentMagnitude", level)
            result = parseInt(result)/10.0
            return result.toFixed(1)
        default:
            return 0
        }
    }

    function convertSpeed(speedval) {
        return (options.metricUnits ? Globals.mileToKm(speedval) : speedval).toFixed(1) + " " + root.speedUnits + application.emptyString
    }

//    onVisibleChanged: if (visible) console.log("synopsis", JSON.stringify(root))

    function computeValueOfMax1(value) {
        var incline = workoutProgram.inclineTable[value - 1]/10.0
        return incline.toFixed(1)
    }

    function computeValueOfMax2(value) {
        var speed = workoutProgram.speedTable[value - 1]/10.0
        return speed.toFixed(1)
    }

    Image {
        id: summaryBackground
        x: root.distanceFromLeft
        y: root.distanceFromTop
        source: "graphics/setup/Workout_Summary_Bluebox.png"
    }

    Column {
        x: root.distanceFromLeft - 537 + summaryBackground.width
        y: root.distanceFromTop + 10

        spacing: 15

        Item {
            id: ageRow
            visible: workoutProgram.userAgeRequired && setupAge > 0
            width: 537
            height: 20
            Text {
                id: step3AgePromptText
                text: qsTr("AGE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }

            Text {
                id: step3AgeText
                text: setupAge
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: ageRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: weightRow
            visible: workoutProgram.userWeightRequired && setupWeight > 0
            width: 537
            height: 20

            Text {
                id: step3WeightPromptText
                text: qsTr("WEIGHT") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }

            Text {
                id: step3WeightText
                text: {
                    return workoutProgram.originalWeight + " " + workoutProgram.weightUnits + application.emptyString
                }
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: weightRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: genderRow
            visible: workoutProgram.userGenderRequired
            width: 537
            height: 20

            Text {
                id: genderPrompt
                text: qsTr("GENDER") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }

            Text {
                id: genderText
                text: (workoutProgram.userGender ? qsTr("F") : qsTr("M")) + application.emptyString
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: genderRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: timeRow
            visible: workoutProgram.timeRequired && totalTime > 0
            width: 537
            height: 20
            Text {
                id: step3TimePromptText
                text: qsTr("WORKOUT TIME") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: step3TimeText
                text: Format.formatTimeString(totalTime * 60);
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }

        }

        Item {
            visible: workoutProgram.profile1.isCustom || workoutProgram.profile2.isCustom
            width: 537
            height: 20
            // NUMBER OF SEGMENTS
            Text {
                id: step3NumSegsPromptText
                text: qsTr("NUMBER OF SEGMENTS") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: step3NumSegsText
                text: numSegments
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }

        }

        Item {
            visible: workoutProgram.profile1.isCustom || workoutProgram.profile2.isCustom
            width: 537
            height: 20
            Text {
                id: step3SegTimePromptText
                text: qsTr("SEGMENT TIME") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: step3SegTimeText
                text: Format.formatTimeString(segmentTime);
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: timeRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: distanceRow
            visible: workoutProgram.distanceRequired && distance>0
            width: 537
            height: 20
            Text {
                id: distancePrompt
                text: qsTr("DISTANCE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: distanceText
                text: {
                    QT_TRANSLATE_NOOP("K")
                    QT_TRANSLATE_NOOP("MI")
                    var dist = workoutProgram.originalDistance
                    var units = workoutProgram.distanceUnits
                    return dist.toFixed(1) + " " + qsTr(units) + application.emptyString
                }
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: distanceRow.visible
            width: 537
            height: 3
            color: "black"
        }

        // MAX PROFILE 2
        Item {
            id: profile2MaxRow
            visible: workoutProgram.profile2.isCustom
            width: 537
            height: 20
            Text {
                id: profile2MaxPrompt
                text: qsTr("MAX") + " " + root.profile2Title + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: profile2MaxText
                text: {
                    if (workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL) {
                        var maxVal = computeValueOfMax2(profile2Max)
                        maxVal = options.metricUnits ? Globals.mileToKm(maxVal).toFixed(1) : maxVal
                        return maxVal + " " + root.speedUnits + application.emptyString
                    } else {
                        return profile2Max
                    }
                }
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: profile2MaxRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: profile1MaxRow
            visible: workoutProgram.profile1.isCustom
            width: 537
            height: 20
            Text {
                id: profile1MaxPrompt
                text: qsTr("MAX") + " " + root.profile1Title + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: profile1MaxText
                text: workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL ? computeValueOfMax1(profile1Max)+"%" : profile1Max
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: profile1MaxRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: maxInclineRow
            visible: workoutProgram.maxInclineRequired
            width: 537
            height: 20
            Text {
                id: maxInclinePrompt
                text: qsTr("MAX INCLINE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: maxInclineText
                text: maxIncline.toFixed(1) + "%"
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: maxInclineRow.visible
            width: 537
            height: 3
            color: "black"
        }


        Item {
            id: maxSpeedRow
            visible: workoutProgram.maxSpeedRequired
            width: 537
            height: 20
            Text {
                id: maxSpeedPrompt
                text: qsTr("MAX SPEED") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: maxSpeedText
                text: convertSpeed(maxSpeed)
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: maxSpeedRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: inclineRow
            visible: workoutProgram.inclineRequired
            width: 537
            height: 20
            Text {
                id: inclinePrompt
                text: qsTr("INCLINE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: inclineText
                text: (workoutProgram.inclineTable[parseInt(incline) - 1]/10.0).toFixed(1) + "%"
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: inclineRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: speedRow
            visible: workoutProgram.speedRequired
            width: 537
            height: 20
            Text {
                id: speedPrompt
                text: qsTr("SPEED") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: speedText
                text: convertSpeed(speed)
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: speedRow.visible
            width: 537
            height: 3
            color: "black"
        }

        // Level for non-treads (treads instead map level to max incline/max speed further down)
        Item {
            id: levelRow
            visible: workoutProgram.levelRequired && workoutProgram.productType != WorkoutProgram.TREADMILL
            width: 537
            height: 20
            Text {
                id: levelPrompt
                text: qsTr("LEVEL") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: levelText
                text: workoutProgram.level
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: levelRow.visible
            width: 537
            height: 3
            color: "black"
        }

        // Max Incline reached in a varied level workout
        Item {
            id: maxLevelInclineRow
            visible: maxLevelIncline > 0
            width: 537
            height: 20
            Text {
                id: maxLevelInclinePrompt
                text: qsTr("MAX INCLINE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: maxLevelInclineText
                text: maxLevelIncline.toFixed(1) + "%"
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: maxLevelInclineRow.visible
            width: 537
            height: 3
            color: "black"
        }

        // Max Speed reached in a varied level workout
        Item {
            id: maxLevelSpeedRow
            visible: maxLevelSpeed > 0
            width: 537
            height: 20
            Text {
                id: maxLevelSpeedPrompt
                text: qsTr("MAX SPEED") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: maxLevelSpeedText
                text: convertSpeed(maxLevelSpeed)
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: maxLevelSpeedRow.visible
            width: 537
            height: 3
            color: "black"
        }


        Item {
            id: workloadRow
            visible: workoutProgram.workloadRequired
            width: 537
            height: 20
            Text {
                id: workloadPrompt
                text: qsTr("WORKLOAD") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: workloadText
                text: workload
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: workloadRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: targetHRRow
            visible: workoutProgram.targetHRRequired
            width: 537
            height: 20
            Text {
                id: targetHRPrompt
                text: qsTr("TARGET HEART RATE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: targetHRText
                text: targetHR + " " + qsTr("BPM") + application.emptyString
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: targetHRRow.visible
            width: 537
            height: 3
            color: "black"
        }


        Item {
            id: workHRRow
            visible: workoutProgram.workHRRequired
            width: 537
            height: 20
            Text {
                id: workHRPrompt
                text: qsTr("WORK HEART RATE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: workHRText
                text: workHR + " " + qsTr("BPM") + application.emptyString
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: workHRRow.visible
            width: 537
            height: 3
            color: "black"
        }


        Item {
            id: restHRRow
            visible: workoutProgram.restHRRequired
            width: 537
            height: 20
            Text {
                id: restHRPrompt
                text: qsTr("REST HEART RATE") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: restHRText
                text: restHR + " " + qsTr("BPM") + application.emptyString
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: restHRRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: restSpeedRow
            visible: workoutProgram.restWalkSpeedRequired
            width: 537
            height: 20
            Text {
                id: restSpeedPrompt
                text: qsTr("REST SPEED") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: restSpeedText
                text: convertSpeed(restSpeed)
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: restSpeedRow.visible
            width: 537
            height: 3
            color: "black"
        }

        Item {
            id: workSpeedRow
            visible: workoutProgram.workRunSpeedRequired
            width: 537
            height: 20
            Text {
                id: workSpeedPrompt
                text: qsTr("WORK SPEED") + application.emptyString
                anchors.left: parent.left
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
            Text {
                id: workSpeedText
                text: convertSpeed(workSpeed)
                anchors.right: parent.right
                anchors.rightMargin: 15
                font.pointSize: 18
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Rectangle {
            visible: workSpeedRow.visible
            width: 537
            height: 3
            color: "black"
        }
    }
}
