import QtQuick 2.4
import VLCVideo 1.0
import Components 1.0

Item {
    id: root

    property string videoFile: ""
    property bool muted: false
    property alias playing: videoPlayer.playing

    function stopVideo() {
        state = "MenuState"
        fullscreenVideoFrame.endFullscreen()
        print("Stop VA Video")
        videoPlayer.stop()
    }

    // start out showing a menu of video thumbnails
    Component.onCompleted: state = "MenuState"

    Image {
        id: background
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter

        source: "graphics/netpulse/DATA_gray shape_120612.png"
    }

    // List Model of videos - name displayed as title, file is video file, thumbnail shows in menu
    ListModel {
        id: videos

        ListElement { name: QT_TR_NOOP("Wild California Run") ; file: "/data/video/TFRN0104_tfe01.mp4"; thumbnail: "/data/video/TFRN0104.png"}
        ListElement { name: QT_TR_NOOP("Germany Run") ; file: "/data/video/TFRN0103_tfe01.mp4"; thumbnail: "/data/video/TFRN0103.png"}
        ListElement { name: QT_TR_NOOP("Chicago Run") ; file: "/data/video/TFRN0102_tfe01.mp4"; thumbnail: "/data/video/TFRN0102.png"}
        ListElement { name: QT_TR_NOOP("American Southwest II") ; file: "/data/video/TFRN0101_tfe01.mp4"; thumbnail: "/data/video/TFRN0101.png"}
        ListElement { name: QT_TR_NOOP("Trinity Mountains") ; file: "/data/video/TFHK0101_tfe01.mp4"; thumbnail: "/data/video/TFHK0101.png"}
        ListElement { name: QT_TR_NOOP("Northern Italy") ; file: "/data/video/TFBK0101_tfe01.mp4"; thumbnail: "/data/video/TFBK0101.png"}

/*
        ListElement { name: QT_TR_NOOP("Wild California") ; file: "/data/video/TFHK0106_Wild CA.mp4"; thumbnail: "/data/video/TFHK0106_Wild CA.png"}
        ListElement { name: QT_TR_NOOP("American Northeast") ; file: "/data/video/TFHK0101_Amer NE.mp4" ; thumbnail: "/data/video/TFHK0101_Amer NE.png"}
        ListElement { name: QT_TR_NOOP("North Italy") ; file: "/data/video/TFHK0103_North Italy.mp4" ; thumbnail: "/data/video/TFHK0103_North Italy.png"}
        ListElement { name: QT_TR_NOOP("American Southwest") ; file: "/data/video/TFHK0102_Amer SW.mp4" ; thumbnail: "/data/video/TFHK0102_Amer SW.png"}
        ListElement { name: QT_TR_NOOP("Swiss Alps") ; file: "/data/video/TFHK0105_Swiss Alps.mp4"; thumbnail: "/data/video/TFHK0105_Swiss Alps.png" }
        ListElement { name: QT_TR_NOOP("Northern Rockies") ; file: "/data/video/TFHK0104_North Rockies.mp4"; thumbnail: "/data/video/TFHK0104_North Rockies.png" }
*/
    }

    // component for video thumbnail to be shown in grid.  Mouse area to select and start video on click
    Component {
        id: videoThumb
        Item {
            property variant myData: model
            width: parent.width / parent.columns ; height: parent.height / parent.rows;

            function startThisVideo() {
                root.videoFile = file
                videoPlayer.mrl = "file://" + root.videoFile
                root.state = "PlayingState"
                videoView.play()
                miscStats.incrementVaVideoUsage(file)
            }

            Image { id: thumb ; width: parent.width - 10 ; height: parent.height - 20 ; source: thumbnail ; fillMode: Image.PreserveAspectFit }
            Text {
                anchors { top: thumb.bottom ;horizontalCenter: thumb.horizontalCenter }
                width: parent.width - 10 ; height: 20 ;
                horizontalAlignment: Text.AlignHCenter
                text: qsTr(name) + application.emptyString
            }
            MouseArea {
                anchors.fill: thumb
                scale: 0.75
                preventStealing: true
                onClicked: {
                    root.videoFile = file
                    videoPlayer.mrl = "file://" + root.videoFile
                    root.state = "PlayingState"
                    print("Play VA Video " + file + "(" + name + ")")
                    videoPlayer.play()
                    miscStats.incrementVaVideoUsage(file)
                }
            }
        }
    }

    // grid layout of video thumbnails
    Grid {
        id: videoMenu

        columns: 3; rows: 2
        spacing: 20
        anchors { fill: parent ; margins: 50 }
        Repeater {
            model: videos
            delegate: videoThumb
        }
    }

    // Video window to play video
    VLCSurface {
        id: videoView

        player: videoPlayer
        playing: !player.fullscreen && videoPlayer.playing
        aspect: videoPlayer.aspect

        visible: true

        anchors {
            left: parent.left
            leftMargin: 10
            right: parent.right
            rightMargin: 10
            top: parent.top
            bottom: parent.bottom
        }

        MouseArea {
            anchors.fill: parent
            onClicked: {
                fullscreenVideoFrame.showFullscreen(videoPlayer)
            }
        }
    }

    VLCVideo {
        id: videoPlayer

        property bool fullscreen

        onPlayCompleted: root.stopVideo()

//        commandLineArgs: ["--avcodec-hw=vaapi"]
        muted: root.muted
    }

    Column {
        spacing: 15

        anchors { verticalCenter: parent.verticalCenter ; right: parent.right ; rightMargin: 25 }
        visible: videoView.visible && ! root.fullscreen

        ImageButton{
            id: stopButton

            downimage: "graphics/netpulse/GRAYbutton_video_PRESSED.png"
            upimage: "graphics/netpulse/GRAYbutton_video.png"
            icon: "graphics/netpulse/Stop_icon_BLACK.png"
            onClicked: root.stopVideo()
        }

        ImageButton{
            id: sizeButton

            downimage: "graphics/netpulse/GRAYbutton_video_PRESSED.png"
            upimage: "graphics/netpulse/GRAYbutton_video.png"
            icon: "graphics/netpulse/Fullscreen_icon.png"
            onClicked: fullscreenVideoFrame.showFullscreen(videoPlayer)
        }
    }

    states: [
        State {
            name: "MenuState"
            PropertyChanges { target: videoMenu ; visible: true }
            PropertyChanges { target: videoView; visible: false }
        },
        State {
            name: "PlayingState"
            PropertyChanges { target: videoMenu ; visible: false }
            PropertyChanges { target: videoView; visible: true }
        }
    ]
}
