import QtQuick 2.4

// Based on the code from https://www.mail-archive.com/qt-qml@qt.nokia.com/msg00990.html
Item {
    id: root

    property string text: "----"
    property bool scrolling: false
    property alias font: elidedText.font
    property alias boundsBehavior: flickable.boundsBehavior
    property alias color: elidedText.color

    height: elidedText.height

    Text {
        id: invisibleText
        visible: false
        text: root.text
        font: elidedText.font
    }

    Flickable {
        id: flickable

        anchors.fill: parent
        contentWidth: invisibleText.paintedWidth
        contentHeight: invisibleText.paintedHeight
        flickableDirection: Flickable.HorizontalFlick
        interactive: invisibleText.width > root.width
        clip: true
//                boundsBehavior: Flickable.StopAtBounds

        Text {
            id: elidedText
            width: root.width
            text: root.text
            horizontalAlignment: paintedWidth > root.width ? Text.AlignLeft : Text.AlignHCenter
            anchors.verticalCenter: parent.verticalCenter
            elide: Text.ElideRight
            smooth: true
        }

        onAtXEndChanged: {
            if(atXEnd)
            {
                animationTimer.stop();
                restartTimer.start();
            }
        }

        onMovementStarted: {
            animationTimer.stop();
            restartTimer.stop();
            startTimer.stop();
        }

        onMovementEnded: {
            if(atXEnd)
                restartTimer.start();
            else
                startTimer.start();
        }
    }

    Timer {
        id: startTimer
        interval: 2000
        running: invisibleText.width > root.width
        onTriggered: {
            animationTimer.start();
        }
    }

    Timer {
        id: animationTimer
        interval: 10
        running: false
        repeat: true
        onTriggered: flickable.contentX += 2
    }

    Timer {
        id: restartTimer
        interval: 2000
        running: false
        repeat: false
        onTriggered: {
            flickable.contentX = 0;
            if(invisibleText.width > root.width)
                startTimer.start();
        }
    }

    states: [
        State {
            name: "scrolling"
            when: !flickable.atXBeginning
            PropertyChanges {
                target: elidedText
                elide: Text.ElideNone
            }
            PropertyChanges {
                target: startTimer
                running: false
            }
            PropertyChanges {
                target: root
                scrolling: true
            }
        }
    ]
}
