import QtQuick 2.4
import "string_format.js" as Format
import Components 1.0

Item {
    id: root

    property variant profile1model
    property variant profile2model
    property string profile1Title
    property string profile2Title
    property string profile1color: "green"
    property string profile2color: "orange"
    property bool saveHasHappened: false

    Item { id: summaryProfileGraph

        width: 761
        height: 506
        x: 20
        y: main.isTft ? 70 : 90

        Image {
            id: step3ProfileBackground
            x: 0
            y: 0
            source: "graphics/setup/Workout_Summary_Lrg_Top.png"
            smooth: true

            Text {
                id: profileBackgroundTitle
                anchors.top: step3ProfileBackground.top
                anchors.topMargin: 30
                anchors.left: step3ProfileBackground.left
                anchors.leftMargin: 28
                text: qsTr("CUSTOM WORKOUT PROFILE") + application.emptyString
                font.pointSize: 16
                font.bold: true
                smooth: true
                color: "black"
            }

            ProfileWidget {
                id: profile1widget

                anchors { top: parent.top ; topMargin: 70 ; bottom: parent.bottom ; bottomMargin: 95 - yPosition ; left: parent.left ; leftMargin: 30 ; right: parent.right ; rightMargin: 30 }
                z:4
                segmentColorInactive: profile1color
                profileVisible: true
                xPositionOffset: 10
                showLevel: true
                // If the segment count is <=30, evenly distribute them over the available space.
                // Avoid doing this for infinitely sized profiles
                columnWidth: (model.count <=30) ? ((width/2.1) / model.count) : 80
                model: profile1model
                hasNegativeValues: machineinfo.treadmillInclineMinPercentGrade < 0.0
                numNegativeValues: {
                    if (!hasNegativeValues) return 0

                    return machineinfo.inclineTable.indexOf(0.0)
                }
                baseOffset: 50
                yPosition: 60
            }

            ProfileWidget {
                id: profile2widget

                anchors { top: parent.top ; topMargin: 70 ; bottom: parent.bottom ; bottomMargin: 95 - yPosition ; left: parent.left ; leftMargin: 30 ; right: parent.right ; rightMargin: 30 }
                z:3
                segmentColorInactive: profile2color
                profileVisible: true
                xPositionOffset: 20
                showLevel: true
                columnWidth: (model.count <=30) ? ((width/2.1) / model.count) : 80
                model: profile2model
                yPosition: 60
            }

            Rectangle {
                id: customProfileSummaryAxis
                anchors.bottom: step3ProfileBackground.bottom
                anchors.bottomMargin: 95
                anchors.left: profileBackgroundTitle.left
                width: 4
                height: 331
                color: "black"
            }

            Rectangle {
                id: customProfileHatch1
                anchors.top: customProfileSummaryAxis.top
                anchors.left: customProfileSummaryAxis.left
                width: 10
                height: 4
                color: "black"
            }

            Rectangle {
                id: customProfileHatch2
                anchors.top: customProfileHatch1.top
                anchors.topMargin: 82
                anchors.left: customProfileSummaryAxis.left
                width: 10
                height: 4
                color: "black"
            }

            Rectangle {
                id: customProfileHatch3
                anchors.top: customProfileHatch2.top
                anchors.topMargin: 82
                anchors.left: customProfileSummaryAxis.left
                width: 10
                height: 4
                color: "black"
            }

            Rectangle {
                id: customProfileHatch4
                anchors.top: customProfileHatch3.top
                anchors.topMargin: 82
                anchors.left: customProfileSummaryAxis.left
                width: 10
                height: 4
                color: "black"
            }
        }

        Item {
            id: profile1Legend
            anchors.horizontalCenter: step3ProfileBackground.horizontalCenter
            anchors.bottom: step3ProfileBackground.bottom
            anchors.bottomMargin: 60

            Rectangle {
                id: profile1LegendRect
                width: 30
                height: 20
                color: profile1color
                border.color: "black"
                border.width: 1
            }

            Text {
                id: profile1LegendText
                anchors.verticalCenter: profile1LegendRect.verticalCenter
                anchors.left: profile1LegendRect.right
                anchors.leftMargin: 10
                text: qsTr(root.profile1Title) + application.emptyString
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }

        Item {
            id: profile2Legend
            anchors.left: profile1Legend.right
            anchors.leftMargin: 200
            anchors.verticalCenter: profile1Legend.verticalCenter

            Rectangle {
                id: profile2LegendRect
                width: 30
                height: 20
                color: profile2color
                border.color: "black"
                border.width: 1
            }

            Text {
                id: profile2LegendText
                anchors.verticalCenter: profile2LegendRect.verticalCenter
                anchors.left: profile2LegendRect.right
                anchors.leftMargin: 10
                text: qsTr(root.profile2Title) + application.emptyString
                font.pointSize: 14
                font.bold: true
                smooth: true
                color: "black"
                z: 2
            }
        }
    }

    Text {
        id: pressEnterText
        visible: main.isTft
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#000000"
        text: qsTr("press ENTER to select or START to begin") + application.emptyString
        width:750
        wrapMode:Text.WordWrap
        anchors {
            top: summaryProfileGraph.bottom
            topMargin: 50
            left: summaryProfileGraph.left
            leftMargin: 50
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: qsTr("step 3 of 3") + application.emptyString
        anchors {
            top: summaryProfileGraph.bottom
            topMargin: 110
            right: summaryProfileGraph.right
            rightMargin: 10
        }
    }

    Connections {
        target: main.isTft && setupScreenManager.state === "Step3" ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "SetupSummary")
            listViewLoader.item.decrementCurrentIndex()
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "SetupSummary")
            listViewLoader.item.incrementCurrentIndex()
        }

        onBackPressed: {
            main.debugKeys("backPressed", "SetupSummary")
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "SetupSummary")
            var currentItem = listViewLoader.item.model.get(listViewLoader.item.currentIndex)
            switch (currentItem.name) {
                case "back":
                    setupScreenManager.state = "Step2"
                    break
                case "save":
                    if (!mainProgItem.saveHasHappened)
                        setupScreenManager.state = "SaveWorkoutScreen"
                    break
            }
        }
    }

    Loader {
        id: listViewLoader
        sourceComponent: main.isTft ? listViewMenuComponent : undefined
        anchors { top: summaryProfileGraph.bottom; topMargin: -15; left: summaryProfileGraph.right; leftMargin: 30 }
        width: 720
        height: 190
        visible: main.isTft

        Component {
            id: listViewMenuComponent
            ListView {
                id: listViewMenu

                keyNavigationWraps: true
                orientation: ListView.Horizontal
                currentIndex: 0
                width: 480
                height: 174
                highlight: Component {
                    Image {
                        source: "graphics/tft/NAV_selector_2.png"
                        width: 244
                        height: 174
                        x: listViewMenu.currentItem.x
                    }
                }
                highlightFollowsCurrentItem: false
                ListModel {
                    id: buttons1
                    ListElement { name: "back"; label: QT_TR_NOOP("BACK"); icon: "tft/nav_icon_BACK.png" }
                }
                ListModel {
                    id: buttons2
                    ListElement { name: "back"; label: QT_TR_NOOP("BACK"); icon: "tft/nav_icon_BACK.png" }
                    ListElement { name: "save"; label: QT_TR_NOOP("SAVE?"); icon: "tft/nav_icon_SAVED.png" }
                }
                model: options.saveWorkoutEnabled ? buttons2 : buttons1
                delegate: Component {
                    Item {
                        id: menuItem

                        width: 240
                        height: 174

                        Item {
                            id: saveItem
                            anchors.fill: parent
                            visible: model.name === "save"
                            ImageButton {
                                id: saveButton
                                width: 126
                                height: 76
                                fontsize: 16

                                label: qsTr(model.label) + (mainProgItem.saveCount > 0 && !mainProgItem.saveHasHappened ? "*" : "") + application.emptyString
                                label_under: true
                                label_y_offset: 50
                                label_color: "black"
                                wrapWidth: 80

                                enabled: !mainProgItem.saveHasHappened
                                disabledOpacity: 1.0
                                anchors.top: parent.top
                                anchors.topMargin: 30
                                anchors.horizontalCenter: parent.horizontalCenter
                                upimage: mainProgItem.saveHasHappened ? "graphics/tft/nav_icon_SAVED-green.png" : "graphics/"+model.icon
                                downimage:"graphics/"+model.icon
                                beep: false
                                mouseAreaScale: 0.7
                            }
                        }
                        Item {
                            id: backItem
                            anchors.fill: parent
                            visible: model.name === "back"
                            ImageButton {
                                id: backButton
                                width: 126
                                height: 76
                                fontsize: 16

                                label: qsTr(model.label) + application.emptyString
                                label_under: true
                                label_y_offset: 50
                                label_color: "black"
                                wrapWidth: 80

                                anchors.top: parent.top
                                anchors.topMargin: 30
                                anchors.horizontalCenter: parent.horizontalCenter
                                upimage: "graphics/"+model.icon
                                downimage: "graphics/"+model.icon
                                beep: false
                                mouseAreaScale: 0.7

                            }
                        }
                    }
                }
            }
        }
    }
}
