import QtQuick 2.4
import ".."
import Components 1.0

Rectangle {
    id: root
    width: 1366
    height: 768
    anchors.fill: parent
    state: ""
    color: "transparent"

    Connections {
        target: main.isTft && root.visible ? keymapper : null

        onLeftButtonPressed: {
            main.debugKeys("leftButtonPressed", "SetupWizardUnits")
            if (metricButton.isDown)
                imperialButton.setDown(true)
            else
                metricButton.setDown(true)
        }

        onRightButtonPressed: {
            main.debugKeys("rightButtonPressed", "SetupWizardUnits")
            if (metricButton.isDown)
                imperialButton.setDown(true)
            else
                metricButton.setDown(true)
        }

        onEnter2Pressed: {
            main.debugKeys("enter2Pressed", "SetupWizardUnits")
            setupWizard.changeState()
        }
    }

    Component.onCompleted: {
        if (options.metricUnits)
            metricButton.setDown(true)
        else
            imperialButton.setDown(true)
    }

    Image {
        id: navCursor
        visible: main.isTft
        source: "graphics/tft/maintenance_menus_cursor.png"
        x: buttonRow.x + (metricButton.isDown ? metricButton.x - 50 : imperialButton.x - 50)
        y: buttonRow.y + metricButton.y + 20
    }

    Row { id: buttonRow

        anchors {
            horizontalCenter: parent.horizontalCenter
            verticalCenter: parent.verticalCenter
            verticalCenterOffset: -100
        }

        ImageButton {
            id: imperialButton

            enabled: true
            label: qsTr("U.S.") + application.emptyString
            label_color: "black"
            label_under: true
            toggle: true

            upimage: "graphics/205/Lrg_Button_Up.png"
            downimage: "graphics/205/Lrg_Button_Down.png"
            icon: isDown ? "graphics/205/IPOD_Checkmark.png" : ""
            radioGroup: [imperialButton, metricButton]
            onIsDownChanged: if (isDown) options.metricUnits = false
        }

        ImageButton {
            id: metricButton

            enabled: true
            label: qsTr("Metric") + application.emptyString
            label_color: "black"
            label_under: true
            toggle: true

            upimage: "graphics/205/Lrg_Button_Up.png"
            downimage: "graphics/205/Lrg_Button_Down.png"
            icon: isDown ? "graphics/205/IPOD_Checkmark.png" : ""
            radioGroup: [imperialButton, metricButton]
            onIsDownChanged: if (isDown) options.metricUnits = true
        }
    }

    Text {
        id: bottomHelpText
        visible: main.isTft

        height: 48
        font { family: "arial"; pixelSize: 36; bold: true }
        color: "#6c6c6c"
        text: {
            if (machinecontrol.isCalibrated)
                return qsTr("use") + " <img src='graphics/tft/arrow_right.png' /> " + qsTr("to continue") + application.emptyString
            else
                return qsTr("press ENTER to continue") + application.emptyString
        }

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 25
        anchors.horizontalCenter: parent.horizontalCenter
    }
}
