// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import WorkoutRunData 1.0
import WorkoutManager 1.0
import TouchAppEnumerations 1.0
import QtQuick 2.4
import "string_format.js" as Format
import Components 1.0

Item {
    id: root

    property variant displayableItems: workoutManager.displayDataVars
    property alias leftDisplay: leftDisplay
    property alias rightDisplay: rightDisplay

    width: parent.width
    height: parent.height


    property string unitState: workoutScreen.unitState

    function reset() {
        hide()
        leftDisplay.reset()
        rightDisplay.reset()
        rotateDataTimer.restart()
    }

    function hide() {
        leftDisplay.state = "Disabled"
        rightDisplay.state = "Disabled"
    }

    DataDisplay{
        id: leftDisplay
        sourceFile: "SideDataDisplays"

        function getData(index)
        {
            var p = leftModel.get(index).precision
            switch(index)
            {
            case 0: return Format.formatTimeStringMinAndSec(aWorkoutRunData.totalTime);
            case 1: return Format.formatTimeStringMinAndSec(aWorkoutRunData.timeRemaining);
            case 2: {
                if (workoutManager.workoutProgram.productType == WorkoutProgram.TREADMILL) {
                    var pace
                    if(unitState == "ENGLISH")
                        pace = aWorkoutRunData.treadPace
                    else
                        pace = aWorkoutRunData.treadPace / 1.61  // inverse mi/km converstion with precision to match brainboard LCD display

                    return Format.formatTimeStringMinAndSec(pace)
                }
                else {
                    return aWorkoutRunData.rpm.toFixed(p);
                }
            }
            case 3:
                if(unitState == "ENGLISH")
                    return aWorkoutRunData.totalDistance.toFixed(p)
                else
                    return Globals.mileToKm(aWorkoutRunData.totalDistance).toFixed(p)
            case 4:
                if (unitState === "ENGLISH")
                    return aWorkoutRunData.strideLength
                else
                    return Math.round(Globals.inchToCm(aWorkoutRunData.strideLength))
            }
        }

        function getUnit(index)
        {
            switch(index)
            {
            case 0: return "";
            case 1: return "";
            case 2: return "";
            case 3: return (unitState == "ENGLISH") ? "MI" : "KM";
            case 4: return ""
            }
        }

        ListModel{
            id: leftModel
            ListElement{ label: QT_TR_NOOP("TIME ELAPSED"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_time}
            ListElement{ label: QT_TR_NOOP("TIME REMAINING"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_timeRemaining}
            ListElement{ label: QT_TR_NOOP("PACE"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_pace}
            ListElement{ label: QT_TR_NOOP("DISTANCE"); isDisplayed: false; precision: 2; dataIndex: TouchAppEnumerations.ENUM_distance}
            ListElement{ label: QT_TR_NOOP("STRIDE LENGTH"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_strideLength}
        }

        headerToggleBool: dataToggleModel.get(TouchAppEnumerations.ENUM_time).thestate
        headerToggleIndex: TouchAppEnumerations.ENUM_time
        Connections{
            target: workoutProgram
            onDisplayDataVarsChanged: {
                leftDisplay.displayModel.setProperty(0,"isDisplayed",items.timeAvailable)
                leftDisplay.displayModel.setProperty(1,"isDisplayed",items.timeRemainingAvailable)
                leftDisplay.displayModel.setProperty(2,"isDisplayed",items.paceAvailable)
                leftDisplay.displayModel.setProperty(3,"isDisplayed",items.distanceAvailable)
                leftDisplay.displayModel.setProperty(4,"isDisplayed",items.strideLengthAvailable || main.isCSA)
            }
        }

        Component.onCompleted: leftDisplay.displayModel = leftModel
    }

    DataDisplay{
        id: rightDisplay
        sourceFile: "SideDataDisplays"
        onRight: true

        function getData(index)
        {
            var p = rightDisplay.displayModel.get(index).precision
            switch(index)
            {

            case 0: return aWorkoutRunData.totalCalories.toFixed(p);
            case 1: return aWorkoutRunData.calsPerHour.toFixed(p);
            case 2: return aWorkoutRunData.watts.toFixed(p);
            case 3: return aWorkoutRunData.mets.toFixed(p);
            case 4:
                if(unitState == "ENGLISH")
                return aWorkoutRunData.totalDistance.toFixed(p)
            else
                return Globals.mileToKm(aWorkoutRunData.totalDistance).toFixed(p)
            case 5:
                if(unitState == "ENGLISH")
                return aWorkoutRunData.distanceRemaining.toFixed(p)
            else
                return Globals.mileToKm(aWorkoutRunData.distanceRemaining).toFixed(p)
            }
        }
        function getUnit(index)
        {
            switch(index)
            {
            case 0: return "";
            case 1: return "";
            case 2: return "";
            case 3: return "";
            case 4: return (unitState == "ENGLISH") ? "MI" : "KM";
            case 5: return (unitState == "ENGLISH") ? "MI" : "KM";
            }
        }

        ListModel{
            id: rightModel
            ListElement{ label: QT_TR_NOOP("CALORIES"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_calories}
            ListElement{ label: QT_TR_NOOP("CALORIES/HR"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_calsPerHour}
            ListElement{ label: QT_TR_NOOP("WATTS"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_watts}
            ListElement{ label: QT_TR_NOOP("METS"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_mets}
            ListElement{ label: QT_TR_NOOP("DISTANCE"); isDisplayed: false; precision: 2; dataIndex: TouchAppEnumerations.ENUM_distanceRight}
            ListElement{ label: QT_TR_NOOP("DISTANCE REMAINING"); isDisplayed: false; precision: 2; dataIndex: TouchAppEnumerations.ENUM_distanceRemaining}
        }

        ListModel{
            id: rightModelen957Mode
            ListElement{ label: QT_TR_NOOP("CALORIES"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_calories}
            ListElement{ label: QT_TR_NOOP("CALORIES/HR"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_calsPerHour}
            ListElement{ label: QT_TR_NOOP("WORK"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_watts}
            ListElement{ label: QT_TR_NOOP("METS"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_mets}
            ListElement{ label: QT_TR_NOOP("DISTANCE"); isDisplayed: false; precision: 2; dataIndex: TouchAppEnumerations.ENUM_distanceRight}
            ListElement{ label: QT_TR_NOOP("DISTANCE REMAINING"); isDisplayed: false; precision: 2; dataIndex: TouchAppEnumerations.ENUM_distanceRemaining}
        }

        headerToggleBool: dataToggleModel.get(TouchAppEnumerations.ENUM_calories).thestate
        headerToggleIndex: TouchAppEnumerations.ENUM_calories

        Connections{
            target: workoutProgram
            onDisplayDataVarsChanged:{
                rightDisplay.displayModel.setProperty(0,"isDisplayed",items.caloriesAvailable)
                rightDisplay.displayModel.setProperty(1,"isDisplayed",items.calsPerHourAvailable)
                rightDisplay.displayModel.setProperty(2,"isDisplayed",items.wattsAvailable)
                rightDisplay.displayModel.setProperty(3,"isDisplayed",items.metsAvailable)
                rightDisplay.displayModel.setProperty(4,"isDisplayed",items.distanceAvailable)
                rightDisplay.displayModel.setProperty(5,"isDisplayed",items.distanceRemainingAvailable)
            }
        }

        Component.onCompleted: rightDisplay.displayModel = options.en957Enabled ? rightModelen957Mode : rightModel

        Connections {
            target: options
            onEn957EnabledChanged: rightDisplay.displayModel = options.en957Enabled ? rightModelen957Mode : rightModel
        }
    }

    Timer {
        id: rotateDataTimer
        interval: 5000; running: true; repeat: true
        onTriggered: {
            if (!root.visible)
                return // avoid unnecessary processing
            if(rightDisplay.state == "Disabled")
                rightDisplay.rotateThruData();
            if(leftDisplay.state == "Disabled")
                leftDisplay.rotateThruData();
        }
    }


}
