// import QtQuick 2.4 // to target S60 5th Edition or Maemo 5
import QtQuick 2.4
//import SimpleViewDisplayItem 1.0
import WorkoutRunData 1.0
import TouchAppEnumerations 1.0
//import ListModel 1.0
import "string_format.js" as Format
import Components 1.0

Item {
    id: root
    width: 1000
    height: 406

    property int simpleTime: 0
    property int simpleTimeRemaining: 0
    property real simpleDistance: 0
    property real simpleDistanceRemaining: 0
    property real simpleCaloriesPerHour: 0
    property real simpleCalories: 0
    property int simpleWatts: 0
    property real simpleMETs: 0
    property int simpleLevel: 1
    property real simpleIncline: 0.0
    property real simpleSpeed: 3.5
    property int currentIndex: 1
    property int unitsSelectionPosition: 50
    property string paceSetterState: "PACESETTER"
    signal simpleLevelUpClicked
    signal simpleLevelDownClicked

    property string dataValueString: ""
    property string dataLabelString: ""

    property string dataElementBackgroundSource: "graphics/224/224_Data_Bar_4.png"
    property string toggleButtonActiveSource: "graphics/224/Toggle_On.png"
    property string toggleButtonInactiveSource: "graphics/224/Toggle_Off.png"
    property string unitSelectionBackgroundSource: "graphics/224/224_Data_Bar_Rounded_Bottom.png"

    property int rotateDataCounter: 0
    property bool _noData: false
    property bool isTreadmill: machineinfo.productTypeString == "Treadmill"

    function addElement(labelName,status) {
        simpleViewDataModel.append({"itemName":labelName,
                                   "itemEnabled":status});
        unitsSelectionPosition = (simpleViewDataModel.count * 57) + 50;
    }

    function clearList() {
        //simpleViewDataModel.clear();
        root.currentIndex = 0;
    }

    function rotateThruData() {
        var j = 0
        var nextFound = false

        for(j = 1; j <= simpleViewDataModel.count; j++)
        {
            var y = (rotateDataCounter + j) % simpleViewDataModel.count
            var item = simpleViewDataModel.get(y)
            var enabled = dataToggleModel.get(item.dataIndex).thestate

            if(item.isDisplayed && enabled == "Enabled"){
                rotateDataCounter = y;
                nextFound = true
                break;
            }
        }

        if(nextFound == false){ _noData = true;rotateDataCounter = 0;}
        else _noData = false
    }



    function getData(index)
    {
        var p = simpleViewDataModel.get(index).precision
        switch(index)
        {
        case 0: return Format.formatTimeStringMinAndSec(aWorkoutRunData.time);
        case 1: return Format.formatTimeStringMinAndSec(aWorkoutRunData.timeRemaining);
        case 2: {
            if (workoutScreen.unitState === "ENGLISH")
                return aWorkoutRunData.distance.toFixed(p)
            else
                return Globals.mileToKm(aWorkoutRunData.distance).toFixed(p)
        }
        case 3: {
            if (workoutScreen.unitState === "ENGLISH")
                return aWorkoutRunData.distanceRemaining.toFixed(p)
            else
                return Globals.mileToKm(aWorkoutRunData.distanceRemaining).toFixed(p)
        }
        case 4: return aWorkoutRunData.calsPerHour.toFixed(p);
        case 5: return aWorkoutRunData.totalCalories.toFixed(p);
        case 6: return aWorkoutRunData.watts.toFixed(p);
        case 7: return aWorkoutRunData.mets.toFixed(p);
        }
    }

    ListModel{
        id: simpleViewDataModel
        ListElement{ label: QT_TR_NOOP("TIME<br/>ELAPSED"); fieldlabel: QT_TR_NOOP("TIME ELAPSED"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_time}
        ListElement{ label: QT_TR_NOOP("TIME<br/>REMAINING"); fieldlabel: QT_TR_NOOP("TIME REMAINING"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_timeRemaining}
        ListElement{ label: QT_TR_NOOP("DISTANCE"); fieldlabel: QT_TR_NOOP("DISTANCE"); isDisplayed: false; precision: 2; dataIndex: TouchAppEnumerations.ENUM_distance}
        ListElement{ label: QT_TR_NOOP("DISTANCE<br/>REMAINING"); fieldlabel: QT_TR_NOOP("DISTANCE REMAINING"); isDisplayed: false; precision: 2; dataIndex: TouchAppEnumerations.ENUM_distanceRemaining}
        ListElement{ label: QT_TR_NOOP("CALS PER<br/>HOUR"); fieldlabel: QT_TR_NOOP("CALS PER HOUR"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_calsPerHour}
        ListElement{ label: QT_TR_NOOP("CALORIES"); fieldlabel: QT_TR_NOOP("CALORIES"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_calories}
        ListElement{ label: QT_TR_NOOP("WATTS"); fieldlabel: QT_TR_NOOP("WATTS"); isDisplayed: false; precision: 0; dataIndex: TouchAppEnumerations.ENUM_watts}
        ListElement{ label: QT_TR_NOOP("METS"); fieldlabel: QT_TR_NOOP("METS"); isDisplayed: false; precision: 1; dataIndex: TouchAppEnumerations.ENUM_mets}
    }

    Connections{
        target: workoutScreen
        onWorkoutStarted: updateAvailable()
    }

    Component.onCompleted: updateAvailable()

    Connections {
        target: options
        onEn957EnabledChanged: updateAvailable()
    }

    function updateAvailable() {
        simpleViewDataModel.setProperty(0,"isDisplayed",workoutProgram.displayDataVars.timeAvailable)
        simpleViewDataModel.setProperty(1,"isDisplayed",workoutProgram.displayDataVars.timeRemainingAvailable)
        simpleViewDataModel.setProperty(2,"isDisplayed",workoutProgram.displayDataVars.distanceAvailable)
        simpleViewDataModel.setProperty(3,"isDisplayed",workoutProgram.displayDataVars.distanceRemainingAvailable)
        simpleViewDataModel.setProperty(4,"isDisplayed",workoutProgram.displayDataVars.calsPerHourAvailable)
        simpleViewDataModel.setProperty(5,"isDisplayed",workoutProgram.displayDataVars.caloriesAvailable)
        simpleViewDataModel.setProperty(6,"isDisplayed",workoutProgram.displayDataVars.wattsAvailable)
        simpleViewDataModel.setProperty(7,"isDisplayed",workoutProgram.displayDataVars.metsAvailable)

        if(options.en957Enabled) {
            simpleViewDataModel.setProperty(6,"label",qsTr("WORK") + application.emptyString)
            simpleViewDataModel.setProperty(6,"fieldlabel",qsTr("WORK") + application.emptyString)
        } else {
            simpleViewDataModel.setProperty(6,"label",qsTr("WATTS") + application.emptyString)
            simpleViewDataModel.setProperty(6,"fieldlabel",qsTr("WATTS") + application.emptyString)
        }
    }

    Image {
        id: simpleViewBackground
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.verticalCenter: parent.verticalCenter
        source: "graphics/netpulse/DATA_simple_120612.png"
    }

    Component{
        id:_delegate
        Item{
            id: _delegateRoot

            property int shadowBorder: 21
            property int originalImageWidth: 199
            property int originalImageHeight: 99

            state: dataToggleModel.get(model.dataIndex).thestate
            width: originalImageWidth
            height: originalImageHeight-(shadowBorder*2)
            clip: false
            visible: model.isDisplayed

            Image{
                id: backgroundImage
                anchors.centerIn: parent
                x: parent.x - shadowBorder
                y: parent.y - shadowBorder
                source: dataElementBackgroundSource

            }

            Text {
                id: label
                anchors.left: _delegateRoot.left
                anchors.leftMargin: 10 + shadowBorder
                anchors.top: _delegateRoot.top;
                anchors.topMargin: 5;

                color: "black"
                font {
                    bold: true
                    pixelSize: 18
                }
                text: qsTr(model.label) + application.emptyString
            }


            Image {
                id: button

                anchors.right: _delegateRoot.right
                anchors.rightMargin: 10 + shadowBorder

                anchors.verticalCenter: label.verticalCenter
            }


            MouseArea{
                id: mouseArea
                anchors.fill: parent
                onClicked:{
                    buzzer.buttonPress()
                    if(parent.state == "Enabled") {
                        dataToggleModel.setProperty(model.dataIndex,"thestate", "Disabled")
                    }
                    else{
                        dataToggleModel.setProperty(model.dataIndex,"thestate", "Enabled")
                    }
                    rotateThruData()
                }
            }

            states: [
                State{name: "Enabled"
                    PropertyChanges { target: button; source: toggleButtonActiveSource}
                },
                State{name: "Disabled"
                    PropertyChanges { target: button; source: toggleButtonInactiveSource}
                }
            ]
        }
    }

    Text {
        id: simpleFieldLabel
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 5
        font {
            bold: true
            pixelSize: 24
        }

        color: "white"
        text: (!_noData) && root.visible ? qsTr(simpleViewDataModel.get(rotateDataCounter).fieldlabel) + application.emptyString : ""
    }

    Text {
        id: simpleField
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.top: parent.top
        anchors.topMargin: 20
        font {
            bold: true
            pixelSize: 180
        }
        color: "white"
        text: (!_noData) && root.visible ? getData(rotateDataCounter) : ""

    }

    Item {
        id: levelControls

        anchors.left: parent.left
        anchors.leftMargin: 190
        anchors.bottom: parent.bottom
        anchors.bottomMargin: -10
        width: 220
        height: 220
        visible: !isTreadmill

        function getWorkloadLabel()
        {
            if(workoutScreen.bikeModeEnabled)
                return qsTr("GEAR") + application.emptyString
            else
                return qsTr("LEVEL") + application.emptyString
        }

        function getPaceLabel()
        {
            if(workoutScreen.bikeModeEnabled)
                return qsTr("CADENCE") + application.emptyString
            else
                return qsTr("PACE") + application.emptyString
        }

        ImageButton {
            id: levelUpButton
            visible: main.isTouch
            repeat: true
            anchors.left: parent.left
            anchors.top: parent.top
            anchors.topMargin: 35
            fontsize: 12
            downimage: "graphics/Arrow_Large_Up_Button_Pressed.png"
            upimage: "graphics/Arrow_Large_Up_Button.png"
            icon: "graphics/Pace_Setter_Simple_Plus.png"
            label: qsTr("")
            onClicked: simpleLevelUpClicked()
        }

        ImageButton {
            id: levelDownButton
            visible: main.isTouch
            repeat: true
            anchors.left: parent.left
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 35
            fontsize: 12
            downimage: "graphics/Arrow_Large_Down_Button_Pressed.png"
            upimage: "graphics/Arrow_Large_Down_Button.png"
            icon: "graphics/Pace_Setter_Simple_Minus.png"
            icon_y_offset: -10
            label: qsTr("")
            onClicked: simpleLevelDownClicked()
        }

        Column {
            id: levelDataColumn
//            anchors.right: parent.right
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 80
            anchors.verticalCenter: parent.verticalCenter
            Text {
                anchors.horizontalCenter: levelDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 18
                }
                text: qsTr("WORKLOAD") + application.emptyString
            }

            Text {
                id: levelValue
                anchors.horizontalCenter: levelDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 110
                }
                text: simpleLevel
            }

            Text {
                anchors.horizontalCenter: levelDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 18
                }
                text: levelControls.getWorkloadLabel()
            }
        }
    }

    Item {
        id: paceSetter

        anchors.bottom: parent.bottom
        anchors.bottomMargin: 5
        anchors.right: parent.right
        anchors.rightMargin: 75
        width: 400
        height: 194
        state: paceSetterState
        visible: !isTreadmill
        Image {
            id: paceSetterShape
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            source: "graphics/pacesetter_shape_simple.png"
        }

        Text {
            id: rpmValue
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: -90
            anchors.top: parent.top
            anchors.topMargin: 33
            color: "white"
            font {
                bold: true
                pixelSize: 110
            }
            text: aWorkoutRunData.rpm
        }

        Text {
            id: rpmTopLabelValue
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: -90
            anchors.top: parent.top
            anchors.topMargin: 33
            color: "white"
            font {
                bold: true
                pixelSize: 18
            }
            text: qsTr("RPM") + application.emptyString
        }

//        Text {
//            id: rpmBottomLabelValue
//            anchors.horizontalCenter: parent.horizontalCenter
//            anchors.horizontalCenterOffset: -130
//            anchors.verticalCenter: parent.verticalCenter
//            anchors.verticalCenterOffset: 65
//            color: "white"
//            font {
//                bold: true
//                pixelSize: 18
//            }
//            text: qsTr("RPM") + application.emptyString
//        }

        Text {
            id: paceSetterLabel
            anchors.top: parent.top
            anchors.topMargin: 5
            anchors.left: parent.left
            anchors.leftMargin: 15
            color: "black"
            font.pointSize: 12
            font.bold: true
            text: qsTr("PACE SETTER") + application.emptyString
        }

        ImageButton {
            id: paceSetterLevelUpButton
            visible: main.isTouch
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 140
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: -52
            downimage: "graphics/Arrow_Large_Up_Button_Pressed.png"
            upimage: "graphics/Arrow_Large_Up_Button.png"
            icon: "graphics/224/Plus_Sign.png"
            onClicked: workoutManager.increasePaceLevel()
        }

        ImageButton {
            id: paceSetterLevelDownButton
            visible: main.isTouch
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 140
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 40
            downimage: "graphics/Arrow_Large_Down_Button_Pressed.png"
            upimage: "graphics/Arrow_Large_Down_Button.png"
            icon: "graphics/224/Minus_Sign.png"
            onClicked: workoutManager.decreasePaceLevel()
        }

        Text {
            // this label is for Touch only
            id: paceSetterLevelLabel
            visible: main.isTouch
            anchors.horizontalCenter: paceSetterLevelUpButton.horizontalCenter
            anchors.top: paceSetterLevelDownButton.bottom
            anchors.topMargin: -8
            color: "white"
            font.pointSize: 12
            font.bold: true
            text: qsTr("LEVEL") + application.emptyString
        }

        Text {
            id: paceSetterLevelLabelTft
            visible: main.isTft
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: 10
            anchors.right: paceSetterLevel.left
            anchors.rightMargin: 5
            color: "black"
            font.pointSize: 14
            font.bold: true
            text: qsTr("LEVEL") + application.emptyString
        }

        Text {
            id: paceSetterLevel
            anchors.horizontalCenter: paceSetterLevelUpButton.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: main.isTft ? 10 : -10
            color: "black"
            font.pointSize: main.isTft ? 20 : 18
            font.bold: true
            text: aWorkoutRunData.paceLevel
        }

        PaceSetterMeter{
            id: paceSetterMeter

            paceTarget: workoutManager.paceTarget
            rpm: aWorkoutRunData.rpm
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: -90
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 8
        }



        states: [
            State {
                name: "PACESETTER"
                PropertyChanges {target: paceSetterShape; visible: true}
                PropertyChanges {target: paceSetterLabel; visible: true}
                PropertyChanges {target: paceSetterLevelLabel; visible: main.isTouch}
                PropertyChanges {target: paceSetterLevelLabelTft; visible: main.isTft}
                PropertyChanges {target: paceSetterLevel; visible: true}
                PropertyChanges {target: paceSetterLevelUpButton; visible: main.isTouch}
                PropertyChanges {target: paceSetterLevelDownButton; visible: main.isTouch}
                PropertyChanges {target: paceSetterMeter; visible: true}
                PropertyChanges {target: paceSetter; anchors.rightMargin: 75}
            },
            State {
                name: "NOPACESETTER"
                PropertyChanges {target: paceSetterShape; visible: false}
                PropertyChanges {target: paceSetterLabel; visible: false}
                PropertyChanges {target: paceSetterLevelLabel; visible: false}
                PropertyChanges {target: paceSetterLevelLabelTft; visible: false}
                PropertyChanges {target: paceSetterLevel; visible: false}
                PropertyChanges {target: paceSetterLevelUpButton; visible: false}
                PropertyChanges {target: paceSetterLevelDownButton; visible: false}
                PropertyChanges {target: paceSetterMeter; visible: false}
                PropertyChanges {target: paceSetter; anchors.rightMargin: 75}
            }
        ]
    }

    Item {
        id: inclineControls

        anchors.left: parent.left
        anchors.leftMargin: 220
        anchors.bottom: parent.bottom
        anchors.bottomMargin: -10
        width: 220
        height: 220
        visible: isTreadmill

        Column {
            id: inclineDataColumn
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 0
            anchors.verticalCenter: parent.verticalCenter
            Text {
                anchors.horizontalCenter: inclineDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 18
                }
                text: qsTr("INCLINE") + application.emptyString
            }

            Text {
                id: inclineValue
                anchors.horizontalCenter: inclineDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 110
                }
                text: (workoutManager.treadIncline / 10.0).toFixed(1)
            }

            Text {
                anchors.horizontalCenter: inclineDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 18
                }
                text: "%"
            }
        }
    } // end inclineControls

    Item {
        id: speedControls

        anchors.bottom: parent.bottom
        anchors.bottomMargin: -10
        anchors.right: parent.right
        anchors.rightMargin: 220
        width: 220
        height: 220
        visible: isTreadmill

        Column {
            id: speedDataColumn
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.horizontalCenterOffset: 0
            anchors.verticalCenter: parent.verticalCenter
            Text {
                anchors.horizontalCenter: speedDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 18
                }
                text: qsTr("SPEED") + application.emptyString
            }

            Text {
                id: speedValue
                anchors.horizontalCenter: speedDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 110
                }
                text: {
                    var tempSpeed;
                    tempSpeed = workoutManager.treadSpeed / 10.0
                    if (workoutScreen.unitState === "ENGLISH")
                        return tempSpeed.toFixed(1)
                    else
                        return Globals.mileToKm(tempSpeed).toFixed(1)
                }
            }

            Text {
                anchors.horizontalCenter: speedDataColumn.horizontalCenter
                color: "white"
                font {
                    bold: true
                    pixelSize: 18
                }
                text: workoutScreen.unitState === "ENGLISH" ? "MPH" : "KPH"
            }
        }
    } // end speedControls

    Image {
        id: dataElementArrowBackground
        anchors.left: parent.left
        anchors.leftMargin: -5
        anchors.top: parent.top
        anchors.topMargin: 15
        source: "graphics/224/224_Data_Bar_4.png"
        width: 199
        height: 99
        visible: false
    }

    ImageButton {
        id: dataSelectionDropDownArrow
        visible: main.isTouch
        anchors.top: parent.top
        anchors.topMargin: 17
        anchors.left: parent.left
        anchors.leftMargin: 15
        upimage: "graphics/205/IPOD_Controls_Down.png"
        downimage: "graphics/205/IPOD_Controls_Down.png"
        mouseAreaScale: 1.5
        transform:
        Rotation{
            origin.x: 22
            origin.y: 15
            angle: dropdownDisplay.state == "showing" ? 180 : 0

            Behavior on angle {PropertyAnimation{}}
        }

        onClicked: {
            if(dropdownDisplay.state == "showing") dropdownDisplay.state = "notshowing"
            else dropdownDisplay.state = "showing"
        }
    }

    Column{
        id: dropdownDisplay
        anchors.top: parent.top
        anchors.topMargin: 0

        anchors.left: dataSelectionDropDownArrow.right
        anchors.leftMargin: -10

        visible: true
        opacity: 1.0

        state: "notshowing"

        Repeater{
            id: testRepeater
            model: simpleViewDataModel
            delegate: _delegate
        }

        Item{
            id: unitDisplay
            property int shadowBorder: 21
            property int originalImageWidth: 199
            property int originalImageHeight: 92
            state: workoutScreen.unitState
            visible: isTreadmill // bug 264 - hide temporarily for non-tread

            width: originalImageWidth
            height: originalImageHeight-(shadowBorder)
            clip: false

            Image{
                id: backgroundImage
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                x: parent.x - unitDisplay.shadowBorder
                y: parent.y - unitDisplay.shadowBorder
                source: unitSelectionBackgroundSource

            }

            Text {
                id: kilometersLabel
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: -50
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -10
                color: "black"
                font.pointSize: 11
                font.bold: true
                text: qsTr("KM") + application.emptyString
            }

            Text {
                id: milesLabel
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: 50
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -10
                color: "black"
                font.pointSize: 11
                font.bold: true
                text: qsTr("MI") + application.emptyString
            }

            Image {
                id: unitSelectionButton
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.horizontalCenterOffset: 0
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: -10
                source: toggleButtonActiveSource
            }

            MouseArea{
                id: unitSelectionMouseArea
                anchors.fill: parent
                onClicked:{
                    buzzer.buttonPress()
                    if(workoutScreen.unitState == "ENGLISH") workoutScreen.unitState = "METRIC"
                    else workoutScreen.unitState = "ENGLISH"
                }
            }

            states: [
                State {
                    name: "ENGLISH";
                    PropertyChanges { target: unitSelectionButton; source: toggleButtonActiveSource}
                },
                State {
                    name: "METRIC";
                    PropertyChanges { target: unitSelectionButton; source: toggleButtonInactiveSource}
                }
            ]
        }

        states: [
            State {
                name: "showing"
                PropertyChanges { target:dropdownDisplay; anchors.topMargin: 0}
            },
                State {
                    name: "notshowing"
                    PropertyChanges { target:dropdownDisplay; anchors.topMargin: -500}
                }

        ]

        transitions: [
            Transition {
                from: "notshowing"
                to: "showing"
                reversible: true
                SequentialAnimation {
                    NumberAnimation { duration: 500; properties: "anchors.topMargin";easing.type:Easing.OutBack }
                }
            }
        ]
    }

    Item {
        id: unitSelection
        anchors.top: parent.top
        anchors.topMargin: unitsSelectionPosition
        anchors.left: parent.left
        anchors.leftMargin: -5
        visible: false

        Image {
            id: unitSelectionBackground
            source: "graphics/224/224_Data_Bar_Rounded_Bottom.png"
        }

        Text {
            id: simpleKilometersLabel
            anchors.left: unitSelectionBackground.left
            anchors.leftMargin: 30
            y: 34
            color: "black"
            font.pointSize: 11
            font.bold: true
            text: qsTr("KM") + application.emptyString
        }

        Text {
            id: simpleMilesLabel
            anchors.right: unitSelectionBackground.right
            anchors.rightMargin: 70
            y: 34
            color: "black"
            font.pointSize: 11
            font.bold: true
            text: qsTr("MI") + application.emptyString
        }

        Image {
            id: simpleUnitSelectionButton
            anchors.left: unitSelectionBackground.left
            anchors.leftMargin: 62
            y: 36
            source: "graphics/224/Toggle_On.png"
            state: "ENGLISH"

            states: [
                State {
                    name: "ENGLISH";
                    PropertyChanges {
                        target: unitSelectionButton
                        source: "graphics/224/Toggle_On.png"
                    }
                },
                State {
                    name: "METRIC";
                    PropertyChanges {
                        target: unitSelectionButton
                        source: "graphics/224/Toggle_Off.png"
                    }
                }
            ]

            MouseArea {
                anchors.fill: parent
                onPressed: {
                    if (unitSelectionButton.state == "ENGLISH") unitSelectionButton.state = "METRIC";
                    else unitSelectionButton.state = "ENGLISH";
                }
            }
        }
    }

    Timer {
        id: rotateSimpleDataTimer
        interval: 5000; running: true; repeat: true
        onTriggered: {
            if (!root.visible)
                return // avoid unnecessary processing
            rotateThruData();
        }
    }

    Connections{
        target:aWorkoutRunData
    }
}
