import QtQuick 2.4
import Process 0.1

Item {
    id: root

    property string scanType: "analog"
    property int scanFreq: 0
    property bool scanning: false
    property int signalsFound: 0
    property int scanChannel:0
    property real progress:0
    property int device: 0
    property string norm: "NTSC-M"
    property alias channels: scanServices
    property string program: "scantv"
    property int mode: Process.MergedChannels
    property bool useMock: false

    signal scanComplete()
    signal channelFound(variant chandata)

    ListModel {
        id: scanServices
    }

    function startScan(countryCode, isCable, norm) {
        root.scanning = true
        root.scanFreq = 0
        root.signalsFound = 0
        root.progress = 0

        scanServices.clear()
        root.norm = norm
        var args = buildArgs(countryCode, isCable, norm)

        analogScanner.arguments = args
        print("analog scanner arguments:" + args)

        analogScanner.start()
    }

    function stopScan(){
        analogScanner.terminate()
        root.scanning = false
    }

    function buildArgs(countryCode, isCable, norm) {
        if (root.useMock) {
//            if (isCable)
//                return ["scripts/scan_mock/scan_mock.sh", "ATSC_US_digital_cable"]
//            else
            return ["scripts/scan_mock/scan_mock.sh", "ntsc_us_analog_antenna.outp"]
        }

        var args = ["-C", "/dev/vbi"+root.device,
                    "-c", "/dev/video"+root.device]
        var scanParams = tv_country_codes.getCountry(countryCode)

        if(!scanParams) {
            print("TVScan: No scan data for country code " + countryCode)
            return
        }

        args = args.concat(["-n", norm])

        if(isCable)
            args = args.concat(["-f", scanParams.actable])
        else
            args = args.concat(["-f", scanParams.attable])

        return args;
    }

    Process {
        id: analogScanner

        program: root.useMock ? "bash" : root.program
        channelMode: Process.MergedChannels

        onFinished: {
            root.scanning = false
            root.scanComplete()
            print("scan complete.")

            for(var i=0 ; i < scanServices.count ; i++) {
                var item = scanServices.get(i)
                print("name:" + item.name + " number:" +item.number + " freq:"+ item.freq)
            }
        }

        onReadyReadStandardOutput: {
            var output = String(readAllStandardOutput())
            output = output.trim()
            //print( "scan output: " + output)
            var lines = output.split("\n")
            var service_name="unknown"
            for(var i=0 ; i < lines.length ; i++) {
                var line = lines[i]

                //read the  freqeuncy
                if( line.match("MHz")) { // found line e.g: "3   ( 61.25 MHz ):"
                    var f = line.substring(line.indexOf("(")+1, line.indexOf(")"))
                    f = f.trim().split(" ")[0]
                    root.scanFreq = parseFloat(f)*1000
                    root.progress = root.scanFreq / 885000;
                }
                //See if the name is availible
                if(line.indexOf("[")==0){
                    service_name=line.substring(line.indexOf("[")+1,line.indexOf("]"))
                }

                //Read the channel number and save
                if(line.match("channel =")) {
                    root.scanChannel = line.split("= ")[1]
                    root.signalsFound++
                    if (service_name.match("unknown")){
                        print("adding channel:" + root.scanChannel + " name:" +root.scanChannel+ "    freq:" + root.scanFreq)
                        scanServices.append({number:""+root.scanChannel, name: ""+root.scanChannel, freq:""+root.scanFreq, analog: true, input:0, norm: root.norm})
                    }
                    else
                    {
                        print("adding channel:" + root.scanChannel + " name:" +service_name+ " freq:" + root.scanFreq)
                        scanServices.append({number:""+root.scanChannel, name:service_name, freq:""+root.scanFreq, analog: true, input:0, norm: root.norm})
                    }

                    root.channelFound(scanServices.get(scanServices.count - 1))
                }
            }
        }
    } // end Process
}
