import QtQuick 2.4
import Components 1.0
import DateTimeUtil 1.0

Item {
    id: root

    property alias selectedItem: carousel.selectedData
    property bool listenKeys: false

    Component.onCompleted: {
        fetchTimezone()
    }

    Connections {
        target: main.isTft && root.listenKeys ? keymapper : null

        onUpButtonPressed: {
            main.debugKeys("upButtonPressed", "TimezoneSelection")
            carousel.decrementCurrentIndex()
        }

        onDownButtonPressed: {
            main.debugKeys("downButtonPressed", "TimezoneSelection")
            carousel.incrementCurrentIndex()
        }
    }

    DateTimeUtil {
        id: dateTimeUtil
    }

    function fetchTimezone() {
        var index = -1
        var systemTimezone = dateTimeUtil.getSystemTimezone()
        for (var i = 0; i < tzModel.count; i++) {
            if (tzModel.get(i).LinuxID === systemTimezone) {
                index = i
                break
            }
        }

        if (index > 0) {
            carousel.currentIndex = index
        }
    }

    ListModel {
        id: tzModel

        ListElement { LinuxID: "Pacific/Honolulu"; UTCOffset: -10; WindowsID: "Hawaiian Standard Time"; label: "(UTC-10:00) Hawaii" }
        ListElement { LinuxID: "America/Anchorage"; UTCOffset: -9; WindowsID: "Alaskan Standard Time"; label: "(UTC-09:00) Alaska" }
        ListElement { LinuxID: "America/Los_Angeles"; UTCOffset: -8; WindowsID: "Pacific Standard Time"; label: "(UTC-08:00) Pacific Time (US & Canada)" }
        ListElement { LinuxID: "America/Tijuana"; UTCOffset: -8; WindowsID: "Pacific Standard Time (Mexico)"; label: "(UTC-08:00) Baja California" }
        ListElement { LinuxID: "America/Chihuahua"; UTCOffset: -7; WindowsID: "Mountain Standard Time (Mexico)"; label: "(UTC-07:00) Chihuahua, La Paz, Mazatlan" }
        ListElement { LinuxID: "America/Denver"; UTCOffset: -7; WindowsID: "Mountain Standard Time"; label: "(UTC-07:00) Mountain Time (US & Canada)" }
        ListElement { LinuxID: "America/Phoenix"; UTCOffset: -7; WindowsID: "US Mountain Standard Time"; label: "(UTC-07:00) Arizona" }
        ListElement { LinuxID: "America/Chicago"; UTCOffset: -6; WindowsID: "Central Standard Time"; label: "(UTC-06:00) Central Time (US & Canada)" }
        ListElement { LinuxID: "America/Costa_Rica"; UTCOffset: -6; WindowsID: "Central America Standard Time"; label: "(UTC-06:00) Central America" }
        ListElement { LinuxID: "America/Mexico_City"; UTCOffset: -6; WindowsID: "Central Standard Time (Mexico)"; label: "(UTC-06:00) Guadalajara, Mexico City, Monterrey" }
        ListElement { LinuxID: "America/Havana"; UTCOffset: -5; WindowsID: "SA Pacific Standard Time"; label: "(UTC-05:00) Bogota, Lima, Quito" }
        ListElement { LinuxID: "America/New_York"; UTCOffset: -5; WindowsID: "Eastern Standard Time"; label: "(UTC-05:00) Eastern Time (US & Canada)" }
        ListElement { LinuxID: "America/Caracas"; UTCOffset: -4.5; WindowsID: "Venezuela Standard Time"; label: "(UTC-04:30) Caracas" }
        ListElement { LinuxID: "America/Anguilla"; UTCOffset: -4; WindowsID: "Pacific SA Standard Time"; label: "(UTC-04:00) Santiago" }
        ListElement { LinuxID: "America/Antigua"; UTCOffset: -4; WindowsID: "Atlantic Standard Time"; label: "(UTC-04:00) Atlantic Time (Canada)" }
        ListElement { LinuxID: "America/Asuncion"; UTCOffset: -4; WindowsID: "Paraguay Standard Time"; label: "(UTC-04:00) Asuncion" }
        ListElement { LinuxID: "America/Cuiaba"; UTCOffset: -4; WindowsID: "Central Brazilian Standard Time"; label: "(UTC-04:00) Cuiaba" }
        ListElement { LinuxID: "America/La_Paz"; UTCOffset: -4; WindowsID: "SA Western Standard Time"; label: "(UTC-04:00) Georgetown, La Paz, Manaus, San Juan" }
        ListElement { LinuxID: "America/St_Johns"; UTCOffset: -3.5; WindowsID: "Newfoundland Standard Time"; label: "(UTC-03:30) Newfoundland" }
        ListElement { LinuxID: "America/Araguaina"; UTCOffset: -3; WindowsID: "E. South America Standard Time"; label: "(UTC-03:00) Brasilia" }
        ListElement { LinuxID: "America/Argentina/Buenos_Aires"; UTCOffset: -3; WindowsID: "Argentina Standard Time"; label: "(UTC-03:00) Buenos Aires" }
        ListElement { LinuxID: "America/Cayenne"; UTCOffset: -3; WindowsID: "SA Eastern Standard Time"; label: "(UTC-03:00) Cayenne, Fortaleza" }
        ListElement { LinuxID: "America/Godthab"; UTCOffset: -3; WindowsID: "Greenland Standard Time"; label: "(UTC-03:00) Greenland" }
        ListElement { LinuxID: "America/Montevideo"; UTCOffset: -3; WindowsID: "Montevideo Standard Time"; label: "(UTC-03:00) Montevideo" }
        ListElement { LinuxID: "America/Noronha"; UTCOffset: -2; WindowsID: "Mid-Atlantic Standard Time"; label: "(UTC-02:00) Mid-Atlantic" }
        ListElement { LinuxID: "America/Scoresbysund"; UTCOffset: -1; WindowsID: "Azores Standard Time"; label: "(UTC-01:00) Azores" }
        ListElement { LinuxID: "Atlantic/Cape_Verde"; UTCOffset: -1; WindowsID: "Cape Verde Standard Time"; label: "(UTC-01:00) Cape Verde Is." }
        ListElement { LinuxID: "Africa/Casablanca"; UTCOffset: 0; WindowsID: "Morocco Standard Time"; label: "(UTC) Casablanca" }
        ListElement { LinuxID: "Atlantic/Reykjavik"; UTCOffset: 0; WindowsID: "Greenwich Standard Time"; label: "(UTC) Monrovia, Reykjavik" }
        ListElement { LinuxID: "GMT"; UTCOffset: 0; WindowsID: "GMT Standard Time"; label: "(UTC) Dublin, Edinburgh, Lisbon, London" }
        ListElement { LinuxID: "UTC"; UTCOffset: 0; WindowsID: "UTC"; label: "(UTC) Coordinated Universal Time" }
        ListElement { LinuxID: "Africa/Algiers"; UTCOffset: 1; WindowsID: "W. Central Africa Standard Time"; label: "(UTC+01:00) West Central Africa" }
        ListElement { LinuxID: "Africa/Windhoek"; UTCOffset: 1; WindowsID: "Namibia Standard Time"; label: "(UTC+01:00) Windhoek" }
        ListElement { LinuxID: "Europe/Amsterdam"; UTCOffset: 1; WindowsID: "W. Europe Standard Time"; label: "(UTC+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Vienna" }
        ListElement { LinuxID: "Europe/Belgrade"; UTCOffset: 1; WindowsID: "Central Europe Standard Time"; label: "(UTC+01:00) Belgrade, Bratislava, Budapest, Ljubljana, Prague" }
        ListElement { LinuxID: "Europe/Brussels"; UTCOffset: 1; WindowsID: "Romance Standard Time"; label: "(UTC+01:00) Brussels, Copenhagen, Madrid, Paris" }
        ListElement { LinuxID: "Europe/Skopje"; UTCOffset: 1; WindowsID: "Central Europe Standard Time"; label: "(UTC+01:00) Sarajevo, Skopje, Warsaw, Zagreb" }
        ListElement { LinuxID: "Africa/Blantyre"; UTCOffset: 2; WindowsID: "South Africa Standard Time"; label: "(UTC+02:00) Harare, Pretoria" }
        ListElement { LinuxID: "Africa/Cairo"; UTCOffset: 2; WindowsID: "Egypt Standard Time"; label: "(UTC+02:00) Cairo" }
        ListElement { LinuxID: "Africa/Tripoli"; UTCOffset: 2; WindowsID: "Middle East Standard Time"; label: "(UTC+02:00) Beirut" }
        ListElement { LinuxID: "Asia/Amman"; UTCOffset: 2; WindowsID: "Jordan Standard Time"; label: "(UTC+02:00) Amman" }
        ListElement { LinuxID: "Asia/Damascus"; UTCOffset: 2; WindowsID: "Syria Standard Time"; label: "(UTC+02:00) Damascus" }
        ListElement { LinuxID: "Asia/Jerusalem"; UTCOffset: 2; WindowsID: "Israel Standard Time"; label: "(UTC+02:00) Jerusalem" }
        ListElement { LinuxID: "Europe/Athens"; UTCOffset: 2; WindowsID: "GTB Standard Time"; label: "(UTC+02:00) Athens, Bucharest" }
        ListElement { LinuxID: "Europe/Chisinau"; UTCOffset: 2; WindowsID: "E. Europe Standard Time"; label: "(UTC+02:00) Minsk" }
        ListElement { LinuxID: "Europe/Istanbul"; UTCOffset: 2; WindowsID: "Turkey Standard Time"; label: "(UTC+02:00) Istanbul" }
        ListElement { LinuxID: "Europe/Riga"; UTCOffset: 2; WindowsID: "FLE Standard Time"; label: "(UTC+02:00) Helsinki, Kyiv, Riga, Sofia, Tallinn, Vilnius" }
        ListElement { LinuxID: "Africa/Addis_Ababa"; UTCOffset: 3; WindowsID: "E. Africa Standard Time"; label: "(UTC+03:00) Nairobi" }
        ListElement { LinuxID: "Asia/Baghdad"; UTCOffset: 3; WindowsID: "Arabic Standard Time"; label: "(UTC+03:00) Baghdad" }
        ListElement { LinuxID: "Asia/Kuwait"; UTCOffset: 3; WindowsID: "Arab Standard Time"; label: "(UTC+03:00) Kuwait, Riyadh" }
        ListElement { LinuxID: "Europe/Kaliningrad"; UTCOffset: 3; WindowsID: "Kaliningrad Standard Time"; label: "(UTC+03:00) Kaliningrad" }
        ListElement { LinuxID: "Asia/Tehran"; UTCOffset: 3.5; WindowsID: "Iran Standard Time"; label: "(UTC+03:30) Tehran" }
        ListElement { LinuxID: "Asia/Baku"; UTCOffset: 4; WindowsID: "Caucasus Standard Time"; label: "(UTC+04:00) Yerevan" }
        ListElement { LinuxID: "Asia/Dubai"; UTCOffset: 4; WindowsID: "Arabian Standard Time"; label: "(UTC+04:00) Abu Dhabi, Muscat" }
        ListElement { LinuxID: "Asia/Tbilisi"; UTCOffset: 4; WindowsID: "Georgian Standard Time"; label: "(UTC+04:00) Tbilisi" }
        ListElement { LinuxID: "Europe/Moscow"; UTCOffset: 4; WindowsID: "Russian Standard Time"; label: "(UTC+04:00) Moscow, St. Petersburg, Volgograd" }
        ListElement { LinuxID: "Indian/Reunion"; UTCOffset: 4; WindowsID: "Mauritius Standard Time"; label: "(UTC+04:00) Port Louis" }
        ListElement { LinuxID: "Asia/Kabul"; UTCOffset: 4.5; WindowsID: "Afghanistan Standard Time"; label: "(UTC+04:30) Kabul" }
        ListElement { LinuxID: "Asia/Aqtau"; UTCOffset: 5; WindowsID: "West Asia Standard Time"; label: "(UTC+05:00) Tashkent" }
        ListElement { LinuxID: "Asia/Karachi"; UTCOffset: 5; WindowsID: "Pakistan Standard Time"; label: "(UTC+05:00) Islamabad, Karachi" }
        ListElement { LinuxID: "Asia/Colombo"; UTCOffset: 5.5; WindowsID: "Sri Lanka Standard Time"; label: "(UTC+05:30) Sri Jayawardenepura" }
        ListElement { LinuxID: "Asia/Kolkata"; UTCOffset: 5.5; WindowsID: "India Standard Time"; label: "(UTC+05:30) Chennai, Kolkata, Mumbai, New Delhi" }
        ListElement { LinuxID: "Asia/Kathmandu"; UTCOffset: 5.75; WindowsID: "Nepal Standard Time"; label: "(UTC+05:45) Kathmandu" }
        ListElement { LinuxID: "Antarctica/Mawson"; UTCOffset: 6; WindowsID: "Central Asia Standard Time"; label: "(UTC+06:00) Astana" }
        ListElement { LinuxID: "Asia/Dhaka"; UTCOffset: 6; WindowsID: "Bangladesh Standard Time"; label: "(UTC+06:00) Dhaka" }
        ListElement { LinuxID: "Asia/Yekaterinburg"; UTCOffset: 6; WindowsID: "Ekaterinburg Standard Time"; label: "(UTC+06:00) Ekaterinburg" }
        ListElement { LinuxID: "Asia/Rangoon"; UTCOffset: 6.5; WindowsID: "Myanmar Standard Time"; label: "(UTC+06:30) Yangon (Rangoon)" }
        ListElement { LinuxID: "Antarctica/Davis"; UTCOffset: 7; WindowsID: "SE Asia Standard Time"; label: "(UTC+07:00) Bangkok, Hanoi, Jakarta" }
        ListElement { LinuxID: "Asia/Hovd"; UTCOffset: 7; WindowsID: "N. Central Asia Standard Time"; label: "(UTC+07:00) Novosibirsk" }
        ListElement { LinuxID: "Asia/Hong_Kong"; UTCOffset: 8; WindowsID: "China Standard Time"; label: "(UTC+08:00) Beijing, Chongqing, Hong Kong, Urumqi" }
        ListElement { LinuxID: "Asia/Kashgar"; UTCOffset: 8; WindowsID: "North Asia Standard Time"; label: "(UTC+08:00) Krasnoyarsk" }
        ListElement { LinuxID: "Asia/Singapore"; UTCOffset: 8; WindowsID: "Singapore Standard Time"; label: "(UTC+08:00) Kuala Lumpur, Singapore" }
        ListElement { LinuxID: "Asia/Taipei"; UTCOffset: 8; WindowsID: "Taipei Standard Time"; label: "(UTC+08:00) Taipei" }
        ListElement { LinuxID: "Asia/Ulaanbaatar"; UTCOffset: 8; WindowsID: "Ulaanbaatar Standard Time"; label: "(UTC+08:00) Ulaanbaatar" }
        ListElement { LinuxID: "Australia/Eucla"; UTCOffset: 8.75; WindowsID: "W. Australia Standard Time"; label: "(UTC+08:00) Perth" }
        ListElement { LinuxID: "Asia/Irkutsk"; UTCOffset: 9; WindowsID: "North Asia East Standard Time"; label: "(UTC+09:00) Irkutsk" }
        ListElement { LinuxID: "Asia/Seoul"; UTCOffset: 9; WindowsID: "Korea Standard Time"; label: "(UTC+09:00) Seoul" }
        ListElement { LinuxID: "Asia/Tokyo"; UTCOffset: 9; WindowsID: "Tokyo Standard Time"; label: "(UTC+09:00) Osaka, Sapporo, Tokyo" }
        ListElement { LinuxID: "Australia/Adelaide"; UTCOffset: 9.5; WindowsID: "Cen. Australia Standard Time"; label: "(UTC+09:30) Adelaide" }
        ListElement { LinuxID: "Australia/Broken_Hill"; UTCOffset: 9.5; WindowsID: "AUS Central Standard Time"; label: "(UTC+09:30) Darwin" }
        ListElement { LinuxID: "Asia/Yakutsk"; UTCOffset: 10; WindowsID: "Yakutsk Standard Time"; label: "(UTC+10:00) Yakutsk" }
        ListElement { LinuxID: "Australia/Brisbane"; UTCOffset: 10; WindowsID: "E. Australia Standard Time"; label: "(UTC+10:00) Brisbane" }
        ListElement { LinuxID: "Australia/Hobart"; UTCOffset: 10; WindowsID: "Tasmania Standard Time"; label: "(UTC+10:00) Hobart" }
        ListElement { LinuxID: "Australia/Melbourne"; UTCOffset: 10; WindowsID: "AUS Eastern Standard Time"; label: "(UTC+10:00) Canberra, Melbourne, Sydney" }
        ListElement { LinuxID: "Pacific/Guam"; UTCOffset: 10; WindowsID: "West Pacific Standard Time"; label: "(UTC+10:00) Guam, Port Moresby" }
        ListElement { LinuxID: "Asia/Sakhalin"; UTCOffset: 11; WindowsID: "Vladivostok Standard Time"; label: "(UTC+11:00) Vladivostok" }
        ListElement { LinuxID: "Pacific/Efate"; UTCOffset: 11; WindowsID: "Central Pacific Standard Time"; label: "(UTC+11:00) Solomon Is., New Caledonia" }
        ListElement { LinuxID: "Antarctica/South_Pole"; UTCOffset: 12; WindowsID: "UTC+12"; label: "(UTC+12:00) Coordinated Universal Time+12" }
        ListElement { LinuxID: "Asia/Anadyr"; UTCOffset: 12; WindowsID: "Magadan Standard Time"; label: "(UTC+12:00) Magadan" }
        ListElement { LinuxID: "Pacific/Auckland"; UTCOffset: 12; WindowsID: "New Zealand Standard Time"; label: "(UTC+12:00) Auckland, Wellington" }
        ListElement { LinuxID: "Pacific/Fiji"; UTCOffset: 12; WindowsID: "Fiji Standard Time"; label: "(UTC+12:00) Fiji" }
        ListElement { LinuxID: "Pacific/Chatham"; UTCOffset: 12.75; WindowsID: "Tonga Standard Time"; label: "(UTC+13:00) Nuku'alofa" }
    }

    SelectList {
        id: carousel

        model: tzModel
        onCurrentIndexChanged: menu_slider.value = currentIndex
        width: 350
        anchors {   top: parent.top ; topMargin: 60 ;
                    bottom: parent.bottom ; bottomMargin: 100;
                    right: parent.right ; rightMargin: 50
        }
    }

    SliderControl {
        id: menu_slider

        orientation: Qt.Vertical
        anchors { top: carousel.top ; bottom: carousel.bottom ; right: carousel.left ; rightMargin: 50 }
        trackImage: "graphics/200/Blue_Slider.png"
        thumbImage: "graphics/205/Arrows_Scrolling_Menu.png"
        thumbMouseAreaScale: 1.8
        maxValue: tzModel.count-1
        minValue: 0
        showButtons: false
        showValue: false
        onValueChanged: {
            carousel.currentIndex = value
        }
        showSelectionCursor: main.isTft && root.listenKeys
    }

}
