import QtQuick 2.4
import Components 1.0

Item {
    id: root
    property int xOffset: 240
    property int yOffset: 225

    onVisibleChanged: {
        if (visible) {
            tvRecordingPopup.show()
        } else {
            tvRecordingPopup.hide()
        }
    }

    Timer {
        id: countTimer
        property int seconds: 0
        running: tvRecordingManager.recording
        repeat: true
        onTriggered: {
            countTimer.seconds++
        }

        onRunningChanged: {
            countTimer.seconds = 0
        }
    }

    ModalDialog{
        id: tvRecordingPopup
        blockKeys: true

        property string message

        onTimedOut: hide()  // hide the pop-up when timer expires
        visible: false

        BorderImage {   // pop-up dialog background
            id: border

            x: root.xOffset
            y: root.yOffset
            width: 800
            height: 350
            source: "graphics/Pop_Up_Lrg_Grey.png"
            border { top: 152; bottom: 165; left: 145; right: 144 }

            Image {
                id: recordIcon
                source: "graphics/record_dot.png"
                anchors.left: parent.left
                anchors.top: parent.top
                anchors.margins: 20
                visible: tvRecordingManager.recording
            }

            Text {
                id: recordText
                visible: tvRecordingManager.recording
                font.bold: true
                font.pixelSize: 24
                color: "#ffffff"
                anchors.verticalCenter: recordIcon.verticalCenter
                anchors.left: recordIcon.right
                text: qsTr("Recording TV") + "... " + Globals.secondsToTime(countTimer.seconds) + application.emptyString

            }

            Text {
                id: copyText
                visible: tvRecordingManager.copying
                anchors.fill: parent
                anchors.margins: 30
                anchors.verticalCenter: parent.verticalCenter
                color: "#ffffff"
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                verticalAlignment: Text.AlignVCenter
                wrapMode: Text.WordWrap
                font.bold: true
                font.pixelSize: 50
                text: qsTr("Copying file to USB key...") + application.emptyString
            }

            MouseArea{
                anchors.fill: parent
                onClicked: if(tvRecordingPopup.dismissable) root.dismissed()
            }

        }
    }
}
