// Code common to SetupParams and KeyedSetupParams

function setParameter(type, value) {
    if(!root.model)
        return
    var obj = root.model.find("fieldType", type)
    if(obj) {
        mainProgItem.valueEntered = true
        if(value > obj.maxValue)
            obj.dataValue = obj.maxValue
        else if(value < obj.minValue)
            obj.dataValue = obj.minValue
        else
            obj.dataValue = value
        mainProgItem.valueEntered = false
    }
}

function getParameter(type) {
    if(!root.model)
        return
    var obj = root.model.find("fieldType", type)
    if(obj)
        return obj.dataValue
    else
        return undefined
}

function maxTreadCalories( speed, incline, weight, time) {
    var calsPerHr = workoutManager.treadmillCalsPerHour(speed, incline, weight)
    return time * calsPerHr / 60.0
}

function validateTreadCalorieGoal() {
    var speed = getParameter(WorkoutProgram.MAX_SPEED_TYPE)
    var inclineIndex = getParameter(WorkoutProgram.MAX_INCLINE_TYPE)
    var incline = (workoutProgram.inclineTable[inclineIndex]/10).toFixed(1)
    var weight = getParameter(WorkoutProgram.WEIGHT_TYPE)
    if (root.model.find("fieldType", WorkoutProgram.WEIGHT_TYPE).units === "KG") {
        weight = Math.round(Globals.kgToPound(weight))
    }
    var time = getParameter(WorkoutProgram.TIME_TYPE)
    var maxCal = maxTreadCalories(speed, incline, weight, time)
    var calgoal = getParameter(WorkoutProgram.CALORIES_TYPE)
    setParameter(WorkoutProgram.CALORIE_POTENTIAL_TYPE, maxCal.toFixed(0))

    if(calgoal > maxCal) {
        setParameter(WorkoutProgram.CALORIES_TYPE, maxCal.toFixed(0))
    }
}

function validateNonTreadCalorieGoal() {
    // when weight, time, or calories change, recalculate max and show warning if needed
    var weight = getParameter(WorkoutProgram.WEIGHT_TYPE)
    root.maxCalPerHr = workoutManager.bikeEllipticalMaxCalsPerHour(weight)
    var calsperhr = Math.floor(calItem.dataValue / (timeItem.dataValue / 60))
    console.log("max cals per hr is", root.maxCalPerHr, "user cals per hour is", calsperhr)
    if (calsperhr > root.maxCalPerHr) {
        calWarning.visible = true
    } else {
        calWarning.visible = false
    }
}

function isSpeedType(fieldType) {
    switch (fieldType) {
    case WorkoutProgram.SPEED_TYPE:
    case WorkoutProgram.MAX_SPEED_TYPE:
    case WorkoutProgram.WALK_SPEED_TYPE:
    case WorkoutProgram.RUN_SPEED_TYPE:
    case WorkoutProgram.WORK_SPEED_TYPE:
    case WorkoutProgram.REST_SPEED_TYPE:
        return true
    default:
        return false
    }
}

function isStrideType(fieldType) {
    return fieldType === WorkoutProgram.MIN_STRIDE_TYPE || fieldType === WorkoutProgram.MAX_STRIDE_TYPE
}

function modelPostProcessing()
{

    calWarning.visible = false

    // get references to the time and distance model items for making the time/dist mutex for manual workout
    timeItem = root.model.find("fieldType", WorkoutProgram.TIME_TYPE)
    if (timeItem) {
        root.model.setProperty(timeItem.fieldIndex - 1, "maxValue", options.workoutTimeMax)
        if (timeItem.dataValue > 0)
            setParameter(WorkoutProgram.TIME_TYPE, timeItem.dataValue) // re-set value in case it is now over max
    }

    distItem = root.model.find("fieldType", WorkoutProgram.DISTANCE_TYPE)
    if(!distItem) {
        distItem = root.model.find("fieldType", WorkoutProgram.DISTANCE_QUICK_TYPE)
        if (!distItem) {
            distItem = root.model.find("fieldType", WorkoutProgram.FIXED_DISTANCE_TYPE)
            if (distItem) {
                console.log("Fixed Dist Item!")
            }
        }
    }

    if(isTreadmill)
        calItem = root.model.find("fieldType", WorkoutProgram.CALORIE_POTENTIAL_TYPE)
    else
        calItem = root.model.find("fieldType", WorkoutProgram.CALORIES_TYPE)


    if(isTreadmill && calItem) {
        validateTreadCalorieGoal()
    }
    if (!isTreadmill && calItem) {
        validateNonTreadCalorieGoal()
    }

    root.timeGoal = false
    root.distGoal = false
    if(timeItem && timeItem.dataValue > 0)
        root.timeGoal = true
    else if(distItem)
        root.distGoal = true

    for(var i = 0; i < myListView.model.count; i++)
    {
        var item = myListView.model.get(i)

        switch(item.fieldType)
        {
        case WorkoutProgram.WORK_HEARTRATE_TYPE:
        case WorkoutProgram.REST_HEARTRATE_TYPE:
        case WorkoutProgram.TARGET_HEARTRATE_TYPE:
            mainProgItem.targetHRType = targetHRTypeEnum.target; // Target
            calculateHRPercentage();
            break;

        case WorkoutProgram.TARGET_HEARTRATEREADONLY_TYPE:
            mainProgItem.targetHRType = targetHRTypeEnum.aerobic; // Aerobic
            calculateHRFromAge();
            break;
        case WorkoutProgram.SEGMENT_TYPE:
            mainProgItem.numSegs = item.dataValue;
            break;
        case WorkoutProgram.TIME_TYPE:
            mainProgItem.workTime = item.dataValue;
            break;
        case WorkoutProgram.DISTANCE_TYPE:
            break;
        case WorkoutProgram.PACE_TYPE:
            mainProgItem.paceLevelForCustom = item.dataValue;
            break;
        case WorkoutProgram.WORKLOAD_TYPE:
            mainProgItem.workloadLevelForCustom = item.dataValue;
            break;
        case WorkoutProgram.AGE_TYPE:
            mainProgItem.ageForProgSummary = item.dataValue;
            break;
        case WorkoutProgram.WEIGHT_TYPE:
            mainProgItem.weightForProgSummary = item.dataValue;
            break;
        }
    }
    dataItemChanged()

    if (isTft)
        myListView.currentIndex = 1 // skip "BACK" button
    else
        myListView.currentIndex = 0

    if (isTouch) {
        var item = myListView.model.get(selectedIndex)
        keypad.clear()
        keypad.length = getMaxDigit(item.maxValue)
        console.debug("index changed to ", selectedIndex, ". Max Value is ", item.maxValue, ". Length is ", keypad.length)
    }
}

function validateParam(i) {
    var item = myListView.model.get(i)
    var correctionsMade = 0
    var newValue = item.dataValue

    // skip ignored values in mutual exclusive goal setting (manual workout time vs. distance)
    if(root.timeGoal && item.fieldType === WorkoutProgram.DISTANCE_TYPE)
        return 0
    if(root.distGoal && item.fieldType === WorkoutProgram.TIME_TYPE)
        return 0

    if (item.dataValue > item.maxValue) {
        newValue = item.maxValue
        // Change invalid speed entries of any type to minimum speed
        if(item.fieldType == WorkoutProgram.SPEED_TYPE || item.fieldType == WorkoutProgram.MAX_SPEED_TYPE ||
                item.fieldType == WorkoutProgram.WORK_SPEED_TYPE || item.fieldType == WorkoutProgram.REST_SPEED_TYPE ||
                item.fieldType == WorkoutProgram.RUN_SPEED_TYPE  || item.fieldType == WorkoutProgram.WALK_SPEED_TYPE){
            newValue = item.minValue
        }
        // Change invalid incline entries to zero grade
        else if(item.units === "%"){
            newValue = 0
        }
    }
    else if (item.dataValue < item.minValue) {
        newValue = item.minValue
    }

    if(item.dataValue != newValue) {
        mainProgItem.valueEntered = true;
        myListView.model.setProperty(i, "dataValue", newValue);
        mainProgItem.valueEntered = false;
        correctionsMade++
    }
    return correctionsMade
}

function validateEntries() {
    var numOutOfRange = 0;
    for (var x = 0; x < myListView.model.count; x++) {
        numOutOfRange += validateParam(x)
    }
    // zero out a parameter if it is excluded by mutual exclusive goal
    if(!root.timeGoal) {
        if(timeItem)
            timeItem.dataValue = 0
    }
    if(!root.distGoal) {
        if(distItem)
            distItem.dataValue = 0
    }
    if(calWarning.visible)
        numOutOfRange++
    return numOutOfRange
}

// Code previously inside ListView delegate

function getItemLabel(item) {
    switch (item.fieldType) {
    case WorkoutProgram.MAX_SPEED_TYPE:
        if (workoutProgram.programIndex === WorkoutProgram.TREAD_CALORIE_PROG) {
            return QT_TRANSLATE_NOOP("WorkoutSetup", "SPEED")
        } else {
            return QT_TRANSLATE_NOOP("WorkoutSetup", "MAX SPEED")
        }
    case WorkoutProgram.MAX_INCLINE_TYPE:
        if (workoutProgram.programIndex === WorkoutProgram.TREAD_CALORIE_PROG) {
            return QT_TRANSLATE_NOOP("WorkoutSetup", "INCLINE")
        } else {
            return QT_TRANSLATE_NOOP("WorkoutSetup", "MAX INCLINE")
        }
    case WorkoutProgram.LEVEL_TYPE:
        if (workoutProgram.programIndex === WorkoutProgram.TREAD_LEG_SHAPER_PROG) {
            return QT_TRANSLATE_NOOP("WorkoutSetup", "SPEED")
        } else {
            return QT_TRANSLATE_NOOP("WorkoutSetup", "LEVEL")
        }
    case WorkoutProgram.SPEED_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "SPEED")
    case WorkoutProgram.RUN_SPEED_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "RUN SPEED")
    case WorkoutProgram.WORK_SPEED_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "WORK SPEED")
    case WorkoutProgram.WALK_SPEED_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "WALK SPEED")
    case WorkoutProgram.REST_SPEED_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "REST SPEED")
    case WorkoutProgram.DISTANCE_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "DISTANCE")
    case WorkoutProgram.DISTANCE_QUICK_TYPE:
    case WorkoutProgram.FIXED_DISTANCE_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "DISTANCE")
    case WorkoutProgram.SEGMENT_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "SEGMENTS")
    case WorkoutProgram.TIME_TYPE:
    case WorkoutProgram.TIMEREADONLY_TYPE:
        return main.isTft ? QT_TRANSLATE_NOOP("WorkoutSetup", "TIME") : QT_TRANSLATE_NOOP("WorkoutSetup", "WORKOUT TIME")
    case WorkoutProgram.PACE_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "PACE")
    case WorkoutProgram.WORKLOAD_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "WORKLOAD")
    case WorkoutProgram.AGE_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "AGE")
    case WorkoutProgram.WEIGHT_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "WEIGHT")
    case WorkoutProgram.GENDER_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "GENDER")
    case WorkoutProgram.INCLINE_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "INCLINE")
    case WorkoutProgram.CALORIES_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "CALORIE GOAL")
    case WorkoutProgram.CALORIE_POTENTIAL_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "CALCULATED CALORIES")

    case WorkoutProgram.WORK_HEARTRATE_TYPE:
        return main.isTft ? QT_TRANSLATE_NOOP("WorkoutSetup", "WORK HR") : QT_TRANSLATE_NOOP("WorkoutSetup", "WORK HEART RATE")
    case WorkoutProgram.REST_HEARTRATE_TYPE:
        return main.isTft ? QT_TRANSLATE_NOOP("WorkoutSetup", "REST HR") : QT_TRANSLATE_NOOP("WorkoutSetup", "REST HEART RATE")
    case WorkoutProgram.TARGET_HEARTRATE_TYPE:
        return main.isTft ? QT_TRANSLATE_NOOP("WorkoutSetup", "TARGET HR") : QT_TRANSLATE_NOOP("WorkoutSetup", "TARGET HEART RATE")
    case WorkoutProgram.TARGET_HEARTRATEREADONLY_TYPE:
        return main.isTft ? QT_TRANSLATE_NOOP("WorkoutSetup", "TARGET HR") : QT_TRANSLATE_NOOP("WorkoutSetup", "TARGET HEART RATE")
    case WorkoutProgram.MIN_STRIDE_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "REST STRIDE")
    case WorkoutProgram.MAX_STRIDE_TYPE:
        return QT_TRANSLATE_NOOP("WorkoutSetup", "WORK STRIDE")
    }
}

// Some items have additional text that cannot be translated
function getItemAdditionalLabel(item) {
    switch (item.fieldType) {
    case WorkoutProgram.PACE_TYPE:
    case WorkoutProgram.WORKLOAD_TYPE:
    case WorkoutProgram.MIN_STRIDE_TYPE:
    case WorkoutProgram.MAX_STRIDE_TYPE:
        // TFT has a linebreak before this text because it looks better
        return (main.isTft ? "\n" : "") + " (" + item.minValue + " - " + item.maxValue + ")"
    default:
        return ""
    }

}

// Code previously inside of ListView element

function getValueString(item)
{
    if (item.precision > 0) {
        if (isSpeedType(item.fieldType)) {
            var valConverted = options.metricUnits ? Globals.mileToKm(item.dataValue) : parseFloat(item.dataValue)
            return valConverted.toFixed(item.precision)
        } else {
            var str = parseFloat(item.dataValue)
            if(!root.distGoal && (item.fieldType == WorkoutProgram.DISTANCE_TYPE || item.fieldType == WorkoutProgram.DISTANCE_QUICK_TYPE)) {
                return "--";
            }

            // special case: display "5K" rather than 5.0K for distance buttons
            if (item.fieldType === WorkoutProgram.DISTANCE_QUICK_TYPE && str - Math.floor(str) === 0.0) {
                return Math.floor(str)
            }

            return str.toFixed(item.precision)
        }
    }
    else {
        if (item.fieldType == WorkoutProgram.TIME_TYPE) { // Time
            mainProgItem.workTime = item.dataValue;
            mainProgItem.segTime = ((item.dataValue * 60) / mainProgItem.numSegs);
            if(!root.timeGoal) {
                return "--";
            }
            return item.dataValue;
        } else if (isStrideType(item.fieldType)) {
            var val = options.metricUnits ? Globals.inchToCm(item.dataValue) : parseFloat(item.dataValue)
            return Math.round(val)
        } else if (item.fieldType == WorkoutProgram.TIMEREADONLY_TYPE) {
            //                    if(!root.timeGoal) {
            //                        return "--";
            //                    }
            return item.dataValue;
        }
        else if (item.fieldType == WorkoutProgram.PACE_TYPE) { // Pace
            mainProgItem.paceLevelForCustom = item.dataValue;
            return item.dataValue;
        }
        else if (item.fieldType == WorkoutProgram.WORKLOAD_TYPE) { // Workload
            mainProgItem.workloadLevelForCustom = item.dataValue;
            return item.dataValue;
        }
        else if (item.fieldType == WorkoutProgram.AGE_TYPE) { // Age
            mainProgItem.ageForProgSummary = item.dataValue;
            return item.dataValue;
        }
        else if (item.fieldType == WorkoutProgram.WEIGHT_TYPE) { // Weight
            mainProgItem.weightForProgSummary = item.dataValue;
            return item.dataValue;
        }
        else if (item.fieldType == WorkoutProgram.GENDER_TYPE) { // Weight
            return item.dataValue ? qsTr("F", "Female Gender Intial") + application.emptyString : qsTr("M", "Male Gender Intial") + application.emptyString
        }
        else if (item.fieldType == WorkoutProgram.INCLINE_TYPE || item.fieldType == WorkoutProgram.MAX_INCLINE_TYPE) { // incline
            return (workoutProgram.inclineTable[item.dataValue]/10).toFixed(1)
        }
        else if (isSpeedType(item.fieldType)) {
            return options.metricUnits ? Globals.mileToKm(item.dataValue) : item.dataValue
        }
        else {
            return item.dataValue;
        }
    }
}

function calculateHRPercentage () {
    var userAge = 0;
    var tempHR = 0;
    var tempCalcHRPercent = 0;

    for (var i = 0; i < myListView.count; i++)
    {
        if (myListView.model.get(i).fieldType == WorkoutProgram.AGE_TYPE) {
            userAge = myListView.model.get(i).dataValue;
        }
        else if (myListView.model.get(i).fieldType == WorkoutProgram.WORK_HEARTRATE_TYPE ||
                 myListView.model.get(i).fieldType == WorkoutProgram.REST_HEARTRATE_TYPE ||
                 myListView.model.get(i).fieldType == WorkoutProgram.TARGET_HEARTRATE_TYPE ||
                 myListView.model.get(i).fieldType == WorkoutProgram.TARGET_HEARTRATEREADONLY_TYPE) {
            // HR
            tempHR = myListView.model.get(i).dataValue;
        }
        if (userAge > 0 && tempHR > 0) {
            if (tempHR > (220 - userAge)) {
                tempHR = (220 - userAge);
                myListView.model.setProperty(i, "dataValue", Math.round(tempHR));
            }
            tempCalcHRPercent = ((tempHR / (220 - userAge)) * 100);
            myListView.model.setProperty(i, "heartRatePercentage", Math.round(tempCalcHRPercent));
            tempHR = 0;
        }
    }

}

function calculateHRFromAge () {
    var userAge = 0;
    var tempHR = 0;
    var tempHRPercent = 0;

    for (var i = 0; i < myListView.count; i++)
    {
        if (myListView.model.get(i).fieldType == WorkoutProgram.AGE_TYPE) {
            userAge = myListView.model.get(i).dataValue;
        }
        else if (myListView.model.get(i).fieldType == WorkoutProgram.TARGET_HEARTRATEREADONLY_TYPE) {
            tempHRPercent = myListView.model.get(i).heartRatePercentage;
        }
        if (userAge > 0 && tempHRPercent > 0) {
            tempHR = ((220 - userAge) * (tempHRPercent / 100.0));
            myListView.model.setProperty(i, "dataValue", Math.round(tempHR));
            tempHRPercent = 0;
        }
    }
}

function calculateMaxSegmentsFromTime() {
    if (!myListView.model)
        return

    var timeMins = getParameter(WorkoutProgram.TIME_TYPE)
    var maxSegs = Math.max(2, Math.min(30, timeMins))
    var item = myListView.model.find("fieldType", WorkoutProgram.SEGMENT_TYPE)
    if(!item)   // no segment count setup field, nothing to do
        return
    var index = item.fieldIndex - 1
    myListView.model.setProperty(index, "maxValue", maxSegs)
    if (getParameter(WorkoutProgram.SEGMENT_TYPE) > maxSegs) {
        // the next line is needed because the slider's binding to model.dataValue gets broken somewhere
        myListView.contentItem.children[index + 1]._slider3.value = maxSegs
    }
}

function getMaxDigit(maxValue)
{
    var str = maxValue.toString()
    return str.length
}

// "micro functions" - callbacks to onChanged and other events that have shared code between Keyed and non-Keyed
// versions, but are not really conceptually meaningful.
function itemValueDetailsTextChanged(sliderObject, sliderObject2, sliderObject3, genderSlider, model) {
    if (mainProgItem.valueEntered) {
        sliderObject.value = model.dataValue;
        sliderObject2.value = model.dataValue;
        sliderObject3.value = model.dataValue;
        genderSlider.value = model.dataValue;
        print("slider change:" + model.dataValue)
        valueEntered = false;
    }
}

function sliderObjectValueChanged(model, value, valueProxyChange, index) {
    if (!valueEntered && !valueProxyChange) {
        // If time/distance has been explicitly zeroed out (e.g. from a saved manual workout being reloaded), prevent the slider
        // from resetting that to the min value (typically 5 minutes) and instead keep the zero value.
        if (value === model.minValue && ((model.fieldType === WorkoutProgram.TIME_TYPE && model.dataValue === 0) || (model.fieldType === WorkoutProgram.DISTANCE_TYPE && model.dataValue === 0))) {
        } else {
            myListView.model.setProperty(index, "dataValue", value);
            dataItemChanged()
        }
    }

    if (model.fieldType == WorkoutProgram.TIME_TYPE) {
        // segments must be 1:00 long minimum, so adjust segment max based on workout time
        calculateMaxSegmentsFromTime()
    }

    if (mainProgItem.targetHRType == targetHRTypeEnum.aerobic) {
        calculateHRFromAge();
    }
    else if (mainProgItem.targetHRType == targetHRTypeEnum.target) {
        calculateHRPercentage();
    }
}

function genderSliderValueChanged(model, value, index) {
    if(model.fieldType != WorkoutProgram.GENDER_TYPE)
        return
    if (!valueEntered) {
        myListView.model.setProperty(index, "dataValue", value);
        dataItemChanged()
    }
}

function sliderObject2ValueChanged(model, value, index) {
    if (model.fieldType != WorkoutProgram.WORK_HEARTRATE_TYPE &&
        model.fieldType != WorkoutProgram.REST_HEARTRATE_TYPE &&
        model.fieldType != WorkoutProgram.TARGET_HEARTRATE_TYPE)
        return

    if (!valueEntered) {
        myListView.model.setProperty(index, "dataValue", value);

        dataItemChanged()
    }

    if (mainProgItem.targetHRType == targetHRTypeEnum.aerobic) {
        calculateHRFromAge();
    }
    else if (mainProgItem.targetHRType == targetHRTypeEnum.target) {
        calculateHRPercentage();
    }
}

function sliderObject3ValueChanged(model, value, index) {
    if (model.fieldType == WorkoutProgram.SEGMENT_TYPE) {
        myListView.model.setProperty(index, "dataValue", value);
        mainProgItem.numSegs = value;
        dataItemChanged()
    }
}

// functions from levelDetails

function levelDetailsGetLabel() {
    switch (workoutProgram.programIndex) {
    case WorkoutProgram.TREAD_CARDIO_CHALLENGE_PROG:
    case WorkoutProgram.TREAD_GLUTE_BUSTER_PROG:
    case WorkoutProgram.TREAD_HILL_INTERVALS_PROG:
    case WorkoutProgram.TREAD_ROLLING_HILLS_PROG:
    case WorkoutProgram.TREAD_SINGLE_HILL_PROG:
    case WorkoutProgram.TREAD_WEIGHT_LOSS_HILLS_PROG:
    case WorkoutProgram.TREAD_RANDOM_HILLS_PROG:
        return isTft ? qsTr("MAX INCLINE") : qsTr("MAXIMUM INCLINE")
    case WorkoutProgram.TREAD_LEG_SHAPER_PROG:
        return isTft ? qsTr("MAX SPEED") : qsTr("MAXIMUM SPEED")
    default:
        return ""
    }
}

function levelDetailsGetProfile() {
    switch (workoutProgram.programIndex) {
    case WorkoutProgram.TREAD_CARDIO_CHALLENGE_PROG:
    case WorkoutProgram.TREAD_GLUTE_BUSTER_PROG:
    case WorkoutProgram.TREAD_HILL_INTERVALS_PROG:
    case WorkoutProgram.TREAD_ROLLING_HILLS_PROG:
    case WorkoutProgram.TREAD_SINGLE_HILL_PROG:
    case WorkoutProgram.TREAD_WEIGHT_LOSS_HILLS_PROG:
    case WorkoutProgram.TREAD_RANDOM_HILLS_PROG:
        return workoutProgram.profile1 // incline
    case WorkoutProgram.TREAD_LEG_SHAPER_PROG:
        return workoutProgram.profile2 // speed
    }
}

function levelDetailsGetSubValue(level) {
    var profile = levelDetailsGetProfile()
    if (!profile)
        return ""

    var result = profile.findMaxWithLevel("segmentMagnitude", level)
    result = parseInt(result)/10.0
    if (options.metricUnits && profile.segmentType === WorkoutProfile.SPEED_SEG_TYPE)
        result = Globals.mileToKm(result)

    console.log("level details value: ", result.toFixed(1))
    return result.toFixed(1)
}

function levelDetailsGetUnits() {
    switch (workoutProgram.programIndex) {
    case WorkoutProgram.TREAD_CARDIO_CHALLENGE_PROG:
    case WorkoutProgram.TREAD_GLUTE_BUSTER_PROG:
    case WorkoutProgram.TREAD_HILL_INTERVALS_PROG:
    case WorkoutProgram.TREAD_ROLLING_HILLS_PROG:
    case WorkoutProgram.TREAD_SINGLE_HILL_PROG:
    case WorkoutProgram.TREAD_WEIGHT_LOSS_HILLS_PROG:
    case WorkoutProgram.TREAD_RANDOM_HILLS_PROG:
        return "%"
    case WorkoutProgram.TREAD_LEG_SHAPER_PROG:
        return options.metricUnits ? qsTr("KPH") : qsTr("MPH")
    default:
        return ""
    }
}

function isHeartRateType(fieldType) {
    switch (fieldType) {
        case WorkoutProgram.WORK_HEARTRATE_TYPE:
        case WorkoutProgram.REST_HEARTRATE_TYPE:
        case WorkoutProgram.TARGET_HEARTRATE_TYPE:
        case WorkoutProgram.TARGET_HEARTRATEREADONLY_TYPE:
            return true
        default:
            return false
    }
}

function isReadOnlyType(fieldType) {
    switch (fieldType) {
        case WorkoutProgram.TARGET_HEARTRATEREADONLY_TYPE:
        case WorkoutProgram.FIXED_DISTANCE_TYPE:
        case WorkoutProgram.TIMEREADONLY_TYPE:
        case WorkoutProgram.CALORIE_POTENTIAL_TYPE:
            return true
        default:
            return false
    }
}
