import QtQuick 2.4
import ProcessContainer 1.0
import Process 0.1

import ".."
import "../Keypad"

Item {
    id: root
    width:1000
    height:406

    property string url
    property bool keyingURL: false
    property string defaultURL: options.homeURL
    property bool noSwipe: true
    property int currentContentWidth:0
    property bool hasBeenShown: false

    function viewdestruct() {
        console.log("viewdestruct called! (WebViewContainer.qml)")
        root.url = ""
        browserProcess.kill()
        flashWatcher.kill()
        html5watcher.kill()
    }

    function shown() {
        root.hasBeenShown = true
        if (flashWatcher.soundIsPlaying || html5watcher.soundIsPlaying)
            audioManager.flashRequest()
    }

    function hidden() {
        browserProcess.write("CMD hidden\n")
        urlKeypad.process.write("CMD hide\n")
        inputKeypad.process.write("CMD hide\n")
        workoutScreen.browserFullscreen = false
    }

    Connections {
        target: application

        onMainViewFocusChanged: {
            if (isFocused) {
                urlKeypad.process.write("CMD hide\n")
                inputKeypad.process.write("CMD hide\n")
            }
        }
    }

    ProcessContainer {
        id: processContainer

        width: workoutScreen.browserFullscreen ? 1200 : 1000
        height: workoutScreen.browserFullscreen ? 665 : 406
        globalX: workoutScreen.browserFullscreen ? 0 : 183
        globalY: workoutScreen.browserFullscreen ? 100 : 171
        anchors.top: parent.top
        visible: true
        frozen: !visible || workoutViewContainer.currentViewName !== "WEB_VIEW" || workoutViewContainer.isMoving || stopPrompt.visible || dialogManager.anyAreShown || inclineKeyPad.state === "showing" || speedKeyPad.state === "showing"
        readyForImage: root.hasBeenShown
        onFrozenChanged: {
            if (!frozen) {
                browserProcess.write("CMD readyToShow\n")
            }
        }
        onEmbedded: {
            if (!frozen) {
                // Force embedded window to re-call show(), so that the show flag
                // gets set and future hide calls work
                visibleChanged(true)
                browserProcess.write("CMD readyToShow\n")
            }
        }

        Component.onCompleted: processContainer.createContainer()
    }

    Process {
        id: browserProcess
        program: "scripts/start_browser.sh"

        arguments: ["--home-url", options.homeURL, "--language", application.currentLanguage]
        onStarted: {
            flashWatcher.start()
            html5watcher.start()
        }
        onReadyReadStandardOutput: {
            var data = (String(readAllStandardOutput())).trim()
            console.log("browserprocess:",data)
            if (data.indexOf("CMD winid") >= 0) {
                var parts = data.split(" ")
                var winid = parseInt(parts[2], 10)
                processContainer.winid = winid
            } else if (data.indexOf("CMD didShow") >= 0) {
                processContainer.readyToShow = true
            }
        }
        onReadyReadStandardError: {
            var data = (String(readAllStandardError())).trim()
            console.log("browserprocess (stderr):",data)
            if (data.indexOf("CMD fullscreen") >= 0) {
                workoutScreen.browserFullscreen = !workoutScreen.browserFullscreen
            }
        }
        onFinished: {
            console.log("Restarting browser...")
            processContainer.readyToShow = false
            restart()
        }
        Component.onCompleted: start()
    }

}
