#!/bin/bash

capture_dir=/tmp/capture
capture_time=30
min_ssd_free_space=1073741
min_usb_free_space=1073741
capture_freq="$1"

# Determine the space on the root partition that can be used to cache the stream
ssd_free_space=$(df -l | grep \/dev\/sda1 | awk '{print $4}')
echo SSD Free Space Required:  $min_ssd_free_space
echo SSD Free Space Available: $ssd_free_space

# Determine the space on the USB drive that can be used to store the stream
usb_free_space=$(df -l | grep usb0| awk '{print $4}')
echo USB Free Space Required:  $min_usb_free_space
echo USB Free Space Available: $usb_free_space

# Confirm we have room on the root partition
if [ $ssd_free_space -gt $min_ssd_free_space -a $usb_free_space -gt $min_usb_free_space ]; then
    # Clear out old files
    if [ -d $capture_dir ]; then
        rm -rf $capture_dir
    fi
    mkdir -p $capture_dir

    echo "CAPTURE_BEGIN"
    #./tscap -m ATSC INVERSION_AUTO BANDWIDTH_7_MHZ FEC_3_4 QAM_64 TRANSMISSION_MODE_8K GUARD_INTERVAL_1_16 HIERARCHY_AUTO -t $capture_time -q 47300000 -o $capture_dir/f47300000.ts
    scripts/tscap "$@"
    echo "CAPTURE_COMPLETE"

    echo "COPY_BEGIN"
    mv $capture_dir/*.ts /media/usb
    echo "Syncing disk..."
    sync
    echo "COPY_COMPLETE"
    exit 0

else
    echo "ERROR_NO_SPACE" >&2
    echo "Not enough space to capture the stream!"
    echo "USB: $min_usb_free_space required, $usb_free_space available"
    echo "SSD: $min_ssd_free_space required, $ssd_free_space available"
    exit 1
fi


